
SET SQL_MODE = "NO_AUTO_VALUE_ON_ZERO";
SET time_zone = "+00:00";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;

--
-- Database: `cscart4182`
--

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]access_restriction`
--

CREATE TABLE `[[dbprefix]]access_restriction` (
  `item_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `value` varchar(66) NOT NULL DEFAULT '',
  `ip_from` varbinary(40) NOT NULL DEFAULT '',
  `ip_to` varbinary(40) NOT NULL DEFAULT '',
  `type` char(3) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'A',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `expires` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`item_id`),
  KEY `type` (`type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]access_restriction_block`
--

CREATE TABLE `[[dbprefix]]access_restriction_block` (
  `id_block` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `ip` varbinary(40) NOT NULL DEFAULT '',
  `tries` smallint(5) unsigned NOT NULL DEFAULT '0',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `expires` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`id_block`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]access_restriction_reason_descriptions`
--

CREATE TABLE `[[dbprefix]]access_restriction_reason_descriptions` (
  `item_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `type` char(3) NOT NULL DEFAULT '',
  `reason` mediumtext,
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`item_id`,`type`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]addons`
--

CREATE TABLE `[[dbprefix]]addons` (
  `addon` varchar(32) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'A',
  `version` varchar(16) NOT NULL DEFAULT '',
  `priority` int(11) unsigned NOT NULL DEFAULT '0',
  `dependencies` varchar(255) NOT NULL DEFAULT '',
  `conflicts` varchar(255) NOT NULL DEFAULT '',
  `separate` tinyint(1) NOT NULL,
  `unmanaged` tinyint(1) NOT NULL,
  `has_icon` tinyint(1) NOT NULL,
  `install_datetime` int(11) NOT NULL DEFAULT '0',
  `marketplace_id` int(11) unsigned DEFAULT NULL,
  `marketplace_license_key` varchar(64) DEFAULT NULL,
  PRIMARY KEY (`addon`),
  KEY `priority` (`priority`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]addons`
--

INSERT INTO `[[dbprefix]]addons` VALUES
('hidpi', 'A', '1.0', 1, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('social_buttons', 'A', '1.0', 100, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('paypal_checkout', 'A', '1.0', 100, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('onboarding_guide', 'A', '1.0', 100, '', '', 0, 1, 0, [[timestamp]], NULL, NULL),
('help_center', 'A', '1.0', 100, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('tags', 'A', '1.0', 200, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('rss_feed', 'A', '1.0', 490, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('newsletters', 'A', '1.0', 500, '', 'email_marketing', 0, 0, 0, [[timestamp]], NULL, NULL),
('email_marketing', 'D', '1.0', 500, '', 'newsletters', 1, 0, 0, [[timestamp]], NULL, NULL),
('attachments', 'A', '1.0', 600, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('customers_also_bought', 'A', '1.0', 900, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('vendor_communication', 'A', '1.0', 1000, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('advanced_import', 'A', '1.0.0', 1000, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('geo_maps', 'A', '1.0', 1000, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('gift_certificates', 'A', '1.0', 1100, '', 'catalog_mode', 0, 0, 0, [[timestamp]], NULL, NULL),
('store_locator', 'A', '1.0', 1200, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('product_variations', 'A', '1.0', 1500, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('recaptcha', 'A', '1.0', 1500, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('product_bundles', 'A', '1.0', 1520, '', 'buy_together', 0, 0, 0, [[timestamp]], NULL, NULL),
('rma', 'D', '1.0', 1600, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('blog', 'A', '1.0', 1700, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('bestsellers', 'A', '1.0', 1700, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('seo', 'A', '1.0', 1800, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('reward_points', 'A', '1.0', 1900, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('google_analytics', 'D', '1.0', 2000, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('facebook_pixel', 'D', '1.0', 2000, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('call_requests', 'A', '1.0', 2300, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('form_builder', 'A', '1.0', 2400, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('barcode', 'A', '1.0', 2500, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('polls', 'D', '1.0', 2600, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('access_restrictions', 'D', '1.0', 2700, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('banners', 'A', '1.0', 2800, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('discussion', 'A', '1.0', 3000, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('watermarks', 'D', '1.0', 3000, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('product_reviews', 'A', '1.0', 3001, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('wishlist', 'A', '1.0', 3100, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('image_zoom', 'A', '1.0', 3500, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('google_sitemap', 'A', '1.0', 3500, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('required_products', 'A', '1.0', 3900, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('data_feeds', 'A', '1.0', 4000, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('price_list', 'A', '1.0', 4100, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('janrain', 'D', '1.0', 4200, '', 'loginza,hybrid_auth', 0, 0, 0, [[timestamp]], NULL, NULL),
('catalog_mode', 'D', '1.0', 4200, '', 'buy_together,gift_certificates,product_configurator', 0, 0, 0, [[timestamp]], NULL, NULL),
('hybrid_auth', 'A', '1.0', 4200, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('zapier', 'A', '1.0', 4320, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('price_per_unit', 'A', '1.0', 4330, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('gdpr', 'A', '1.0', 9999, '', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('shopify_import', 'A', '1.0', 4328362, 'product_variations', '', 0, 0, 0, [[timestamp]], NULL, NULL),
('tech_support_chat', 'A', '1.0', 4294967294, '', '', 0, 1, 0, [[timestamp]], NULL, NULL),
('my_changes', 'D', '1.0', 4294967294, '', '', 0, 0, 0, [[timestamp]], NULL, NULL);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]addon_data`
--

CREATE TABLE `[[dbprefix]]addon_data` (
  `addon` varchar(32) NOT NULL DEFAULT '',
  `is_favorite` char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (`addon`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]addon_descriptions`
--

CREATE TABLE `[[dbprefix]]addon_descriptions` (
  `addon` varchar(32) NOT NULL DEFAULT '',
  `name` varchar(255) NOT NULL DEFAULT '',
  `description` varchar(255) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`addon`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]addon_descriptions`
--

INSERT INTO `[[dbprefix]]addon_descriptions` VALUES
('hidpi', 'HiDPI displays support', 'Support for Retina displays', 'en'),
('social_buttons', 'Social buttons', 'Adds the buttons for sharing products and pages in social media (Twitter, Facebook, etc.). Helps social networks and messengers to display better previews for the links to your site', 'en'),
('paypal_checkout', 'PayPal Complete Payments', 'A PayPal solution for online stores. Lets you accept payments through PayPal and other means.', 'en'),
('onboarding_guide', 'Onboarding guide', 'Introduces the marketplace to administrators and allows quickly set up basic functionality.', 'en'),
('help_center', 'Help center', 'Adds a help button with links to relevant documentation and/or videos to various pages in the admin panel.', 'en'),
('tags', 'Tags', 'Enables product tags', 'en'),
('rss_feed', 'RSS feed', 'Generates RSS feeds for products and blog posts', 'en'),
('newsletters', 'Newsletters', 'Lets you configure newsletter sending', 'en'),
('email_marketing', 'E-mail marketing', 'Synchronizes your newsletter subscriber lists with MailChimp and Mad Mimi', 'en'),
('attachments', 'Attachments', 'Makes it possible to attach files to products', 'en'),
('customers_also_bought', 'Customers also bought', 'Makes it possible to create a special block for the products often purchased along with the current one', 'en'),
('vendor_communication', 'Message center', 'Allows customers, vendors, and administrators to contact each other via the built-in chat.', 'en'),
('advanced_import', 'Advanced products import', 'Allows you to match the fields in the imported file with the product properties. These matchings and other import settings can also be saved as presets for later use.', 'en'),
('geo_maps', 'Maps and geolocation', 'Enables Google or Yandex maps and geolocation functionality in your store.', 'en'),
('gift_certificates', 'Gift certificates', 'Adds a built-in gift certificate system', 'en'),
('store_locator', 'Stores and pickup points', 'Allows you to mark your physical stores on the map and offer your customers to collect orders from there, if a corresponding shipping method is configured.', 'en'),
('product_variations', 'Product Variations', 'Create products with different feature variants (for example, a different color or size), and let customers select the desired variant.', 'en'),
('recaptcha', 'Google reCAPTCHA', 'Adds the support of Google reCAPTCHA to protect your store against bots', 'en'),
('product_bundles', 'Product bundles', 'Allows you to create product bundles and set up discounts for them.', 'en'),
('rma', 'RMA', 'Adds a return management system', 'en'),
('blog', 'Blog', 'Lets you start your blog easily', 'en'),
('bestsellers', 'Bestsellers & On-Sale Products', 'Collects best selling & on sale product data and adds block fillings to show such products', 'en'),
('seo', 'SEO', 'Adds Search engine-friendly URLs support', 'en'),
('reward_points', 'Reward points', 'Lets customers earn and spend points for purchases', 'en'),
('google_analytics', 'Google Analytics', 'Integrates a Google Analytics service with the store', 'en'),
('facebook_pixel', 'Facebook Pixel', 'Integrates a Facebook Pixel with the store', 'en'),
('call_requests', 'Call requests', 'Adds the "Buy now with one click" and "Request call" buttons', 'en'),
('form_builder', 'Form builder', 'Lets you create custom forms (e.g. Contact us)', 'en'),
('barcode', 'Order barcode', 'Makes it possible to configure and attach barcodes to orders', 'en'),
('polls', 'Polls', 'Adds a possibility to add customized polls to the site', 'en'),
('access_restrictions', 'Access restrictions', 'Lets you limit storefront and administrator area access to certain IP-addresses with different options', 'en'),
('banners', 'Banners management', 'Allows you to create text and visual banners', 'en'),
('discussion', 'Comments and reviews', 'Lets customers leave comments to categories, pages, etc., review vendors and write testimonials', 'en'),
('watermarks', 'Watermarks', 'Allows you to add watermarks to product and category images', 'en'),
('product_reviews', 'Product reviews', 'Allows your customers to leave reviews for products. That can build up trust, provide social proof, and add user-generated content to your site.', 'en'),
('wishlist', 'Wish List', 'Lets customers store items in personal wish lists', 'en'),
('image_zoom', 'Image zoom', 'Shows zoomed image on product image hover', 'en'),
('google_sitemap', 'Google sitemap', 'Creates a sitemap.xml for Google', 'en'),
('required_products', 'Required products', 'Makes it possible to specify products required for purchase', 'en'),
('data_feeds', 'Data feeds', 'Makes it possible to create product data feeds in CSV', 'en'),
('price_list', 'Price list', 'Generates configurable price list in PDF or XLS', 'en'),
('janrain', 'Janrain', 'Adds the Social Login feature; allows customers use Facebook, Twitter, etc. to log in on the store', 'en'),
('catalog_mode', 'Catalog mode', 'Allows you to use the store as a product catalog', 'en'),
('hybrid_auth', 'Social login', 'Adds the Social Login feature; allows customers use Facebook, Twitter, etc. to log in on the store', 'en'),
('zapier', 'Integration with Zapier', 'Allows you to integrate CS-Cart with over 4 000 other apps through Zapier.', 'en'),
('price_per_unit', 'Price per unit', 'Allows you to display price per unit on catalog and product pages.', 'en'),
('gdpr', 'GDPR Compliance (EU)', 'Helps you to comply with GDPR (a European Union regulation on personal data) by showing customers info about their personal data, asking their consent for its processing, and by offering ways to delete or export personal data.', 'en'),
('shopify_import', 'Import from Shopify', 'Allows you to import products from Shopify.', 'en'),
('tech_support_chat', 'Techical support chat', 'Adds live chat with the technical support team int the Administration panel', 'en'),
('my_changes', 'My Changes (example add-on)', 'A dummy add-on to let devs see how add-ons work. You can also use it to introduce small changes not worthy of a separate add-on', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]also_bought_products`
--

CREATE TABLE `[[dbprefix]]also_bought_products` (
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `related_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `amount` smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`product_id`,`related_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]also_bought_products`
--

INSERT INTO `[[dbprefix]]also_bought_products` VALUES
(12, 11, 1),
(12, 7, 1),
(12, 79, 1),
(11, 12, 1),
(7, 12, 1),
(79, 12, 1),
(114, 199, 1),
(199, 114, 1),
(21, 112, 1),
(21, 110, 1),
(110, 21, 1),
(112, 21, 1),
(18, 108, 1),
(18, 103, 1),
(108, 18, 1),
(103, 18, 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]attachments`
--

CREATE TABLE `[[dbprefix]]attachments` (
  `attachment_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `object_type` varchar(30) NOT NULL DEFAULT '',
  `object_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `type` char(1) NOT NULL DEFAULT '',
  `position` int(11) NOT NULL DEFAULT '0',
  `filename` varchar(100) NOT NULL DEFAULT '',
  `filesize` int(11) unsigned NOT NULL DEFAULT '0',
  `usergroup_ids` varchar(255) NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'A',
  `on_server` char(1) NOT NULL DEFAULT 'Y',
  `url` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`attachment_id`),
  KEY `object_type` (`object_type`,`object_id`),
  KEY `type` (`type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]attachment_descriptions`
--

CREATE TABLE `[[dbprefix]]attachment_descriptions` (
  `attachment_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `description` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`attachment_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]banners`
--

CREATE TABLE `[[dbprefix]]banners` (
  `banner_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `status` char(1) NOT NULL DEFAULT 'A',
  `type` char(1) NOT NULL DEFAULT 'G',
  `target` char(1) NOT NULL DEFAULT 'B',
  `localization` varchar(255) NOT NULL DEFAULT '',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`banner_id`),
  KEY `localization` (`localization`),
  KEY `status` (`status`),
  KEY `company_id` (`company_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=23 ;

--
-- Dumping data for table `[[dbprefix]]banners`
--

INSERT INTO `[[dbprefix]]banners` VALUES
(7, 'A', 'G', 'T', '', [[timestamp]], 1),
(8, 'A', 'G', 'T', '', [[timestamp]], 1),
(16, 'A', 'G', 'T', '', [[timestamp]], 1),
(17, 'A', 'G', 'T', '', [[timestamp]], 1),
(18, 'A', 'G', 'T', '', [[timestamp]], 1),
(19, 'A', 'G', 'T', '', [[timestamp]], 1),
(6, 'A', 'G', 'T', '', [[timestamp]], 1),
(9, 'A', 'G', 'T', '', [[timestamp]], 1),
(20, 'A', 'G', 'T', '', [[timestamp]], 1),
(21, 'A', 'G', 'T', '', [[timestamp]], 1),
(22, 'A', 'G', 'T', '', [[timestamp]], 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]banner_descriptions`
--

CREATE TABLE `[[dbprefix]]banner_descriptions` (
  `banner_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `banner` varchar(255) NOT NULL DEFAULT '',
  `url` varchar(255) NOT NULL DEFAULT '',
  `description` mediumtext,
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`banner_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]banner_descriptions`
--

INSERT INTO `[[dbprefix]]banner_descriptions` VALUES
(6, 'Free shipping', 'index.php?dispatch=pages.view&page_id=22', '', 'en'),
(7, 'Gift certificate', 'gift_certificates.add', '', 'en'),
(8, 'Holiday gift guide', 'gift_certificates.add', '', 'en'),
(9, 'Discount if select pickup', 'index.php?dispatch=pages.view&page_id=20', '', 'en'),
(16, 'Final sale', 'index.php?dispatch=products.final_sale', '', 'en'),
(17, 'X-Box', 'index.php?dispatch=products.view&product_id=248', '', 'en'),
(18, 'Bonus points', 'index.php?dispatch=pages.view&page_id=23', '', 'en'),
(19, 'Gift certificates', 'index.php?dispatch=pages.view&page_id=19', '', 'en'),
(20, 'X-Box Mobile', 'index.php?dispatch=products.view&product_id=5764', '', 'en'),
(21, 'Acme Mobile', 'index.php?dispatch=pages.view&page_id=25', '', 'en'),
(22, 'Multivendor demo mobile', 'index.php?dispatch=pages.view&page_id=24', '', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]banner_images`
--

CREATE TABLE `[[dbprefix]]banner_images` (
  `banner_image_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `banner_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`banner_image_id`),
  UNIQUE KEY `banner` (`banner_id`,`lang_code`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=48 ;

--
-- Dumping data for table `[[dbprefix]]banner_images`
--

INSERT INTO `[[dbprefix]]banner_images` VALUES
(16, 7, 'en'),
(39, 6, 'en'),
(40, 9, 'en'),
(18, 8, 'en'),
(35, 16, 'en'),
(36, 17, 'en'),
(37, 18, 'en'),
(38, 19, 'en'),
(41, 20, 'en'),
(42, 21, 'en'),
(47, 22, 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]blog_authors`
--

CREATE TABLE `[[dbprefix]]blog_authors` (
  `page_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`page_id`,`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]blog_authors`
--

INSERT INTO `[[dbprefix]]blog_authors` VALUES
(7, 1),
(8, 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]bm_blocks`
--

CREATE TABLE `[[dbprefix]]bm_blocks` (
  `block_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `type` varchar(64) NOT NULL DEFAULT '',
  `properties` text,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`block_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=54 ;

--
-- Dumping data for table `[[dbprefix]]bm_blocks`
--

INSERT INTO `[[dbprefix]]bm_blocks` VALUES
(1, 'languages', 'a:3:{s:8:"template";s:20:"blocks/languages.tpl";s:6:"format";s:4:"icon";s:14:"dropdown_limit";s:1:"0";}', 1, 1),
(2, 'currencies', 'a:3:{s:8:"template";s:21:"blocks/currencies.tpl";s:6:"format";s:6:"symbol";s:14:"dropdown_limit";s:1:"3";}', 1, 1),
(3, 'menu', 'a:2:{s:8:"template";s:26:"blocks/menu/text_links.tpl";s:18:"show_items_in_line";s:1:"Y";}', 1, 1),
(4, 'my_account', 'a:1:{s:8:"template";s:21:"blocks/my_account.tpl";}', 1, 1),
(5, 'template', 'a:2:{s:8:"template";s:32:"blocks/static_templates/logo.tpl";s:11:"enable_link";s:1:"Y";}', 1, 1),
(6, 'call_request', 'a:1:{s:8:"template";s:44:"addons/call_requests/blocks/call_request.tpl";}', 1, 1),
(7, 'template', 'a:1:{s:8:"template";s:34:"blocks/static_templates/search.tpl";}', 1, 1),
(8, 'cart_content', 'a:5:{s:8:"template";s:23:"blocks/cart_content.tpl";s:22:"display_bottom_buttons";s:1:"Y";s:20:"display_delete_icons";s:1:"Y";s:19:"products_links_type";s:5:"thumb";s:20:"generate_block_title";s:1:"Y";}', 1, 1),
(9, 'menu', 'a:3:{s:8:"template";s:35:"blocks/menu/dropdown_horizontal.tpl";s:30:"dropdown_second_level_elements";s:2:"12";s:29:"dropdown_third_level_elements";s:1:"6";}', 1, 1),
(10, 'breadcrumbs', 'a:1:{s:8:"template";s:22:"common/breadcrumbs.tpl";}', 1, 1),
(11, 'main', '', 1, 1),
(12, 'template', 'a:1:{s:8:"template";s:65:"addons/newsletters/blocks/static_templates/subscribe_advanced.tpl";}', 1, 1),
(13, 'safe_smarty_block', 'a:1:{s:8:"template";s:28:"blocks/safe_smarty_block.tpl";}', 1, 1),
(14, 'template', 'a:1:{s:8:"template";s:53:"blocks/static_templates/my_account_links_advanced.tpl";}', 1, 1),
(15, 'menu', 'a:2:{s:8:"template";s:26:"blocks/menu/text_links.tpl";s:18:"show_items_in_line";s:1:"N";}', 1, 1),
(16, 'menu', 'a:2:{s:8:"template";s:26:"blocks/menu/text_links.tpl";s:18:"show_items_in_line";s:1:"N";}', 1, 1),
(17, 'safe_smarty_block', 'a:1:{s:8:"template";s:28:"blocks/safe_smarty_block.tpl";}', 1, 1),
(18, 'template', 'a:1:{s:8:"template";s:37:"blocks/static_templates/copyright.tpl";}', 1, 1),
(19, 'template', 'a:1:{s:8:"template";s:41:"blocks/static_templates/payment_icons.tpl";}', 1, 1),
(20, 'banners', 'a:3:{s:8:"template";s:34:"addons/banners/blocks/carousel.tpl";s:10:"navigation";s:1:"P";s:5:"delay";s:3:"333";}', 1, 1),
(21, 'banners', 'a:1:{s:8:"template";s:34:"addons/banners/blocks/original.tpl";}', 1, 1),
(22, 'banners', 'a:1:{s:8:"template";s:34:"addons/banners/blocks/original.tpl";}', 1, 1),
(23, 'products', 'a:11:{s:8:"template";s:37:"blocks/products/products_scroller.tpl";s:10:"show_price";s:1:"Y";s:17:"enable_quick_view";s:1:"N";s:24:"not_scroll_automatically";s:1:"Y";s:5:"speed";s:3:"400";s:15:"scroll_per_page";s:1:"Y";s:11:"pause_delay";s:1:"3";s:13:"item_quantity";s:1:"4";s:15:"thumbnail_width";s:3:"160";s:23:"hide_add_to_cart_button";s:1:"Y";s:18:"outside_navigation";s:1:"Y";}', 1, 1),
(24, 'products', 'a:4:{s:8:"template";s:41:"blocks/products/products_multicolumns.tpl";s:11:"item_number";s:1:"N";s:17:"number_of_columns";s:1:"4";s:23:"hide_add_to_cart_button";s:1:"Y";}', 1, 1),
(25, 'blog', 'a:1:{s:8:"template";s:33:"addons/blog/blocks/text_links.tpl";}', 1, 1),
(26, 'testimonials', 'a:8:{s:8:"template";s:41:"addons/discussion/blocks/testimonials.tpl";s:5:"limit";s:2:"10";s:6:"random";s:1:"N";s:24:"not_scroll_automatically";s:1:"Y";s:5:"speed";s:3:"400";s:11:"pause_delay";s:1:"3";s:13:"item_quantity";s:1:"1";s:18:"outside_navigation";s:1:"N";}', 1, 1),
(27, 'our_brands', 'a:9:{s:8:"template";s:21:"blocks/our_brands.tpl";s:24:"not_scroll_automatically";s:1:"Y";s:5:"speed";s:3:"400";s:15:"scroll_per_page";s:1:"Y";s:11:"pause_delay";s:1:"3";s:13:"item_quantity";s:1:"7";s:11:"total_items";s:2:"14";s:15:"thumbnail_width";s:2:"75";s:18:"outside_navigation";s:1:"N";}', 1, 1),
(28, 'safe_smarty_block', 'a:1:{s:8:"template";s:28:"blocks/safe_smarty_block.tpl";}', 1, 1),
(29, 'products', 'a:4:{s:8:"template";s:41:"blocks/products/products_multicolumns.tpl";s:11:"item_number";s:1:"N";s:17:"number_of_columns";s:1:"2";s:23:"hide_add_to_cart_button";s:1:"Y";}', 1, 1),
(30, 'products', 'a:2:{s:8:"template";s:30:"blocks/products/short_list.tpl";s:23:"hide_add_to_cart_button";s:1:"Y";}', 1, 1),
(31, 'product_filters', 'a:1:{s:8:"template";s:48:"blocks/product_filters/for_category/original.tpl";}', 1, 1),
(32, 'products', 'a:3:{s:8:"template";s:40:"blocks/products/products_small_items.tpl";s:11:"item_number";s:1:"N";s:23:"hide_add_to_cart_button";s:1:"Y";}', 1, 1),
(33, 'template', 'a:2:{s:8:"template";s:32:"blocks/static_templates/logo.tpl";s:11:"enable_link";s:1:"N";}', 1, 1),
(34, 'lite_checkout_location', 'a:1:{s:8:"template";s:33:"blocks/lite_checkout/location.tpl";}', 1, 1),
(35, 'lite_checkout_shipping_methods', 'a:1:{s:8:"template";s:41:"blocks/lite_checkout/shipping_methods.tpl";}', 1, 1),
(36, 'lite_checkout_customer_sign_in', 'a:1:{s:8:"template";s:41:"blocks/lite_checkout/customer_sign_in.tpl";}', 1, 1),
(37, 'lite_checkout_customer_address', 'a:1:{s:8:"template";s:41:"blocks/lite_checkout/customer_address.tpl";}', 1, 1),
(38, 'lite_checkout_customer_information', 'a:1:{s:8:"template";s:45:"blocks/lite_checkout/customer_information.tpl";}', 1, 1),
(39, 'lite_checkout_customer_notes', 'a:1:{s:8:"template";s:39:"blocks/lite_checkout/customer_notes.tpl";}', 1, 1),
(40, 'lite_checkout_payment_methods', 'a:1:{s:8:"template";s:40:"blocks/lite_checkout/payment_methods.tpl";}', 1, 1),
(41, 'lite_checkout_customer_billing', 'a:1:{s:8:"template";s:41:"blocks/lite_checkout/customer_billing.tpl";}', 1, 1),
(42, 'lite_checkout_terms_and_conditions', 'a:1:{s:8:"template";s:45:"blocks/lite_checkout/terms_and_conditions.tpl";}', 1, 1),
(43, 'lite_checkout_newsletters', 'a:1:{s:8:"template";s:55:"addons/newsletters/blocks/lite_checkout/newsletters.tpl";}', 1, 1),
(44, 'checkout', 'a:1:{s:8:"template";s:36:"blocks/checkout/products_in_cart.tpl";}', 1, 1),
(45, 'checkout', 'a:1:{s:8:"template";s:27:"blocks/checkout/summary.tpl";}', 1, 1),
(46, 'template', 'a:1:{s:8:"template";s:37:"blocks/static_templates/auth_info.tpl";}', 1, 1),
(47, 'template', 'a:1:{s:8:"template";s:40:"blocks/static_templates/profile_info.tpl";}', 1, 1),
(48, 'template', 'a:1:{s:8:"template";s:31:"blocks/static_templates/404.tpl";}', 1, 1),
(49, 'product_filters', 'a:1:{s:8:"template";s:58:"blocks/product_filters/for_category/horizontal_filters.tpl";}', 1, 1),
(50, 'blog', 'a:1:{s:8:"template";s:35:"addons/blog/blocks/recent_posts.tpl";}', 1, 1),
(51, 'gift_certificates_verify', 'a:1:{s:8:"template";s:60:"addons/gift_certificates/blocks/gift_certificates_verify.tpl";}', 1, 1),
(52, 'products', 'a:5:{s:8:"template";s:61:"addons/product_variations/blocks/products/variations_list.tpl";s:46:"product_variations.hide_add_to_wishlist_button";s:1:"N";s:23:"hide_add_to_cart_button";s:1:"N";s:36:"product_variations.show_product_code";s:1:"Y";s:44:"product_variations.show_variation_thumbnails";s:1:"Y";}', 1, 1),
(53, 'product_bundles', 'a:1:{s:8:"template";s:49:"addons/product_bundles/blocks/product_bundles.tpl";}', 1, 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]bm_blocks_content`
--

CREATE TABLE `[[dbprefix]]bm_blocks_content` (
  `snapping_id` int(11) unsigned NOT NULL,
  `object_id` int(11) unsigned NOT NULL DEFAULT '0',
  `object_type` varchar(64) NOT NULL DEFAULT '',
  `block_id` int(11) unsigned NOT NULL,
  `lang_code` char(2) NOT NULL DEFAULT '',
  `content` text NOT NULL,
  PRIMARY KEY (`block_id`,`snapping_id`,`lang_code`,`object_id`,`object_type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]bm_blocks_content`
--

INSERT INTO `[[dbprefix]]bm_blocks_content` VALUES
(0, 0, '', 1, 'en', 'a:1:{s:4:"text";s:0:"";}'),
(0, 0, '', 2, 'en', 'a:1:{s:4:"text";s:0:"";}'),
(0, 0, '', 3, 'en', 'a:1:{s:4:"menu";s:1:"1";}'),
(0, 0, '', 3, 'ru', 'a:1:{s:4:"menu";s:1:"1";}'),
(0, 0, '', 4, 'en', ''),
(0, 0, '', 5, 'en', ''),
(0, 0, '', 6, 'en', ''),
(0, 0, '', 7, 'en', ''),
(0, 0, '', 8, 'en', ''),
(0, 0, '', 9, 'en', 'a:1:{s:4:"menu";s:1:"2";}'),
(0, 0, '', 9, 'ru', 'a:1:{s:4:"menu";s:1:"2";}'),
(0, 0, '', 10, 'en', ''),
(0, 0, '', 11, 'en', ''),
(0, 0, '', 12, 'en', ''),
(0, 0, '', 13, 'en', 'a:1:{s:7:"content";s:773:"<div class="ty-social-link-block"><h3 class="ty-social-link__title">{__("get_social")}</h3>\n\n<div class="ty-social-link facebook">\n    <a href="http://www.facebook.com/pages/CS-Cart/156687676230"><span class="ty-icon ty-icon-facebook ty-icon-moon-facebook"></span></a>\n</div>\n\n<div class="ty-social-link instagram">\n    <a href="https://www.instagram.com"><span class="ty-icon ty-icon-instagram ty-icon-moon-instagram"></span></a>\n</div>\n\n<div class="ty-social-link twitter">\n    <a href="https://twitter.com/cscart"><span class="ty-icon ty-icon-twitter ty-icon-moon-twitter"></span></a>\n</div>\n\n<div class="ty-social-link youtube">\n    <a href="https://www.youtube.com/user/cscartvideos"><span class="ty-icon ty-icon-youtube ty-icon-moon-youtube"></span></a>\n</div></div>\n";}'),
(0, 0, '', 13, 'ru', 'a:1:{s:7:"content";s:772:"<div class="ty-social-link-block"><h3 class="ty-social-link__title">{__("get_social")}</h3>\n\n<div class="ty-social-link facebook">\n    <a href="http://www.facebook.com/pages/CS-Cart/156687676230"><span class="ty-icon ty-icon-facebook ty-icon-moon-facebook"></span></a>\n</div>\n\n<div class="ty-social-link instagram">\n    <a href="https://www.instagram.com"><span class="ty-icon ty-icon-instagram ty-icon-moon-instagram"></span></a>\n</div>\n\n<div class="ty-social-link twitter">\n    <a href="https://twitter.com/cscart"><span class="ty-icon ty-icon-twitter ty-icon-moon-twitter"></span></a>\n</div>\n\n<div class="ty-social-link youtube">\n    <a href="https://www.youtube.com/user/cscartvideos"><span class="ty-icon ty-icon-youtube ty-icon-moon-youtube"></span></a>\n</div></div>";}'),
(0, 0, '', 14, 'en', ''),
(0, 0, '', 15, 'en', 'a:1:{s:4:"menu";s:1:"3";}'),
(0, 0, '', 15, 'ru', 'a:1:{s:4:"menu";s:1:"3";}'),
(0, 0, '', 16, 'en', 'a:1:{s:4:"menu";s:1:"4";}'),
(0, 0, '', 16, 'ru', 'a:1:{s:4:"menu";s:1:"4";}'),
(0, 0, '', 17, 'en', 'a:1:{s:7:"content";s:394:"<ul>\n    <li>3993 Hanover Street<br/>New York, NY 10016\n</li>\n    <li><bdi>+19177227425</bdi> (call is free)</li>\n    <li><bdi>10 am — 6 pm</bdi><br/>\nMonday - Friday</li>\n    <li><a class="ty-exception__links-a greeny" href="mailto:sales@example.com">sales@example.com</a></li>\n\n    <li><a href="{"pages.view?page_id=20"|fn_url}" class="ty-exception__links-a">About company</a></li>\n\n</ul>\n\n";}'),
(0, 0, '', 17, 'ru', 'a:1:{s:7:"content";s:411:"<ul>\n    <li>3993 Hanover Street<br/>New York, NY 10016\n</li>\n    <li><bdi>+19177227425 (звонок бесплатный)</bdi></li>\n    <li><bdi>Пн-Пт 10.00 - 18.00</bdi></li>\n    <li><a class="ty-exception__links-a greeny" href="mailto:sales@example.com">sales@example.com</a></li>\n\n    <li><a href="{"pages.view?page_id=20"|fn_url}" class="ty-exception__links-a">О компании</a></li>\n\n</ul>\n\n\n\n";}'),
(0, 0, '', 18, 'en', ''),
(0, 0, '', 19, 'en', ''),
(0, 0, '', 20, 'en', 'a:1:{s:5:"items";a:4:{s:7:"filling";s:6:"newest";s:6:"period";s:1:"A";s:9:"last_days";s:1:"1";s:5:"limit";s:1:"4";}}'),
(0, 0, '', 20, 'ru', 'a:1:{s:5:"items";a:4:{s:7:"filling";s:6:"newest";s:6:"period";s:1:"A";s:9:"last_days";s:1:"1";s:5:"limit";s:1:"4";}}'),
(0, 0, '', 21, 'en', 'a:1:{s:5:"items";a:2:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:1:"6";}}'),
(0, 0, '', 21, 'ru', 'a:1:{s:5:"items";a:2:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:1:"6";}}'),
(0, 0, '', 22, 'en', 'a:1:{s:5:"items";a:2:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:1:"9";}}'),
(0, 0, '', 22, 'ru', 'a:1:{s:5:"items";a:2:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:1:"9";}}'),
(0, 0, '', 23, 'en', 'a:1:{s:5:"items";a:4:{s:7:"filling";s:6:"newest";s:6:"period";s:1:"A";s:9:"last_days";s:1:"1";s:5:"limit";s:1:"6";}}'),
(0, 0, '', 23, 'ru', 'a:1:{s:5:"items";a:4:{s:7:"filling";s:6:"newest";s:6:"period";s:1:"A";s:9:"last_days";s:1:"1";s:5:"limit";s:1:"6";}}'),
(0, 0, '', 24, 'en', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:7:"on_sale";s:5:"limit";s:1:"8";s:3:"cid";s:0:"";}}'),
(0, 0, '', 24, 'ru', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:7:"on_sale";s:5:"limit";s:1:"8";s:3:"cid";s:0:"";}}'),
(0, 0, '', 25, 'en', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:15:"blog.text_links";s:14:"parent_page_id";s:1:"7";s:5:"limit";s:1:"5";}}'),
(0, 0, '', 25, 'ru', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:15:"blog.text_links";s:14:"parent_page_id";s:1:"7";s:5:"limit";s:1:"5";}}'),
(0, 0, '', 26, 'en', ''),
(0, 0, '', 27, 'en', ''),
(0, 0, '', 28, 'en', 'a:1:{s:7:"content";s:1170:"<div class="ty-benefits-guarantees clearfix">\n<ul class="ty-benefits-guarantees__list">\n    <li class="ty-benefits-guarantees__item">\n        <a class="ty-benefits-guarantees__a" href="{"pages.view?page_id=6"|fn_url}">\n        <span class="ty-icon ty-benefits-guarantees__icon ty-benefits-low-price"></span>\n        <h4 class="ty-benefits-guarantees__title"><strong>Low price</strong> Guarantee</h4>\n        </a>\n    </li>\n    <li class="ty-benefits-guarantees__item">\n        <a class="ty-benefits-guarantees__a" href="{"pages.view?page_id=5"|fn_url}">\n        <span class="ty-icon ty-benefits-guarantees__icon ty-benefits-free-shipping"></span>\n        <h4 class="ty-benefits-guarantees__title"><strong>Free</strong> shipping</h4>\n        <p class="ty-benefits-guarantees__txt">Orders $19 and up.</p>\n        </a>\n    </li>\n    <li class="ty-benefits-guarantees__item">\n        <a class="ty-benefits-guarantees__a" href="{"pages.view?page_id=4"|fn_url}">\n        <span class="ty-icon ty-benefits-guarantees__icon ty-benefits-free-returns"></span>\n        <h4 class="ty-benefits-guarantees__title"><strong>Free</strong> returns</h4>\n        </a>\n    </li>\n</ul>\n\n</div>";}'),
(0, 0, '', 28, 'ru', 'a:1:{s:7:"content";s:1170:"<div class="ty-benefits-guarantees clearfix">\n<ul class="ty-benefits-guarantees__list">\n    <li class="ty-benefits-guarantees__item">\n        <a class="ty-benefits-guarantees__a" href="{"pages.view?page_id=6"|fn_url}">\n        <span class="ty-icon ty-benefits-guarantees__icon ty-benefits-low-price"></span>\n        <h4 class="ty-benefits-guarantees__title"><strong>Low price</strong> Guarantee</h4>\n        </a>\n    </li>\n    <li class="ty-benefits-guarantees__item">\n        <a class="ty-benefits-guarantees__a" href="{"pages.view?page_id=5"|fn_url}">\n        <span class="ty-icon ty-benefits-guarantees__icon ty-benefits-free-shipping"></span>\n        <h4 class="ty-benefits-guarantees__title"><strong>Free</strong> shipping</h4>\n        <p class="ty-benefits-guarantees__txt">Orders $19 and up.</p>\n        </a>\n    </li>\n    <li class="ty-benefits-guarantees__item">\n        <a class="ty-benefits-guarantees__a" href="{"pages.view?page_id=4"|fn_url}">\n        <span class="ty-icon ty-benefits-guarantees__icon ty-benefits-free-returns"></span>\n        <h4 class="ty-benefits-guarantees__title"><strong>Free</strong> returns</h4>\n        </a>\n    </li>\n</ul>\n\n</div>";}'),
(0, 0, '', 29, 'en', 'a:1:{s:5:"items";a:6:{s:7:"filling";s:7:"similar";s:5:"limit";s:1:"4";s:13:"percent_range";s:0:"";s:16:"similar_category";s:1:"Y";s:15:"similar_subcats";s:1:"Y";s:16:"similar_in_stock";s:1:"Y";}}'),
(0, 0, '', 29, 'ru', 'a:1:{s:5:"items";a:6:{s:7:"filling";s:7:"similar";s:5:"limit";s:1:"4";s:13:"percent_range";s:0:"";s:16:"similar_category";s:1:"Y";s:15:"similar_subcats";s:1:"Y";s:16:"similar_in_stock";s:1:"Y";}}'),
(0, 0, '', 30, 'en', 'a:1:{s:5:"items";a:6:{s:7:"filling";s:7:"similar";s:5:"limit";s:1:"3";s:13:"percent_range";s:1:"5";s:16:"similar_category";s:1:"N";s:15:"similar_subcats";s:1:"N";s:16:"similar_in_stock";s:1:"N";}}'),
(0, 0, '', 30, 'ru', 'a:1:{s:5:"items";a:6:{s:7:"filling";s:7:"similar";s:5:"limit";s:1:"3";s:13:"percent_range";s:1:"5";s:16:"similar_category";s:1:"N";s:15:"similar_subcats";s:1:"N";s:16:"similar_in_stock";s:1:"N";}}'),
(0, 0, '', 31, 'en', 'a:1:{s:5:"items";a:1:{s:7:"filling";s:8:"manually";}}'),
(0, 0, '', 31, 'ru', 'a:1:{s:5:"items";a:1:{s:7:"filling";s:8:"manually";}}'),
(0, 0, '', 32, 'en', 'a:1:{s:5:"items";a:2:{s:7:"filling";s:15:"recent_products";s:5:"limit";s:1:"3";}}'),
(0, 0, '', 32, 'ru', 'a:1:{s:5:"items";a:2:{s:7:"filling";s:15:"recent_products";s:5:"limit";s:1:"3";}}'),
(0, 0, '', 33, 'en', ''),
(0, 0, '', 34, 'en', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:8:"23,25,27";s:8:"required";a:3:{s:11:"field_id_23";s:1:"N";s:11:"field_id_25";s:1:"N";s:11:"field_id_27";s:1:"N";}}}'),
(0, 0, '', 34, 'ru', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:8:"23,25,27";s:8:"required";a:3:{s:11:"field_id_23";s:1:"N";s:11:"field_id_25";s:1:"N";s:11:"field_id_27";s:1:"N";}}}'),
(0, 0, '', 35, 'en', ''),
(0, 0, '', 36, 'en', ''),
(0, 0, '', 37, 'en', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:5:"19,29";s:8:"required";a:2:{s:11:"field_id_19";s:1:"Y";s:11:"field_id_29";s:1:"Y";}}}'),
(0, 0, '', 37, 'ru', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:5:"19,29";s:8:"required";a:2:{s:11:"field_id_19";s:1:"Y";s:11:"field_id_29";s:1:"Y";}}}'),
(0, 0, '', 38, 'en', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:8:"6,7,9,32";s:8:"required";a:4:{s:10:"field_id_6";s:1:"N";s:10:"field_id_7";s:1:"N";s:10:"field_id_9";s:1:"N";s:11:"field_id_32";s:1:"Y";}}}'),
(0, 0, '', 38, 'ru', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:8:"6,7,9,32";s:8:"required";a:4:{s:10:"field_id_6";s:1:"N";s:10:"field_id_7";s:1:"N";s:10:"field_id_9";s:1:"N";s:11:"field_id_32";s:1:"N";}}}'),
(0, 0, '', 39, 'en', ''),
(0, 0, '', 40, 'en', ''),
(0, 0, '', 41, 'en', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:23:"14,16,30,18,28,22,24,26";s:8:"required";a:8:{s:11:"field_id_14";s:1:"N";s:11:"field_id_16";s:1:"N";s:11:"field_id_30";s:1:"N";s:11:"field_id_18";s:1:"N";s:11:"field_id_28";s:1:"N";s:11:"field_id_22";s:1:"N";s:11:"field_id_24";s:1:"N";s:11:"field_id_26";s:1:"N";}}}'),
(0, 0, '', 42, 'en', ''),
(0, 0, '', 43, 'en', ''),
(0, 0, '', 44, 'en', ''),
(0, 0, '', 45, 'en', ''),
(0, 0, '', 46, 'en', ''),
(0, 0, '', 47, 'en', ''),
(0, 0, '', 48, 'en', ''),
(0, 0, '', 49, 'en', 'a:1:{s:5:"items";a:2:{s:7:"filling";s:8:"manually";s:8:"item_ids";s:0:"";}}'),
(0, 0, '', 49, 'ru', 'a:1:{s:5:"items";a:1:{s:7:"filling";s:8:"manually";}}'),
(0, 0, '', 50, 'en', 'a:1:{s:5:"items";a:4:{s:7:"filling";s:17:"blog.recent_posts";s:6:"period";s:1:"A";s:9:"last_days";s:1:"1";s:5:"limit";s:1:"3";}}'),
(0, 0, '', 50, 'ru', 'a:1:{s:5:"items";a:4:{s:7:"filling";s:17:"blog.recent_posts";s:6:"period";s:1:"A";s:9:"last_days";s:1:"1";s:5:"limit";s:1:"3";}}'),
(0, 0, '', 51, 'en', ''),
(0, 0, '', 52, 'en', 'a:1:{s:5:"items";a:3:{s:7:"filling";s:37:"product_variations.variations_filling";s:5:"limit";s:3:"100";s:19:"variations_in_stock";s:1:"N";}}'),
(0, 0, '', 53, 'en', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]bm_blocks_descriptions`
--

CREATE TABLE `[[dbprefix]]bm_blocks_descriptions` (
  `block_id` int(11) unsigned NOT NULL,
  `lang_code` char(2) NOT NULL DEFAULT '',
  `name` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`block_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]bm_blocks_descriptions`
--

INSERT INTO `[[dbprefix]]bm_blocks_descriptions` VALUES
(1, 'en', 'Languages'),
(2, 'en', 'Currencies'),
(3, 'en', 'Quick links'),
(4, 'en', 'My Account'),
(5, 'en', 'Logo'),
(6, 'en', 'Call Request'),
(7, 'en', 'Search'),
(8, 'en', 'Cart content'),
(9, 'en', 'Main menu'),
(10, 'en', 'Breadcrumbs'),
(11, 'en', 'Main Content'),
(12, 'en', 'Subscribe'),
(13, 'en', 'Social links'),
(14, 'en', 'My account'),
(15, 'en', 'Shop'),
(16, 'en', 'Create order'),
(17, 'en', 'About us'),
(18, 'en', 'Copyright'),
(19, 'en', 'Payment icons'),
(20, 'en', 'Main banners'),
(21, 'en', 'Free shipping'),
(22, 'en', 'Discount for pickup'),
(23, 'en', 'Hot deals'),
(24, 'en', 'Sale'),
(25, 'en', 'Blog'),
(26, 'en', 'Reviews'),
(27, 'en', 'Brands'),
(28, 'en', 'Guarantees and benefits'),
(29, 'en', 'Similar products'),
(30, 'en', 'At the same price!'),
(31, 'en', 'Product filters'),
(32, 'en', 'Recently Viewed'),
(33, 'en', 'Logo without link'),
(34, 'en', 'Deliver to'),
(35, 'en', 'Shipping methods'),
(36, 'en', 'Customer'),
(37, 'en', 'Address'),
(38, 'en', 'Customer information'),
(39, 'en', 'Customer''s notes'),
(40, 'en', 'Payment methods'),
(41, 'en', 'Billing address'),
(42, 'en', 'Terms and conditions'),
(43, 'en', 'Sign up for our newsletters!'),
(44, 'en', 'Products in your order'),
(45, 'en', 'Order summary'),
(46, 'en', 'Auth information'),
(47, 'en', 'Profile information'),
(48, 'en', '404'),
(49, 'en', 'Product filters'),
(50, 'en', 'Recent posts'),
(51, 'en', 'Gift certificate verification'),
(52, 'en', 'Variations list'),
(53, 'en', 'Bundles with this product');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]bm_block_statuses`
--

CREATE TABLE `[[dbprefix]]bm_block_statuses` (
  `snapping_id` int(11) NOT NULL,
  `object_ids` text,
  `object_type` varchar(32) NOT NULL,
  UNIQUE KEY `snapping_id` (`snapping_id`,`object_type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]bm_containers`
--

CREATE TABLE `[[dbprefix]]bm_containers` (
  `container_id` mediumint(9) unsigned NOT NULL AUTO_INCREMENT,
  `location_id` mediumint(9) unsigned NOT NULL,
  `position` enum('TOP_PANEL','HEADER','CONTENT','FOOTER') NOT NULL,
  `width` tinyint(4) NOT NULL,
  `user_class` varchar(128) NOT NULL DEFAULT '',
  `linked_to_default` varchar(1) NOT NULL DEFAULT 'Y',
  `status` varchar(1) NOT NULL DEFAULT 'A',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT 'If a vendor uses custom block configuration for a container, his/her vendor ID is stored here',
  PRIMARY KEY (`container_id`),
  KEY `location_id` (`location_id`),
  KEY `location_id_company_id` (`location_id`,`company_id`),
  KEY `location_id_position_company_id` (`location_id`,`position`,`company_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=65 ;

--
-- Dumping data for table `[[dbprefix]]bm_containers`
--

INSERT INTO `[[dbprefix]]bm_containers` VALUES
(1, 1, 'TOP_PANEL', 16, 'top-grid', 'Y', 'A', 0),
(2, 1, 'HEADER', 16, 'header-grid', 'Y', 'A', 0),
(3, 1, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(4, 1, 'FOOTER', 16, 'ty-footer-grid', 'Y', 'A', 0),
(5, 2, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(6, 2, 'HEADER', 16, '', 'Y', 'A', 0),
(7, 2, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(8, 2, 'FOOTER', 16, '', 'Y', 'A', 0),
(9, 3, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(10, 3, 'HEADER', 16, '', 'Y', 'A', 0),
(11, 3, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(12, 3, 'FOOTER', 16, '', 'Y', 'A', 0),
(13, 4, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(14, 4, 'HEADER', 16, '', 'Y', 'A', 0),
(15, 4, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(16, 4, 'FOOTER', 16, '', 'Y', 'A', 0),
(17, 5, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(18, 5, 'HEADER', 16, '', 'Y', 'A', 0),
(19, 5, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(20, 5, 'FOOTER', 16, '', 'Y', 'A', 0),
(21, 6, 'TOP_PANEL', 16, '', 'N', 'D', 0),
(22, 6, 'HEADER', 16, 'litecheckout__header', 'N', 'A', 0),
(23, 6, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(24, 6, 'FOOTER', 16, 'litecheckout__footer', 'N', 'A', 0),
(25, 7, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(26, 7, 'HEADER', 16, '', 'Y', 'A', 0),
(27, 7, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(28, 7, 'FOOTER', 16, '', 'Y', 'A', 0),
(29, 8, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(30, 8, 'HEADER', 16, '', 'Y', 'A', 0),
(31, 8, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(32, 8, 'FOOTER', 16, '', 'Y', 'A', 0),
(33, 9, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(34, 9, 'HEADER', 16, '', 'Y', 'A', 0),
(35, 9, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(36, 9, 'FOOTER', 16, '', 'Y', 'A', 0),
(37, 10, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(38, 10, 'HEADER', 16, '', 'Y', 'A', 0),
(39, 10, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(40, 10, 'FOOTER', 16, '', 'Y', 'A', 0),
(41, 11, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(42, 11, 'HEADER', 16, '', 'Y', 'A', 0),
(43, 11, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(44, 11, 'FOOTER', 16, '', 'Y', 'A', 0),
(45, 12, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(46, 12, 'HEADER', 16, '', 'Y', 'A', 0),
(47, 12, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(48, 12, 'FOOTER', 16, '', 'Y', 'A', 0),
(49, 13, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(50, 13, 'HEADER', 16, '', 'Y', 'A', 0),
(51, 13, 'CONTENT', 16, '', 'Y', 'A', 0),
(52, 13, 'FOOTER', 16, '', 'Y', 'A', 0),
(57, 15, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(58, 15, 'HEADER', 16, '', 'Y', 'A', 0),
(59, 15, 'CONTENT', 16, 'content-grid', 'Y', 'A', 0),
(60, 15, 'FOOTER', 16, '', 'Y', 'A', 0),
(61, 16, 'TOP_PANEL', 16, '', 'Y', 'A', 0),
(62, 16, 'HEADER', 16, '', 'Y', 'A', 0),
(63, 16, 'CONTENT', 16, '', 'Y', 'A', 0),
(64, 16, 'FOOTER', 16, '', 'Y', 'A', 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]bm_grids`
--

CREATE TABLE `[[dbprefix]]bm_grids` (
  `grid_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `container_id` mediumint(9) unsigned NOT NULL,
  `parent_id` int(11) unsigned NOT NULL DEFAULT '0',
  `order` mediumint(9) unsigned NOT NULL DEFAULT '0',
  `width` tinyint(4) unsigned NOT NULL DEFAULT '1',
  `offset` tinyint(4) unsigned NOT NULL DEFAULT '0',
  `user_class` varchar(128) NOT NULL DEFAULT '',
  `omega` tinyint(1) unsigned NOT NULL DEFAULT '0',
  `alpha` tinyint(1) unsigned NOT NULL DEFAULT '0',
  `wrapper` varchar(128) NOT NULL DEFAULT '',
  `content_align` enum('LEFT','RIGHT','FULL_WIDTH') NOT NULL DEFAULT 'FULL_WIDTH',
  `html_element` varchar(8) NOT NULL DEFAULT 'div',
  `clear` tinyint(1) unsigned NOT NULL DEFAULT '0',
  `status` varchar(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`grid_id`),
  KEY `container_id` (`container_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=79 ;

--
-- Dumping data for table `[[dbprefix]]bm_grids`
--

INSERT INTO `[[dbprefix]]bm_grids` VALUES
(1, 1, 0, 0, 3, 0, 'top-links-grid ty-top-grid_float', 0, 1, '', 'LEFT', 'div', 0, 'A'),
(2, 1, 0, 0, 11, 0, 'top-links-grid', 0, 0, '', 'LEFT', 'div', 0, 'A'),
(3, 1, 0, 0, 2, 0, 'top-links-grid', 1, 0, '', 'RIGHT', 'div', 1, 'A'),
(4, 2, 0, 0, 3, 0, 'top-logo-grid', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(5, 2, 0, 0, 5, 0, 'ty-cr-content-grid', 0, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(6, 2, 0, 0, 8, 0, '', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(7, 2, 6, 0, 4, 0, 'search-block-grid', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(8, 2, 6, 0, 4, 0, 'cart-content-grid', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(9, 2, 0, 0, 16, 0, 'top-menu-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(10, 3, 0, 0, 16, 0, 'breadcrumbs-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(11, 3, 0, 0, 16, 0, 'main-content-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(12, 4, 0, 0, 16, 0, 'ty-footer-grid__full-width footer-stay-connected', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(13, 4, 12, 0, 10, 0, 'ty-grid', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(14, 4, 12, 0, 6, 0, 'ty-grid', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(15, 4, 0, 0, 16, 0, 'ty-footer-grid__full-width ty-footer-menu', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(16, 4, 15, 0, 4, 0, 'my-account-grid', 0, 1, '', 'LEFT', 'div', 0, 'A'),
(17, 4, 15, 0, 4, 0, 'footer-store-grid', 0, 0, '', 'LEFT', 'div', 0, 'A'),
(18, 4, 15, 0, 4, 0, 'customer-service-grid', 0, 0, '', 'LEFT', 'div', 0, 'A'),
(19, 4, 15, 0, 4, 0, 'about-grid', 1, 0, '', 'LEFT', 'div', 1, 'A'),
(20, 4, 0, 0, 16, 0, 'ty-footer-grid__full-width footer-copyright', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(21, 4, 20, 0, 8, 0, '', 0, 1, '', 'LEFT', 'div', 0, 'A'),
(22, 4, 20, 0, 8, 0, '', 1, 0, '', 'RIGHT', 'div', 1, 'A'),
(23, 7, 0, 0, 16, 0, '', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(24, 7, 23, 0, 10, 0, '', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(25, 7, 23, 0, 6, 0, '', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(26, 7, 0, 0, 16, 0, '', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(27, 7, 0, 0, 8, 0, '', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(28, 7, 0, 0, 8, 0, '', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(29, 7, 0, 0, 16, 0, '', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(30, 9, 0, 0, 16, 0, '', 0, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(31, 11, 0, 0, 16, 0, 'breadcrumbs-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(32, 11, 0, 0, 16, 0, 'main-content-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(33, 11, 0, 0, 9, 0, '', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(34, 11, 0, 0, 7, 0, '', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(35, 12, 0, 0, 16, 0, '', 0, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(36, 13, 0, 0, 16, 0, '', 0, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(37, 15, 0, 0, 16, 0, 'breadcrumbs-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(38, 15, 0, 0, 4, 0, 'side-grid', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(39, 15, 0, 0, 12, 0, 'main-content-grid', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(40, 16, 0, 0, 16, 0, '', 0, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(41, 17, 0, 0, 16, 0, '', 1, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(42, 19, 0, 0, 16, 0, 'breadcrumbs-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(43, 19, 0, 0, 16, 0, 'main-content-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(44, 20, 0, 0, 16, 0, '', 0, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(45, 21, 0, 0, 16, 0, '', 0, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(46, 22, 0, 0, 3, 0, 'top-logo-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(47, 23, 0, 0, 12, 0, 'main-content-grid', 0, 1, 'blocks/grid_wrappers/lite_checkout.tpl', 'FULL_WIDTH', 'div', 0, 'A'),
(48, 23, 0, 0, 4, 0, 'side-grid litecheckout__cart', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(49, 24, 0, 0, 16, 0, 'ty-footer-grid__full-width footer-copyright', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(50, 24, 49, 0, 2, 0, '', 0, 1, '', 'LEFT', 'div', 0, 'A'),
(51, 24, 49, 0, 14, 0, '', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(52, 27, 0, 0, 16, 0, 'breadcrumbs-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(53, 27, 0, 0, 8, 0, 'main-content-grid', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(54, 27, 0, 0, 8, 0, 'auth-information-grid', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(55, 31, 0, 0, 16, 0, 'breadcrumbs-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(56, 31, 0, 0, 8, 0, 'main-content-grid', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(57, 31, 0, 0, 8, 0, 'profile-information-grid', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(58, 35, 0, 0, 16, 0, 'main-content-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(59, 37, 0, 0, 16, 0, '', 0, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(60, 39, 0, 0, 16, 0, 'main-content-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(61, 40, 0, 0, 16, 0, '', 0, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(62, 41, 0, 0, 16, 0, '', 0, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(63, 43, 0, 0, 16, 0, 'breadcrumbs-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(64, 43, 0, 0, 4, 0, 'side-grid', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'D'),
(65, 43, 0, 0, 12, 0, 'main-content-grid', 1, 0, '', 'FULL_WIDTH', 'div', 1, 'A'),
(66, 44, 0, 0, 16, 0, '', 0, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(67, 47, 0, 0, 16, 0, 'main-content-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(68, 51, 0, 0, 16, 0, 'breadcrumbs-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(69, 51, 0, 0, 16, 0, 'main-content-grid', 1, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(78, 63, 0, 0, 3, 0, '', 1, 0, '', 'FULL_WIDTH', 'div', 0, 'A'),
(77, 63, 0, 0, 13, 0, 'ty-blog-grid', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(76, 63, 0, 0, 16, 0, '', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(73, 59, 0, 0, 16, 0, 'breadcrumbs-grid', 1, 1, '', 'FULL_WIDTH', 'div', 1, 'A'),
(74, 59, 0, 0, 8, 0, 'main-content-grid', 0, 1, '', 'FULL_WIDTH', 'div', 0, 'A'),
(75, 59, 0, 0, 8, 0, 'certificates-verify-grid', 1, 0, '', 'RIGHT', 'div', 0, 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]bm_layouts`
--

CREATE TABLE `[[dbprefix]]bm_layouts` (
  `layout_id` int(11) NOT NULL AUTO_INCREMENT,
  `name` varchar(64) NOT NULL DEFAULT '',
  `is_default` tinyint(4) NOT NULL DEFAULT '0',
  `width` tinyint(4) NOT NULL DEFAULT '16',
  `layout_width` enum('fixed','fluid','full_width') NOT NULL DEFAULT 'fixed',
  `min_width` int(11) unsigned NOT NULL DEFAULT '760',
  `max_width` int(11) unsigned NOT NULL DEFAULT '960',
  `theme_name` varchar(64) NOT NULL DEFAULT '',
  `style_id` varchar(64) NOT NULL DEFAULT '',
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`layout_id`),
  KEY `is_default` (`is_default`,`storefront_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]bm_layouts`
--

INSERT INTO `[[dbprefix]]bm_layouts` VALUES
(1, 'Main', 1, 16, 'fluid', 280, 1200, 'bright_theme', 'Bright_theme', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]bm_locations`
--

CREATE TABLE `[[dbprefix]]bm_locations` (
  `location_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `dispatch` varchar(64) NOT NULL,
  `is_default` tinyint(1) NOT NULL,
  `layout_id` int(11) unsigned NOT NULL DEFAULT '0',
  `object_ids` text,
  `custom_html` text,
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`location_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=17 ;

--
-- Dumping data for table `[[dbprefix]]bm_locations`
--

INSERT INTO `[[dbprefix]]bm_locations` VALUES
(1, 'default', 1, 1, '', '', 10),
(2, 'index.index', 0, 1, '', '', 20),
(3, 'products.view', 0, 1, '', '', 30),
(4, 'categories.view', 0, 1, '', '', 40),
(5, 'checkout.cart', 0, 1, '', '', 50),
(6, 'checkout', 0, 1, '', '', 60),
(7, 'auth', 0, 1, '', '', 70),
(8, 'profiles', 0, 1, '', '', 80),
(9, 'profiles.success_add', 0, 1, '', '', 90),
(10, 'checkout.complete', 0, 1, '', '', 100),
(11, 'pages.view', 0, 1, '', '', 110),
(12, 'no_page', 0, 1, '', '', 160),
(13, 'products.search', 0, 1, '', '', 170),
(15, 'gift_certificates', 0, 1, '', NULL, 130),
(16, 'pages.view?page_type=B', 0, 1, '', '', 170);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]bm_locations_descriptions`
--

CREATE TABLE `[[dbprefix]]bm_locations_descriptions` (
  `location_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `lang_code` char(2) NOT NULL DEFAULT '',
  `name` varchar(64) NOT NULL,
  `title` text NOT NULL,
  `meta_description` text NOT NULL,
  `meta_keywords` text NOT NULL,
  PRIMARY KEY (`location_id`,`lang_code`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=17 ;

--
-- Dumping data for table `[[dbprefix]]bm_locations_descriptions`
--

INSERT INTO `[[dbprefix]]bm_locations_descriptions` VALUES
(1, 'en', 'Default', '', '', ''),
(2, 'en', 'Homepage', 'Shopping Cart Software & Ecommerce Software Solutions by CS-Cart', 'Secure and full-featured Online Shopping Cart Software with the complete set of powerful ecommerce options to create your own online store with minimum efforts involved.', 'shopping cart, software, ecommerce software, online store'),
(3, 'en', 'Products', '', '', ''),
(4, 'en', 'Categories', '', '', ''),
(5, 'en', 'Cart', '', '', ''),
(6, 'en', 'Checkout', '', '', ''),
(7, 'en', 'Auth', '', '', ''),
(8, 'en', 'Profiles', '', '', ''),
(9, 'en', 'Successful registration', '', '', ''),
(10, 'en', 'Order landing page', '', '', ''),
(11, 'en', 'Pages', '', '', ''),
(12, 'en', '404', 'Page not found', '', ''),
(13, 'en', 'Search results', '', '', ''),
(15, 'en', 'Gift certificates', '', '', ''),
(16, 'en', 'Blog', '', '', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]bm_snapping`
--

CREATE TABLE `[[dbprefix]]bm_snapping` (
  `snapping_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `block_id` int(11) unsigned NOT NULL,
  `grid_id` int(11) unsigned NOT NULL,
  `wrapper` varchar(128) NOT NULL DEFAULT '',
  `user_class` varchar(128) NOT NULL DEFAULT '',
  `order` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `status` varchar(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`snapping_id`),
  KEY `grid_id` (`grid_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=83 ;

--
-- Dumping data for table `[[dbprefix]]bm_snapping`
--

INSERT INTO `[[dbprefix]]bm_snapping` VALUES
(1, 1, 1, '', 'top-languages', 2, 'A'),
(2, 2, 1, '', 'top-currencies', 3, 'A'),
(3, 3, 2, '', 'top-quick-links', 3, 'A'),
(4, 4, 3, 'blocks/wrappers/onclick_dropdown.tpl', 'top-my-account', 2, 'A'),
(5, 5, 4, '', 'top-logo', 0, 'A'),
(6, 6, 5, '', '', 0, 'A'),
(7, 7, 7, '', 'top-search', 0, 'A'),
(8, 8, 8, '', 'top-cart-content', 2, 'A'),
(9, 9, 9, '', 'top-menu', 2, 'A'),
(10, 10, 10, '', '', 0, 'A'),
(11, 11, 11, 'blocks/wrappers/mainbox_general.tpl', '', 0, 'A'),
(12, 12, 13, '', '', 2, 'A'),
(13, 13, 14, '', '', 2, 'A'),
(14, 14, 16, 'blocks/wrappers/footer_general.tpl', '', 0, 'A'),
(15, 15, 17, 'blocks/wrappers/footer_general.tpl', 'footer-menu-shop', 0, 'A'),
(16, 16, 18, 'blocks/wrappers/footer_general.tpl', 'footer-menu-create-orders', 0, 'A'),
(17, 17, 19, 'blocks/wrappers/footer_general.tpl', 'footer-no-wysiwyg footer-contacts', 0, 'A'),
(18, 18, 21, '', '', 2, 'A'),
(19, 19, 22, '', '', 2, 'A'),
(20, 20, 24, '', 'homepage-banners', 0, 'A'),
(21, 21, 25, '', 'ty-banners-free-ship', 3, 'A'),
(22, 22, 25, '', 'ty-banners-pickup', 4, 'A'),
(23, 23, 26, 'blocks/wrappers/mainbox_simple.tpl', 'homepage-hotdeals', 2, 'A'),
(24, 24, 26, 'blocks/wrappers/mainbox_simple.tpl', 'homepage-on-sale', 5, 'A'),
(25, 25, 27, 'blocks/wrappers/mainbox_simple.tpl', '', 0, 'A'),
(26, 26, 28, 'blocks/wrappers/mainbox_simple.tpl', 'homepage-reviews', 0, 'A'),
(27, 11, 29, '', '', 1, 'A'),
(28, 27, 29, 'blocks/wrappers/mainbox_simple.tpl', 'homepage-our-brands', 2, 'A'),
(29, 28, 29, '', 'homepage-benefits-guarantees', 3, 'D'),
(30, 10, 31, '', '', 0, 'A'),
(31, 11, 32, '', '', 0, 'A'),
(32, 29, 33, 'blocks/wrappers/mainbox_simple.tpl', '', 2, 'A'),
(33, 30, 34, 'blocks/wrappers/mainbox_simple.tpl', '', 2, 'A'),
(34, 10, 37, '', '', 0, 'A'),
(35, 31, 38, 'blocks/wrappers/sidebox_important.tpl', '', 0, 'A'),
(36, 32, 38, 'blocks/wrappers/sidebox_important.tpl', '', 0, 'A'),
(37, 11, 39, 'blocks/wrappers/mainbox_general.tpl', '', 0, 'A'),
(38, 10, 42, '', '', 0, 'A'),
(39, 11, 43, 'blocks/wrappers/mainbox_general.tpl', '', 0, 'A'),
(40, 33, 46, '', '', 0, 'A'),
(41, 34, 47, '', '', 0, 'A'),
(42, 35, 47, '', '', 1, 'A'),
(43, 36, 47, '', '', 2, 'A'),
(44, 37, 47, '', '', 3, 'A'),
(45, 38, 47, '', '', 4, 'A'),
(46, 39, 47, '', '', 5, 'A'),
(47, 40, 47, 'blocks/lite_checkout/wrappers/checkout_block_with_heading.tpl', '', 6, 'A'),
(48, 41, 47, '', '', 7, 'A'),
(49, 42, 47, '', '', 8, 'A'),
(50, 43, 47, '', '', 9, 'A'),
(51, 11, 47, 'blocks/wrappers/mainbox_general.tpl', '', 10, 'D'),
(52, 44, 48, '', 'order-products', 0, 'A'),
(53, 45, 48, '', '', 1, 'A'),
(54, 5, 50, '', 'top-logo', 0, 'A'),
(55, 18, 51, '', '', 2, 'A'),
(56, 10, 52, '', '', 0, 'A'),
(57, 11, 53, 'blocks/wrappers/mainbox_general.tpl', '', 0, 'A'),
(58, 46, 54, '', '', 0, 'A'),
(59, 10, 55, '', '', 0, 'A'),
(60, 11, 56, 'blocks/wrappers/mainbox_general.tpl', '', 2, 'A'),
(61, 47, 57, '', '', 0, 'A'),
(62, 10, 58, '', '', 0, 'A'),
(63, 11, 58, 'blocks/wrappers/mainbox_general.tpl', '', 1, 'A'),
(64, 10, 60, '', '', 0, 'A'),
(65, 11, 60, 'blocks/wrappers/mainbox_general.tpl', '', 1, 'A'),
(66, 10, 63, '', '', 0, 'A'),
(67, 4, 64, 'blocks/wrappers/sidebox_important.tpl', '', 1, 'A'),
(68, 32, 64, 'blocks/wrappers/sidebox_important.tpl', '', 2, 'A'),
(69, 11, 65, '', '', 0, 'A'),
(70, 48, 67, '', '', 0, 'A'),
(71, 10, 68, '', '', 0, 'A'),
(72, 49, 68, 'blocks/wrappers/sidebox_important.tpl', '', 0, 'A'),
(73, 11, 69, 'blocks/wrappers/mainbox_general.tpl', '', 0, 'A'),
(82, 50, 78, 'blocks/wrappers/sidebox_important.tpl', '', 0, 'A'),
(81, 11, 77, 'blocks/wrappers/mainbox_general.tpl', '', 0, 'A'),
(80, 10, 76, '', '', 0, 'A'),
(77, 10, 73, '', '', 0, 'A'),
(78, 11, 74, 'blocks/wrappers/mainbox_general.tpl', '', 0, 'A'),
(79, 51, 75, '', '', 0, 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]cache_handlers`
--

CREATE TABLE `[[dbprefix]]cache_handlers` (
  `table_name` varchar(128) NOT NULL COMMENT 'Table name the cache record depends on',
  `cache_key` varchar(128) NOT NULL COMMENT 'Cache key or prefix used to register cache record',
  UNIQUE KEY `table_name_cache_key` (`table_name`,`cache_key`),
  KEY `table_name` (`table_name`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Stores relations between cache records registered with TyghRegistry::registerCache() and tables they depend on';

--
-- Dumping data for table `[[dbprefix]]cache_handlers`
--

INSERT INTO `[[dbprefix]]cache_handlers` VALUES
('addons', 'addons'),
('addons', 'schemas'),
('addons', 'template_overrides'),
('addons', 'thooks_A'),
('addons', 'unmanaged_addons'),
('addons', 'upgrade_packages'),
('companies', 'all_available_company_ids'),
('countries', 'available_countries_hash'),
('currencies', 'init_currency'),
('currency_descriptions', 'init_currency'),
('images', 'template_logos'),
('images_links', 'template_logos'),
('languages', 'init_language'),
('language_values', 'lang_cache'),
('logos', 'template_logos'),
('settings_descriptions', 'addons'),
('settings_descriptions', 'settings'),
('settings_objects', 'addons'),
('settings_objects', 'init_cdn_settings'),
('settings_objects', 'init_storage_settings'),
('settings_objects', 'schemas'),
('settings_objects', 'seo_settings'),
('settings_objects', 'settings'),
('settings_objects', 'storefront_protocol'),
('settings_sections', 'addons'),
('settings_sections', 'settings'),
('settings_variants', 'addons'),
('settings_variants', 'settings'),
('settings_vendor_values', 'addons'),
('settings_vendor_values', 'seo_settings'),
('settings_vendor_values', 'settings'),
('storefronts', 'seo_settings'),
('storefronts_currencies', 'init_currency'),
('storefronts_languages', 'init_language'),
('storefronts_languages', 'seo_settings'),
('ult_language_values', 'lang_cache');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]call_requests`
--

CREATE TABLE `[[dbprefix]]call_requests` (
  `request_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `order_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `status` enum('new','in_progress','completed','no_answer') NOT NULL DEFAULT 'new',
  `name` varchar(250) NOT NULL DEFAULT '',
  `phone` varchar(128) NOT NULL DEFAULT '',
  `time_from` varchar(32) NOT NULL DEFAULT '',
  `time_to` varchar(32) NOT NULL DEFAULT '',
  `notes` text,
  `cart_products` text NOT NULL COMMENT 'Serialized data',
  PRIMARY KEY (`request_id`),
  KEY `user_id` (`company_id`,`user_id`),
  KEY `timestamp` (`timestamp`),
  KEY `status` (`status`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]categories`
--

CREATE TABLE `[[dbprefix]]categories` (
  `category_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `parent_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `id_path` varchar(255) NOT NULL DEFAULT '',
  `level` int(11) unsigned NOT NULL DEFAULT '1',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `usergroup_ids` varchar(255) NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'A',
  `product_count` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `is_op` char(1) NOT NULL DEFAULT 'N',
  `localization` varchar(255) NOT NULL DEFAULT '',
  `age_verification` char(1) NOT NULL DEFAULT 'N',
  `age_limit` tinyint(4) NOT NULL DEFAULT '0',
  `parent_age_verification` char(1) NOT NULL DEFAULT 'N',
  `parent_age_limit` tinyint(4) NOT NULL DEFAULT '0',
  `selected_views` text,
  `default_view` varchar(50) NOT NULL DEFAULT '',
  `product_details_view` varchar(50) NOT NULL DEFAULT '',
  `product_columns` tinyint(3) unsigned NOT NULL DEFAULT '0',
  `is_trash` char(1) NOT NULL DEFAULT 'N',
  `is_default` char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (`category_id`),
  KEY `c_status` (`usergroup_ids`,`status`,`parent_id`),
  KEY `position` (`position`),
  KEY `parent` (`parent_id`),
  KEY `id_path` (`id_path`),
  KEY `localization` (`localization`),
  KEY `age_verification` (`age_verification`,`age_limit`),
  KEY `parent_age_verification` (`parent_age_verification`,`parent_age_limit`),
  KEY `p_category_id` (`category_id`,`usergroup_ids`,`status`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=264 ;

--
-- Dumping data for table `[[dbprefix]]categories`
--

INSERT INTO `[[dbprefix]]categories` VALUES
(165, 167, '166/167/165', 3, 1, 1, '0', 'A', 6, 100, 1310932800, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(166, 0, '166', 1, 1, 1, '0', 'A', 0, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(167, 166, '166/167', 2, 1, 1, '0', 'A', 0, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(168, 167, '166/167/168', 3, 1, 1, '0', 'A', 4, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(169, 167, '166/167/169', 3, 1, 1, '0', 'A', 4, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(170, 167, '166/167/170', 3, 1, 1, '0', 'A', 3, 110, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(171, 167, '166/167/171', 3, 1, 1, '0', 'A', 4, 120, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(172, 167, '166/167/172', 3, 1, 1, '0', 'A', 4, 130, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(174, 166, '166/174', 2, 1, 1, '0', 'A', 0, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(175, 166, '166/175', 2, 1, 1, '0', 'A', 0, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(176, 175, '166/175/176', 3, 1, 1, '0', 'A', 5, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(177, 166, '166/177', 2, 1, 1, '0', 'A', 0, 50, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(178, 177, '166/177/178', 3, 1, 1, '0', 'A', 2, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(179, 177, '166/177/179', 3, 1, 1, '0', 'A', 9, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(180, 177, '166/177/180', 3, 1, 1, '0', 'A', 5, 40, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(181, 177, '166/177/181', 3, 1, 1, '0', 'A', 5, 50, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(182, 177, '166/177/182', 3, 1, 1, '0', 'A', 4, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(199, 196, '166/196/199', 3, 1, 1, '0', 'A', 12, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(185, 175, '166/175/185', 3, 1, 1, '0', 'A', 5, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(186, 175, '166/175/186', 3, 1, 1, '0', 'A', 4, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(187, 175, '166/175/187', 3, 1, 1, '0', 'A', 3, 50, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(188, 175, '166/175/188', 3, 1, 1, '0', 'A', 2, 60, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(189, 175, '166/175/189', 3, 1, 1, '0', 'A', 5, 70, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(190, 174, '166/174/190', 3, 1, 1, '0', 'A', 5, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(191, 174, '166/174/191', 3, 1, 1, '0', 'A', 3, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(194, 174, '166/174/194', 3, 1, 1, '0', 'A', 4, 40, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(193, 174, '166/174/193', 3, 1, 1, '0', 'A', 3, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(195, 174, '166/174/195', 3, 1, 1, '0', 'A', 4, 50, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(196, 166, '166/196', 2, 1, 1, '0', 'A', 0, 60, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(197, 196, '166/196/197', 3, 1, 1, '0', 'A', 3, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(198, 196, '166/196/198', 3, 1, 1, '0', 'A', 8, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(200, 196, '166/196/200', 3, 1, 1, '0', 'A', 5, 40, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(201, 167, '166/167/201', 3, 1, 1, '0', 'A', 3, 140, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(202, 175, '166/175/202', 3, 1, 1, '0', 'A', 3, 40, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(203, 0, '203', 1, 1, 1, '0', 'A', 0, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(204, 203, '203/204', 2, 1, 1, '0', 'A', 0, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(211, 203, '203/211', 2, 1, 1, '0', 'A', 0, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(212, 211, '203/211/212', 3, 1, 1, '0', 'A', 4, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(208, 204, '203/204/208', 3, 1, 1, '0', 'A', 3, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(209, 204, '203/204/209', 3, 1, 1, '0', 'A', 3, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(210, 204, '203/204/210', 3, 1, 1, '0', 'A', 4, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(213, 211, '203/211/213', 3, 1, 1, '0', 'A', 1, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(214, 211, '203/211/214', 3, 1, 1, '0', 'A', 3, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(215, 203, '203/215', 2, 1, 1, '0', 'A', 0, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(216, 215, '203/215/216', 3, 1, 1, '0', 'A', 3, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(217, 215, '203/215/217', 3, 1, 1, '0', 'A', 3, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(218, 215, '203/215/218', 3, 1, 1, '0', 'A', 2, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(219, 0, '219', 1, 1, 1, '0', 'D', 0, 40, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(220, 219, '219/220', 2, 1, 1, '0', 'A', 3, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(221, 219, '219/221', 2, 1, 1, '0', 'A', 3, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(222, 219, '219/222', 2, 1, 1, '0', 'A', 3, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(223, 0, '223', 1, 1, 1, '0', 'A', 0, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(224, 223, '223/224', 2, 1, 1, '0', 'A', 4, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(225, 223, '223/225', 2, 1, 1, '0', 'A', 6, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(226, 223, '223/226', 2, 1, 1, '0', 'A', 4, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'bigpicture_template', 0, 'N', 'N'),
(227, 223, '223/227', 2, 1, 1, '0', 'A', 5, 40, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(228, 0, '228', 1, 1, 1, '0', 'A', 0, 50, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(229, 228, '228/229', 2, 1, 1, '0', 'A', 3, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(230, 228, '228/230', 2, 1, 1, '0', 'A', 4, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(231, 228, '228/231', 2, 1, 1, '0', 'A', 2, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(232, 228, '228/232', 2, 1, 1, '0', 'A', 5, 40, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(234, 166, '166/234', 2, 1, 1, '0', 'A', 0, 40, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(235, 234, '166/234/235', 3, 1, 1, '0', 'A', 3, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(236, 234, '166/234/236', 3, 1, 1, '0', 'A', 5, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(237, 234, '166/234/237', 3, 1, 1, '0', 'A', 4, 50, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(238, 234, '166/234/238', 3, 1, 1, '0', 'A', 4, 40, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(240, 234, '166/234/240', 3, 1, 1, '0', 'A', 5, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(241, 0, '241', 1, 1, 1, '0', 'A', 0, 60, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(242, 241, '241/242', 2, 1, 1, '0', 'A', 5, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(243, 241, '241/243', 2, 1, 1, '0', 'A', 5, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(244, 241, '241/244', 2, 1, 1, '0', 'A', 4, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(245, 0, '245', 1, 1, 1, '0', 'A', 0, 70, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(246, 245, '245/246', 2, 1, 1, '0', 'A', 5, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(247, 245, '245/247', 2, 1, 1, '0', 'A', 4, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(248, 245, '245/248', 2, 1, 1, '0', 'A', 5, 40, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(249, 245, '245/249', 2, 1, 1, '0', 'A', 4, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(250, 0, '250', 1, 1, 1, '0', 'A', 0, 80, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(251, 250, '250/251', 2, 1, 1, '0', 'A', 3, 10, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(252, 250, '250/252', 2, 1, 1, '0', 'A', 5, 20, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(253, 250, '250/253', 2, 1, 1, '0', 'A', 3, 30, 1328475600, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(254, 166, '166/254', 2, 1, 1, '0', 'A', 0, 70, 1412280000, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(255, 263, '166/254/263/255', 4, 1, 1, '0', 'A', 1, 10, 1412601391, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N'),
(263, 254, '166/254/263', 3, 1, 1, '0', 'A', 0, 160, 1412539200, 'N', '', 'N', 0, 'N', 0, '', '', 'default', 0, 'N', 'N');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]category_descriptions`
--

CREATE TABLE `[[dbprefix]]category_descriptions` (
  `category_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `category` varchar(255) NOT NULL DEFAULT '',
  `description` mediumtext,
  `meta_keywords` varchar(255) NOT NULL DEFAULT '',
  `meta_description` varchar(255) NOT NULL DEFAULT '',
  `page_title` varchar(255) NOT NULL DEFAULT '',
  `age_warning_message` text,
  PRIMARY KEY (`category_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]category_descriptions`
--

INSERT INTO `[[dbprefix]]category_descriptions` VALUES
(165, 'en', 'Tablets', '', '', '', '', ''),
(166, 'en', 'Electronics', '', '', '', '', ''),
(167, 'en', 'Computers', '', '', '', '', ''),
(168, 'en', 'Desktops', '', '', '', '', ''),
(169, 'en', 'Laptops', '', '', '', '', ''),
(170, 'en', 'Monitors', '', '', '', '', ''),
(171, 'en', 'Networking', '', '', '', '', ''),
(172, 'en', 'Printers & Scanners', '', '', '', '', ''),
(174, 'en', 'TV & Video', '', '', '', '', ''),
(177, 'en', 'MP3 Players', '', '', '', '', ''),
(175, 'en', 'Car Electronics', '', '', '', '', ''),
(176, 'en', 'GPS & Navigation', '', '', '', '', ''),
(178, 'en', 'iPods', '', '', '', '', ''),
(179, 'en', 'MP3 Players', '', '', '', '', ''),
(180, 'en', 'MP3 Speaker Systems', '', '', '', '', ''),
(181, 'en', 'Headphones', '', '', '', '', ''),
(182, 'en', 'Android', '', '', '', '', ''),
(199, 'en', 'Camcorders', '', '', '', '', ''),
(185, 'en', 'In-Dash Stereos', '', '', '', '', ''),
(186, 'en', 'Speakers', '', '', '', '', ''),
(187, 'en', 'Amplifiers', '', '', '', '', ''),
(188, 'en', 'Car DVD & Video', '', '', '', '', ''),
(189, 'en', 'Radar Detectors', '', '', '', '', ''),
(190, 'en', 'LED TVs', '', '', '', '', ''),
(191, 'en', 'Plasma TVs', '', '', '', '', ''),
(194, 'en', 'DVD & Blu-ray Players', '', '', '', '', ''),
(193, 'en', '3D TVs', '', '', '', '', ''),
(195, 'en', 'Home Theater Systems', '', '', '', '', ''),
(196, 'en', 'Cameras & Photo', '', '', '', '', ''),
(197, 'en', 'DSLR Cameras', '', '', '', '', ''),
(198, 'en', 'Digital Cameras', '', '', '', '', ''),
(200, 'en', 'Lenses', '', '', '', '', ''),
(201, 'en', 'Processors', '', '', '', '', ''),
(202, 'en', 'Subwoofers', '', '', '', '', ''),
(203, 'en', 'Sports & Outdoors', '', '', '', '', ''),
(204, 'en', 'Bikes', '', '', '', '', ''),
(211, 'en', 'Golf', '', '', '', '', ''),
(208, 'en', 'Mountain Bikes', '', '', '', '', ''),
(209, 'en', 'Road Bikes', '', '', '', '', ''),
(210, 'en', 'Comfort & Cruisers', '', '', '', '', ''),
(212, 'en', 'Golf Clubs', '', '', '', '', ''),
(213, 'en', 'Golf Balls', '', '', '', '', ''),
(214, 'en', 'Golf Bags & Carts', '', '', '', '', ''),
(215, 'en', 'Camping', '', '', '', '', ''),
(216, 'en', 'Backpacks', '', '', '', '', ''),
(217, 'en', 'Sleeping Bags', '', '', '', '', ''),
(218, 'en', 'Tents', '', '', '', '', ''),
(219, 'en', 'Books', '', '', '', '', ''),
(220, 'en', 'Computing & Internet', '', '', '', '', ''),
(221, 'en', 'Education', '', '', '', '', ''),
(222, 'en', 'Business & Investing', '', '', '', '', ''),
(223, 'en', 'Apparel', '', '', '', '', ''),
(224, 'en', 'Men''s Clothing', '', '', '', '', ''),
(225, 'en', 'Women''s Clothing', '', '', '', '', ''),
(226, 'en', 'Shoes', '', '', '', '', ''),
(227, 'en', 'Watches & Jewelry', '', '', '', '', ''),
(228, 'en', 'Music', '', '', '', '', ''),
(229, 'en', 'Blues', '', '', '', '', ''),
(230, 'en', 'Classical', '', '', '', '', ''),
(231, 'en', 'Jazz', '', '', '', '', ''),
(232, 'en', 'Rock', '', '', '', '', ''),
(234, 'en', 'Cell Phones', '', '', '', '', ''),
(235, 'en', 'Apple iPhone', '', '', '', '', ''),
(236, 'en', 'HTC', '', '', '', '', ''),
(237, 'en', 'Samsung', '', '', '', '', ''),
(238, 'en', 'Nokia', '', '', '', '', ''),
(240, 'en', 'Motorola', '', '', '', '', ''),
(241, 'en', 'Movies & TV', '', '', '', '', ''),
(242, 'en', 'Blu-ray Discs', '', '', '', '', ''),
(243, 'en', 'Movies (DVD)', '', '', '', '', ''),
(244, 'en', 'TV Shows (DVD)', '', '', '', '', ''),
(245, 'en', 'Video Games', '', '', '', '', ''),
(246, 'en', 'Nintendo Wii', '', '', '', '', ''),
(247, 'en', 'PlayStation 3', '', '', '', '', ''),
(248, 'en', 'X-Box One', '', '', '', '', ''),
(249, 'en', 'PlayStation Vita', '', '', '', '', ''),
(250, 'en', 'Office Supplies', '', '', '', '', ''),
(251, 'en', 'Calculators', '', '', '', '', ''),
(252, 'en', 'Desk Accessories', '', '', '', '', ''),
(253, 'en', 'Safes', '', '', '', '', ''),
(254, 'en', 'Game consoles', '', '', '', '', ''),
(255, 'en', 'Microsoft', '', '', '', '', ''),
(263, 'en', 'Consoles', '', '', '', '', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]common_descriptions`
--

CREATE TABLE `[[dbprefix]]common_descriptions` (
  `object_id` int(11) unsigned NOT NULL DEFAULT '0',
  `object_type` varchar(32) NOT NULL DEFAULT '',
  `description` mediumtext,
  `lang_code` char(2) NOT NULL DEFAULT '',
  `object` varchar(128) NOT NULL DEFAULT '',
  `object_holder` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`object_id`,`lang_code`,`object_holder`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]common_descriptions`
--

INSERT INTO `[[dbprefix]]common_descriptions` VALUES
(2, '', '', 'en', 'My account', 'sitemap_sections'),
(1, '', 'View cart', 'en', 'View cart', 'sitemap_links'),
(2, '', 'Wish List', 'en', 'Wish List', 'sitemap_links'),
(3, '', 'Checkout', 'en', 'Checkout', 'sitemap_links'),
(4, '', 'Edit profile', 'en', 'Edit profile', 'sitemap_links'),
(11, '', 'Fourth affiliate plan description.', 'en', 'Test plan', 'affiliate_plans'),
(1, '', 'Branding', 'en', '', 'quick_menu'),
(2, '', 'Legal documents', 'en', '', 'quick_menu'),
(4, '', 'Checkout', 'en', '', 'quick_menu'),
(5, '', 'Logo', 'en', '', 'quick_menu'),
(6, '', 'Company & contacts', 'en', '', 'quick_menu'),
(7, '', 'Theme colors & fonts', 'en', '', 'quick_menu'),
(8, '', 'Terms for customers', 'en', '', 'quick_menu'),
(9, '', 'Privacy policy', 'en', '', 'quick_menu'),
(10, '', 'GDPR', 'en', '', 'quick_menu'),
(11, '', 'Returns and exchanges', 'en', '', 'quick_menu'),
(19, '', 'Structure and fields', 'en', '', 'quick_menu'),
(20, '', 'Extra fields', 'en', '', 'quick_menu'),
(21, '', 'Payment methods', 'en', '', 'quick_menu'),
(22, '', 'Shipping methods', 'en', '', 'quick_menu'),
(23, '', 'Taxes', 'en', '', 'quick_menu'),
(180, '', 'men_clothes.jpg', 'en', '', 'images'),
(181, '', 'w-phones_cat.gif', 'en', '', 'images'),
(182, '', '100009923665.gif', 'en', '', 'images'),
(183, '', 'audio_video.gif', 'en', '', 'images'),
(184, '', 'computes.gif', 'en', '', 'images'),
(185, '', 'pc-desktops-sony_cat.jpg', 'en', '', 'images'),
(186, '', 'dvds.gif', 'en', '', 'images'),
(187, '', 'books.jpg', 'en', '', 'images'),
(188, '', 'music.gif', 'en', '', 'images'),
(189, '', 'build_your_pc.jpg', 'en', '', 'images'),
(190, '', 'special_offer_ads.gif', 'en', '', 'images'),
(191, '', 'thumbnail_B000068IG9.01._SCMZZZZZZZ_.jpg', 'en', '', 'images'),
(192, '', 'modems.jpg', 'en', '', 'images'),
(193, '', 'tjpg', 'en', '', 'images'),
(194, '', 'ujpg', 'en', '', 'images'),
(195, '', 'group_ddr_memory.jpg', 'en', '', 'images'),
(196, '', 'group_laser_printers.jpg', 'en', '', 'images'),
(197, '', 'tjpg', 'en', '', 'images'),
(198, '', 'ujpg', 'en', '', 'images'),
(199, '', 'tjpg', 'en', '', 'images'),
(200, '', 'ujpg', 'en', '', 'images'),
(237, '', '', 'en', '', 'images'),
(238, '', '', 'en', '', 'images'),
(239, '', '', 'en', '', 'images'),
(240, '', '', 'en', '', 'images'),
(243, '', '', 'en', '', 'images'),
(244, '', '', 'en', '', 'images'),
(245, '', '', 'en', '', 'images'),
(246, '', '', 'en', '', 'images'),
(247, '', '', 'en', '', 'images'),
(248, '', '', 'en', '', 'images'),
(249, '', '', 'en', '', 'images'),
(250, '', '', 'en', '', 'images'),
(251, '', '', 'en', '', 'images'),
(252, '', '', 'en', '', 'images'),
(254, '', '', 'en', '', 'images'),
(255, '', '', 'en', '', 'images'),
(256, '', '', 'en', '', 'images'),
(257, '', '', 'en', '', 'images'),
(258, '', '', 'en', '', 'images'),
(259, '', '', 'en', '', 'images'),
(260, '', '', 'en', '', 'images'),
(261, '', '', 'en', '', 'images'),
(262, '', '', 'en', '', 'images'),
(263, '', '', 'en', '', 'images'),
(264, '', '', 'en', '', 'images'),
(265, '', '', 'en', '', 'images'),
(266, '', '', 'en', '', 'images'),
(267, '', '', 'en', '', 'images'),
(268, '', '', 'en', '', 'images'),
(269, '', '', 'en', '', 'images'),
(270, '', '', 'en', '', 'images'),
(271, '', '', 'en', '', 'images'),
(274, '', '', 'en', '', 'images'),
(275, '', '', 'en', '', 'images'),
(276, '', '', 'en', '', 'images'),
(277, '', '', 'en', '', 'images'),
(278, '', '', 'en', '', 'images'),
(279, '', '', 'en', '', 'images'),
(280, '', '', 'en', '', 'images'),
(281, '', '', 'en', '', 'images'),
(282, '', '', 'en', '', 'images'),
(283, '', '', 'en', '', 'images'),
(284, '', '', 'en', '', 'images'),
(285, '', '', 'en', '', 'images'),
(286, '', '', 'en', '', 'images'),
(287, '', '', 'en', '', 'images'),
(288, '', '', 'en', '', 'images'),
(289, '', '', 'en', '', 'images'),
(290, '', '', 'en', '', 'images'),
(291, '', '', 'en', '', 'images'),
(292, '', '', 'en', '', 'images'),
(293, '', '', 'en', '', 'images'),
(294, '', '', 'en', '', 'images'),
(295, '', '', 'en', '', 'images'),
(296, '', '', 'en', '', 'images'),
(297, '', '', 'en', '', 'images'),
(298, '', '', 'en', '', 'images'),
(299, '', '', 'en', '', 'images'),
(300, '', '', 'en', '', 'images'),
(301, '', '', 'en', '', 'images'),
(302, '', '', 'en', '', 'images'),
(303, '', '', 'en', '', 'images'),
(304, '', '', 'en', '', 'images'),
(305, '', '', 'en', '', 'images'),
(306, '', '', 'en', '', 'images'),
(307, '', '', 'en', '', 'images'),
(308, '', '', 'en', '', 'images'),
(309, '', '', 'en', '', 'images'),
(310, '', '', 'en', '', 'images'),
(311, '', '', 'en', '', 'images'),
(312, '', '', 'en', '', 'images'),
(313, '', '', 'en', '', 'images'),
(314, '', '', 'en', '', 'images'),
(315, '', '', 'en', '', 'images'),
(316, '', '', 'en', '', 'images'),
(317, '', '', 'en', '', 'images'),
(318, '', '', 'en', '', 'images'),
(319, '', '', 'en', '', 'images'),
(320, '', '', 'en', '', 'images'),
(321, '', '', 'en', '', 'images'),
(322, '', '', 'en', '', 'images'),
(323, '', '', 'en', '', 'images'),
(324, '', '', 'en', '', 'images'),
(325, '', '', 'en', '', 'images'),
(327, '', '', 'en', '', 'images'),
(328, '', '', 'en', '', 'images'),
(329, '', '', 'en', '', 'images'),
(330, '', '', 'en', '', 'images'),
(331, '', '', 'en', '', 'images'),
(332, '', '', 'en', '', 'images'),
(333, '', '', 'en', '', 'images'),
(334, '', '', 'en', '', 'images'),
(335, '', '', 'en', '', 'images'),
(336, '', '', 'en', '', 'images'),
(337, '', '', 'en', '', 'images'),
(338, '', '', 'en', '', 'images'),
(339, '', '', 'en', '', 'images'),
(340, '', '', 'en', '', 'images'),
(341, '', '', 'en', '', 'images'),
(342, '', '', 'en', '', 'images'),
(343, '', '', 'en', '', 'images'),
(344, '', '', 'en', '', 'images'),
(345, '', '', 'en', '', 'images'),
(346, '', '', 'en', '', 'images'),
(347, '', '', 'en', '', 'images'),
(348, '', '', 'en', '', 'images'),
(349, '', '', 'en', '', 'images'),
(350, '', '', 'en', '', 'images'),
(351, '', '', 'en', '', 'images'),
(352, '', '', 'en', '', 'images'),
(353, '', '', 'en', '', 'images'),
(354, '', '', 'en', '', 'images'),
(355, '', '', 'en', '', 'images'),
(356, '', '', 'en', '', 'images'),
(357, '', '', 'en', '', 'images'),
(358, '', '', 'en', '', 'images'),
(359, '', '', 'en', '', 'images'),
(360, '', '', 'en', '', 'images'),
(361, '', '', 'en', '', 'images'),
(362, '', '', 'en', '', 'images'),
(363, '', '', 'en', '', 'images'),
(364, '', '', 'en', '', 'images'),
(365, '', '', 'en', '', 'images'),
(366, '', '', 'en', '', 'images'),
(367, '', '', 'en', '', 'images'),
(368, '', '', 'en', '', 'images'),
(369, '', '', 'en', '', 'images'),
(370, '', '', 'en', '', 'images'),
(371, '', '', 'en', '', 'images'),
(372, '', '', 'en', '', 'images'),
(373, '', '', 'en', '', 'images'),
(374, '', '', 'en', '', 'images'),
(375, '', '', 'en', '', 'images'),
(376, '', '', 'en', '', 'images'),
(377, '', '', 'en', '', 'images'),
(378, '', '', 'en', '', 'images'),
(379, '', '', 'en', '', 'images'),
(380, '', '', 'en', '', 'images'),
(381, '', '', 'en', '', 'images'),
(382, '', '', 'en', '', 'images'),
(383, '', '', 'en', '', 'images'),
(384, '', '', 'en', '', 'images'),
(385, '', '', 'en', '', 'images'),
(386, '', '', 'en', '', 'images'),
(390, '', '', 'en', '', 'images'),
(391, '', '', 'en', '', 'images'),
(392, '', '', 'en', '', 'images'),
(393, '', '', 'en', '', 'images'),
(394, '', '', 'en', '', 'images'),
(395, '', '', 'en', '', 'images'),
(396, '', '', 'en', '', 'images'),
(397, '', '', 'en', '', 'images'),
(398, '', '', 'en', '', 'images'),
(399, '', '', 'en', '', 'images'),
(400, '', '', 'en', '', 'images'),
(401, '', '', 'en', '', 'images'),
(402, '', '', 'en', '', 'images'),
(403, '', '', 'en', '', 'images'),
(404, '', '', 'en', '', 'images'),
(405, '', '', 'en', '', 'images'),
(406, '', '', 'en', '', 'images'),
(407, '', '', 'en', '', 'images'),
(408, '', '', 'en', '', 'images'),
(409, '', '', 'en', '', 'images'),
(410, '', '', 'en', '', 'images'),
(411, '', '', 'en', '', 'images'),
(412, '', '', 'en', '', 'images'),
(413, '', '', 'en', '', 'images'),
(414, '', '', 'en', '', 'images'),
(415, '', '', 'en', '', 'images'),
(416, '', '', 'en', '', 'images'),
(417, '', '', 'en', '', 'images'),
(418, '', '', 'en', '', 'images'),
(419, '', '', 'en', '', 'images'),
(420, '', '', 'en', '', 'images'),
(421, '', '', 'en', '', 'images'),
(422, '', '', 'en', '', 'images'),
(423, '', '', 'en', '', 'images'),
(424, '', '', 'en', '', 'images'),
(425, '', '', 'en', '', 'images'),
(426, '', '', 'en', '', 'images'),
(427, '', '', 'en', '', 'images'),
(428, '', '', 'en', '', 'images'),
(429, '', '', 'en', '', 'images'),
(430, '', '', 'en', '', 'images'),
(431, '', '', 'en', '', 'images'),
(432, '', '', 'en', '', 'images'),
(433, '', '', 'en', '', 'images'),
(434, '', '', 'en', '', 'images'),
(435, '', '', 'en', '', 'images'),
(436, '', '', 'en', '', 'images'),
(437, '', '', 'en', '', 'images'),
(438, '', '', 'en', '', 'images'),
(439, '', '', 'en', '', 'images'),
(440, '', '', 'en', '', 'images'),
(441, '', '', 'en', '', 'images'),
(442, '', '', 'en', '', 'images'),
(443, '', '', 'en', '', 'images'),
(444, '', '', 'en', '', 'images'),
(445, '', '', 'en', '', 'images'),
(446, '', '', 'en', '', 'images'),
(447, '', '', 'en', '', 'images'),
(522, '', '', 'en', '', 'images'),
(525, '', '', 'en', '', 'images'),
(524, '', '', 'en', '', 'images'),
(523, '', '', 'en', '', 'images'),
(453, '', '', 'en', '', 'images'),
(454, '', '', 'en', '', 'images'),
(455, '', '', 'en', '', 'images'),
(456, '', '', 'en', '', 'images'),
(457, '', '', 'en', '', 'images'),
(458, '', '', 'en', '', 'images'),
(459, '', '', 'en', '', 'images'),
(460, '', '', 'en', '', 'images'),
(461, '', '', 'en', '', 'images'),
(462, '', '', 'en', '', 'images'),
(463, '', '', 'en', '', 'images'),
(464, '', '', 'en', '', 'images'),
(465, '', '', 'en', '', 'images'),
(466, '', '', 'en', '', 'images'),
(467, '', '', 'en', '', 'images'),
(468, '', '', 'en', '', 'images'),
(469, '', '', 'en', '', 'images'),
(470, '', '', 'en', '', 'images'),
(471, '', '', 'en', '', 'images'),
(510, '', '', 'en', '', 'images'),
(473, '', '', 'en', '', 'images'),
(474, '', '', 'en', '', 'images'),
(475, '', '', 'en', '', 'images'),
(476, '', '', 'en', '', 'images'),
(477, '', '', 'en', '', 'images'),
(478, '', '', 'en', '', 'images'),
(479, '', '', 'en', '', 'images'),
(480, '', '', 'en', '', 'images'),
(481, '', '', 'en', '', 'images'),
(482, '', '', 'en', '', 'images'),
(483, '', '', 'en', '', 'images'),
(484, '', '', 'en', '', 'images'),
(485, '', '', 'en', '', 'images'),
(486, '', '', 'en', '', 'images'),
(487, '', '', 'en', '', 'images'),
(488, '', '', 'en', '', 'images'),
(489, '', '', 'en', '', 'images'),
(511, '', '', 'en', '', 'images'),
(491, '', '', 'en', '', 'images'),
(514, '', '', 'en', '', 'images'),
(495, '', '', 'en', '', 'images'),
(516, '', '', 'en', '', 'images'),
(515, '', '', 'en', '', 'images'),
(498, '', '', 'en', '', 'images'),
(513, '', '', 'en', '', 'images'),
(500, '', '', 'en', '', 'images'),
(501, '', '', 'en', '', 'images'),
(502, '', '', 'en', '', 'images'),
(503, '', '', 'en', '', 'images'),
(504, '', '', 'en', '', 'images'),
(518, '', '', 'en', '', 'images'),
(517, '', '', 'en', '', 'images'),
(507, '', '', 'en', '', 'images'),
(508, '', '', 'en', '', 'images'),
(509, '', '', 'en', '', 'images'),
(512, '', '', 'en', '', 'images'),
(519, '', '', 'en', '', 'images'),
(520, '', '', 'en', '', 'images'),
(521, '', '', 'en', '', 'images'),
(526, '', '', 'en', '', 'images'),
(527, '', '', 'en', '', 'images'),
(528, '', '', 'en', '', 'images'),
(529, '', '', 'en', '', 'images'),
(530, '', '', 'en', '', 'images'),
(531, '', '', 'en', '', 'images'),
(532, '', '', 'en', '', 'images'),
(533, '', '', 'en', '', 'images'),
(534, '', '', 'en', '', 'images'),
(535, '', '', 'en', '', 'images'),
(536, '', '', 'en', '', 'images'),
(537, '', '', 'en', '', 'images'),
(538, '', '', 'en', '', 'images'),
(539, '', '', 'en', '', 'images'),
(540, '', '', 'en', '', 'images'),
(541, '', '', 'en', '', 'images'),
(542, '', '', 'en', '', 'images'),
(543, '', '', 'en', '', 'images'),
(544, '', '', 'en', '', 'images'),
(545, '', '', 'en', '', 'images'),
(546, '', '', 'en', '', 'images'),
(547, '', '', 'en', '', 'images'),
(548, '', '', 'en', '', 'images'),
(549, '', '', 'en', '', 'images'),
(550, '', '', 'en', '', 'images'),
(551, '', '', 'en', '', 'images'),
(552, '', '', 'en', '', 'images'),
(553, '', '', 'en', '', 'images'),
(554, '', '', 'en', '', 'images'),
(555, '', '', 'en', '', 'images'),
(556, '', '', 'en', '', 'images'),
(557, '', '', 'en', '', 'images'),
(558, '', '', 'en', '', 'images'),
(559, '', '', 'en', '', 'images'),
(560, '', '', 'en', '', 'images'),
(561, '', '', 'en', '', 'images'),
(562, '', '', 'en', '', 'images'),
(563, '', '', 'en', '', 'images'),
(572, '', '', 'en', '', 'images'),
(565, '', '', 'en', '', 'images'),
(566, '', '', 'en', '', 'images'),
(567, '', '', 'en', '', 'images'),
(568, '', '', 'en', '', 'images'),
(569, '', '', 'en', '', 'images'),
(570, '', '', 'en', '', 'images'),
(571, '', '', 'en', '', 'images'),
(573, '', '', 'en', '', 'images'),
(574, '', '', 'en', '', 'images'),
(575, '', '', 'en', '', 'images'),
(576, '', '', 'en', '', 'images'),
(577, '', '', 'en', '', 'images'),
(578, '', '', 'en', '', 'images'),
(579, '', '', 'en', '', 'images'),
(580, '', '', 'en', '', 'images'),
(581, '', '', 'en', '', 'images'),
(582, '', '', 'en', '', 'images'),
(583, '', '', 'en', '', 'images'),
(584, '', '', 'en', '', 'images'),
(585, '', '', 'en', '', 'images'),
(586, '', '', 'en', '', 'images'),
(587, '', '', 'en', '', 'images'),
(588, '', '', 'en', '', 'images'),
(589, '', '', 'en', '', 'images'),
(590, '', '', 'en', '', 'images'),
(591, '', '', 'en', '', 'images'),
(592, '', '', 'en', '', 'images'),
(593, '', '', 'en', '', 'images'),
(594, '', '', 'en', '', 'images'),
(595, '', '', 'en', '', 'images'),
(596, '', '', 'en', '', 'images'),
(597, '', '', 'en', '', 'images'),
(598, '', '', 'en', '', 'images'),
(599, '', '', 'en', '', 'images'),
(600, '', '', 'en', '', 'images'),
(601, '', '', 'en', '', 'images'),
(602, '', '', 'en', '', 'images'),
(603, '', '', 'en', '', 'images'),
(604, '', '', 'en', '', 'images'),
(605, '', '', 'en', '', 'images'),
(606, '', '', 'en', '', 'images'),
(607, '', '', 'en', '', 'images'),
(608, '', '', 'en', '', 'images'),
(609, '', '', 'en', '', 'images'),
(610, '', '', 'en', '', 'images'),
(611, '', '', 'en', '', 'images'),
(612, '', '', 'en', '', 'images'),
(613, '', '', 'en', '', 'images'),
(614, '', '', 'en', '', 'images'),
(615, '', '', 'en', '', 'images'),
(616, '', '', 'en', '', 'images'),
(617, '', '', 'en', '', 'images'),
(618, '', '', 'en', '', 'images'),
(619, '', '', 'en', '', 'images'),
(620, '', '', 'en', '', 'images'),
(621, '', '', 'en', '', 'images'),
(622, '', '', 'en', '', 'images'),
(623, '', '', 'en', '', 'images'),
(624, '', '', 'en', '', 'images'),
(625, '', '', 'en', '', 'images'),
(626, '', '', 'en', '', 'images'),
(627, '', '', 'en', '', 'images'),
(628, '', '', 'en', '', 'images'),
(629, '', '', 'en', '', 'images'),
(630, '', '', 'en', '', 'images'),
(631, '', '', 'en', '', 'images'),
(632, '', '', 'en', '', 'images'),
(633, '', '', 'en', '', 'images'),
(634, '', '', 'en', '', 'images'),
(635, '', '', 'en', '', 'images'),
(636, '', '', 'en', '', 'images'),
(637, '', '', 'en', '', 'images'),
(638, '', '', 'en', '', 'images'),
(639, '', '', 'en', '', 'images'),
(640, '', '', 'en', '', 'images'),
(641, '', '', 'en', '', 'images'),
(642, '', '', 'en', '', 'images'),
(643, '', '', 'en', '', 'images'),
(644, '', '', 'en', '', 'images'),
(645, '', '', 'en', '', 'images'),
(646, '', '', 'en', '', 'images'),
(647, '', '', 'en', '', 'images'),
(648, '', '', 'en', '', 'images'),
(649, '', '', 'en', '', 'images'),
(650, '', '', 'en', '', 'images'),
(651, '', '', 'en', '', 'images'),
(652, '', '', 'en', '', 'images'),
(653, '', '', 'en', '', 'images'),
(654, '', '', 'en', '', 'images'),
(655, '', '', 'en', '', 'images'),
(656, '', '', 'en', '', 'images'),
(657, '', '', 'en', '', 'images'),
(658, '', '', 'en', '', 'images'),
(659, '', '', 'en', '', 'images'),
(660, '', '', 'en', '', 'images'),
(661, '', '', 'en', '', 'images'),
(662, '', '', 'en', '', 'images'),
(663, '', '', 'en', '', 'images'),
(664, '', '', 'en', '', 'images'),
(665, '', '', 'en', '', 'images'),
(666, '', '', 'en', '', 'images'),
(667, '', '', 'en', '', 'images'),
(668, '', '', 'en', '', 'images'),
(669, '', '', 'en', '', 'images'),
(670, '', '', 'en', '', 'images'),
(671, '', '', 'en', '', 'images'),
(672, '', '', 'en', '', 'images'),
(673, '', '', 'en', '', 'images'),
(674, '', '', 'en', '', 'images'),
(675, '', '', 'en', '', 'images'),
(676, '', '', 'en', '', 'images'),
(677, '', '', 'en', '', 'images'),
(678, '', '', 'en', '', 'images'),
(679, '', '', 'en', '', 'images'),
(680, '', '', 'en', '', 'images'),
(681, '', '', 'en', '', 'images'),
(682, '', '', 'en', '', 'images'),
(683, '', '', 'en', '', 'images'),
(684, '', '', 'en', '', 'images'),
(685, '', '', 'en', '', 'images'),
(686, '', '', 'en', '', 'images'),
(687, '', '', 'en', '', 'images'),
(688, '', '', 'en', '', 'images'),
(689, '', '', 'en', '', 'images'),
(690, '', '', 'en', '', 'images'),
(691, '', '', 'en', '', 'images'),
(692, '', '', 'en', '', 'images'),
(693, '', '', 'en', '', 'images'),
(694, '', '', 'en', '', 'images'),
(695, '', '', 'en', '', 'images'),
(696, '', '', 'en', '', 'images'),
(697, '', '', 'en', '', 'images'),
(698, '', '', 'en', '', 'images'),
(699, '', '', 'en', '', 'images'),
(700, '', '', 'en', '', 'images'),
(701, '', '', 'en', '', 'images'),
(702, '', '', 'en', '', 'images'),
(703, '', '', 'en', '', 'images'),
(704, '', '', 'en', '', 'images'),
(705, '', '', 'en', '', 'images'),
(706, '', '', 'en', '', 'images'),
(707, '', '', 'en', '', 'images'),
(708, '', '', 'en', '', 'images'),
(709, '', '', 'en', '', 'images'),
(710, '', '', 'en', '', 'images'),
(711, '', '', 'en', '', 'images'),
(712, '', '', 'en', '', 'images'),
(713, '', '', 'en', '', 'images'),
(714, '', '', 'en', '', 'images'),
(715, '', '', 'en', '', 'images'),
(716, '', '', 'en', '', 'images'),
(717, '', '', 'en', '', 'images'),
(718, '', '', 'en', '', 'images'),
(719, '', '', 'en', '', 'images'),
(720, '', '', 'en', '', 'images'),
(721, '', '', 'en', '', 'images'),
(722, '', '', 'en', '', 'images'),
(723, '', '', 'en', '', 'images'),
(724, '', '', 'en', '', 'images'),
(725, '', '', 'en', '', 'images'),
(739, '', '', 'en', '', 'images'),
(727, '', '', 'en', '', 'images'),
(728, '', '', 'en', '', 'images'),
(729, '', '', 'en', '', 'images'),
(730, '', '', 'en', '', 'images'),
(731, '', '', 'en', '', 'images'),
(732, '', '', 'en', '', 'images'),
(733, '', '', 'en', '', 'images'),
(734, '', '', 'en', '', 'images'),
(735, '', '', 'en', '', 'images'),
(736, '', '', 'en', '', 'images'),
(737, '', '', 'en', '', 'images'),
(738, '', '', 'en', '', 'images'),
(740, '', '', 'en', '', 'images'),
(741, '', '', 'en', '', 'images'),
(742, '', '', 'en', '', 'images'),
(743, '', '', 'en', '', 'images'),
(744, '', '', 'en', '', 'images'),
(745, '', '', 'en', '', 'images'),
(746, '', '', 'en', '', 'images'),
(747, '', '', 'en', '', 'images'),
(748, '', '', 'en', '', 'images'),
(749, '', '', 'en', '', 'images'),
(750, '', '', 'en', '', 'images'),
(751, '', '', 'en', '', 'images'),
(752, '', '', 'en', '', 'images'),
(753, '', '', 'en', '', 'images'),
(754, '', '', 'en', '', 'images'),
(755, '', '', 'en', '', 'images'),
(756, '', '', 'en', '', 'images'),
(757, '', '', 'en', '', 'images'),
(758, '', '', 'en', '', 'images'),
(759, '', '', 'en', '', 'images'),
(760, '', '', 'en', '', 'images'),
(761, '', '', 'en', '', 'images'),
(762, '', '', 'en', '', 'images'),
(763, '', '', 'en', '', 'images'),
(764, '', '', 'en', '', 'images'),
(765, '', '', 'en', '', 'images'),
(766, '', '', 'en', '', 'images'),
(767, '', '', 'en', '', 'images'),
(768, '', '', 'en', '', 'images'),
(769, '', '', 'en', '', 'images'),
(833, '', '', 'en', '', 'images'),
(771, '', '', 'en', '', 'images'),
(772, '', '', 'en', '', 'images'),
(773, '', '', 'en', '', 'images'),
(774, '', '', 'en', '', 'images'),
(775, '', '', 'en', '', 'images'),
(776, '', '', 'en', '', 'images'),
(777, '', '', 'en', '', 'images'),
(778, '', '', 'en', '', 'images'),
(779, '', '', 'en', '', 'images'),
(780, '', '', 'en', '', 'images'),
(781, '', '', 'en', '', 'images'),
(782, '', '', 'en', '', 'images'),
(783, '', '', 'en', '', 'images'),
(784, '', '', 'en', '', 'images'),
(785, '', '', 'en', '', 'images'),
(786, '', '', 'en', '', 'images'),
(787, '', '', 'en', '', 'images'),
(788, '', '', 'en', '', 'images'),
(789, '', '', 'en', '', 'images'),
(790, '', '', 'en', '', 'images'),
(791, '', '', 'en', '', 'images'),
(792, '', '', 'en', '', 'images'),
(793, '', '', 'en', '', 'images'),
(794, '', '', 'en', '', 'images'),
(795, '', '', 'en', '', 'images'),
(796, '', '', 'en', '', 'images'),
(797, '', '', 'en', '', 'images'),
(798, '', '', 'en', '', 'images'),
(799, '', '', 'en', '', 'images'),
(800, '', '', 'en', '', 'images'),
(801, '', '', 'en', '', 'images'),
(802, '', '', 'en', '', 'images'),
(803, '', '', 'en', '', 'images'),
(804, '', '', 'en', '', 'images'),
(805, '', '', 'en', '', 'images'),
(806, '', '', 'en', '', 'images'),
(807, '', '', 'en', '', 'images'),
(808, '', '', 'en', '', 'images'),
(809, '', '', 'en', '', 'images'),
(810, '', '', 'en', '', 'images'),
(811, '', '', 'en', '', 'images'),
(812, '', '', 'en', '', 'images'),
(813, '', '', 'en', '', 'images'),
(814, '', '', 'en', '', 'images'),
(815, '', '', 'en', '', 'images'),
(816, '', '', 'en', '', 'images'),
(817, '', '', 'en', '', 'images'),
(818, '', '', 'en', '', 'images'),
(819, '', '', 'en', '', 'images'),
(820, '', '', 'en', '', 'images'),
(821, '', '', 'en', '', 'images'),
(822, '', '', 'en', '', 'images'),
(823, '', '', 'en', '', 'images'),
(824, '', '', 'en', '', 'images'),
(825, '', '', 'en', '', 'images'),
(826, '', '', 'en', '', 'images'),
(827, '', '', 'en', '', 'images'),
(828, '', '', 'en', '', 'images'),
(829, '', '', 'en', '', 'images'),
(830, '', '', 'en', '', 'images'),
(831, '', '', 'en', '', 'images'),
(832, '', '', 'en', '', 'images'),
(834, '', '', 'en', '', 'images'),
(835, '', '', 'en', '', 'images'),
(836, '', '', 'en', '', 'images'),
(837, '', '', 'en', '', 'images'),
(838, '', '', 'en', '', 'images'),
(839, '', '', 'en', '', 'images'),
(840, '', '', 'en', '', 'images'),
(841, '', '', 'en', '', 'images'),
(842, '', '', 'en', '', 'images'),
(843, '', '', 'en', '', 'images'),
(844, '', '', 'en', '', 'images'),
(845, '', '', 'en', '', 'images'),
(846, '', '', 'en', '', 'images'),
(847, '', '', 'en', '', 'images'),
(848, '', '', 'en', '', 'images'),
(849, '', '', 'en', '', 'images'),
(850, '', '', 'en', '', 'images'),
(851, '', '', 'en', '', 'images'),
(852, '', '', 'en', '', 'images'),
(853, '', '', 'en', '', 'images'),
(854, '', '', 'en', '', 'images'),
(855, '', '', 'en', '', 'images'),
(856, '', '', 'en', '', 'images'),
(857, '', '', 'en', '', 'images'),
(858, '', '', 'en', '', 'images'),
(862, '', '', 'en', '', 'images'),
(861, '', '', 'en', '', 'images'),
(863, '', '', 'en', '', 'images'),
(879, '', '', 'en', '', 'images'),
(898, '', '', 'en', '', 'images'),
(881, '', '', 'en', '', 'images'),
(882, '', '', 'en', '', 'images'),
(905, '', '', 'en', '', 'images'),
(906, '', '', 'en', '', 'images'),
(908, '', '', 'en', '', 'images'),
(909, '', '', 'en', '', 'images'),
(904, '', '', 'en', '', 'images'),
(907, '', '', 'en', '', 'images'),
(926, '', '', 'en', '', 'images'),
(1006, '', '', 'en', '', 'images'),
(1007, '', '', 'en', '', 'images'),
(1008, '', '', 'en', '', 'images'),
(1009, '', '', 'en', '', 'images'),
(1010, '', '', 'en', '', 'images'),
(1011, '', '', 'en', '', 'images'),
(1012, '', '', 'en', '', 'images'),
(1013, '', '', 'en', '', 'images'),
(1014, '', '', 'en', '', 'images'),
(1015, '', '', 'en', '', 'images'),
(1016, '', '', 'en', '', 'images'),
(1017, '', '', 'en', '', 'images'),
(1018, '', '', 'en', '', 'images'),
(1019, '', '', 'en', '', 'images'),
(1020, '', '', 'en', '', 'images'),
(1021, '', '', 'en', '', 'images'),
(1022, '', '', 'en', '', 'images'),
(1023, '', '', 'en', '', 'images'),
(1024, '', '', 'en', '', 'images'),
(1025, '', '', 'en', '', 'images'),
(1026, '', '', 'en', '', 'images'),
(1027, '', '', 'en', '', 'images'),
(1028, '', '', 'en', '', 'images'),
(1029, '', '', 'en', '', 'images'),
(1030, '', '', 'en', '', 'images'),
(1031, '', '', 'en', '', 'images'),
(1032, '', '', 'en', '', 'images'),
(1033, '', '', 'en', '', 'images'),
(1034, '', '', 'en', '', 'images'),
(1035, '', '', 'en', '', 'images'),
(1036, '', '', 'en', '', 'images'),
(1037, '', '', 'en', '', 'images'),
(1038, '', '', 'en', '', 'images'),
(1039, '', '', 'en', '', 'images'),
(1040, '', '', 'en', '', 'images'),
(1041, '', '', 'en', '', 'images'),
(1042, '', '', 'en', '', 'images'),
(1043, '', '', 'en', '', 'images'),
(1044, '', '', 'en', '', 'images'),
(1045, '', '', 'en', '', 'images'),
(1046, '', '', 'en', '', 'images'),
(1047, '', '', 'en', '', 'images'),
(1048, '', '', 'en', '', 'images'),
(1051, '', '', 'en', '', 'images'),
(1052, '', '', 'en', '', 'images'),
(1053, '', '', 'en', '', 'images'),
(1054, '', '', 'en', '', 'images'),
(1055, '', '', 'en', '', 'images'),
(1, '', '', 'en', 'Company news and unique discounts for subscribers', 'mailing_lists'),
(8649, '', '', 'en', '', 'images'),
(8650, '', '', 'en', '', 'images'),
(8651, '', '', 'en', '', 'images');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]companies`
--

CREATE TABLE `[[dbprefix]]companies` (
  `company_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `status` char(1) NOT NULL DEFAULT 'A',
  `company` varchar(255) NOT NULL,
  `lang_code` char(2) NOT NULL DEFAULT '',
  `address` varchar(255) NOT NULL,
  `city` varchar(64) NOT NULL,
  `state` varchar(32) NOT NULL,
  `country` char(2) NOT NULL,
  `zipcode` varchar(16) NOT NULL,
  `email` varchar(128) NOT NULL,
  `phone` varchar(128) NOT NULL,
  `url` varchar(128) NOT NULL,
  `storefront` varchar(255) NOT NULL DEFAULT '',
  `secure_storefront` varchar(255) NOT NULL DEFAULT '',
  `entry_page` varchar(50) NOT NULL DEFAULT 'none',
  `redirect_customer` char(1) NOT NULL DEFAULT 'Y',
  `countries_list` text,
  `timestamp` int(11) NOT NULL,
  `shippings` text,
  `logos` text,
  `request_user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `request_account_name` varchar(255) NOT NULL DEFAULT '',
  `request_account_data` blob,
  PRIMARY KEY (`company_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]companies`
--

INSERT INTO `[[dbprefix]]companies` VALUES
(1, 'A', 'CS-Cart', 'en', 'Boston street', 'Boston', 'MA', 'US', '02125', 'cs-cart@example.com', '+16175556985', 'http://example.com', '[[domhost]][[relativeurl]]', '[[domhost]][[relativeurl]]', 'none', 'Y', NULL, 1269610461, '1', '', 0, '', NULL);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]company_descriptions`
--

CREATE TABLE `[[dbprefix]]company_descriptions` (
  `company_id` int(11) unsigned NOT NULL,
  `lang_code` char(2) NOT NULL,
  `company_description` text,
  PRIMARY KEY (`company_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]countries`
--

CREATE TABLE `[[dbprefix]]countries` (
  `code` char(2) NOT NULL DEFAULT '',
  `code_A3` char(3) NOT NULL DEFAULT '',
  `code_N3` char(3) NOT NULL DEFAULT '',
  `region` char(2) NOT NULL DEFAULT '',
  `lat` float NOT NULL DEFAULT '0',
  `lon` float NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`code`),
  KEY `status` (`status`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]countries`
--

INSERT INTO `[[dbprefix]]countries` VALUES
('AF', 'AFG', '004', 'AS', 33, 65, 'A'),
('AL', 'ALB', '008', 'EU', 41, 20, 'A'),
('DZ', 'DZA', '012', 'AF', 28, 3, 'A'),
('AS', 'ASM', '016', 'AU', -14.2, -170, 'A'),
('AD', 'AND', '020', 'EU', 42.3, 1.3, 'A'),
('AO', 'AGO', '024', 'AF', -12.3, 18.3, 'A'),
('AI', 'AIA', '660', 'LA', 18.15, -63.1, 'A'),
('AQ', 'ATA', '010', 'AN', -90, 0, 'A'),
('AG', 'ATG', '028', 'LA', 17.03, -61.48, 'A'),
('AR', 'ARG', '032', 'LA', -34, -64, 'A'),
('AM', 'ARM', '051', 'AS', 40, 45, 'A'),
('AW', 'ABW', '533', 'LA', 12.3, -69.58, 'A'),
('AU', 'AUS', '036', 'AU', -27, 133, 'A'),
('AT', 'AUT', '040', 'EU', 47.2, 13.2, 'A'),
('AZ', 'AZE', '031', 'AS', 40.3, 47.3, 'A'),
('BS', 'BHS', '044', 'LA', 24.15, -76, 'A'),
('BH', 'BHR', '048', 'AS', 26, 50.33, 'A'),
('BD', 'BGD', '050', 'AS', 24, 90, 'A'),
('BB', 'BRB', '052', 'LA', 13.1, -59.32, 'A'),
('BY', 'BLR', '112', 'EU', 53, 28, 'A'),
('BE', 'BEL', '056', 'EU', 50.5, 4, 'A'),
('BZ', 'BLZ', '084', 'LA', 17.15, -88.45, 'A'),
('BJ', 'BEN', '204', 'AF', 9.3, 2.15, 'A'),
('BM', 'BMU', '060', 'LA', 32.2, -64.45, 'A'),
('BT', 'BTN', '064', 'AS', 27.3, 90.3, 'A'),
('BO', 'BOL', '068', 'LA', -17, -65, 'A'),
('BA', 'BIH', '070', 'EU', 44, 18, 'A'),
('BW', 'BWA', '072', 'AF', -22, 24, 'A'),
('BV', 'BVT', '074', 'AN', -54.26, 3.24, 'A'),
('BR', 'BRA', '076', 'LA', -10, -55, 'A'),
('IO', 'IOT', '086', 'AS', -6, 71.3, 'A'),
('VG', 'VGB', '092', 'LA', 18.2, -64.5, 'A'),
('BN', 'BRN', '096', 'AS', 4.3, 114.4, 'A'),
('BG', 'BGR', '100', 'EU', 43, 25, 'A'),
('BF', 'BFA', '854', 'AF', 13, -2, 'A'),
('BI', 'BDI', '108', 'AF', -3.3, 30, 'A'),
('KH', 'KHM', '116', 'AS', 13, 105, 'A'),
('CM', 'CMR', '120', 'AF', 6, 12, 'A'),
('CA', 'CAN', '124', 'NA', 60, -95, 'A'),
('CV', 'CPV', '132', 'AF', 16, -24, 'A'),
('KY', 'CYM', '136', 'LA', 19.3, -80.3, 'A'),
('CF', 'CAF', '140', 'AF', 7, 21, 'A'),
('TD', 'TCD', '148', 'AF', 15, 19, 'A'),
('CL', 'CHL', '152', 'LA', -30, -71, 'A'),
('CN', 'CHN', '156', 'AS', 35, 105, 'A'),
('CX', 'CXR', '162', 'AU', -10.3, 105.4, 'A'),
('CC', 'CCK', '166', 'AU', -12.3, 96.5, 'A'),
('CO', 'COL', '170', 'LA', 4, -72, 'A'),
('KM', 'COM', '174', 'AF', -12.1, 44.15, 'A'),
('CG', 'COG', '178', 'AF', 0, 25, 'A'),
('CK', 'COK', '184', 'AU', -21.14, -159.46, 'A'),
('CR', 'CRI', '188', 'LA', 10, -84, 'A'),
('CI', 'CIV', '384', 'AF', 7.64, -4.93, 'A'),
('HR', 'HRV', '191', 'EU', 45.1, 15.3, 'A'),
('CU', 'CUB', '192', 'LA', 21.3, -80, 'A'),
('CY', 'CYP', '196', 'EU', 35, 33, 'A'),
('CZ', 'CZE', '203', 'EU', 49.45, 15.3, 'A'),
('DK', 'DNK', '208', 'EU', 56, 10, 'A'),
('DJ', 'DJI', '262', 'AF', 11.3, 43, 'A'),
('DM', 'DMA', '212', 'LA', 15.25, -61.2, 'A'),
('DO', 'DOM', '214', 'LA', 19, -70.4, 'A'),
('TL', 'TLS', '626', 'AS', -8.5, 125.55, 'A'),
('EC', 'ECU', '218', 'LA', -2, -77.3, 'A'),
('EG', 'EGY', '818', 'AF', 27, 30, 'A'),
('SV', 'SLV', '222', 'LA', 13.5, -88.55, 'A'),
('GQ', 'GNQ', '226', 'AF', 2, 10, 'A'),
('ER', 'ERI', '232', 'AF', 15, 39, 'A'),
('EE', 'EST', '233', 'EU', 59, 26, 'A'),
('ET', 'ETH', '210', 'AF', 8, 38, 'A'),
('FK', 'FLK', '238', 'LA', -51.45, -59, 'A'),
('FO', 'FRO', '234', 'EU', 62, -7, 'A'),
('FJ', 'FJI', '242', 'AU', -18, 175, 'A'),
('FI', 'FIN', '246', 'EU', 64, 26, 'A'),
('FR', 'FRA', '250', 'EU', 46, 2, 'A'),
('FX', 'FXX', '249', 'EU', 0, 0, 'A'),
('GF', 'GUF', '254', 'LA', 4, -53, 'A'),
('PF', 'PYF', '258', 'AU', -15, -140, 'A'),
('TF', 'ATF', '260', 'AN', -43, 67, 'A'),
('GA', 'GAB', '266', 'AF', -1, 11.45, 'A'),
('GE', 'GEO', '268', 'AS', 42, 43.3, 'A'),
('GM', 'GMB', '270', 'AF', 13.28, -16.34, 'A'),
('PS', 'PSE', '275', 'AS', 31.89, 34.9, 'A'),
('DE', 'DEU', '276', 'EU', 51, 9, 'A'),
('GH', 'GHA', '288', 'AF', 8, -2, 'A'),
('GI', 'GIB', '292', 'EU', 36.8, -5.21, 'A'),
('GR', 'GRC', '300', 'EU', 39, 22, 'A'),
('GL', 'GRL', '304', 'NA', 72, -40, 'A'),
('GD', 'GRD', '308', 'LA', 12.07, -61.4, 'A'),
('GP', 'GLP', '312', 'LA', 16.15, -61.35, 'A'),
('GU', 'GUM', '316', 'AU', 13.28, 144.47, 'A'),
('GT', 'GTM', '320', 'LA', 15.3, -90.15, 'A'),
('GN', 'GIN', '324', 'AF', 11, -10, 'A'),
('GW', 'GNB', '624', 'AF', 12, -15, 'A'),
('GY', 'GUY', '328', 'LA', 5, -59, 'A'),
('HT', 'HTI', '332', 'LA', 19, -72.25, 'A'),
('HM', 'HMD', '334', 'AU', -53.06, 72.31, 'A'),
('HN', 'HND', '340', 'LA', 15, -86.3, 'A'),
('HK', 'HKG', '344', 'AS', 22.15, 114.1, 'A'),
('HU', 'HUN', '348', 'EU', 47, 20, 'A'),
('IS', 'ISL', '352', 'EU', 65, -18, 'A'),
('IN', 'IND', '356', 'AS', 20, 77, 'A'),
('ID', 'IDN', '360', 'AS', -5, 120, 'A'),
('IQ', 'IRQ', '368', 'AS', 33, 44, 'A'),
('IE', 'IRL', '372', 'EU', 53, -8, 'A'),
('IR', 'IRN', '364', 'AS', 32, 53, 'A'),
('IL', 'ISR', '376', 'AS', 31.3, 34.45, 'A'),
('IT', 'ITA', '380', 'EU', 42.5, 12.5, 'A'),
('JM', 'JAM', '388', 'LA', 18.15, -77.3, 'A'),
('JP', 'JPN', '392', 'AS', 36, 138, 'A'),
('JO', 'JOR', '400', 'AS', 31, 36, 'A'),
('KZ', 'KAZ', '398', 'AS', 48, 68, 'A'),
('KE', 'KEN', '404', 'AF', 1, 38, 'A'),
('KI', 'KIR', '296', 'AU', 1.25, 173, 'A'),
('KP', 'PRK', '408', 'AS', 40, 127, 'A'),
('KR', 'KOR', '410', 'AS', 37, 127.3, 'A'),
('KW', 'KWT', '414', 'AS', 29.3, 45.45, 'A'),
('KG', 'KGZ', '417', 'AS', 41, 75, 'A'),
('LA', 'LAO', '418', 'AS', 18, 105, 'A'),
('LV', 'LVA', '428', 'EU', 57, 25, 'A'),
('LB', 'LBN', '422', 'AS', 33.5, 35.5, 'A'),
('LS', 'LSO', '426', 'AF', -29.3, 28.3, 'A'),
('LR', 'LBR', '430', 'AF', 6.3, -9.3, 'A'),
('LY', 'LBY', '434', 'AF', 25, 17, 'A'),
('LI', 'LIE', '438', 'EU', 47.16, 9.32, 'A'),
('LT', 'LTU', '440', 'EU', 56, 24, 'A'),
('LU', 'LUX', '442', 'EU', 49.45, 6.1, 'A'),
('MO', 'MAC', '446', 'AS', 22.1, 113.33, 'A'),
('MK', 'MKD', '807', 'EU', 41.5, 22, 'A'),
('MG', 'MDG', '450', 'AF', -20, 47, 'A'),
('MW', 'MWI', '454', 'AF', -13.3, 34, 'A'),
('MY', 'MYS', '458', 'AS', 2.3, 112.3, 'A'),
('MV', 'MDV', '462', 'AS', 3.15, 73, 'A'),
('ML', 'MLI', '466', 'AF', 17, -4, 'A'),
('MT', 'MLT', '470', 'EU', 35.5, 14.35, 'A'),
('MH', 'MHL', '584', 'AU', 9, 168, 'A'),
('MQ', 'MTQ', '474', 'LA', 14.4, -61, 'A'),
('MR', 'MRT', '478', 'AF', 20, -12, 'A'),
('MU', 'MUS', '480', 'AF', -20.17, 57.33, 'A'),
('YT', 'MYT', '175', 'AF', -12.5, 45.1, 'A'),
('MX', 'MEX', '484', 'LA', 23, -102, 'A'),
('FM', 'FSM', '583', 'AU', 6.55, 158.15, 'A'),
('MD', 'MDA', '498', 'EU', 47, 29, 'A'),
('MC', 'MCO', '492', 'EU', 43.44, 7.24, 'A'),
('MN', 'MNG', '496', 'AS', 46, 105, 'A'),
('MS', 'MSR', '500', 'LA', 16.45, -62.12, 'A'),
('MA', 'MAR', '504', 'AF', 32, -5, 'A'),
('MZ', 'MOZ', '508', 'AF', -18.15, 35, 'A'),
('MM', 'MMR', '104', 'AS', 22, 98, 'A'),
('NA', 'NAM', '516', 'AF', -22, 17, 'A'),
('NR', 'NRU', '520', 'AU', -0.32, 166.55, 'A'),
('NP', 'NPL', '524', 'AS', 28, 84, 'A'),
('NL', 'NLD', '528', 'EU', 52.3, 5.45, 'A'),
('NC', 'NCL', '540', 'AU', -21.3, 165.3, 'A'),
('NZ', 'NZL', '554', 'AU', -41, 174, 'A'),
('NI', 'NIC', '558', 'LA', 13, -85, 'A'),
('NE', 'NER', '562', 'AF', 16, 8, 'A'),
('NG', 'NGA', '566', 'AF', 10, 8, 'A'),
('NU', 'NIU', '570', 'AU', -19.02, -169.52, 'A'),
('NF', 'NFK', '574', 'AU', -29.02, 167.57, 'A'),
('MP', 'MNP', '580', 'AU', 15.12, 145.45, 'A'),
('NO', 'NOR', '578', 'EU', 62, 10, 'A'),
('OM', 'OMN', '512', 'AS', 21, 57, 'A'),
('PK', 'PAK', '586', 'AS', 30, 70, 'A'),
('PW', 'PLW', '585', 'AU', 7.3, 134.3, 'A'),
('PA', 'PAN', '591', 'LA', 9, -80, 'A'),
('PG', 'PNG', '598', 'AS', -6, 147, 'A'),
('PY', 'PRY', '600', 'LA', -23, -58, 'A'),
('PE', 'PER', '604', 'LA', -10, -76, 'A'),
('PH', 'PHL', '608', 'AS', 13, 122, 'A'),
('PN', 'PCN', '612', 'AU', -25.04, -130.06, 'A'),
('PL', 'POL', '616', 'EU', 52, 20, 'A'),
('PT', 'PRT', '620', 'EU', 39.3, -8, 'A'),
('PR', 'PRI', '630', 'LA', 18.15, -66.3, 'A'),
('QA', 'QAT', '634', 'AS', 25.3, 51.15, 'A'),
('RE', 'REU', '638', 'AF', -21.06, 55.36, 'A'),
('RO', 'ROU', '642', 'EU', 46, 25, 'A'),
('RU', 'RUS', '643', 'EU', 60, 100, 'A'),
('RW', 'RWA', '646', 'AF', -2, 30, 'A'),
('LC', 'LCA', '662', 'LA', 13.53, -60.68, 'A'),
('WS', 'WSM', '685', 'AU', -13.35, -172.2, 'A'),
('SM', 'SMR', '674', 'EU', 43.46, 12.25, 'A'),
('ST', 'STP', '678', 'AF', 1, 7, 'A'),
('SA', 'SAU', '682', 'AS', 25, 45, 'A'),
('SN', 'SEN', '686', 'AF', 14, -14, 'A'),
('SC', 'SYC', '690', 'AF', -4.35, 55.4, 'A'),
('SL', 'SLE', '694', 'AF', 8.3, -11.3, 'A'),
('SG', 'SGP', '702', 'AS', 1.22, 103.48, 'A'),
('SK', 'SVK', '703', 'EU', 48.4, 19.3, 'A'),
('SI', 'SVN', '705', 'EU', 46.07, 14.49, 'A'),
('SB', 'SLB', '090', 'AU', -8, 159, 'A'),
('SO', 'SOM', '706', 'AF', 10, 49, 'A'),
('ZA', 'ZAF', '710', 'AF', -29, 24, 'A'),
('ES', 'ESP', '724', 'EU', 40, -4, 'A'),
('LK', 'LKA', '144', 'AS', 7, 81, 'A'),
('SH', 'SHN', '654', 'AF', -15.56, -5.42, 'A'),
('KN', 'KNA', '659', 'LA', 17.2, -62.45, 'A'),
('PM', 'SPM', '666', 'NA', 46.5, -56.2, 'A'),
('VC', 'VCT', '670', 'LA', 13.15, -61.12, 'A'),
('SD', 'SDN', '736', 'AF', 15, 30, 'A'),
('SR', 'SUR', '740', 'LA', 4, -56, 'A'),
('SJ', 'SJM', '744', 'EU', 78, 20, 'A'),
('SZ', 'SWZ', '748', 'AF', -26.3, 31.3, 'A'),
('SE', 'SWE', '752', 'EU', 62, 15, 'A'),
('CH', 'CHE', '756', 'EU', 47, 8, 'A'),
('SY', 'SYR', '760', 'AS', 35, 38, 'A'),
('TW', 'TWN', '158', 'AS', 23.3, 121, 'A'),
('TJ', 'TJK', '762', 'AS', 39, 71, 'A'),
('TZ', 'TZA', '834', 'AF', -6, 35, 'A'),
('TH', 'THA', '764', 'AS', 15, 100, 'A'),
('TG', 'TGO', '768', 'AF', 8, 1.1, 'A'),
('TK', 'TKL', '772', 'AU', -9, -172, 'A'),
('TO', 'TON', '776', 'AU', -20, -175, 'A'),
('TT', 'TTO', '780', 'LA', 11, -61, 'A'),
('TN', 'TUN', '788', 'AF', 34, 9, 'A'),
('TR', 'TUR', '792', 'EU', 39, 35, 'A'),
('TM', 'TKM', '795', 'AS', 40, 60, 'A'),
('TC', 'TCA', '796', 'LA', 21.45, -71.35, 'A'),
('TV', 'TUV', '798', 'AU', -8, 178, 'A'),
('UG', 'UGA', '800', 'AF', 1, 32, 'A'),
('UA', 'UKR', '804', 'EU', 49, 32, 'A'),
('AE', 'ARE', '784', 'AS', 24, 54, 'A'),
('GB', 'GBR', '826', 'EU', 54, -2, 'A'),
('US', 'USA', '840', 'NA', 38, -97, 'A'),
('VI', 'VIR', '850', 'LA', 18.2, -64.5, 'A'),
('UY', 'URY', '858', 'LA', -33, -56, 'A'),
('UZ', 'UZB', '860', 'AS', 41, 64, 'A'),
('VU', 'VUT', '548', 'AU', -16, 167, 'A'),
('VA', 'VAT', '336', 'EU', 41.54, 12.27, 'A'),
('VE', 'VEN', '862', 'LA', 8, -66, 'A'),
('VN', 'VNM', '704', 'AS', 16, 106, 'A'),
('WF', 'WLF', '876', 'AU', -13.18, -176.12, 'A'),
('EH', 'ESH', '732', 'AF', 24.3, -13, 'A'),
('YE', 'YEM', '887', 'AS', 15, 48, 'A'),
('CS', 'SCG', '891', 'EU', 43.57, 21.41, 'A'),
('ZR', 'ZAR', '180', 'AF', 0, 0, 'A'),
('ZM', 'ZMB', '894', 'AF', -15, 30, 'A'),
('ZW', 'ZWE', '716', 'AF', -20, 30, 'A'),
('AP', '', '', '', -2.81, 128.5, 'A'),
('RS', 'SRB', '688', 'EU', 44.02, 21.01, 'A'),
('AX', 'ALA', '248', 'EU', 60.21, 20.16, 'A'),
('EU', '', '', '', 0, 0, 'A'),
('ME', 'MNE', '499', 'EU', 42.47, 19.28, 'A'),
('GG', 'GGY', '831', 'EU', 49.27, 2.33, 'A'),
('JE', 'JEY', '832', 'EU', 49.11, 2.06, 'A'),
('IM', 'IMN', '833', 'EU', 54.09, 4.29, 'A'),
('CW', 'CUW', '531', 'LA', 12.18, -69, 'A'),
('SX', 'SXM', '534', 'LA', 18.07, -63.05, 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]country_descriptions`
--

CREATE TABLE `[[dbprefix]]country_descriptions` (
  `code` char(2) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `country` varchar(128) NOT NULL DEFAULT '',
  PRIMARY KEY (`code`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]country_descriptions`
--

INSERT INTO `[[dbprefix]]country_descriptions` VALUES
('AD', 'en', 'Andorra'),
('AE', 'en', 'United Arab Emirates'),
('AF', 'en', 'Afghanistan'),
('AG', 'en', 'Antigua and Barbuda'),
('AI', 'en', 'Anguilla'),
('AL', 'en', 'Albania'),
('AM', 'en', 'Armenia'),
('AO', 'en', 'Angola'),
('AQ', 'en', 'Antarctica'),
('AR', 'en', 'Argentina'),
('AS', 'en', 'American Samoa'),
('AT', 'en', 'Austria'),
('AU', 'en', 'Australia'),
('AW', 'en', 'Aruba'),
('AZ', 'en', 'Azerbaijan'),
('BA', 'en', 'Bosnia and Herzegovina'),
('BB', 'en', 'Barbados'),
('BD', 'en', 'Bangladesh'),
('BE', 'en', 'Belgium'),
('BF', 'en', 'Burkina Faso'),
('BG', 'en', 'Bulgaria'),
('BH', 'en', 'Bahrain'),
('BI', 'en', 'Burundi'),
('BJ', 'en', 'Benin'),
('BM', 'en', 'Bermuda'),
('BN', 'en', 'Brunei Darussalam'),
('BO', 'en', 'Bolivia'),
('BR', 'en', 'Brazil'),
('BS', 'en', 'Bahamas'),
('BT', 'en', 'Bhutan'),
('BV', 'en', 'Bouvet Island'),
('BW', 'en', 'Botswana'),
('BY', 'en', 'Belarus'),
('BZ', 'en', 'Belize'),
('CA', 'en', 'Canada'),
('CC', 'en', 'Cocos (Keeling) Islands'),
('CF', 'en', 'Central African Republic'),
('CG', 'en', 'Congo'),
('CH', 'en', 'Switzerland'),
('CI', 'en', 'Cote D''ivoire'),
('CK', 'en', 'Cook Islands'),
('CL', 'en', 'Chile'),
('CM', 'en', 'Cameroon'),
('CN', 'en', 'China'),
('CO', 'en', 'Colombia'),
('CR', 'en', 'Costa Rica'),
('CU', 'en', 'Cuba'),
('CV', 'en', 'Cape Verde'),
('CX', 'en', 'Christmas Island'),
('CY', 'en', 'Cyprus'),
('CZ', 'en', 'Czech Republic'),
('DE', 'en', 'Germany'),
('DJ', 'en', 'Djibouti'),
('DK', 'en', 'Denmark'),
('DM', 'en', 'Dominica'),
('DO', 'en', 'Dominican Republic'),
('DZ', 'en', 'Algeria'),
('EC', 'en', 'Ecuador'),
('EE', 'en', 'Estonia'),
('EG', 'en', 'Egypt'),
('EH', 'en', 'Western Sahara'),
('ER', 'en', 'Eritrea'),
('ES', 'en', 'Spain'),
('ET', 'en', 'Ethiopia'),
('FI', 'en', 'Finland'),
('FJ', 'en', 'Fiji'),
('FK', 'en', 'Falkland Islands (Malvinas)'),
('FM', 'en', 'Micronesia'),
('FO', 'en', 'Faroe Islands'),
('FR', 'en', 'France'),
('FX', 'en', 'France, Metropolitan'),
('GA', 'en', 'Gabon'),
('GB', 'en', 'United Kingdom (Great Britain)'),
('GD', 'en', 'Grenada'),
('GE', 'en', 'Georgia'),
('GF', 'en', 'French Guiana'),
('GH', 'en', 'Ghana'),
('GI', 'en', 'Gibraltar'),
('GL', 'en', 'Greenland'),
('GM', 'en', 'Gambia'),
('GN', 'en', 'Guinea'),
('GP', 'en', 'Guadeloupe'),
('GQ', 'en', 'Equatorial Guinea'),
('GR', 'en', 'Greece'),
('GT', 'en', 'Guatemala'),
('GU', 'en', 'Guam'),
('GW', 'en', 'Guinea-Bissau'),
('GY', 'en', 'Guyana'),
('HK', 'en', 'Hong Kong'),
('HM', 'en', 'Heard and McDonald Islands'),
('HN', 'en', 'Honduras'),
('HR', 'en', 'Croatia'),
('HT', 'en', 'Haiti'),
('HU', 'en', 'Hungary'),
('ID', 'en', 'Indonesia'),
('IE', 'en', 'Ireland'),
('IL', 'en', 'Israel'),
('IN', 'en', 'India'),
('IO', 'en', 'British Indian Ocean Territory'),
('IQ', 'en', 'Iraq'),
('IR', 'en', 'Islamic Republic of Iran'),
('IS', 'en', 'Iceland'),
('IT', 'en', 'Italy'),
('IM', 'en', 'Isle of Man'),
('JM', 'en', 'Jamaica'),
('JO', 'en', 'Jordan'),
('JP', 'en', 'Japan'),
('KE', 'en', 'Kenya'),
('KG', 'en', 'Kyrgyzstan'),
('KH', 'en', 'Cambodia'),
('KI', 'en', 'Kiribati'),
('KM', 'en', 'Comoros'),
('KN', 'en', 'St. Kitts and Nevis'),
('KP', 'en', 'Korea'),
('KR', 'en', 'Korea, Republic of'),
('KW', 'en', 'Kuwait'),
('KY', 'en', 'Cayman Islands'),
('KZ', 'en', 'Kazakhstan'),
('LA', 'en', 'Laos'),
('LB', 'en', 'Lebanon'),
('LC', 'en', 'Saint Lucia'),
('LI', 'en', 'Liechtenstein'),
('LK', 'en', 'Sri Lanka'),
('LR', 'en', 'Liberia'),
('LS', 'en', 'Lesotho'),
('LT', 'en', 'Lithuania'),
('LU', 'en', 'Luxembourg'),
('LV', 'en', 'Latvia'),
('LY', 'en', 'Libyan Arab Jamahiriya'),
('MA', 'en', 'Morocco'),
('MC', 'en', 'Monaco'),
('MD', 'en', 'Moldova, Republic of'),
('MG', 'en', 'Madagascar'),
('MH', 'en', 'Marshall Islands'),
('MK', 'en', 'Macedonia'),
('ML', 'en', 'Mali'),
('MM', 'en', 'Myanmar'),
('MN', 'en', 'Mongolia'),
('ME', 'en', 'Montenegro'),
('MO', 'en', 'Macau'),
('MP', 'en', 'Northern Mariana Islands'),
('MQ', 'en', 'Martinique'),
('MR', 'en', 'Mauritania'),
('MS', 'en', 'Montserrat'),
('MT', 'en', 'Malta'),
('MU', 'en', 'Mauritius'),
('MV', 'en', 'Maldives'),
('MW', 'en', 'Malawi'),
('MX', 'en', 'Mexico'),
('MY', 'en', 'Malaysia'),
('MZ', 'en', 'Mozambique'),
('NA', 'en', 'Namibia'),
('NC', 'en', 'New Caledonia'),
('NE', 'en', 'Niger'),
('NF', 'en', 'Norfolk Island'),
('NG', 'en', 'Nigeria'),
('NI', 'en', 'Nicaragua'),
('NL', 'en', 'Netherlands'),
('NO', 'en', 'Norway'),
('NP', 'en', 'Nepal'),
('NR', 'en', 'Nauru'),
('NU', 'en', 'Niue'),
('NZ', 'en', 'New Zealand'),
('OM', 'en', 'Oman'),
('PA', 'en', 'Panama'),
('PE', 'en', 'Peru'),
('PF', 'en', 'French Polynesia'),
('PG', 'en', 'Papua New Guinea'),
('PH', 'en', 'Philippines'),
('PK', 'en', 'Pakistan'),
('PL', 'en', 'Poland'),
('PM', 'en', 'St. Pierre and Miquelon'),
('PN', 'en', 'Pitcairn'),
('PR', 'en', 'Puerto Rico'),
('PS', 'en', 'Palestine Authority'),
('PT', 'en', 'Portugal'),
('PW', 'en', 'Palau'),
('PY', 'en', 'Paraguay'),
('QA', 'en', 'Qatar'),
('RE', 'en', 'Reunion'),
('RO', 'en', 'Romania'),
('RU', 'en', 'Russian Federation'),
('RW', 'en', 'Rwanda'),
('SA', 'en', 'Saudi Arabia'),
('CS', 'en', 'Serbia'),
('SB', 'en', 'Solomon Islands'),
('SC', 'en', 'Seychelles'),
('SD', 'en', 'Sudan'),
('SE', 'en', 'Sweden'),
('SG', 'en', 'Singapore'),
('SH', 'en', 'St. Helena'),
('SI', 'en', 'Slovenia'),
('SJ', 'en', 'Svalbard and Jan Mayen Islands'),
('SK', 'en', 'Slovakia'),
('SL', 'en', 'Sierra Leone'),
('SM', 'en', 'San Marino'),
('SN', 'en', 'Senegal'),
('SO', 'en', 'Somalia'),
('SR', 'en', 'Suriname'),
('ST', 'en', 'Sao Tome and Principe'),
('SV', 'en', 'El Salvador'),
('SY', 'en', 'Syrian Arab Republic'),
('SZ', 'en', 'Swaziland'),
('TC', 'en', 'Turks and Caicos Islands'),
('TD', 'en', 'Chad'),
('TF', 'en', 'French Southern Territories'),
('TG', 'en', 'Togo'),
('TH', 'en', 'Thailand'),
('TJ', 'en', 'Tajikistan'),
('TK', 'en', 'Tokelau'),
('TM', 'en', 'Turkmenistan'),
('TN', 'en', 'Tunisia'),
('TO', 'en', 'Tonga'),
('TL', 'en', 'East Timor'),
('TR', 'en', 'Turkey'),
('TT', 'en', 'Trinidad and Tobago'),
('TV', 'en', 'Tuvalu'),
('TW', 'en', 'Taiwan'),
('TZ', 'en', 'Tanzania, United Republic of'),
('UA', 'en', 'Ukraine'),
('UG', 'en', 'Uganda'),
('US', 'en', 'United States'),
('UY', 'en', 'Uruguay'),
('UZ', 'en', 'Uzbekistan'),
('VA', 'en', 'Vatican City State'),
('VC', 'en', 'St. Vincent and the Grenadines'),
('VE', 'en', 'Venezuela'),
('VG', 'en', 'British Virgin Islands'),
('VI', 'en', 'United States Virgin Islands'),
('VN', 'en', 'Viet Nam'),
('VU', 'en', 'Vanuatu'),
('WF', 'en', 'Wallis And Futuna Islands'),
('WS', 'en', 'Samoa'),
('YE', 'en', 'Yemen'),
('YT', 'en', 'Mayotte'),
('ZA', 'en', 'South Africa'),
('ZM', 'en', 'Zambia'),
('ZR', 'en', 'Zaire'),
('ZW', 'en', 'Zimbabwe'),
('CD', 'en', 'Democratic Republic of Congo'),
('AP', 'en', 'Asia-Pacific'),
('RS', 'en', 'Republic of Serbia'),
('AX', 'en', 'Aland Islands'),
('EU', 'en', 'Europe'),
('GG', 'en', 'Guernsey'),
('JE', 'en', 'Jersey'),
('CW', 'en', 'Curaçao'),
('SX', 'en', 'Sint Maarten');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]currencies`
--

CREATE TABLE `[[dbprefix]]currencies` (
  `currency_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `currency_code` varchar(10) NOT NULL DEFAULT '',
  `after` char(1) NOT NULL DEFAULT 'N',
  `symbol` tinytext,
  `coefficient` double(12,5) NOT NULL DEFAULT '1.00000',
  `is_primary` char(1) NOT NULL DEFAULT 'N',
  `position` smallint(5) NOT NULL,
  `decimals_separator` varchar(6) NOT NULL DEFAULT '.',
  `thousands_separator` varchar(6) NOT NULL DEFAULT ',',
  `decimals` smallint(5) NOT NULL DEFAULT '2',
  `status` char(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`currency_id`),
  UNIQUE KEY `currency_code` (`currency_code`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=4 ;

--
-- Dumping data for table `[[dbprefix]]currencies`
--

INSERT INTO `[[dbprefix]]currencies` VALUES
(1, 'USD', 'N', '$', 1.00000, 'Y', 10, '.', ',', 2, 'A'),
(2, 'EUR', 'N', '€', 1.28000, 'N', 20, '.', ',', 2, 'A'),
(3, 'GBP', 'N', '£', 1.88000, 'N', 30, '.', ',', 2, 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]currency_descriptions`
--

CREATE TABLE `[[dbprefix]]currency_descriptions` (
  `currency_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `description` varchar(255) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`currency_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]currency_descriptions`
--

INSERT INTO `[[dbprefix]]currency_descriptions` VALUES
(1, 'US Dollars', 'en'),
(2, 'Euro', 'en'),
(3, 'GB Pound', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]custom_blocks`
--

CREATE TABLE `[[dbprefix]]custom_blocks` (
  `block_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `status` char(1) NOT NULL DEFAULT 'A',
  `section` char(1) DEFAULT NULL,
  `type` char(1) NOT NULL DEFAULT 'B',
  `area` char(1) NOT NULL DEFAULT 'V',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`block_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]custom_blocks_content`
--

CREATE TABLE `[[dbprefix]]custom_blocks_content` (
  `block_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `content` text,
  PRIMARY KEY (`block_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]custom_menu`
--

CREATE TABLE `[[dbprefix]]custom_menu` (
  `item_id` varchar(64) NOT NULL DEFAULT '',
  `href` varchar(255) NOT NULL DEFAULT '',
  `alt` varchar(255) NOT NULL DEFAULT '',
  `new_window` char(1) NOT NULL DEFAULT 'N',
  `status` char(1) NOT NULL DEFAULT 'A',
  `location` varchar(255) NOT NULL DEFAULT 'central',
  `area` char(1) NOT NULL DEFAULT 'V',
  `position` smallint(5) NOT NULL DEFAULT '0',
  `parent_id` varchar(64) NOT NULL DEFAULT '0',
  `id_path` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`item_id`,`id_path`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]custom_menu_descriptions`
--

CREATE TABLE `[[dbprefix]]custom_menu_descriptions` (
  `item_id` varchar(64) NOT NULL DEFAULT '',
  `id_path` varchar(255) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `title` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`item_id`,`id_path`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]data_feeds`
--

CREATE TABLE `[[dbprefix]]data_feeds` (
  `datafeed_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `categories` text,
  `products` text,
  `fields` text,
  `export_location` char(1) NOT NULL DEFAULT 'L',
  `export_by_cron` char(1) NOT NULL DEFAULT 'N',
  `ftp_url` varchar(255) NOT NULL DEFAULT '',
  `ftp_user` varchar(50) NOT NULL DEFAULT '',
  `ftp_pass` varchar(50) NOT NULL DEFAULT '',
  `file_name` varchar(50) NOT NULL DEFAULT '',
  `enclosure` char(1) NOT NULL DEFAULT '',
  `csv_delimiter` char(1) NOT NULL DEFAULT '',
  `exclude_disabled_products` char(1) NOT NULL DEFAULT 'N',
  `exclude_shared_products` char(1) NOT NULL DEFAULT 'N',
  `export_options` text,
  `save_dir` varchar(255) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT '',
  `layout_id` int(11) unsigned NOT NULL DEFAULT '0',
  `params` text,
  PRIMARY KEY (`datafeed_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]data_feed_descriptions`
--

CREATE TABLE `[[dbprefix]]data_feed_descriptions` (
  `datafeed_id` int(11) unsigned NOT NULL DEFAULT '0',
  `datafeed_name` varchar(255) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`datafeed_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]destinations`
--

CREATE TABLE `[[dbprefix]]destinations` (
  `destination_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `localization` varchar(255) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`destination_id`),
  KEY `localization` (`localization`),
  KEY `c_status` (`destination_id`,`status`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=9 ;

--
-- Dumping data for table `[[dbprefix]]destinations`
--

INSERT INTO `[[dbprefix]]destinations` VALUES
(1, '', 'A'),
(7, '', 'A'),
(8, '', 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]destination_descriptions`
--

CREATE TABLE `[[dbprefix]]destination_descriptions` (
  `destination_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `destination` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`destination_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]destination_descriptions`
--

INSERT INTO `[[dbprefix]]destination_descriptions` VALUES
(7, 'en', 'USA'),
(8, 'en', 'Canada'),
(1, 'en', 'Default rate area (all countries)');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]destination_elements`
--

CREATE TABLE `[[dbprefix]]destination_elements` (
  `element_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `destination_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `element` varchar(255) NOT NULL DEFAULT '',
  `element_type` char(1) NOT NULL DEFAULT 'S',
  PRIMARY KEY (`element_id`),
  KEY `c_status` (`destination_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=355 ;

--
-- Dumping data for table `[[dbprefix]]destination_elements`
--

INSERT INTO `[[dbprefix]]destination_elements` VALUES
(59, 7, '13', 'S'),
(60, 7, '12', 'S'),
(61, 7, '11', 'S'),
(62, 7, '10', 'S'),
(63, 7, '15', 'S'),
(64, 7, '16', 'S'),
(65, 7, '17', 'S'),
(66, 7, '18', 'S'),
(67, 7, '19', 'S'),
(68, 7, '20', 'S'),
(69, 7, '21', 'S'),
(70, 7, '22', 'S'),
(71, 7, '23', 'S'),
(72, 7, '24', 'S'),
(73, 7, '25', 'S'),
(74, 7, '26', 'S'),
(75, 7, '27', 'S'),
(76, 7, '28', 'S'),
(77, 7, '29', 'S'),
(78, 7, '30', 'S'),
(79, 7, '31', 'S'),
(80, 7, '32', 'S'),
(81, 7, '33', 'S'),
(82, 7, '34', 'S'),
(83, 7, '35', 'S'),
(84, 7, '36', 'S'),
(85, 7, '37', 'S'),
(86, 7, '38', 'S'),
(87, 7, '39', 'S'),
(88, 7, '40', 'S'),
(89, 7, '41', 'S'),
(90, 7, '42', 'S'),
(91, 7, '43', 'S'),
(92, 7, '44', 'S'),
(93, 7, '45', 'S'),
(94, 7, '46', 'S'),
(95, 7, '47', 'S'),
(96, 7, '48', 'S'),
(97, 7, '49', 'S'),
(98, 7, '50', 'S'),
(99, 7, '51', 'S'),
(100, 7, '52', 'S'),
(101, 7, '53', 'S'),
(102, 7, '54', 'S'),
(103, 7, '55', 'S'),
(104, 7, '56', 'S'),
(105, 7, '57', 'S'),
(106, 7, '58', 'S'),
(107, 7, '59', 'S'),
(108, 7, '60', 'S'),
(109, 7, '61', 'S'),
(110, 7, '62', 'S'),
(111, 7, '63', 'S'),
(112, 7, '64', 'S'),
(113, 7, 'US', 'C'),
(114, 1, 'AF', 'C'),
(115, 1, 'AL', 'C'),
(116, 1, 'DZ', 'C'),
(117, 1, 'AS', 'C'),
(118, 1, 'AD', 'C'),
(119, 1, 'AO', 'C'),
(120, 1, 'AI', 'C'),
(121, 1, 'AQ', 'C'),
(122, 1, 'AG', 'C'),
(123, 1, 'AR', 'C'),
(124, 1, 'AM', 'C'),
(125, 1, 'AW', 'C'),
(126, 1, 'AU', 'C'),
(127, 1, 'AT', 'C'),
(128, 1, 'AZ', 'C'),
(129, 1, 'BS', 'C'),
(130, 1, 'BH', 'C'),
(131, 1, 'BD', 'C'),
(132, 1, 'BB', 'C'),
(133, 1, 'BY', 'C'),
(134, 1, 'BE', 'C'),
(135, 1, 'BZ', 'C'),
(136, 1, 'BJ', 'C'),
(137, 1, 'BM', 'C'),
(138, 1, 'BT', 'C'),
(139, 1, 'BO', 'C'),
(140, 1, 'BA', 'C'),
(141, 1, 'BW', 'C'),
(142, 1, 'BV', 'C'),
(143, 1, 'BR', 'C'),
(144, 1, 'IO', 'C'),
(145, 1, 'VG', 'C'),
(146, 1, 'BN', 'C'),
(147, 1, 'BG', 'C'),
(148, 1, 'BF', 'C'),
(149, 1, 'BI', 'C'),
(150, 1, 'KH', 'C'),
(151, 1, 'CM', 'C'),
(152, 1, 'CA', 'C'),
(153, 1, 'CV', 'C'),
(154, 1, 'KY', 'C'),
(155, 1, 'CF', 'C'),
(156, 1, 'TD', 'C'),
(157, 1, 'CL', 'C'),
(158, 1, 'CN', 'C'),
(159, 1, 'CX', 'C'),
(160, 1, 'CC', 'C'),
(161, 1, 'CO', 'C'),
(162, 1, 'KM', 'C'),
(163, 1, 'CG', 'C'),
(164, 1, 'CK', 'C'),
(165, 1, 'CR', 'C'),
(166, 1, 'CI', 'C'),
(167, 1, 'HR', 'C'),
(168, 1, 'CU', 'C'),
(169, 1, 'CY', 'C'),
(170, 1, 'CZ', 'C'),
(171, 1, 'DK', 'C'),
(172, 1, 'DJ', 'C'),
(173, 1, 'DM', 'C'),
(174, 1, 'DO', 'C'),
(175, 1, 'TP', 'C'),
(176, 1, 'EC', 'C'),
(177, 1, 'EG', 'C'),
(178, 1, 'SV', 'C'),
(179, 1, 'GQ', 'C'),
(180, 1, 'ER', 'C'),
(181, 1, 'EE', 'C'),
(182, 1, 'ET', 'C'),
(183, 1, 'FK', 'C'),
(184, 1, 'FO', 'C'),
(185, 1, 'FJ', 'C'),
(186, 1, 'FI', 'C'),
(187, 1, 'FR', 'C'),
(188, 1, 'FX', 'C'),
(189, 1, 'GF', 'C'),
(190, 1, 'PF', 'C'),
(191, 1, 'TF', 'C'),
(192, 1, 'GA', 'C'),
(193, 1, 'GM', 'C'),
(194, 1, 'GE', 'C'),
(195, 1, 'DE', 'C'),
(196, 1, 'GH', 'C'),
(197, 1, 'GI', 'C'),
(198, 1, 'GR', 'C'),
(199, 1, 'GL', 'C'),
(200, 1, 'GD', 'C'),
(201, 1, 'GP', 'C'),
(202, 1, 'GU', 'C'),
(203, 1, 'GT', 'C'),
(204, 1, 'GN', 'C'),
(205, 1, 'GW', 'C'),
(206, 1, 'GY', 'C'),
(207, 1, 'HT', 'C'),
(208, 1, 'HM', 'C'),
(209, 1, 'HN', 'C'),
(210, 1, 'HK', 'C'),
(211, 1, 'HU', 'C'),
(212, 1, 'IS', 'C'),
(213, 1, 'IN', 'C'),
(214, 1, 'ID', 'C'),
(215, 1, 'IQ', 'C'),
(216, 1, 'IE', 'C'),
(217, 1, 'IR', 'C'),
(218, 1, 'IL', 'C'),
(219, 1, 'IT', 'C'),
(220, 1, 'JM', 'C'),
(221, 1, 'JP', 'C'),
(222, 1, 'JO', 'C'),
(223, 1, 'KZ', 'C'),
(224, 1, 'KE', 'C'),
(225, 1, 'KI', 'C'),
(226, 1, 'KP', 'C'),
(227, 1, 'KR', 'C'),
(228, 1, 'KW', 'C'),
(229, 1, 'KG', 'C'),
(230, 1, 'LA', 'C'),
(231, 1, 'LV', 'C'),
(232, 1, 'LB', 'C'),
(233, 1, 'LS', 'C'),
(234, 1, 'LR', 'C'),
(235, 1, 'LY', 'C'),
(236, 1, 'LI', 'C'),
(237, 1, 'LT', 'C'),
(238, 1, 'LU', 'C'),
(239, 1, 'MO', 'C'),
(240, 1, 'MK', 'C'),
(241, 1, 'MG', 'C'),
(242, 1, 'MW', 'C'),
(243, 1, 'MY', 'C'),
(244, 1, 'MV', 'C'),
(245, 1, 'ML', 'C'),
(246, 1, 'MT', 'C'),
(247, 1, 'MH', 'C'),
(248, 1, 'MQ', 'C'),
(249, 1, 'MR', 'C'),
(250, 1, 'MU', 'C'),
(251, 1, 'YT', 'C'),
(252, 1, 'MX', 'C'),
(253, 1, 'FM', 'C'),
(254, 1, 'MD', 'C'),
(255, 1, 'MC', 'C'),
(256, 1, 'MN', 'C'),
(257, 1, 'MS', 'C'),
(258, 1, 'MA', 'C'),
(259, 1, 'MZ', 'C'),
(260, 1, 'MM', 'C'),
(261, 1, 'NA', 'C'),
(262, 1, 'NR', 'C'),
(263, 1, 'NP', 'C'),
(264, 1, 'NL', 'C'),
(266, 1, 'NC', 'C'),
(267, 1, 'NZ', 'C'),
(268, 1, 'NI', 'C'),
(269, 1, 'NE', 'C'),
(270, 1, 'NG', 'C'),
(271, 1, 'NU', 'C'),
(272, 1, 'NF', 'C'),
(273, 1, 'MP', 'C'),
(274, 1, 'NO', 'C'),
(275, 1, 'OM', 'C'),
(276, 1, 'PK', 'C'),
(277, 1, 'PW', 'C'),
(278, 1, 'PA', 'C'),
(279, 1, 'PG', 'C'),
(280, 1, 'PY', 'C'),
(281, 1, 'PE', 'C'),
(282, 1, 'PH', 'C'),
(283, 1, 'PN', 'C'),
(284, 1, 'PL', 'C'),
(285, 1, 'PT', 'C'),
(286, 1, 'PR', 'C'),
(287, 1, 'QA', 'C'),
(288, 1, 'RE', 'C'),
(289, 1, 'RO', 'C'),
(290, 1, 'RU', 'C'),
(291, 1, 'RW', 'C'),
(292, 1, 'LC', 'C'),
(293, 1, 'WS', 'C'),
(294, 1, 'SM', 'C'),
(295, 1, 'ST', 'C'),
(296, 1, 'SA', 'C'),
(297, 1, 'SN', 'C'),
(298, 1, 'SC', 'C'),
(299, 1, 'SL', 'C'),
(300, 1, 'SG', 'C'),
(301, 1, 'SK', 'C'),
(302, 1, 'SI', 'C'),
(303, 1, 'SB', 'C'),
(304, 1, 'SO', 'C'),
(305, 1, 'ZA', 'C'),
(306, 1, 'ES', 'C'),
(307, 1, 'LK', 'C'),
(308, 1, 'SH', 'C'),
(309, 1, 'KN', 'C'),
(310, 1, 'PM', 'C'),
(311, 1, 'VC', 'C'),
(312, 1, 'SD', 'C'),
(313, 1, 'SR', 'C'),
(314, 1, 'SJ', 'C'),
(315, 1, 'SZ', 'C'),
(316, 1, 'SE', 'C'),
(317, 1, 'CH', 'C'),
(318, 1, 'SY', 'C'),
(319, 1, 'TW', 'C'),
(320, 1, 'TJ', 'C'),
(321, 1, 'TZ', 'C'),
(322, 1, 'TH', 'C'),
(323, 1, 'TG', 'C'),
(324, 1, 'TK', 'C'),
(325, 1, 'TO', 'C'),
(326, 1, 'TT', 'C'),
(327, 1, 'TN', 'C'),
(328, 1, 'TR', 'C'),
(329, 1, 'TM', 'C'),
(330, 1, 'TC', 'C'),
(331, 1, 'TV', 'C'),
(332, 1, 'UG', 'C'),
(333, 1, 'UA', 'C'),
(334, 1, 'AE', 'C'),
(335, 1, 'GB', 'C'),
(336, 1, 'US', 'C'),
(337, 1, 'VI', 'C'),
(338, 1, 'UY', 'C'),
(339, 1, 'UZ', 'C'),
(340, 1, 'VU', 'C'),
(341, 1, 'VA', 'C'),
(342, 1, 'VE', 'C'),
(343, 1, 'VN', 'C'),
(344, 1, 'WF', 'C'),
(345, 1, 'EH', 'C'),
(346, 1, 'YE', 'C'),
(347, 1, 'YU', 'C'),
(348, 1, 'ZR', 'C'),
(349, 1, 'ZM', 'C'),
(350, 1, 'ZW', 'C'),
(351, 8, 'CA', 'C'),
(352, 1, 'IM', 'C'),
(353, 1, 'CW', 'C'),
(354, 1, 'SX', 'C');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]discussion`
--

CREATE TABLE `[[dbprefix]]discussion` (
  `thread_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `object_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `object_type` char(1) NOT NULL DEFAULT '',
  `type` char(1) NOT NULL DEFAULT 'D',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`thread_id`),
  UNIQUE KEY `object_id` (`object_id`,`object_type`,`company_id`),
  KEY `idx_company_id` (`company_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=27 ;

--
-- Dumping data for table `[[dbprefix]]discussion`
--

INSERT INTO `[[dbprefix]]discussion` VALUES
(1, 228, 'P', 'B', 1),
(2, 242, 'P', 'B', 1),
(3, 78, 'P', 'B', 1),
(4, 16, 'P', 'B', 1),
(5, 170, 'P', 'B', 1),
(7, 1, 'A', 'D', 1),
(8, 2, 'A', 'D', 1),
(9, 3, 'A', 'D', 1),
(11, 167, 'C', 'D', 1),
(16, 243, 'P', 'D', 1),
(17, 224, 'P', 'B', 1),
(18, 5, 'P', 'B', 1),
(19, 1, 'P', 'B', 1),
(20, 23, 'P', 'B', 1),
(21, 8, 'P', 'B', 1),
(22, 172, 'P', 'B', 1),
(23, 238, 'P', 'B', 1),
(24, 167, 'P', 'B', 1),
(25, 239, 'P', 'B', 1),
(26, 0, 'E', 'B', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]discussion_messages`
--

CREATE TABLE `[[dbprefix]]discussion_messages` (
  `message` mediumtext,
  `post_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `thread_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`post_id`),
  KEY `thread_id` (`thread_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]discussion_messages`
--

INSERT INTO `[[dbprefix]]discussion_messages` VALUES
('I first noticed this monitor at one of those computer stores where they place all the monitors on the same shelf. This one really stood out for color and very sharp focus. I watch movies and play some games and I haven''t noticed any ghosting. The only thing that I wish I could do is rotate the screen for word processing (kind of a minor complaint). Otherwise this is a very good monitor and the price is good for a 3D LCD. ', 1, 1),
('This monitor is way too light (everything appears faded out), and adjusting the contrast and brightness controls don''t help. No matter what brightness contrast setting is used, everything is either way too dim & gray or way too light. The monitor''s brightness & contrast controls seem to have the exact same function - contrast setting appears to actually be adjusting the brightness and nothing seems to be actually changing the contrast. This will probably be returned soon, unless someone can tell me how to get the correct brightness/contrast setting. ', 2, 1),
('Just a perfect product!', 3, 2),
('I do not like. \n\nAt all.', 4, 2),
('Beautiful boots.\n\nMy opinion is they are just best.', 5, 3),
('I got the Galaxy Tab over on Friday from a local BestBuy apparent they are not suppose to sell it until Monday. The screen has very wide viewing angle, I looked at the Ipad2 before I looked at the Galaxy Tab, and I couldn''t tell the difference based on memory, but I''m sure Galaxy Tab is better. Though the screen is better than the Xoom which I also own.', 8, 17),
('We don''t get much of a choice here in Russia, really only the Iconia, Xoom & the Samsung Galaxy, so far this Iconia is my favourite.', 9, 17),
('I am extremely satisfied with this LCD TV. I have searched for and read all I could about the flat screen TVS. I am so impressed with the picture and sound quality, even though some of the reviews I read did not give this model the best reviews on sound quality and volume. All in all, the benefits for me are: Built-in speakers, Bright display, Durable, Realistic color, Lightweight, can be carried by one person. Would definitely recommend this to my friends. ', 10, 18),
('Absolutely enjoy this TV. The colors are amazing: the depth, the balance and everything else is just top notch! I can plug in my hard drive and watch videos instantly! I am still amazed at the clarity from all the angles. Just getting into Blue-ray capabilities now. Although the price is relatively high, I can truly say that it''s a stunning piece of technological craftsmanship. ', 11, 19),
(' Purchased this for my home theater. I am a bit wary when it comes to 5.1 Channel systems, but decided to give it a try. The sound is nice, although the mid-range could have been a bit clearer. The system definitely lacks the low frequencies, so I am currently in search for a good sub-woofer. The high frequencies are crystal clear, though, and the surround sound simply blows you away. I wouldn''t recommend this to everyone, but it definitely is quite a good product in its segment, although not perfect. ', 12, 20),
('Good picture quality for a LED-based LCD, with relatively deep levels in dark scenes, as well as good white balance in the bright ones. It includes built-in Wi-Fi, 3D with a pair of glasses, and many other cool features.  Overall it''s quite good, although the picture sometimes loses fidelity from off-angle in dark scenes. ', 13, 21),
('I was looking for a handy and easy-to-use camcorder when I came across this little bird, and I have to say — it really does everything perfectly! Whether you just want to catch some memory in a form of a video, or plan to do a full video project — this camcorder will become your best friend! All the necessary features are present and easily adjustable. I didn''t come across any problem using this amazing piece of technology. Definitely worth its money! ', 14, 22),
('A good and reliable phone is a necessity for a person like me, that''s why I decided to choose iPhone. Apple is a remarkable company, and it is always at pace with time, forward-thinking and innovative. The iPhone is clear-cut, easy-to-use and definitely the most stylish phone on the market now. I enjoy it, although I sometimes experience troubles with software & maintenance, and there phone is literally crammed with a lot of features I never use. I would recommend this mostly to younger generation, whereas people of my age might find it a bit bewildering at first. ', 15, 23),
('I was hesitant to choose between Nikon and Canon at first, but when I had a chance to compare the 2 similar models of the 2 competing giants, I chose Nikon. It just feels right, you know. The colors, the matrix, the interface — everything about this product is just beyond expectations! I''ve already made a portfolio with the help of it. Simply perfect! ', 16, 24),
('I’ve been using an iPhone 5 daily for the past year, and the iPhone 5s seems to feel exactly the same: the same curved edges, same dimensions, same everything. It''s only an updated Home button and the new camera flash which make you realize that this is not an iPhone 5.  Many people think that releasing the same design twice is bad, and there are others who realize that sometimes there''s no need for change. Apple might want to understand that the competition is strong, and it needs to stay relevant. ', 17, 25),
('You guys have the BEST customer service known to man!!! I have always been impressed with how fast you help us out!', 18, 26),
('You''re the best! Thank you most graciously and appreciatively!', 19, 26);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]discussion_posts`
--

CREATE TABLE `[[dbprefix]]discussion_posts` (
  `post_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `thread_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `name` varchar(128) NOT NULL DEFAULT '',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `ip_address` varbinary(40) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'D',
  PRIMARY KEY (`post_id`),
  KEY `thread_id` (`thread_id`,`ip_address`),
  KEY `thread_id_2` (`thread_id`,`status`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=20 ;

--
-- Dumping data for table `[[dbprefix]]discussion_posts`
--

INSERT INTO `[[dbprefix]]discussion_posts` VALUES
(1, 1, 'Customer Customer', 1129547428, 3, '192.168.0.2', 'A'),
(2, 1, 'A PC Hardware Fan', 1129559367, 0, '192.168.0.2', 'A'),
(3, 2, 'Admin Admin', 1129558427, 1, '192.168.0.2', 'A'),
(4, 2, 'Guest', 1129558457, 0, '192.168.0.2', 'A'),
(5, 3, 'Customer Customer', 1129559626, 3, '192.168.0.2', 'A'),
(8, 17, 'John', 1311063983, 0, '127.0.0.1', 'A'),
(9, 17, 'Michael', 1311079049, 0, '127.0.0.1', 'A'),
(10, 18, 'David', 1383914308, 0, '10.7.7.93', 'A'),
(11, 19, 'Brian', 1383914367, 0, '10.7.7.93', 'A'),
(12, 20, 'Sophie', 1383914425, 0, '10.7.7.93', 'A'),
(13, 21, 'Jeniffer', 1383914502, 0, '10.7.7.93', 'A'),
(14, 22, 'Alex', 1383914559, 0, '10.7.7.93', 'A'),
(15, 23, 'George', 1383914632, 0, '10.7.7.93', 'A'),
(16, 24, 'Melissa', 1383914678, 0, '10.7.7.93', 'A'),
(17, 25, 'John', 1383914729, 0, '10.7.7.93', 'A'),
(18, 26, 'Alex', 1383914729, 0, '10.7.7.93', 'A'),
(19, 26, 'Michael', 1383914678, 0, '10.7.7.93', 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]discussion_rating`
--

CREATE TABLE `[[dbprefix]]discussion_rating` (
  `rating_value` tinyint(4) unsigned NOT NULL DEFAULT '0',
  `post_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `thread_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`post_id`),
  KEY `thread_id` (`thread_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]discussion_rating`
--

INSERT INTO `[[dbprefix]]discussion_rating` VALUES
(4, 1, 1),
(2, 2, 1),
(5, 3, 2),
(2, 4, 2),
(4, 5, 3),
(4, 8, 17),
(5, 9, 17),
(4, 10, 18),
(4, 11, 19),
(3, 12, 20),
(4, 13, 21),
(4, 14, 22),
(4, 15, 23),
(5, 16, 24),
(3, 17, 25),
(4, 18, 26),
(5, 19, 26);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]ekeys`
--

CREATE TABLE `[[dbprefix]]ekeys` (
  `object_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `object_string` varchar(128) NOT NULL DEFAULT '',
  `object_type` char(1) NOT NULL DEFAULT 'R',
  `ekey` varchar(255) NOT NULL DEFAULT '',
  `ttl` int(11) unsigned NOT NULL DEFAULT '0',
  `data` text,
  PRIMARY KEY (`object_id`,`object_type`,`ekey`(64)),
  UNIQUE KEY `object_string` (`object_string`,`object_type`,`ekey`(64)),
  KEY `c_status` (`ekey`(64),`object_type`,`ttl`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]em_mailchimp_webhooks`
--

CREATE TABLE `[[dbprefix]]em_mailchimp_webhooks` (
  `webhook_id` varchar(128) NOT NULL DEFAULT '',
  `list_id` varchar(128) NOT NULL DEFAULT '',
  PRIMARY KEY (`webhook_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]em_subscribers`
--

CREATE TABLE `[[dbprefix]]em_subscribers` (
  `subscriber_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `email` varchar(128) NOT NULL DEFAULT '',
  `name` varchar(128) NOT NULL DEFAULT '',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `ip_address` varbinary(40) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'A',
  `unsubscribe_key` varchar(32) NOT NULL DEFAULT '',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`subscriber_id`),
  UNIQUE KEY `email` (`email`,`company_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]exim_layouts`
--

CREATE TABLE `[[dbprefix]]exim_layouts` (
  `layout_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(128) NOT NULL DEFAULT '',
  `cols` text,
  `options` text,
  `pattern_id` varchar(128) NOT NULL DEFAULT '',
  `active` char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (`layout_id`),
  KEY `pattern_id` (`pattern_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=30 ;

--
-- Dumping data for table `[[dbprefix]]exim_layouts`
--

INSERT INTO `[[dbprefix]]exim_layouts` VALUES
(18, 'general', 'Product code,Language,Product id,Category,List price,Price,Weight,Available,Quantity,Min quantity,Shipping freight,Date added,Downloadable,Files,Ship downloadable,Inventory tracking,Free shipping,Feature comparison,Zero price action,Thumbnail,Detailed image,Product name,Description,Meta keywords,Meta description,Search words,Page title,Taxes,Features,Options,Secondary categories,Pay by points,Override points,Override exchange rate,Supplier,SEO name,Short description,Localizations,Status,Popularity', NULL, 'products', 'Y'),
(17, 'general', 'Product code,Pair type,Thumbnail,Detailed image', NULL, 'product_images', 'Y'),
(7, 'general', 'Product code,Language,Price,Lower limit,User group,Percentage discount', NULL, 'qty_discounts', 'Y'),
(15, 'general', 'id,product_type,quantity,price,upc,title,description,link,image_link,brand,condition,weight', NULL, 'google', 'Y'),
(19, 'general', 'E-mail,User type,Active,User group ID,Password,Salt,Title,First name,Last name,Company,Fax,Phone,Web site,Tax exempt,Language,Billing: title,Billing: first name,Billing: last name,Billing: address,Billing: address (line 2),Billing: city,Billing: state,Billing: country,Billing: zipcode,Shipping: title,Shipping: first name,Shipping: last name,Shipping: address,Shipping: address (line 2),Shipping: city,Shipping: state,Shipping: country,Shipping: zipcode,Extra fields', NULL, 'users', 'Y'),
(22, 'general', 'Order ID,E-mail,Store,User ID,Total,Subtotal,Discount,Subtotal discount,Payment surcharge,Shipping cost,Date,Status,Notes,Payment ID,IP address,Details,Payment information,Taxes,Coupons,Shipping,First name,Last name,Company,Fax,Phone,Web site,Tax exempt,Language,Billing: first name,Billing: last name,Billing: address,Billing: address (line 2),Billing: city,Billing: state,Billing: country,Billing: zipcode,Shipping: first name,Shipping: last name,Shipping: address,Shipping: address (line 2),Shipping: city,Shipping: state,Shipping: country,Shipping: zipcode', NULL, 'orders', 'Y'),
(20, 'general', 'Order ID,Item ID,Product ID,Product code,Price,Quantity,Supplier,Extra', NULL, 'order_items', 'Y'),
(21, 'general', 'Name,Value,Language', NULL, 'language_variables', 'Y'),
(23, 'general', 'State,Code,Country code', NULL, 'states', 'Y'),
(25, 'general', 'Feature name,Feature ID,Language,Type,Purpose,Feature style,Filter style,Group,Description,Categories,Show on the features tab,Show in product list,Show in product header,Position,Status,Store,Storefront name', NULL, 'features', 'Y'),
(26, 'general', 'Variant,Variant ID,Language,Feature name,Feature group,Position', NULL, 'feature_variants', 'Y'),
(27, 'general', 'Product ID,Language,Combination', NULL, 'option_exceptions', 'Y'),
(28, 'general', 'Pickup ID,Language,Latitude,Longitude,Country,Name,City', NULL, 'pickup', 'Y'),
(29, 'general_data_feeds', 'Product code,Language,Product id,Category,List price,Price,Weight,Available,Quantity,Min quantity,Shipping freight,Date added,Downloadable,Files,Ship downloadable,Inventory tracking,Free shipping,Feature comparison,Zero price action,Thumbnail,Detailed image,Product name,Description,Meta keywords,Meta description,Search words,Page title,Taxes,Features,Options,Secondary categories,Pay by points,Override points,Override exchange rate,Supplier,SEO name,Short description,Localizations,Status,Popularity', NULL, 'data_feeds', 'Y');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]form_descriptions`
--

CREATE TABLE `[[dbprefix]]form_descriptions` (
  `object_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `description` text,
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`object_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]form_descriptions`
--

INSERT INTO `[[dbprefix]]form_descriptions` VALUES
(1, 'Full name', 'en'),
(2, 'Email', 'en'),
(3, 'Body', 'en'),
(4, 'Thank you for contacting us. We''ll answer you at first opportunity.', 'en'),
(7, 'Subject', 'en'),
(9, '', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]form_options`
--

CREATE TABLE `[[dbprefix]]form_options` (
  `element_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `page_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `parent_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `element_type` char(1) NOT NULL DEFAULT 'I',
  `value` varchar(255) NOT NULL DEFAULT '',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `required` char(1) NOT NULL DEFAULT 'N',
  `status` char(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`element_id`),
  KEY `page_id` (`page_id`,`status`),
  KEY `position` (`position`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=10 ;

--
-- Dumping data for table `[[dbprefix]]form_options`
--

INSERT INTO `[[dbprefix]]form_options` VALUES
(1, 30, 0, 'I', '', 3, 'Y', 'A'),
(2, 30, 0, 'Y', '', 1, 'Y', 'A'),
(3, 30, 0, 'T', '', 20, 'Y', 'A'),
(4, 30, 0, 'L', '', 0, 'N', 'A'),
(5, 30, 0, 'J', '[[admin_email]]', 0, 'N', 'A'),
(6, 30, 0, 'U', 'N', 0, 'N', 'A'),
(7, 30, 0, 'I', 'N', 4, 'Y', 'A'),
(8, 30, 0, 'E', '7', 0, 'N', 'A'),
(9, 30, 0, 'K', '', 0, 'N', 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]gdpr_user_agreements`
--

CREATE TABLE `[[dbprefix]]gdpr_user_agreements` (
  `agreement_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` mediumint(8) unsigned DEFAULT '0',
  `email` varchar(128) DEFAULT '',
  `type` varchar(128) DEFAULT '',
  `timestamp` int(11) unsigned DEFAULT '0',
  `agreement` text,
  PRIMARY KEY (`agreement_id`),
  KEY `idx_user_id_email` (`user_id`,`email`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]gdpr_user_data`
--

CREATE TABLE `[[dbprefix]]gdpr_user_data` (
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `anonymized` char(1) DEFAULT 'N',
  PRIMARY KEY (`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]gift_certificates`
--

CREATE TABLE `[[dbprefix]]gift_certificates` (
  `gift_cert_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `gift_cert_code` varchar(255) NOT NULL DEFAULT '',
  `sender` varchar(64) NOT NULL DEFAULT '',
  `recipient` varchar(64) NOT NULL DEFAULT '',
  `send_via` char(1) NOT NULL DEFAULT 'E',
  `amount` decimal(12,2) NOT NULL DEFAULT '0.00',
  `email` varchar(64) NOT NULL DEFAULT '',
  `address` varchar(255) NOT NULL DEFAULT '',
  `address_2` varchar(255) NOT NULL DEFAULT '',
  `city` varchar(255) NOT NULL DEFAULT '',
  `state` varchar(32) NOT NULL DEFAULT '',
  `country` char(2) NOT NULL DEFAULT '',
  `zipcode` varchar(10) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'P',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `phone` varchar(32) NOT NULL DEFAULT '',
  `order_ids` varchar(255) NOT NULL DEFAULT '',
  `template` varchar(128) NOT NULL DEFAULT '',
  `message` mediumtext,
  `products` text,
  PRIMARY KEY (`gift_cert_id`),
  KEY `status` (`status`),
  KEY `timestamp` (`timestamp`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]gift_certificates_log`
--

CREATE TABLE `[[dbprefix]]gift_certificates_log` (
  `log_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `gift_cert_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `area` char(1) NOT NULL DEFAULT 'C',
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `order_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `amount` decimal(12,2) NOT NULL DEFAULT '0.00',
  `debit` decimal(12,2) NOT NULL DEFAULT '0.00',
  `products` text,
  `debit_products` text,
  PRIMARY KEY (`log_id`),
  KEY `area` (`area`),
  KEY `user_id` (`user_id`),
  KEY `order_id` (`order_id`),
  KEY `timestamp` (`timestamp`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]hybrid_auth_providers`
--

CREATE TABLE `[[dbprefix]]hybrid_auth_providers` (
  `provider_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL DEFAULT '',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `provider` varchar(32) NOT NULL,
  `position` smallint(6) NOT NULL DEFAULT '0',
  `app_id` varchar(255) NOT NULL DEFAULT '',
  `app_secret_key` varchar(255) DEFAULT '',
  `app_public_key` varchar(255) DEFAULT '',
  `app_params` text,
  `status` char(1) DEFAULT 'D',
  PRIMARY KEY (`provider_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]hybrid_auth_storefronts_providers`
--

CREATE TABLE `[[dbprefix]]hybrid_auth_storefronts_providers` (
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `provider_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`storefront_id`,`provider_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]hybrid_auth_users`
--

CREATE TABLE `[[dbprefix]]hybrid_auth_users` (
  `user_id` mediumint(8) unsigned NOT NULL,
  `provider_id` mediumint(8) unsigned NOT NULL,
  `identifier` varchar(128) NOT NULL DEFAULT '',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`user_id`,`provider_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]images`
--

CREATE TABLE `[[dbprefix]]images` (
  `image_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `image_path` varchar(255) NOT NULL DEFAULT '',
  `image_x` int(5) NOT NULL DEFAULT '0',
  `image_y` int(5) NOT NULL DEFAULT '0',
  `is_high_res` char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (`image_id`),
  KEY `image_path` (`image_path`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=8652 ;

--
-- Dumping data for table `[[dbprefix]]images`
--

INSERT INTO `[[dbprefix]]images` VALUES
(237, 'd85_smartTV.jpg', 400, 400, 'N'),
(238, 'LED800065NAL30_1.jpg', 500, 500, 'N'),
(239, 'LED800065NAfront_2.jpg', 500, 500, 'N'),
(240, 'LED800065NAR30_2.jpg', 500, 500, 'N'),
(243, 'UN40D5003BFXZA.jpg', 800, 800, 'N'),
(244, 'LED4003400532NAL30_1.jpg', 500, 500, 'N'),
(245, 'LED4003400532NAR30_1.jpg', 500, 500, 'N'),
(246, 'LCD_610_Sailing_Frt_3.jpg', 600, 600, 'N'),
(247, 'LCD610_R70_1.jpg', 600, 600, 'N'),
(248, 'LCD610_R45.jpg', 1000, 1000, 'N'),
(249, 'LCD610_R90_1.jpg', 600, 600, 'N'),
(250, 'LCD610_Back_1.jpg', 600, 600, 'N'),
(251, 'lcd-tv-32C120-01.jpg', 600, 600, 'N'),
(252, 'X41185_01.jpg', 500, 500, 'N'),
(254, 'lcd-tv-32C120-02.jpg', 600, 600, 'N'),
(255, 'lcd-tv-32C120-04.jpg', 600, 600, 'N'),
(256, 'lcd-tv-32C120-03.jpg', 600, 600, 'N'),
(257, 'led-tv-32TL515-01.jpg', 715, 496, 'N'),
(258, 'led-tv-32TL515-02.jpg', 1280, 764, 'N'),
(259, 'led-tv-TL515-04.jpg', 1280, 764, 'N'),
(260, 'led-tv-32TL515-03.jpg', 600, 600, 'N'),
(261, 'led-tv-42TL515-01.jpg', 715, 496, 'N'),
(262, 'led-tv-42TL515-02.jpg', 1280, 764, 'N'),
(263, 'led-tv-42TL515-03.jpg', 600, 600, 'N'),
(264, 'led-tv-TL515-0413286204504f3123a20c4ea.jpg', 1280, 764, 'N'),
(265, '47tl515.jpg', 300, 300, 'N'),
(266, 'X32444_01.jpg', 2000, 2000, 'N'),
(267, 'X32444_02.jpg', 1806, 2586, 'N'),
(268, 'led-tv-47TL515-01.jpg', 715, 496, 'N'),
(269, 'led-tv-47TL515-02.jpg', 1280, 764, 'N'),
(270, 'led-tv-47TL515-03.jpg', 600, 600, 'N'),
(271, 'led-tv-TL515-0413286206244f312450e72f4.jpg', 1280, 764, 'N'),
(274, 'Z2580.jpg', 500, 766, 'N'),
(275, '40e220u.jpg', 500, 500, 'N'),
(276, 'lcd-tv-40E220-01.jpg', 600, 600, 'N'),
(277, 'lcd-tv-40E220-02.jpg', 600, 600, 'N'),
(278, 'lcd-tv-40E220-03.jpg', 600, 600, 'N'),
(279, 'lcd-tv-40E220-04.jpg', 600, 600, 'N'),
(280, '452499_010_A.jpg', 900, 600, 'N'),
(281, '452499_010_B.jpg', 900, 600, 'N'),
(282, 'BD-D7500_01-copy_5.jpg', 600, 600, 'N'),
(283, 'BD_D7500_FrtAngle_2.jpg', 600, 600, 'N'),
(284, 'BD-D7500_04-copy_3.jpg', 600, 600, 'N'),
(285, 'Z6595.jpg', 510, 680, 'N'),
(286, 'BD-D7000_F_5.jpg', 600, 600, 'N'),
(287, 'BD-D7000_R45_2.jpg', 600, 600, 'N'),
(288, 'bluray-bdx2150-600-01.jpg', 600, 600, 'N'),
(289, 'bluray-bdx2150-600-02.jpg', 600, 600, 'N'),
(290, 'bluray-bdx2150-600-03.jpg', 600, 600, 'N'),
(291, 'bluray-bdx2150-600-04.jpg', 600, 600, 'N'),
(292, '1886039720.jpg', 500, 500, 'N'),
(293, 'dvd-player-sd3300-600-01.jpg', 600, 600, 'N'),
(294, 'dvd-player-sd3300-600-02.jpg', 600, 600, 'N'),
(295, 'HT_D6730W_5.jpg', 1086, 768, 'N'),
(296, 'HTD6500WF1_5.jpg', 1500, 1500, 'N'),
(297, 'HT-D5500_FRONT-copy_5.jpg', 1500, 1500, 'N'),
(298, 'HT_D5500_2.jpg', 800, 800, 'N'),
(299, 'HWD7000Fopen_6.jpg', 600, 600, 'N'),
(300, 'cat.gif', 500, 500, 'N'),
(301, 'V31582_01.jpg', 800, 800, 'N'),
(302, 'V31582_02.jpg', 800, 800, 'N'),
(303, 'X35533_01.jpg', 500, 500, 'N'),
(304, 'X35533_02.jpg', 500, 500, 'N'),
(305, 'TT_VIALIVE135_FRONT-GENERIC_image_tcm137-14537.jpg', 850, 593, 'N'),
(306, 'Top-Gear-Image-1_tcm137-20857.jpg', 1585, 1664, 'N'),
(307, 'TT_VIALIVE135_LOGO_L-GENERIC_image_tcm137-14539.jpg', 1280, 1250, 'N'),
(308, 'TT_VIALIVE135_DOCK-R_tcm137-14608.jpg', 500, 500, 'N'),
(309, 'TT_VIALIVE135_DOCK2-L_s_tcm137-14610.jpg', 1857, 2064, 'N'),
(310, 'mount_angle_500_tcm137-7794.jpg', 500, 500, 'N'),
(311, '450676_063_A.jpg', 900, 600, 'N'),
(312, '450676_063_B.jpg', 900, 600, 'N'),
(313, 'front_500_tcm137-7792.jpg', 500, 330, 'N'),
(314, 'Siena-0001_Image_tcm137-6416.jpg', 750, 493, 'N'),
(315, 'Siena-0018_Image_tcm137-6423.jpg', 800, 800, 'N'),
(316, 'cf-lg.jpg', 500, 500, 'N'),
(317, 'pd-01-lg.jpg', 500, 500, 'N'),
(318, 'pd-03-lg.jpg', 500, 500, 'N'),
(319, 'rf-lg.jpg', 500, 500, 'N'),
(320, '451160_063_A.jpg', 900, 600, 'N'),
(321, '451160_063_B.jpg', 900, 600, 'N'),
(322, 'pd-01-lg13286231214f312e1193b91.jpg', 500, 500, 'N'),
(323, 'pd-03-lg13286231214f312e11985e8.jpg', 900, 900, 'N'),
(324, 'url_uploaded_file_13286231494f312e2e48377.jpg', 504, 648, 'N'),
(325, 'url_uploaded_file_13286235024f312f8f85905.jpg', 500, 614, 'N'),
(327, '1951_800_550.jpg', 1000, 1000, 'N'),
(328, '437394_010_A.jpg', 900, 600, 'N'),
(329, '437394_010_B.jpg', 900, 600, 'N'),
(330, 'DEH-80PRS_large.jpg', 800, 800, 'N'),
(331, 'DEH-Card-Remote-BT-2012_large.jpg', 500, 500, 'N'),
(332, 'DEH-80PRS_rear.jpg', 800, 800, 'N'),
(333, 'DEH-80PRS_angle.jpg', 800, 800, 'N'),
(334, 'DEH-P8400BH_large.jpg', 1600, 591, 'N'),
(335, 'DEH-P8400BH_rear.jpg', 1000, 1000, 'N'),
(336, 'DEH-Card-Remote-BT-2012_large13286238444f3130e4e4dcf.jpg', 500, 500, 'N'),
(337, 'DEH-P8400BH_angle1.jpg', 1000, 519, 'N'),
(338, 'DEH-P8400BH_angle2.jpg', 1200, 1200, 'N'),
(339, 'X32679_01.jpg', 500, 500, 'N'),
(340, 'X32679_02.jpg', 500, 500, 'N'),
(341, 'DEH-1300MP_large.jpg', 800, 800, 'N'),
(342, 'DEH-1300MP_angle.jpg', 800, 800, 'N'),
(343, 'DEH-Card-Remote-2011_large.jpg', 500, 500, 'N'),
(344, 'FH-P8000BT_main_Lrg.jpg', 800, 800, 'N'),
(345, 'Bluetooth_Remote.jpg', 500, 500, 'N'),
(346, 'FH-P8000BT_Right_Lrg.jpg', 800, 800, 'N'),
(347, 'FH-P8000BT_Back_lrg.jpg', 800, 800, 'N'),
(348, 'FH-P8000BT_Left_Lrg.jpg', 800, 800, 'N'),
(349, 'Main_116.jpg', 500, 500, 'N'),
(350, '29336_McBride_The_Process_of_Research_in_Psychology_72ppiRGB_150pixW.jpg', 500, 500, 'N'),
(351, '008525B.jpg', 1240, 1633, 'N'),
(352, 'MvC3_PS3CE_moreboxshot.jpg', 500, 500, 'N'),
(353, 'MvC3_PS3CE_productimage.jpg', 500, 500, 'N'),
(354, '95531493TS-MR2040_Front_med.jpg', 500, 500, 'N'),
(355, '66349997TS-MR1640_front_med.jpg', 654, 654, 'N'),
(356, 'TS-D1720C_large.jpg', 833, 625, 'N'),
(357, 'TS-D1720C_tweeters.jpg', 800, 400, 'N'),
(358, 'TS-D1720C_crossovers.jpg', 800, 800, 'N'),
(359, 'TS-D1720C_woofers.jpg', 800, 800, 'N'),
(360, 'TS-D6902R_large.jpg', 700, 700, 'N'),
(361, '1967_675_600.jpg', 1200, 900, 'N'),
(362, '1150_570_600.jpg', 900, 900, 'N'),
(363, 'TS-W3002D2D4_large.jpg', 1024, 1024, 'N'),
(364, 'PRS-D800_large.jpg', 1000, 1000, 'N'),
(365, 'PRS-D800_side1.jpg', 1000, 1000, 'N'),
(366, 'PRS-D800_side2.jpg', 1000, 1000, 'N'),
(367, 'PRS-D800_top.jpg', 1000, 1000, 'N'),
(368, 'GM-6500F_large.jpg', 800, 800, 'N'),
(369, 'GM-6500F_left.jpg', 800, 800, 'N'),
(370, 'GM-D8500M_angle_large.jpg', 800, 450, 'N'),
(371, 'GM-D8500F_Remote_large.jpg', 500, 500, 'N'),
(372, 'AVH-P8400BH_large.jpg', 800, 600, 'N'),
(373, 'AVH-P8400BH_angle1.jpg', 800, 600, 'N'),
(374, 'AVH-P8400BH_angle2.jpg', 800, 600, 'N'),
(375, 'AVH-P8400BH_in-dash.jpg', 800, 600, 'N'),
(376, 'AVH-P8400BH_DFS.jpg', 800, 600, 'N'),
(377, 'AVH-P8400BH_rear.jpg', 800, 600, 'N'),
(378, 'AVH-Remote-2012_CXE5116_large.jpg', 600, 600, 'N'),
(379, 'AVH-P4400BH_large.jpg', 800, 600, 'N'),
(380, 'AVH-P4400BH_angle1.jpg', 800, 600, 'N'),
(381, 'AVH-P4400BH_angle2.jpg', 800, 600, 'N'),
(382, 'AVH-P4400BH_rear.jpg', 800, 600, 'N'),
(383, 'AVH-Remote-2012_CXE5116_large13286304494f314ab18b007.jpg', 600, 600, 'N'),
(384, 'AVIC-Z130BT_reg.jpg', 500, 500, 'N'),
(385, 'AVIC-Z130BT.jpg', 400, 400, 'N'),
(386, 'AVIC-Z130BT_UC_in-dash.jpg', 800, 800, 'N'),
(390, 'XRS9945_LRG.jpg', 500, 500, 'N'),
(391, 'XRS9770_MD.jpg', 809, 500, 'N'),
(392, 'XRS9745_LRG.jpg', 1000, 1000, 'N'),
(393, 'XRS9370_MD.jpg', 650, 403, 'N'),
(394, 'XRS9970G_R-med.jpg', 805, 805, 'N'),
(395, 'wildfires-metropcs-MoreViews-2985.jpg', 500, 500, 'N'),
(396, 'wildfires-metropcs-MoreViews-2986.jpg', 500, 500, 'N'),
(397, 'wildfires-metropcs-MoreViews-2987.jpg', 500, 500, 'N'),
(398, 'wildfires-metropcs-MoreViews-2988.jpg', 500, 500, 'N'),
(399, 'titan-att-MoreViews-3012.jpg', 500, 608, 'N'),
(400, 'titan-att-MoreViews-3013.jpg', 500, 608, 'N'),
(401, 'titan-att-MoreViews-3014.jpg', 500, 608, 'N'),
(402, 'titan-att-MoreViews-3015.jpg', 500, 608, 'N'),
(403, 'titan-att-MoreViews-3016.jpg', 500, 608, 'N'),
(404, 'titan-att-MoreViews-3017.jpg', 500, 608, 'N'),
(405, 'titan-att-MoreViews-3018.jpg', 500, 608, 'N'),
(406, 'titan-att-MoreViews-3019.jpg', 500, 608, 'N'),
(407, 'titan-att-MoreViews-3021.jpg', 500, 608, 'N'),
(408, 'rhyme-verizon-MoreViews-2645.jpg', 500, 500, 'N'),
(409, 'rhyme-verizon-MoreViews-2646.jpg', 500, 500, 'N'),
(410, 'rhyme-verizon-MoreViews-2647.jpg', 600, 600, 'N'),
(411, 'rhyme-verizon-MoreViews-2648.jpg', 644, 644, 'N'),
(412, 'rhyme-verizon-MoreViews-2649.jpg', 500, 500, 'N'),
(413, 'evodesign4g-sprint-MoreViews-2839.jpg', 800, 948, 'N'),
(414, 'evodesign4g-sprint-MoreViews-2840.jpg', 800, 800, 'N'),
(415, 'evodesign4g-sprint-MoreViews-2841.jpg', 500, 500, 'N'),
(416, 'evodesign4g-sprint-MoreViews-2842.jpg', 818, 1210, 'N'),
(417, 'evodesign4g-sprint-MoreViews-2843.jpg', 606, 404, 'N'),
(418, 'incredible2-verizon-MoreViews-1922.jpg', 1100, 1026, 'N'),
(419, 'incredible2-verizon-MoreViews-1918.jpg', 1500, 1360, 'N'),
(420, 'incredible2-verizon-MoreViews-1919.jpg', 600, 600, 'N'),
(421, 'incredible2-verizon-MoreViews-1920.jpg', 500, 500, 'N'),
(422, 'incredible2-verizon-MoreViews-1921.jpg', 900, 900, 'N'),
(423, '31igDkhoUNL._SX220_.jpg', 500, 500, 'N'),
(424, '21SXU3Z1iGL._SX220_.jpg', 500, 500, 'N'),
(425, '31FZtzlRY+L._SX220_.jpg', 500, 500, 'N'),
(426, '318v60DwLzL._SX220_.jpg', 500, 500, 'N'),
(427, '11UG7jOeaaL._SX220_.jpg', 500, 500, 'N'),
(428, '21HZgrCmlnL._SX220_.jpg', 500, 500, 'N'),
(429, '21LllLxrG7L._SX220_.jpg', 500, 500, 'N'),
(430, '21m6Oh-3V7L._SX220_.jpg', 500, 500, 'N'),
(431, '21NE2eQ9cGL._SX220_.jpg', 500, 500, 'N'),
(432, '21nGYVjaXcL._SX220_.jpg', 500, 500, 'N'),
(433, '21Y7tnPMVHL._SX220_.jpg', 500, 500, 'N'),
(434, '21J1GvD2+OL._SX220_.jpg', 500, 500, 'N'),
(435, '219VLxUNBVL._SX220_.jpg', 500, 500, 'N'),
(436, '21YX09ju46L._SX220_.jpg', 500, 500, 'N'),
(437, '31XNsUOJQ2L._SX220_.jpg', 500, 500, 'N'),
(438, '21ey9KYVJBL._SX220_.jpg', 500, 500, 'N'),
(439, '217t6mWmKtL._SX220_.jpg', 500, 500, 'N'),
(440, '21o5d8HaEPL._SX220_.jpg', 500, 500, 'N'),
(441, '31OMU8eIbpL._SX220_.jpg', 500, 500, 'N'),
(442, '21NteLdVarL._SX220_.jpg', 500, 500, 'N'),
(443, '217Lf0Ah3rL._SX220_.jpg', 500, 500, 'N'),
(444, '31jwZ9SwA8L._SX220_.jpg', 500, 500, 'N'),
(445, '31fu60vb60L._SX220_.jpg', 500, 500, 'N'),
(446, '31OZNMeCWBL._SX220_.jpg', 500, 500, 'N'),
(447, '21hNMRIx66L._SX220_.jpg', 500, 500, 'N'),
(522, 'i515_400x400_large1_cf_1.jpg', 1000, 1000, 'N'),
(523, '1000173538_f.jpg', 500, 500, 'N'),
(524, 'i515_400x400_large1_cl.jpg', 800, 800, 'N'),
(525, 'i515_400x400_large1_cr.jpg', 619, 600, 'N'),
(526, 'i515_400x400_large1_cr13286900474f32337fcaa2a.jpg', 619, 600, 'N'),
(453, 'G48874_01.jpg', 500, 500, 'N'),
(454, 'G48874_02.jpg', 500, 500, 'N'),
(455, 'G48874_03.jpg', 500, 500, 'N'),
(456, 'G48874_04.jpg', 500, 500, 'N'),
(457, 'G48874_05.jpg', 500, 500, 'N'),
(458, 'U42918_01.jpg', 500, 500, 'N'),
(459, 'U42918_02.jpg', 500, 500, 'N'),
(460, 'U42918_03.jpg', 500, 500, 'N'),
(461, 'U42918_04.jpg', 500, 500, 'N'),
(462, 'U42918_05.jpg', 500, 500, 'N'),
(463, '476750_003_A.jpg', 900, 600, 'N'),
(464, '476750_003_B.jpg', 900, 600, 'N'),
(465, '7210_4815_200_f.jpg', 1119, 1253, 'N'),
(466, '7210_4815_200_d2.jpg', 1119, 1253, 'N'),
(467, '7210_4815_200_d1.jpg', 1119, 1253, 'N'),
(468, '2817406.jpg', 878, 1200, 'N'),
(469, '1907188.jpg', 500, 512, 'N'),
(470, '2083726.jpg', 640, 906, 'N'),
(471, '1000009496_f.jpg', 500, 500, 'N'),
(510, '700-red-front-png13286885734f322dbde9ae7.jpg', 500, 500, 'N'),
(473, '2817655.jpg', 1000, 1000, 'N'),
(474, '3086390.jpg', 1040, 1040, 'N'),
(475, '2954384.jpg', 1200, 1200, 'N'),
(476, '1000202232_f.jpg', 1200, 1200, 'N'),
(477, '102337_l.ashx.jpg', 500, 500, 'N'),
(478, '102337_890x364_01.ashx.jpg', 890, 890, 'N'),
(479, '102337_890x364_02.ashx.jpg', 890, 890, 'N'),
(480, '102337_890x364_03.ashx.jpg', 411, 411, 'N'),
(481, '102337_890x364_04.ashx.jpg', 890, 890, 'N'),
(482, '101551_l.ashx.jpg', 500, 500, 'N'),
(483, '101551_890x364_01.ashx.jpg', 890, 890, 'N'),
(484, '101551_890x364_02.ashx.jpg', 890, 890, 'N'),
(485, '101551_890x364_03.ashx.jpg', 408, 408, 'N'),
(486, '2423577.jpg', 1000, 1000, 'N'),
(487, '1000176186_f.jpg', 625, 849, 'N'),
(488, '2832686.jpg', 500, 512, 'N'),
(489, '1000235553_f.jpg', 1200, 1200, 'N'),
(511, '1565865.jpg', 500, 512, 'N'),
(491, '1000156676_f.jpg', 500, 500, 'N'),
(514, 'i677_600x600_xlarge_cf.jpg', 600, 600, 'N'),
(515, 'i677_600x600_xlarge_bk.jpg', 600, 600, 'N'),
(516, 'i677_600x600_xlarge_cl.jpg', 600, 600, 'N'),
(495, '1000156675_f.jpg', 500, 500, 'N'),
(521, '1837696.jpg', 500, 512, 'N'),
(517, 'i677_600x600_xlarge_cr.jpg', 600, 600, 'N'),
(498, 'X3-02-white-front-png.jpg', 500, 500, 'N'),
(513, '2419089.jpg', 500, 512, 'N'),
(500, 't049_210_11_017_00.jpg', 500, 500, 'N'),
(501, '2980245.jpg', 600, 881, 'N'),
(502, '3083326.jpg', 700, 959, 'N'),
(503, 'Searay-white-Front-png.jpg', 1000, 1000, 'N'),
(504, 'E5-black-front-black-png13286888164f322eb054f4c.jpg', 1000, 1000, 'N'),
(520, 'CB-evolve.jpg', 936, 612, 'N'),
(518, 'i677_600x600_xlarge_s1.jpg', 600, 600, 'N'),
(507, '03804_l.ashx.jpg', 500, 500, 'N'),
(508, '2891878.jpg', 500, 636, 'N'),
(509, '101796_l.ashx.jpg', 500, 500, 'N'),
(512, '2411125.jpg', 500, 512, 'N'),
(519, '1917865.jpg', 1071, 1185, 'N'),
(527, 'i515_400x400_large1_s1.jpg', 500, 500, 'N'),
(528, 'i515_400x400_large1_s2.jpg', 500, 500, 'N'),
(529, 'i515_400x400_large1_bk_2.jpg', 650, 650, 'N'),
(530, '2957882.jpg', 1445, 1600, 'N'),
(531, 'd710_600x600_xlarge_cf.jpg', 600, 600, 'N'),
(532, '2980261.jpg', 500, 512, 'N'),
(533, 'CB-evolution.jpg', 936, 612, 'N'),
(534, '1000172227_f.jpg', 500, 500, 'N'),
(535, 'CB-truth.jpg', 936, 612, 'N'),
(536, 'd710_400x400_large1_bk.jpg', 400, 400, 'N'),
(537, 'd710_400x400_large1_cl.jpg', 400, 400, 'N'),
(538, 'd710_400x400_large1_cr.jpg', 400, 400, 'N'),
(539, 'd710_400x400_large1_s1.jpg', 500, 500, 'N'),
(540, 'd710_400x400_large1_s2.jpg', 600, 600, 'N'),
(541, 'i777_400x400_large1_cf_1.jpg', 700, 700, 'N'),
(542, 'fx-cg10_xlarge.jpg', 500, 529, 'N'),
(543, 'i777_400x400_large1_bk.jpg', 400, 400, 'N'),
(544, 'i777_400x400_large1_cl.jpg', 600, 600, 'N'),
(545, 'i777_400x400_large1_cr.jpg', 650, 650, 'N'),
(546, 'i777_400x400_large1_s1.jpg', 500, 500, 'N'),
(547, 'i777_400x400_large1_s2.jpg', 500, 500, 'N'),
(548, '1312496083_CR5-2011-315-sram.jpg', 618, 500, 'N'),
(549, '1312496057_CR5-2011-225-sram.jpg', 618, 500, 'N'),
(550, '1312496025_CR5-2011-180-sram.jpg', 618, 500, 'N'),
(551, '1312496004_CR5-2011-135-sram.jpg', 618, 500, 'N'),
(552, '1312495974_CR5-2011-45-sram.jpg', 618, 500, 'N'),
(553, '1312495960_CR5-2011-0-sram.jpg', 618, 500, 'N'),
(554, 'fx-115es_xlarge.jpg', 500, 529, 'N'),
(555, '1316633534_CR1-2012-315.jpg', 618, 500, 'N'),
(556, '1316633442_CR1-2012-0.jpg', 618, 500, 'N'),
(557, '1316633497_CR1-2012-180.jpg', 618, 500, 'N'),
(558, '1316633471_CR1-2012-90.jpg', 618, 500, 'N'),
(559, 'dr-210tmbk_xlarge.jpg', 1175, 1166, 'N'),
(560, '1316556371_CA-2012-45.jpg', 618, 500, 'N'),
(561, '1316556344_CA-2012-0.jpg', 618, 500, 'N'),
(562, '1316556781_CA-2012-315.jpg', 618, 500, 'N'),
(563, 'WiFi_Galaxy5_front3_4.jpg', 800, 800, 'N'),
(572, 'Wifi_Galaxy_Player_4_front2_14.jpg', 800, 800, 'N'),
(565, 'GalaxyPlayer5_18_213286919574f323af5ddfc8.jpg', 600, 600, 'N'),
(566, 'GalaxyPlayer5_26.jpg', 600, 600, 'N'),
(567, 'GalaxyPlayer5_28_2.jpg', 600, 600, 'N'),
(568, 'GalaxyPlayer5_07.jpg', 600, 600, 'N'),
(569, 'GalaxyPlayer5_05_2.jpg', 600, 600, 'N'),
(570, 'GalaxyPlayer5_04.jpg', 600, 600, 'N'),
(571, 'GalaxyPlayer5_03_5.jpg', 600, 600, 'N'),
(573, 'rearr1_2.jpg', 600, 600, 'N'),
(574, 'rear2.jpg', 600, 600, 'N'),
(575, 'side1_5.jpg', 600, 600, 'N'),
(576, 'Untitled-1.jpg', 600, 600, 'N'),
(577, 'Wifi_Galaxy_Player_4_extleft2_2.jpg', 800, 800, 'N'),
(578, 'Wifi_Galaxy_Player_4_extright2.jpg', 800, 800, 'N'),
(579, 'Wifi_Galaxy_Player_4_left2_2.jpg', 800, 800, 'N'),
(580, '41rz1TVrQdL.jpg', 500, 500, 'N'),
(581, '51g+lhvGGQL.jpg', 500, 500, 'N'),
(582, 'bbex_boxart_psvita.jpg', 500, 637, 'N'),
(583, 'url_uploaded_file_13286945074f3244ec33aed.jpg', 1200, 1200, 'N'),
(584, '1328221407-ridgeracer-gameart_landing.jpg', 500, 500, 'N'),
(585, '1328221297-documentvi-gameart_landing.jpg', 500, 500, 'N'),
(586, 'p149239z.jpg', 450, 450, 'N'),
(587, 'p149240z.jpg', 450, 450, 'N'),
(588, 'p95910z.jpg', 500, 500, 'N'),
(589, 'p98947z.jpg', 500, 500, 'N'),
(590, 'p98945z.jpg', 500, 500, 'N'),
(591, 'Fuzeplusred_210.jpg', 600, 600, 'N'),
(592, 'clip_plus_red.jpg', 500, 500, 'N'),
(593, 'NWZA865BLK.jpg', 1000, 1000, 'N'),
(594, 'NWZA865BLK_1.jpg', 800, 600, 'N'),
(595, 'NWZE464RED.jpg', 1000, 1000, 'N'),
(596, 'DB_2011_WILDWOOD-CITI_Blue_LG.jpg', 800, 523, 'N'),
(597, 'DB_2011_WILDWOOD-CITI_Black_LG.jpg', 800, 530, 'N'),
(598, 'DB_2011_DRIFTER-2_Grey_LG.jpg', 800, 513, 'N'),
(599, 'url_uploaded_file_13286977924f3251c3f2695.jpg', 1000, 1000, 'N'),
(600, 'url_uploaded_file_13286978134f3251d8b881b.jpg', 1000, 1000, 'N'),
(601, 'NWZE464RED_1.jpg', 1000, 1000, 'N'),
(602, 'url_uploaded_file_13286980754f3252e10c119.jpg', 1000, 1000, 'N'),
(603, 'url_uploaded_file_13286980934f3252f0a7257.jpg', 1000, 1000, 'N'),
(604, 'url_uploaded_file_13286981734f3253431b01f.jpg', 1000, 1000, 'N'),
(605, 'url_uploaded_file_13286983184f3253d32faa0.jpg', 1000, 1000, 'N'),
(606, 'url_uploaded_file_13286983184f3253d55fbaf.jpg', 1000, 1000, 'N'),
(607, 'url_uploaded_file_13286983184f3253da9b588.jpg', 1000, 1000, 'N'),
(608, 'url_uploaded_file_13286983184f3253dece8d3.jpg', 1000, 1000, 'N'),
(609, 'MDRXB1000.jpg', 800, 800, 'N'),
(610, 'MDRXB1000_1.jpg', 500, 500, 'N'),
(611, 'MDRZ1000.jpg', 500, 500, 'N'),
(612, 'MDRZ1000_1.jpg', 500, 500, 'N'),
(613, 'icon-01.jpg', 500, 500, 'N'),
(614, 'cs-53.jpg', 500, 500, 'N'),
(615, 'DB2010Drifter3SatinRed_Profile_LRG.jpg', 800, 800, 'N'),
(616, 'MV800_NEW_KV_6.jpg', 600, 600, 'N'),
(617, 'cs-180.jpg', 500, 511, 'N'),
(618, 'MV800_02_MB_1024x768.jpg', 600, 600, 'N'),
(619, 'MV800_03_MB_1024x768_2.jpg', 600, 600, 'N'),
(620, 'MV800_04_MB_1024x768.jpg', 600, 600, 'N'),
(621, 'MV800_37_MB_1024x768_2.jpg', 600, 600, 'N'),
(622, 'MV800_38_MB_1024x768_3.jpg', 600, 600, 'N'),
(623, 'MV800_45_MB_1024x768.jpg', 600, 600, 'N'),
(624, 'MV800_46_MB_1024x768_2.jpg', 600, 600, 'N'),
(625, 'MV800_F2_MB_1024x768.jpg', 600, 600, 'N'),
(626, 'MV800_FS1_MB_1024x768_2.jpg', 600, 600, 'N'),
(627, 'NX200_F4_B_1024x768_6.jpg', 1000, 819, 'N'),
(628, 'main_2.jpg', 800, 600, 'N'),
(629, 'NX200_B_B.jpg', 1024, 768, 'N'),
(630, 'NX200_BS1_B_2.jpg', 1280, 1280, 'N'),
(631, 'NX200_BS2_B.jpg', 897, 448, 'N'),
(632, 'NX200_FS1_B_2.jpg', 600, 600, 'N'),
(633, 'NX200_FS2_B.jpg', 1200, 1200, 'N'),
(634, 'NX200_FT1_B_2.jpg', 1024, 768, 'N'),
(635, 'NX200_S2_B.jpg', 1000, 1000, 'N'),
(636, 'NX200_T2_B_4.jpg', 1000, 1000, 'N'),
(637, 'NX200_WS1_B_1.jpg', 891, 797, 'N'),
(638, 'NX200_WS2_B_2.jpg', 600, 600, 'N'),
(639, 'NX200_F5_B_1024x768_2.jpg', 1024, 768, 'N'),
(640, 'NX-system_2_1024x768.jpg', 600, 600, 'N'),
(641, 'WB210_F_R_Global_4.jpg', 1024, 768, 'N'),
(642, 'WB210_FS_R_Global_2.jpg', 1000, 1000, 'N'),
(643, 'WB210_T_R_Global_2.jpg', 1024, 768, 'N'),
(644, 'WB210_B_R_Global_2.jpg', 800, 800, 'N'),
(645, '27528_1.jpg', 1024, 698, 'N'),
(646, '27528_2.jpg', 1024, 768, 'N'),
(647, '27528_3.jpg', 1135, 900, 'N'),
(648, '27528_4.jpg', 700, 700, 'N'),
(649, '27534_1.jpg', 700, 595, 'N'),
(650, '27534_2.jpg', 1200, 900, 'N'),
(651, '27534_4.jpg', 500, 500, 'N'),
(652, '27534_3.jpg', 500, 500, 'N'),
(653, '25472_1.jpg', 1000, 1000, 'N'),
(654, '25472_2.jpg', 1280, 1280, 'N'),
(655, '25472_4.jpg', 1200, 1200, 'N'),
(656, '25472_3.jpg', 1024, 783, 'N'),
(657, '25464_1.jpg', 900, 900, 'N'),
(658, '25464_2.jpg', 1024, 854, 'N'),
(659, '25464_4.jpg', 700, 700, 'N'),
(660, '25464_3.jpg', 1600, 1200, 'N'),
(661, '25478_1.jpg', 1200, 1200, 'N'),
(662, '25478_2.jpg', 1000, 1000, 'N'),
(663, '25478_4.jpg', 500, 500, 'N'),
(664, '25478_3.jpg', 500, 500, 'N'),
(665, '25478_5.jpg', 1000, 1000, 'N'),
(666, '588crm_hero.jpg', 800, 800, 'N'),
(667, '588crm_address.jpg', 800, 800, 'N'),
(668, '588crm_face.jpg', 800, 800, 'N'),
(669, '588crm_money.jpg', 800, 800, 'N'),
(670, 'url_uploaded_file_13287005214f325c6eac3d5.jpg', 632, 632, 'N'),
(671, 'T10_use_5.jpg', 750, 474, 'N'),
(672, 'T10_F2_O_1024x768.jpg', 600, 600, 'N'),
(673, 'T10_S1_O_1024x768.jpg', 600, 600, 'N'),
(674, 'T10_F2_O_1024x768_dimg_2.jpg', 600, 600, 'N'),
(675, 'T10_FS3_O_1024x768.jpg', 600, 600, 'N'),
(676, 'T10_T_O_1024x768_2.jpg', 600, 600, 'N'),
(677, 'T10_FS5_O_1024x768_2.jpg', 800, 544, 'N'),
(678, 'h300_main_5.jpg', 600, 600, 'N'),
(679, 'url_uploaded_file_13287007294f325d3b12476.jpg', 1375, 1093, 'N'),
(680, 'H300_FT_B_2.jpg', 800, 600, 'N'),
(681, 'H300_FS3_B_2.jpg', 1000, 1000, 'N'),
(682, 'H300_FS2_B_2.jpg', 1000, 1000, 'N'),
(683, 'H300_F2_B_2.jpg', 3000, 2000, 'N'),
(684, 'H300_F1_B_2.jpg', 600, 600, 'N'),
(685, 'H300_BS_B_2.jpg', 600, 600, 'N'),
(686, 'H300_B_B_2.jpg', 600, 600, 'N'),
(687, 'F50_front_5.jpg', 600, 600, 'N'),
(688, 'url_uploaded_file_13287009294f325e041c8e1.jpg', 550, 550, 'N'),
(689, 'F50_B_S_1024x768_2.jpg', 1024, 794, 'N'),
(690, 'F50_FS5_S_1024x768_2.jpg', 600, 600, 'N'),
(691, 'F50_BS_S_1024x768.jpg', 600, 600, 'N'),
(692, 'F50_F1_S_1024x768_2.jpg', 600, 600, 'N'),
(693, 'F50_S1_S_1024x768.jpg', 600, 600, 'N'),
(694, 'F50_FS2_S_1024x768_1.jpg', 600, 600, 'N'),
(695, 'F50_T1_S_1024x768_2.jpg', 600, 600, 'N'),
(696, 'F50_T2_S_1024x768.jpg', 600, 600, 'N'),
(697, 'blkdrv_hero.jpg', 800, 800, 'N'),
(698, 'blkdrv_face.jpg', 800, 800, 'N'),
(699, 'blkdrv_super.jpg', 800, 800, 'N'),
(700, 'blkdrv_toe.jpg', 800, 800, 'N'),
(701, 'mbank30208_w550_h550.jpg', 550, 550, 'N'),
(702, '16_bp_1.jpg', 800, 800, 'N'),
(703, '16_bp_2.jpg', 800, 800, 'N'),
(704, '16_bp_3.jpg', 800, 800, 'N'),
(705, '16_bp_4.jpg', 800, 800, 'N'),
(706, 'EX-S1855SB_600.jpg', 600, 600, 'N'),
(707, 'bloom_berry_set1.jpg', 800, 800, 'N'),
(708, 'bloom_berry_set2.jpg', 800, 800, 'N'),
(709, 'bloom_berry_driver_hero.jpg', 800, 800, 'N'),
(710, 'bloom_berry_8iron_hero.jpg', 800, 800, 'N'),
(711, 'bloom_berry_niblick_hero.jpg', 800, 800, 'N'),
(712, 'mbank15770_w550_h550.jpg', 550, 550, 'N'),
(713, 'NX_50-200_Lens_600.jpg', 600, 600, 'N'),
(714, 'ED-30NB_pancake2_600_1.jpg', 700, 700, 'N'),
(715, 'cameraLens_4.jpg', 600, 600, 'N'),
(716, '5e1cdabf5a35c38ba2b747c9adfddb7f.jpg', 800, 800, 'N'),
(717, '8ad650de56e5e2272b240d3a6c171545.jpg', 800, 800, 'N'),
(718, '167734bda696f56942c278bee07e7236.jpg', 800, 800, 'N'),
(719, '50Elite_Yellow_12ball_Render.jpg', 500, 500, 'N'),
(720, '50Elite_Yellow_3ball_Sleeve_Render.jpg', 500, 500, 'N'),
(721, '50Eilte_Yellow_Ball_Front_render.jpg', 500, 500, 'N'),
(722, '2163_1.jpg', 850, 850, 'N'),
(723, '2181_1.jpg', 1000, 816, 'N'),
(724, '02xrms-cd.jpg', 300, 300, 'N'),
(725, 'lenny_cover.jpg', 1000, 1000, 'N'),
(739, 'DIR-657_front.jpg', 1224, 1224, 'N'),
(727, 'U2TCD020.jpg', 1500, 1500, 'N'),
(728, '603497948727.sml_0.jpg', 500, 500, 'N'),
(729, 'feedingthemonkies_frntLRG.jpg', 600, 600, 'N'),
(730, 'url_uploaded_file_13287662164f335d096a3ce.jpg', 650, 650, 'N'),
(731, 'feedingthemonkies_bckLRG.jpg', 600, 600, 'N'),
(732, 'bbk_onekindfavorcdcover_sm.jpg', 500, 500, 'N'),
(733, 'bbk_originalhitscd.jpg', 500, 500, 'N'),
(734, 'url_uploaded_file_13287719184f33734f6b3e9.jpg', 1426, 1413, 'N'),
(735, 'url_uploaded_file_13287720374f3373c6eef1f.jpg', 600, 600, 'N'),
(736, 'cover1.jpg', 500, 500, 'N'),
(737, 'cover113287723384f3374f2d5491.jpg', 500, 500, 'N'),
(738, '5OCD09.jpg', 600, 600, 'N'),
(740, 'DIR-657_back.jpg', 800, 746, 'N'),
(741, 'DIR-657_package.jpg', 800, 600, 'N'),
(742, 'DIR-657_side.jpg', 1040, 922, 'N'),
(743, 'hyyfnOGfxDQXnGM0_500.jpg', 1680, 1187, 'N'),
(744, '6f2jZfBiIngiA5w9_500.jpg', 1574, 1134, 'N'),
(745, 'lLazPZxUGkwbxiMD_500.jpg', 1500, 1500, 'N'),
(746, '8nGC9Ie9LzTeYwhG_500.jpg', 800, 800, 'N'),
(747, 'Wfx1S8niGkMLf4J6_500.jpg', 800, 880, 'N'),
(748, 'KAFs4kAWJIJzo9Wn_500.jpg', 1024, 1238, 'N'),
(749, 'oddRDU1adeGw7hzT_500.jpg', 1514, 1833, 'N'),
(750, 'P_500.jpg', 500, 500, 'N'),
(751, 'QsZIfPvMYSFALNDL_500.jpg', 1280, 1280, 'N'),
(752, 'r8eFbY8vK54nOPhI_500.jpg', 800, 800, 'N'),
(753, '0um2OBCCu8446Wls_500.jpg', 500, 500, 'N'),
(754, 'TL-SC3430-01.jpg', 800, 800, 'N'),
(755, 'TL-SC3430-02.jpg', 1000, 1000, 'N'),
(756, 'TL-SC3430-03.jpg', 800, 600, 'N'),
(757, 'TL-SC3430-04.jpg', 500, 500, 'N'),
(758, 'l2698a_300.jpg', 500, 500, 'N'),
(759, 'cn216a_main.jpg', 500, 500, 'N'),
(760, 'cn577a_main.jpg', 500, 500, 'N'),
(761, '0120b3d3-82ef-4d27-8d43-9d75b4db19a1.jpg', 700, 525, 'N'),
(762, '4a3aa57f-6894-47b9-86d5-5ba73e9fd732.jpg', 700, 525, 'N'),
(763, 'adc9c3b2-94d7-4e17-a1d6-f2c29448bc4e.jpg', 700, 525, 'N'),
(764, 'imageservice.jpg', 1732, 2182, 'N'),
(765, 'P_50013287768924f3386bc5fe80.jpg', 500, 500, 'N'),
(766, 'nDMJWQLHhMN4fi8b_500.jpg', 500, 500, 'N'),
(767, 'b3k0951cYIyn1LDE_500.jpg', 500, 500, 'N'),
(768, 'vx8EzIhsyOV81i8h_500.jpg', 735, 750, 'N'),
(769, 'uMhBLQB2lSbT9kBm_500.jpg', 1000, 1000, 'N'),
(833, 'HN274H_350x250.jpg', 500, 500, 'N'),
(771, 'imageservice13287772554f338827bf601.jpg', 1000, 1000, 'N'),
(772, 'P_50013287772614f33882d85395.jpg', 500, 500, 'N'),
(773, 'YG1btKkZMPz16ZnZ_500.jpg', 1300, 1300, 'N'),
(774, 'xMTkMl6sfppE75Wt_500.jpg', 1300, 1300, 'N'),
(775, 'XDhwZOlu58p5FmeS_500.jpg', 500, 500, 'N'),
(776, 'P_50013287774434f3388e3b9edd.jpg', 500, 500, 'N'),
(777, 'w91u59ZCZzPzZ8RO_500.jpg', 500, 500, 'N'),
(778, 'OTPci8iqEoHfq8rX_500.jpg', 500, 500, 'N'),
(779, 'nO6yAKoQVtSOrbZv_500.jpg', 500, 500, 'N'),
(780, '300V5A_Raspberry-Pink_04_6.jpg', 600, 600, 'N'),
(781, '300V5A_Raspberry-Pink_02_2.jpg', 600, 600, 'N'),
(782, '300V5A_Raspberry-Pink_05.jpg', 600, 600, 'N'),
(783, '700Z-side_back_open-01.jpg', 900, 600, 'N'),
(784, '700Z3A_01_2.jpg', 600, 600, 'N'),
(785, '700Z3A_06.jpg', 600, 600, 'N'),
(786, '700Z3A_02.jpg', 600, 600, 'N'),
(787, '700Z3A_03_2.jpg', 600, 600, 'N'),
(788, '700Z3A_09_2.jpg', 600, 600, 'N'),
(789, '700Z3A_05.jpg', 600, 600, 'N'),
(790, '700Z3A_08.jpg', 600, 600, 'N'),
(791, '700Z3A_07_2.jpg', 600, 600, 'N'),
(792, '700Z-side_back_open-03.jpg', 1000, 749, 'N'),
(793, '700Z-side_front_open-01_2.jpg', 980, 735, 'N'),
(794, '700Z-side-01_2.jpg', 600, 600, 'N'),
(795, '9-Series-Laptop_04_4.jpg', 1024, 768, 'N'),
(796, '9-Series-Laptop_11_2.jpg', 850, 850, 'N'),
(797, '9-Series-Laptop_07_2.jpg', 600, 600, 'N'),
(798, '9-Series-Laptop_12_2.jpg', 1200, 1200, 'N'),
(799, '9-Series-Laptop_05_2.jpg', 1024, 1024, 'N'),
(800, '9-Series-Laptop_09_2.jpg', 600, 600, 'N'),
(801, '9-Series-Laptop_02_2.jpg', 1024, 1024, 'N'),
(802, '9-Series-Laptop_08_2.jpg', 600, 600, 'N'),
(803, '9-Series-Laptop_10_2.jpg', 600, 600, 'N'),
(804, '9-Series-Laptop_13_2.jpg', 600, 600, 'N'),
(805, '9-Series-Laptop_14_2.jpg', 1200, 843, 'N'),
(806, '600x600_NP300E5A-A01_main.jpg', 600, 600, 'N'),
(807, '600x600_front.jpg', 600, 600, 'N'),
(808, '600x600_angle.jpg', 600, 600, 'N'),
(809, 'p7310_400x400_large1_cf_1.jpg', 728, 546, 'N'),
(810, 'p7310_600x600_xlarge_vf.jpg', 600, 600, 'N'),
(811, 'p7310_600x600_xlarge_bk.jpg', 1200, 1200, 'N'),
(812, 'p7310_600x600_xlarge_s2.jpg', 600, 600, 'N'),
(813, 'p7310_600x600_xlarge_vf_1.jpg', 600, 600, 'N'),
(814, 'p7310_600x600_xlarge_vl.jpg', 640, 480, 'N'),
(815, 'p7310_600x600_xlarge_hl.jpg', 850, 700, 'N'),
(816, 'i957_600x600_xlarge_hf.jpg', 600, 600, 'N'),
(817, 'i957_600x600_xlarge_hl.jpg', 600, 600, 'N'),
(818, 'i957_600x600_xlarge_s2.jpg', 600, 600, 'N'),
(819, 'i957_600x600_xlarge_vb.jpg', 600, 600, 'N'),
(820, 'i957_600x600_xlarge_vf.jpg', 600, 600, 'N'),
(821, 'i957_600x600_xlarge_vl.jpg', 600, 600, 'N'),
(822, 'Ver_Galaxy_Tab_front2_5.jpg', 1000, 1000, 'N'),
(823, 'Ver_Galaxy_Tab_extbackleft_8.jpg', 600, 600, 'N'),
(824, 'Ver_Galaxy_Tab_horizback_10.jpg', 600, 600, 'N'),
(825, 'Ver_Galaxy_Tab_extbackright_6.jpg', 600, 600, 'N'),
(826, 'Ver_Galaxy_Tab_extleft2_2.jpg', 600, 600, 'N'),
(827, 'Ver_Galaxy_Tab_right2_2.jpg', 637, 606, 'N'),
(828, 'Ver_Galaxy_Tab_extright2.jpg', 600, 600, 'N'),
(829, 'Ver_Galaxy_Tab_left2_1.jpg', 600, 600, 'N'),
(830, 'Ver_Galaxy_Tab_horizfront2.jpg', 680, 680, 'N'),
(831, 'Ver_Galaxy_Tab_side1_6.jpg', 600, 600, 'N'),
(832, 'imageservice_(1).jpg', 1500, 1924, 'N'),
(834, 'large01.jpg', 1400, 1400, 'N'),
(835, 'large02.jpg', 1024, 576, 'N'),
(836, 'large03.jpg', 750, 750, 'N'),
(837, 'large04.jpg', 1772, 1158, 'N'),
(838, 'xp600aa_300.jpg', 1000, 1000, 'N'),
(839, 'url_uploaded_file_13287871234f33aeb3d0793.jpg', 1000, 1000, 'N'),
(840, 'url_uploaded_file_13287871534f33aed1a26d2.jpg', 850, 518, 'N'),
(841, 'url_uploaded_file_13287871534f33aed237cf7.jpg', 850, 518, 'N'),
(842, 'url_uploaded_file_13287872334f33af2276de4.jpg', 1095, 1095, 'N'),
(843, 'url_uploaded_file_13287872754f33af4c7159c.jpg', 1095, 1095, 'N'),
(844, 'url_uploaded_file_13287872754f33af4d0657a.jpg', 850, 518, 'N'),
(845, 'url_uploaded_file_13287873494f33af96095d8.jpg', 1000, 1000, 'N'),
(846, 'url_uploaded_file_13287873674f33afa7f19d6.jpg', 850, 518, 'N'),
(847, '2000004455_500.jpg', 500, 500, 'N'),
(848, '2000004453_500.jpg', 500, 500, 'N'),
(849, '2000004467_500.jpg', 500, 500, 'N'),
(850, '2000001597_500.jpg', 500, 500, 'N'),
(851, '2000004674_500.jpg', 500, 500, 'N'),
(852, '2000004674_500a.jpg', 500, 500, 'N'),
(853, '2000004674_500b.jpg', 500, 500, 'N'),
(854, 'white-iphone-hi.jpg', 1000, 1000, 'N'),
(855, 'iphone-smartphone-hi.jpg', 500, 596, 'N'),
(856, 'white-iphone-hi.jpg', 1000, 1000, 'N'),
(857, 'apple-ipod-hi.jpg', 700, 700, 'N'),
(858, 'ipod-shuffle-hi.jpg', 600, 521, 'N'),
(862, '242265_01.jpg', 500, 500, 'N'),
(861, '173283_01.jpg', 500, 500, 'N'),
(863, 'X29580_01.jpg', 500, 500, 'N'),
(879, '173283_0113298267324f438bac97eaf.jpg', 500, 500, 'N'),
(898, 'X41181_01.jpg', 2400, 2400, 'N'),
(881, 'X41182_01.jpg', 500, 500, 'N'),
(882, 'X41187_01.jpg', 500, 500, 'N'),
(904, 'ipad-black-1.jpg', 536, 742, 'N'),
(907, 'ipad-white-1.jpg', 536, 742, 'N'),
(905, 'ipad-black-2.jpg', 536, 742, 'N'),
(906, 'ipad-black-3.jpg', 536, 742, 'N'),
(908, 'ipad-white-2.jpg', 536, 742, 'N'),
(909, 'ipad-white-3.jpg', 536, 742, 'N'),
(926, 'clip_plus_black.jpg', 500, 500, 'N'),
(1006, 'Adidas_Logo.svg.png', 200, 133, 'N'),
(1007, '200px-Logo_NIKE.svg.png', 200, 72, 'N'),
(1008, '200px-ASUS_Logo.svg.png', 200, 35, 'N'),
(1009, 'Samsung_Logo.svg.png', 200, 68, 'N'),
(1010, 'Universal_Music_Group.svg.png', 225, 85, 'N'),
(1011, 'Apple_logo_black.svg.png', 150, 180, 'N'),
(1012, '250px-Acer_2011.svg.png', 250, 60, 'N'),
(1013, '150px-HP_logo_2012.svg.png', 150, 150, 'N'),
(1014, 'LG_Logo.svg.png', 200, 95, 'N'),
(1015, '250px-D-Link.svg.png', 250, 75, 'N'),
(1016, 'Concordjazzlogo.png', 68, 67, 'N'),
(1017, 'TP-Link_logo.jpg', 220, 61, 'N'),
(1018, 'Panasonic_logo_(Blue).svg.png', 220, 52, 'N'),
(1019, '230px-Pioneer_logo.svg.png', 230, 34, 'N'),
(1020, '190px-TomTom.svg.png', 190, 41, 'N'),
(1021, '225px-Garmin_logo.svg.png', 225, 61, 'N'),
(1022, '175px-Company-Logo-of-Kenwood001.png', 175, 34, 'N'),
(1023, 'cobra-logo.jpg', 152, 48, 'N'),
(1024, '225px-Roadrunner_Records_Logo.svg.png', 225, 68, 'N'),
(1025, '200px-Toshiba_logo.svg.png', 200, 31, 'N'),
(1026, 'Rhinologo_whiteonwhite.png', 150, 79, 'N'),
(1027, '200px-Htc_new_logo.svg.png', 200, 111, 'N'),
(1028, '250px-Motorola.svg.png', 250, 47, 'N'),
(1029, 'Nokia_wordmark.svg.png', 200, 34, 'N'),
(1030, 'Creative_Technology_logo.svg.png', 200, 45, 'N'),
(1031, '200px-YamahaCorp.svg.png', 200, 45, 'N'),
(1032, 'Entertainment_One_logo.svg.png', 150, 172, 'N'),
(1033, 'Sony_logo.svg.png', 220, 37, 'N'),
(1034, 'koss_logo.jpg', 300, 88, 'N'),
(1035, 'Nikon_logo.svg.png', 150, 150, 'N'),
(1036, '79085903.jpg', 150, 48, 'N'),
(1037, '200px-Warner_Bros.svg.png', 200, 209, 'N'),
(1038, '200px-Warner_Bros.svg.png', 200, 209, 'N'),
(1039, 'Arc_system_works.jpg', 64, 65, 'N'),
(1040, 'SanDisk_Logo_2007.svg.png', 200, 40, 'N'),
(1041, '230px-Namco_logo.svg.png', 230, 32, 'N'),
(1042, 'Namco_Bandai_Games_Logo.png', 243, 222, 'N'),
(1043, '220px-Capcom_logo.svg.png', 220, 40, 'N'),
(1044, 'Casio_logo.svg.png', 250, 50, 'N'),
(1045, 'Quartet_Logo_jpg.jpg', 250, 92, 'N'),
(1046, 'Swingline_Logo.jpg', 200, 53, 'N'),
(1047, 'logo_wilsonjones.gif', 204, 112, 'N'),
(1048, 'aiko_safe_t.gif', 80, 50, 'N'),
(1051, 'Clevelandgolf_logo.png', 320, 128, 'N'),
(1052, 'CamelBak_Logo.jpg', 150, 48, 'N'),
(1053, 'Wilson_Staff_Logo.jpg', 274, 292, 'N'),
(1054, 'Montblanc_logo.png', 85, 46, 'N'),
(1055, 'Tissot_Logo.svg.png', 85, 31, 'N'),
(1057, 'Intel-logo.jpg', 323, 300, 'N'),
(1058, 'pocket_bell.jpg', 700, 700, 'N'),
(1062, 'iphone_green.png', 600, 600, 'N'),
(1061, 'pocket_bell2.jpg', 700, 700, 'N'),
(1063, 'iphone_5c2.png', 600, 600, 'N'),
(1064, 'iphones_5c.png', 600, 600, 'N'),
(1065, 'go_pro.png', 600, 600, 'N'),
(1066, 'go_pro_2.png', 600, 600, 'N'),
(1067, 'go_pro_3.png', 600, 600, 'N'),
(1068, 'go_pro_4.png', 600, 600, 'N'),
(1069, 'gopro-logo-whitebgd.jpg', 288, 90, 'N'),
(1074, '1.png', 894, 305, 'N'),
(1073, '2_en_1.png', 894, 305, 'N'),
(1072, '3_en_1.png', 894, 305, 'N'),
(1279, 'comp.png', 60, 48, 'N'),
(1280, 'cars.png', 60, 48, 'N'),
(1281, 'mp3.png', 60, 48, 'N'),
(1282, 'cell.png', 60, 48, 'N'),
(1283, 'tv.png', 60, 48, 'N'),
(1284, 'camera.png', 60, 48, 'N'),
(1285, 'nokia_n1_perspectives_-_app.jpg', 5000, 3096, 'N'),
(1286, 'nokia-n1-tablet-thin.jpg', 780, 112, 'N'),
(1287, 'nokia-n1.jpg', 1702, 1100, 'N'),
(1288, 'a05b922ffd50ee0d1818527e9d4a.jpg', 900, 548, 'N'),
(1187, 'i.jpg', 478, 616, 'N'),
(1188, 'i_(1).jpg', 280, 160, 'N'),
(1189, 'i_(2).jpg', 280, 85, 'N'),
(1190, 'i_(3).jpg', 701, 245, 'N'),
(1191, 'i_(4).jpg', 701, 615, 'N'),
(1386, '664187.jpg', 295, 249, 'N'),
(1270, 'ea.png', 152, 151, 'N'),
(1220, '1.png', 256, 144, 'N'),
(1226, '1.jpg', 120, 120, 'N'),
(1223, 'nintendo.jpg', 156, 117, 'N'),
(8644, 'promotion_coupon.jpg', 770, 471, 'N'),
(8643, 'promotion_pickup.jpg', 770, 471, 'N'),
(8642, 'promotion_xbox_one.jpg', 770, 471, 'N'),
(8640, 'promotion_10_for_demo.jpg', 770, 471, 'N'),
(8639, 'promotion_free_shipping.jpg', 770, 471, 'N'),
(8645, 'cart.png', 300, 49, 'N'),
(8646, 'favicon.ico', 48, 48, 'N'),
(8647, 'invoice_logo.png', 300, 49, 'N'),
(8648, 'gift_cert_logo.png', 176, 42, 'N'),
(1396, 't-13.jpg', 2400, 2838, 'N'),
(1397, 't-6.jpg', 400, 543, 'N'),
(1398, 't-3.jpg', 400, 543, 'N'),
(1399, 't-10.jpg', 1000, 1182, 'N'),
(1400, 't-11.jpg', 700, 700, 'N'),
(1401, 't-4.jpg', 2300, 2415, 'N'),
(1402, 't-12.jpg', 1500, 1500, 'N'),
(1403, 't-8.jpg', 1500, 1500, 'N'),
(1404, 't-2.jpg', 2300, 2415, 'N'),
(1405, 't-7.jpg', 1500, 1500, 'N'),
(1406, 't-5.jpg', 1500, 1500, 'N'),
(1407, 't-9.jpg', 700, 700, 'N'),
(8649, '3.jpg', 500, 500, 'N'),
(8650, '1.jpg', 800, 800, 'N'),
(8651, '2.jpg', 500, 500, 'N'),
(1076, 'gift_certificate.png', 1200, 136, 'N'),
(1077, 'holiday_gift.png', 900, 175, 'N'),
(1300, 'banner-en-sale-40-80.png', 740, 395, 'N'),
(1301, 'banner-en-xbox360.png', 740, 395, 'N'),
(1302, 'banner-en-point.png', 740, 395, 'N'),
(1303, 'banner-en-girl.png', 740, 395, 'N'),
(1304, 'banner_en_free_ship_lies-pz.png', 434, 185, 'N'),
(1305, 'banner_en_pickup_ok56-7h.png', 434, 185, 'N'),
(8633, 'banner_acme_mobile.jpg', 770, 471, 'N'),
(8634, 'banner_multivendor_mobile.jpg', 770, 471, 'N'),
(8632, 'banner_x-box_mobile.jpg', 770, 471, 'N');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]images_links`
--

CREATE TABLE `[[dbprefix]]images_links` (
  `pair_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `object_id` int(11) unsigned NOT NULL DEFAULT '0',
  `object_type` varchar(24) NOT NULL DEFAULT '',
  `image_id` int(11) unsigned NOT NULL DEFAULT '0',
  `detailed_id` int(11) unsigned NOT NULL DEFAULT '0',
  `type` char(1) NOT NULL DEFAULT 'M',
  `position` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`pair_id`),
  KEY `object_id` (`object_id`,`object_type`,`type`),
  KEY `detailed_id` (`detailed_id`),
  KEY `image_id` (`image_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=3262 ;

--
-- Dumping data for table `[[dbprefix]]images_links`
--

INSERT INTO `[[dbprefix]]images_links` VALUES
(181, 1, 'product', 0, 237, 'M', 0),
(182, 1, 'product', 0, 238, 'A', 0),
(183, 1, 'product', 0, 239, 'A', 0),
(184, 1, 'product', 0, 240, 'A', 0),
(187, 4, 'product', 0, 243, 'M', 0),
(188, 4, 'product', 0, 244, 'A', 0),
(189, 4, 'product', 0, 245, 'A', 0),
(190, 5, 'product', 0, 246, 'M', 0),
(191, 5, 'product', 0, 247, 'A', 0),
(192, 5, 'product', 0, 248, 'A', 0),
(193, 5, 'product', 0, 249, 'A', 0),
(194, 5, 'product', 0, 250, 'A', 0),
(195, 6, 'product', 0, 251, 'M', 0),
(196, 7, 'product', 0, 252, 'M', 0),
(198, 6, 'product', 0, 254, 'A', 0),
(199, 6, 'product', 0, 255, 'A', 0),
(200, 6, 'product', 0, 256, 'A', 0),
(201, 8, 'product', 0, 257, 'M', 0),
(202, 8, 'product', 0, 258, 'A', 0),
(203, 8, 'product', 0, 259, 'A', 0),
(204, 8, 'product', 0, 260, 'A', 0),
(205, 9, 'product', 0, 261, 'M', 0),
(206, 9, 'product', 0, 262, 'A', 0),
(207, 9, 'product', 0, 263, 'A', 0),
(208, 9, 'product', 0, 264, 'A', 0),
(209, 10, 'product', 0, 265, 'M', 0),
(210, 11, 'product', 0, 266, 'M', 0),
(211, 11, 'product', 0, 267, 'A', 0),
(212, 10, 'product', 0, 268, 'A', 0),
(213, 10, 'product', 0, 269, 'A', 0),
(214, 10, 'product', 0, 270, 'A', 0),
(215, 10, 'product', 0, 271, 'A', 0),
(218, 13, 'product', 0, 274, 'M', 0),
(219, 14, 'product', 0, 275, 'M', 0),
(220, 14, 'product', 0, 276, 'A', 0),
(221, 14, 'product', 0, 277, 'A', 0),
(222, 14, 'product', 0, 278, 'A', 0),
(223, 14, 'product', 0, 279, 'A', 0),
(224, 15, 'product', 0, 280, 'M', 0),
(225, 15, 'product', 0, 281, 'A', 0),
(226, 16, 'product', 0, 282, 'M', 0),
(227, 16, 'product', 0, 283, 'A', 0),
(228, 16, 'product', 0, 284, 'A', 0),
(229, 17, 'product', 0, 285, 'M', 0),
(230, 18, 'product', 0, 286, 'M', 0),
(231, 18, 'product', 0, 287, 'A', 0),
(232, 19, 'product', 0, 288, 'M', 0),
(233, 19, 'product', 0, 289, 'A', 0),
(234, 19, 'product', 0, 290, 'A', 0),
(235, 19, 'product', 0, 291, 'A', 0),
(236, 20, 'product', 0, 292, 'M', 0),
(237, 21, 'product', 0, 293, 'M', 0),
(238, 21, 'product', 0, 294, 'A', 0),
(239, 22, 'product', 0, 295, 'M', 0),
(240, 23, 'product', 0, 296, 'M', 0),
(241, 24, 'product', 0, 297, 'M', 0),
(242, 24, 'product', 0, 298, 'A', 0),
(243, 25, 'product', 0, 299, 'M', 0),
(244, 26, 'product', 0, 300, 'M', 0),
(245, 27, 'product', 0, 301, 'M', 0),
(246, 27, 'product', 0, 302, 'A', 0),
(247, 28, 'product', 0, 303, 'M', 0),
(248, 28, 'product', 0, 304, 'A', 0),
(249, 29, 'product', 0, 305, 'M', 0),
(250, 29, 'product', 0, 306, 'A', 0),
(251, 29, 'product', 0, 307, 'A', 0),
(252, 29, 'product', 0, 308, 'A', 0),
(253, 29, 'product', 0, 309, 'A', 0),
(254, 30, 'product', 0, 310, 'M', 0),
(255, 31, 'product', 0, 311, 'M', 0),
(256, 31, 'product', 0, 312, 'A', 0),
(257, 30, 'product', 0, 313, 'A', 0),
(258, 30, 'product', 0, 314, 'A', 0),
(259, 30, 'product', 0, 315, 'A', 0),
(260, 32, 'product', 0, 316, 'M', 0),
(261, 32, 'product', 0, 317, 'A', 0),
(262, 32, 'product', 0, 318, 'A', 0),
(263, 33, 'product', 0, 319, 'M', 0),
(264, 34, 'product', 0, 320, 'M', 0),
(265, 34, 'product', 0, 321, 'A', 0),
(266, 33, 'product', 0, 322, 'A', 0),
(267, 33, 'product', 0, 323, 'A', 0),
(268, 35, 'product', 0, 324, 'M', 0),
(269, 36, 'product', 0, 325, 'M', 0),
(271, 37, 'product', 0, 327, 'M', 0),
(272, 38, 'product', 0, 328, 'M', 0),
(273, 38, 'product', 0, 329, 'A', 0),
(274, 39, 'product', 0, 330, 'M', 0),
(275, 39, 'product', 0, 331, 'A', 0),
(276, 39, 'product', 0, 332, 'A', 0),
(277, 39, 'product', 0, 333, 'A', 0),
(278, 40, 'product', 0, 334, 'M', 0),
(279, 40, 'product', 0, 335, 'A', 0),
(280, 40, 'product', 0, 336, 'A', 0),
(281, 40, 'product', 0, 337, 'A', 0),
(282, 40, 'product', 0, 338, 'A', 0),
(283, 41, 'product', 0, 339, 'M', 0),
(284, 41, 'product', 0, 340, 'A', 0),
(285, 42, 'product', 0, 341, 'M', 0),
(286, 42, 'product', 0, 342, 'A', 0),
(287, 42, 'product', 0, 343, 'A', 0),
(288, 43, 'product', 0, 344, 'M', 0),
(289, 43, 'product', 0, 345, 'A', 0),
(290, 43, 'product', 0, 346, 'A', 0),
(291, 43, 'product', 0, 347, 'A', 0),
(292, 43, 'product', 0, 348, 'A', 0),
(293, 44, 'product', 0, 349, 'M', 0),
(294, 45, 'product', 0, 350, 'M', 0),
(295, 46, 'product', 0, 351, 'M', 0),
(296, 47, 'product', 0, 352, 'M', 0),
(297, 47, 'product', 0, 353, 'A', 0),
(298, 48, 'product', 0, 354, 'M', 0),
(299, 49, 'product', 0, 355, 'M', 0),
(300, 50, 'product', 0, 356, 'M', 0),
(301, 50, 'product', 0, 357, 'A', 0),
(302, 50, 'product', 0, 358, 'A', 0),
(303, 50, 'product', 0, 359, 'A', 0),
(304, 51, 'product', 0, 360, 'M', 0),
(305, 52, 'product', 0, 361, 'M', 0),
(306, 53, 'product', 0, 362, 'M', 0),
(307, 54, 'product', 0, 363, 'M', 0),
(308, 55, 'product', 0, 364, 'M', 0),
(309, 55, 'product', 0, 365, 'A', 0),
(310, 55, 'product', 0, 366, 'A', 0),
(311, 55, 'product', 0, 367, 'A', 0),
(312, 56, 'product', 0, 368, 'M', 0),
(313, 56, 'product', 0, 369, 'A', 0),
(314, 57, 'product', 0, 370, 'M', 0),
(315, 57, 'product', 0, 371, 'A', 0),
(316, 58, 'product', 0, 372, 'M', 0),
(317, 58, 'product', 0, 373, 'A', 0),
(318, 58, 'product', 0, 374, 'A', 0),
(319, 58, 'product', 0, 375, 'A', 0),
(320, 58, 'product', 0, 376, 'A', 0),
(321, 58, 'product', 0, 377, 'A', 0),
(322, 58, 'product', 0, 378, 'A', 0),
(323, 59, 'product', 0, 379, 'M', 0),
(324, 59, 'product', 0, 380, 'A', 0),
(325, 59, 'product', 0, 381, 'A', 0),
(326, 59, 'product', 0, 382, 'A', 0),
(327, 59, 'product', 0, 383, 'A', 0),
(328, 60, 'product', 0, 384, 'M', 0),
(329, 60, 'product', 0, 385, 'A', 0),
(330, 60, 'product', 0, 386, 'A', 0),
(334, 62, 'product', 0, 390, 'M', 0),
(335, 63, 'product', 0, 391, 'M', 0),
(336, 64, 'product', 0, 392, 'M', 0),
(337, 65, 'product', 0, 393, 'M', 0),
(338, 66, 'product', 0, 394, 'M', 0),
(339, 67, 'product', 0, 395, 'M', 0),
(340, 67, 'product', 0, 396, 'A', 0),
(341, 67, 'product', 0, 397, 'A', 0),
(342, 67, 'product', 0, 398, 'A', 0),
(343, 68, 'product', 0, 399, 'M', 0),
(344, 68, 'product', 0, 400, 'A', 0),
(345, 68, 'product', 0, 401, 'A', 0),
(346, 68, 'product', 0, 402, 'A', 0),
(347, 68, 'product', 0, 403, 'A', 0),
(348, 68, 'product', 0, 404, 'A', 0),
(349, 68, 'product', 0, 405, 'A', 0),
(350, 68, 'product', 0, 406, 'A', 0),
(351, 68, 'product', 0, 407, 'A', 0),
(352, 69, 'product', 0, 408, 'M', 0),
(353, 69, 'product', 0, 409, 'A', 0),
(354, 69, 'product', 0, 410, 'A', 0),
(355, 69, 'product', 0, 411, 'A', 0),
(356, 69, 'product', 0, 412, 'A', 0),
(357, 70, 'product', 0, 413, 'M', 0),
(358, 70, 'product', 0, 414, 'A', 0),
(359, 70, 'product', 0, 415, 'A', 0),
(360, 70, 'product', 0, 416, 'A', 0),
(361, 70, 'product', 0, 417, 'A', 0),
(362, 71, 'product', 0, 418, 'M', 0),
(363, 71, 'product', 0, 419, 'A', 0),
(364, 71, 'product', 0, 420, 'A', 0),
(365, 71, 'product', 0, 421, 'A', 0),
(366, 71, 'product', 0, 422, 'A', 0),
(367, 72, 'product', 0, 423, 'M', 0),
(368, 72, 'product', 0, 424, 'A', 0),
(369, 72, 'product', 0, 425, 'A', 0),
(370, 72, 'product', 0, 426, 'A', 0),
(371, 72, 'product', 0, 427, 'A', 0),
(372, 73, 'product', 0, 428, 'M', 0),
(373, 73, 'product', 0, 429, 'A', 0),
(374, 73, 'product', 0, 430, 'A', 0),
(375, 73, 'product', 0, 431, 'A', 0),
(376, 73, 'product', 0, 432, 'A', 0),
(377, 74, 'product', 0, 433, 'M', 0),
(378, 74, 'product', 0, 434, 'A', 0),
(379, 74, 'product', 0, 435, 'A', 0),
(380, 74, 'product', 0, 436, 'A', 0),
(381, 74, 'product', 0, 437, 'A', 0),
(382, 75, 'product', 0, 438, 'M', 0),
(383, 75, 'product', 0, 439, 'A', 0),
(384, 75, 'product', 0, 440, 'A', 0),
(385, 75, 'product', 0, 441, 'A', 0),
(386, 75, 'product', 0, 442, 'A', 0),
(387, 76, 'product', 0, 443, 'M', 0),
(388, 76, 'product', 0, 444, 'A', 0),
(389, 76, 'product', 0, 445, 'A', 0),
(390, 76, 'product', 0, 446, 'A', 0),
(391, 76, 'product', 0, 447, 'A', 0),
(466, 117, 'product', 0, 522, 'M', 0),
(469, 117, 'product', 0, 525, 'A', 0),
(468, 117, 'product', 0, 524, 'A', 0),
(467, 118, 'product', 0, 523, 'M', 0),
(397, 78, 'product', 0, 453, 'M', 0),
(398, 78, 'product', 0, 454, 'A', 0),
(399, 78, 'product', 0, 455, 'A', 0),
(400, 78, 'product', 0, 456, 'A', 0),
(401, 78, 'product', 0, 457, 'A', 0),
(402, 79, 'product', 0, 458, 'M', 0),
(403, 79, 'product', 0, 459, 'A', 0),
(404, 79, 'product', 0, 460, 'A', 0),
(405, 79, 'product', 0, 461, 'A', 0),
(406, 79, 'product', 0, 462, 'A', 0),
(407, 80, 'product', 0, 463, 'M', 0),
(408, 80, 'product', 0, 464, 'A', 0),
(409, 81, 'product', 0, 465, 'M', 0),
(410, 81, 'product', 0, 466, 'A', 0),
(411, 81, 'product', 0, 467, 'A', 0),
(412, 82, 'product', 0, 468, 'M', 0),
(413, 83, 'product', 0, 469, 'M', 0),
(414, 84, 'product', 0, 470, 'M', 0),
(415, 85, 'product', 0, 471, 'M', 0),
(454, 86, 'product', 0, 510, 'M', 0),
(417, 87, 'product', 0, 473, 'M', 0),
(418, 88, 'product', 0, 474, 'M', 0),
(419, 89, 'product', 0, 475, 'M', 0),
(420, 90, 'product', 0, 476, 'M', 0),
(421, 91, 'product', 0, 477, 'M', 0),
(422, 91, 'product', 0, 478, 'A', 0),
(423, 91, 'product', 0, 479, 'A', 0),
(424, 91, 'product', 0, 480, 'A', 0),
(425, 91, 'product', 0, 481, 'A', 0),
(426, 92, 'product', 0, 482, 'M', 0),
(427, 92, 'product', 0, 483, 'A', 0),
(428, 92, 'product', 0, 484, 'A', 0),
(429, 92, 'product', 0, 485, 'A', 0),
(430, 93, 'product', 0, 486, 'M', 0),
(431, 94, 'product', 0, 487, 'M', 0),
(432, 95, 'product', 0, 488, 'M', 0),
(433, 96, 'product', 0, 489, 'M', 0),
(455, 110, 'product', 0, 511, 'M', 0),
(435, 97, 'product', 0, 491, 'M', 0),
(458, 113, 'product', 0, 514, 'M', 0),
(459, 113, 'product', 0, 515, 'A', 0),
(439, 100, 'product', 0, 495, 'M', 0),
(461, 113, 'product', 0, 517, 'A', 0),
(460, 113, 'product', 0, 516, 'A', 0),
(442, 101, 'product', 0, 498, 'M', 0),
(457, 112, 'product', 0, 513, 'M', 0),
(444, 102, 'product', 0, 500, 'M', 0),
(445, 103, 'product', 0, 501, 'M', 0),
(446, 104, 'product', 0, 502, 'M', 0),
(447, 105, 'product', 0, 503, 'M', 0),
(448, 106, 'product', 0, 504, 'M', 0),
(463, 114, 'product', 0, 519, 'M', 0),
(462, 113, 'product', 0, 518, 'A', 0),
(451, 107, 'product', 0, 507, 'M', 0),
(452, 108, 'product', 0, 508, 'M', 0),
(453, 109, 'product', 0, 509, 'M', 0),
(456, 111, 'product', 0, 512, 'M', 0),
(464, 115, 'product', 0, 520, 'M', 0),
(465, 116, 'product', 0, 521, 'M', 0),
(470, 117, 'product', 0, 526, 'A', 0),
(471, 117, 'product', 0, 527, 'A', 0),
(472, 117, 'product', 0, 528, 'A', 0),
(473, 117, 'product', 0, 529, 'A', 0),
(474, 119, 'product', 0, 530, 'M', 0),
(475, 120, 'product', 0, 531, 'M', 0),
(476, 121, 'product', 0, 532, 'M', 0),
(477, 122, 'product', 0, 533, 'M', 0),
(478, 123, 'product', 0, 534, 'M', 0),
(479, 124, 'product', 0, 535, 'M', 0),
(480, 120, 'product', 0, 536, 'A', 0),
(481, 120, 'product', 0, 537, 'A', 0),
(482, 120, 'product', 0, 538, 'A', 0),
(483, 120, 'product', 0, 539, 'A', 0),
(484, 120, 'product', 0, 540, 'A', 0),
(485, 125, 'product', 0, 541, 'M', 0),
(486, 126, 'product', 0, 542, 'M', 0),
(487, 125, 'product', 0, 543, 'A', 0),
(488, 125, 'product', 0, 544, 'A', 0),
(489, 125, 'product', 0, 545, 'A', 0),
(490, 125, 'product', 0, 546, 'A', 0),
(491, 125, 'product', 0, 547, 'A', 0),
(492, 127, 'product', 0, 548, 'M', 0),
(493, 127, 'product', 0, 549, 'A', 0),
(494, 127, 'product', 0, 550, 'A', 0),
(495, 127, 'product', 0, 551, 'A', 0),
(496, 127, 'product', 0, 552, 'A', 0),
(497, 127, 'product', 0, 553, 'A', 0),
(498, 128, 'product', 0, 554, 'M', 0),
(499, 129, 'product', 0, 555, 'M', 0),
(500, 129, 'product', 0, 556, 'A', 0),
(501, 129, 'product', 0, 557, 'A', 0),
(502, 129, 'product', 0, 558, 'A', 0),
(503, 130, 'product', 0, 559, 'M', 0),
(504, 131, 'product', 0, 560, 'M', 0),
(505, 131, 'product', 0, 561, 'A', 0),
(506, 131, 'product', 0, 562, 'A', 0),
(507, 132, 'product', 0, 563, 'M', 0),
(516, 133, 'product', 0, 572, 'M', 0),
(509, 132, 'product', 0, 565, 'A', 0),
(510, 132, 'product', 0, 566, 'A', 0),
(511, 132, 'product', 0, 567, 'A', 0),
(512, 132, 'product', 0, 568, 'A', 0),
(513, 132, 'product', 0, 569, 'A', 0),
(514, 132, 'product', 0, 570, 'A', 0),
(515, 132, 'product', 0, 571, 'A', 0),
(517, 133, 'product', 0, 573, 'A', 0),
(518, 133, 'product', 0, 574, 'A', 0),
(519, 133, 'product', 0, 575, 'A', 0),
(520, 133, 'product', 0, 576, 'A', 0),
(521, 133, 'product', 0, 577, 'A', 0),
(522, 133, 'product', 0, 578, 'A', 0),
(523, 133, 'product', 0, 579, 'A', 0),
(524, 134, 'product', 0, 580, 'M', 0),
(525, 135, 'product', 0, 581, 'M', 0),
(526, 136, 'product', 0, 582, 'M', 0),
(527, 137, 'product', 0, 583, 'M', 0),
(528, 138, 'product', 0, 584, 'M', 0),
(529, 139, 'product', 0, 585, 'M', 0),
(530, 140, 'product', 0, 586, 'M', 0),
(531, 141, 'product', 0, 587, 'M', 0),
(532, 142, 'product', 0, 588, 'M', 0),
(533, 143, 'product', 0, 589, 'M', 0),
(534, 144, 'product', 0, 590, 'M', 0),
(535, 145, 'product', 0, 591, 'M', 0),
(536, 147, 'product', 0, 592, 'M', 0),
(537, 148, 'product', 0, 593, 'M', 0),
(538, 148, 'product', 0, 594, 'A', 0),
(539, 149, 'product', 0, 595, 'M', 0),
(540, 150, 'product', 0, 596, 'M', 0),
(541, 151, 'product', 0, 597, 'M', 0),
(542, 152, 'product', 0, 598, 'M', 0),
(543, 153, 'product', 0, 599, 'M', 0),
(544, 153, 'product', 0, 600, 'A', 0),
(545, 149, 'product', 0, 601, 'A', 0),
(546, 154, 'product', 0, 602, 'M', 0),
(547, 154, 'product', 0, 603, 'A', 0),
(548, 155, 'product', 0, 604, 'M', 0),
(549, 155, 'product', 0, 605, 'A', 0),
(550, 155, 'product', 0, 606, 'A', 0),
(551, 155, 'product', 0, 607, 'A', 0),
(552, 155, 'product', 0, 608, 'A', 0),
(553, 156, 'product', 0, 609, 'M', 0),
(554, 156, 'product', 0, 610, 'A', 0),
(555, 157, 'product', 0, 611, 'M', 0),
(556, 157, 'product', 0, 612, 'A', 0),
(557, 158, 'product', 0, 613, 'M', 0),
(558, 159, 'product', 0, 614, 'M', 0),
(559, 160, 'product', 0, 615, 'M', 0),
(560, 161, 'product', 0, 616, 'M', 0),
(561, 162, 'product', 0, 617, 'M', 0),
(562, 161, 'product', 0, 618, 'A', 0),
(563, 161, 'product', 0, 619, 'A', 0),
(564, 161, 'product', 0, 620, 'A', 0),
(565, 161, 'product', 0, 621, 'A', 0),
(566, 161, 'product', 0, 622, 'A', 0),
(567, 161, 'product', 0, 623, 'A', 0),
(568, 161, 'product', 0, 624, 'A', 0),
(569, 161, 'product', 0, 625, 'A', 0),
(570, 161, 'product', 0, 626, 'A', 0),
(571, 163, 'product', 0, 627, 'M', 0),
(572, 163, 'product', 0, 628, 'A', 0),
(573, 163, 'product', 0, 629, 'A', 0),
(574, 163, 'product', 0, 630, 'A', 0),
(575, 163, 'product', 0, 631, 'A', 0),
(576, 163, 'product', 0, 632, 'A', 0),
(577, 163, 'product', 0, 633, 'A', 0),
(578, 163, 'product', 0, 634, 'A', 0),
(579, 163, 'product', 0, 635, 'A', 0),
(580, 163, 'product', 0, 636, 'A', 0),
(581, 163, 'product', 0, 637, 'A', 0),
(582, 163, 'product', 0, 638, 'A', 0),
(583, 163, 'product', 0, 639, 'A', 0),
(584, 163, 'product', 0, 640, 'A', 0),
(585, 164, 'product', 0, 641, 'M', 0),
(586, 164, 'product', 0, 642, 'A', 0),
(587, 164, 'product', 0, 643, 'A', 0),
(588, 164, 'product', 0, 644, 'A', 0),
(589, 165, 'product', 0, 645, 'M', 0),
(590, 165, 'product', 0, 646, 'A', 0),
(591, 165, 'product', 0, 647, 'A', 0),
(592, 165, 'product', 0, 648, 'A', 0),
(593, 166, 'product', 0, 649, 'M', 0),
(594, 166, 'product', 0, 650, 'A', 0),
(595, 166, 'product', 0, 651, 'A', 0),
(596, 166, 'product', 0, 652, 'A', 0),
(597, 167, 'product', 0, 653, 'M', 0),
(598, 167, 'product', 0, 654, 'A', 0),
(599, 167, 'product', 0, 655, 'A', 0),
(600, 167, 'product', 0, 656, 'A', 0),
(601, 168, 'product', 0, 657, 'M', 0),
(602, 168, 'product', 0, 658, 'A', 0),
(603, 168, 'product', 0, 659, 'A', 0),
(604, 168, 'product', 0, 660, 'A', 0),
(605, 169, 'product', 0, 661, 'M', 0),
(606, 169, 'product', 0, 662, 'A', 0),
(607, 169, 'product', 0, 663, 'A', 0),
(608, 169, 'product', 0, 664, 'A', 0),
(609, 169, 'product', 0, 665, 'A', 0),
(610, 170, 'product', 0, 666, 'M', 0),
(611, 170, 'product', 0, 667, 'A', 0),
(612, 170, 'product', 0, 668, 'A', 0),
(613, 170, 'product', 0, 669, 'A', 0),
(614, 171, 'product', 0, 670, 'M', 0),
(615, 172, 'product', 0, 671, 'M', 0),
(616, 172, 'product', 0, 672, 'A', 0),
(617, 172, 'product', 0, 673, 'A', 0),
(618, 172, 'product', 0, 674, 'A', 0),
(619, 172, 'product', 0, 675, 'A', 0),
(620, 172, 'product', 0, 676, 'A', 0),
(621, 172, 'product', 0, 677, 'A', 0),
(622, 173, 'product', 0, 678, 'M', 0),
(623, 174, 'product', 0, 679, 'M', 0),
(624, 173, 'product', 0, 680, 'A', 0),
(625, 173, 'product', 0, 681, 'A', 0),
(626, 173, 'product', 0, 682, 'A', 0),
(627, 173, 'product', 0, 683, 'A', 0),
(628, 173, 'product', 0, 684, 'A', 0),
(629, 173, 'product', 0, 685, 'A', 0),
(630, 173, 'product', 0, 686, 'A', 0),
(631, 175, 'product', 0, 687, 'M', 0),
(632, 176, 'product', 0, 688, 'M', 0),
(633, 175, 'product', 0, 689, 'A', 0),
(634, 175, 'product', 0, 690, 'A', 0),
(635, 175, 'product', 0, 691, 'A', 0),
(636, 175, 'product', 0, 692, 'A', 0),
(637, 175, 'product', 0, 693, 'A', 0),
(638, 175, 'product', 0, 694, 'A', 0),
(639, 175, 'product', 0, 695, 'A', 0),
(640, 175, 'product', 0, 696, 'A', 0),
(641, 177, 'product', 0, 697, 'M', 0),
(642, 177, 'product', 0, 698, 'A', 0),
(643, 177, 'product', 0, 699, 'A', 0),
(644, 177, 'product', 0, 700, 'A', 0),
(645, 178, 'product', 0, 701, 'M', 0),
(646, 179, 'product', 0, 702, 'M', 0),
(647, 179, 'product', 0, 703, 'A', 0),
(648, 179, 'product', 0, 704, 'A', 0),
(649, 179, 'product', 0, 705, 'A', 0),
(650, 180, 'product', 0, 706, 'M', 0),
(651, 181, 'product', 0, 707, 'M', 0),
(652, 181, 'product', 0, 708, 'A', 0),
(653, 181, 'product', 0, 709, 'A', 0),
(654, 181, 'product', 0, 710, 'A', 0),
(655, 181, 'product', 0, 711, 'A', 0),
(656, 182, 'product', 0, 712, 'M', 0),
(657, 183, 'product', 0, 713, 'M', 0),
(658, 184, 'product', 0, 714, 'M', 0),
(659, 184, 'product', 0, 715, 'A', 0),
(660, 185, 'product', 0, 716, 'M', 0),
(661, 186, 'product', 0, 717, 'M', 0),
(662, 187, 'product', 0, 718, 'M', 0),
(663, 188, 'product', 0, 719, 'M', 0),
(664, 188, 'product', 0, 720, 'A', 0),
(665, 188, 'product', 0, 721, 'A', 0),
(666, 189, 'product', 0, 722, 'M', 0),
(667, 190, 'product', 0, 723, 'M', 0),
(668, 191, 'product', 0, 724, 'M', 0),
(669, 192, 'product', 0, 725, 'M', 0),
(683, 205, 'product', 0, 739, 'M', 0),
(671, 194, 'product', 0, 727, 'M', 0),
(672, 195, 'product', 0, 728, 'M', 0),
(673, 196, 'product', 0, 729, 'M', 0),
(674, 197, 'product', 0, 730, 'M', 0),
(675, 196, 'product', 0, 731, 'A', 0),
(676, 198, 'product', 0, 732, 'M', 0),
(677, 199, 'product', 0, 733, 'M', 0),
(678, 200, 'product', 0, 734, 'M', 0),
(679, 201, 'product', 0, 735, 'M', 0),
(680, 202, 'product', 0, 736, 'M', 0),
(681, 203, 'product', 0, 737, 'M', 0),
(682, 204, 'product', 0, 738, 'M', 0),
(684, 205, 'product', 0, 740, 'A', 0),
(685, 205, 'product', 0, 741, 'A', 0),
(686, 205, 'product', 0, 742, 'A', 0),
(687, 206, 'product', 0, 743, 'M', 0),
(688, 206, 'product', 0, 744, 'A', 0),
(689, 206, 'product', 0, 745, 'A', 0),
(690, 206, 'product', 0, 746, 'A', 0),
(691, 206, 'product', 0, 747, 'A', 0),
(692, 206, 'product', 0, 748, 'A', 0),
(693, 206, 'product', 0, 749, 'A', 0),
(694, 207, 'product', 0, 750, 'M', 0),
(695, 207, 'product', 0, 751, 'A', 0),
(696, 207, 'product', 0, 752, 'A', 0),
(697, 207, 'product', 0, 753, 'A', 0),
(698, 208, 'product', 0, 754, 'M', 0),
(699, 208, 'product', 0, 755, 'A', 0),
(700, 208, 'product', 0, 756, 'A', 0),
(701, 208, 'product', 0, 757, 'A', 0),
(702, 209, 'product', 0, 758, 'M', 0),
(703, 210, 'product', 0, 759, 'M', 0),
(704, 211, 'product', 0, 760, 'M', 0),
(705, 212, 'product', 0, 761, 'M', 0),
(706, 212, 'product', 0, 762, 'A', 0),
(707, 212, 'product', 0, 763, 'A', 0),
(708, 213, 'product', 0, 764, 'M', 0),
(709, 214, 'product', 0, 765, 'M', 0),
(710, 214, 'product', 0, 766, 'A', 0),
(711, 214, 'product', 0, 767, 'A', 0),
(712, 214, 'product', 0, 768, 'A', 0),
(713, 214, 'product', 0, 769, 'A', 0),
(777, 227, 'product', 0, 833, 'M', 0),
(715, 215, 'product', 0, 771, 'M', 0),
(716, 217, 'product', 0, 772, 'M', 0),
(717, 217, 'product', 0, 773, 'A', 0),
(718, 217, 'product', 0, 774, 'A', 0),
(719, 217, 'product', 0, 775, 'A', 0),
(720, 218, 'product', 0, 776, 'M', 0),
(721, 218, 'product', 0, 777, 'A', 0),
(722, 218, 'product', 0, 778, 'A', 0),
(723, 218, 'product', 0, 779, 'A', 0),
(724, 219, 'product', 0, 780, 'M', 0),
(725, 219, 'product', 0, 781, 'A', 0),
(726, 219, 'product', 0, 782, 'A', 0),
(727, 220, 'product', 0, 783, 'M', 0),
(728, 220, 'product', 0, 784, 'A', 0),
(729, 220, 'product', 0, 785, 'A', 0),
(730, 220, 'product', 0, 786, 'A', 0),
(731, 220, 'product', 0, 787, 'A', 0),
(732, 220, 'product', 0, 788, 'A', 0),
(733, 220, 'product', 0, 789, 'A', 0),
(734, 220, 'product', 0, 790, 'A', 0),
(735, 220, 'product', 0, 791, 'A', 0),
(736, 220, 'product', 0, 792, 'A', 0),
(737, 220, 'product', 0, 793, 'A', 0),
(738, 220, 'product', 0, 794, 'A', 0),
(739, 221, 'product', 0, 795, 'M', 0),
(740, 221, 'product', 0, 796, 'A', 0),
(741, 221, 'product', 0, 797, 'A', 0),
(742, 221, 'product', 0, 798, 'A', 0),
(743, 221, 'product', 0, 799, 'A', 0),
(744, 221, 'product', 0, 800, 'A', 0),
(745, 221, 'product', 0, 801, 'A', 0),
(746, 221, 'product', 0, 802, 'A', 0),
(747, 221, 'product', 0, 803, 'A', 0),
(748, 221, 'product', 0, 804, 'A', 0),
(749, 221, 'product', 0, 805, 'A', 0),
(750, 222, 'product', 0, 806, 'M', 0),
(751, 222, 'product', 0, 807, 'A', 0),
(752, 222, 'product', 0, 808, 'A', 0),
(753, 223, 'product', 0, 809, 'M', 0),
(754, 223, 'product', 0, 810, 'A', 0),
(755, 223, 'product', 0, 811, 'A', 0),
(756, 223, 'product', 0, 812, 'A', 0),
(757, 223, 'product', 0, 813, 'A', 0),
(758, 223, 'product', 0, 814, 'A', 0),
(759, 223, 'product', 0, 815, 'A', 0),
(760, 224, 'product', 0, 816, 'M', 0),
(761, 224, 'product', 0, 817, 'A', 0),
(762, 224, 'product', 0, 818, 'A', 0),
(763, 224, 'product', 0, 819, 'A', 0),
(764, 224, 'product', 0, 820, 'A', 0),
(765, 224, 'product', 0, 821, 'A', 0),
(766, 225, 'product', 0, 822, 'M', 0),
(767, 225, 'product', 0, 823, 'A', 0),
(768, 225, 'product', 0, 824, 'A', 0),
(769, 225, 'product', 0, 825, 'A', 0),
(770, 225, 'product', 0, 826, 'A', 0),
(771, 225, 'product', 0, 827, 'A', 0),
(772, 225, 'product', 0, 828, 'A', 0),
(773, 225, 'product', 0, 829, 'A', 0),
(774, 225, 'product', 0, 830, 'A', 0),
(775, 225, 'product', 0, 831, 'A', 0),
(776, 226, 'product', 0, 832, 'M', 0),
(778, 228, 'product', 0, 834, 'M', 0),
(779, 228, 'product', 0, 835, 'A', 0),
(780, 228, 'product', 0, 836, 'A', 0),
(781, 228, 'product', 0, 837, 'A', 0),
(782, 229, 'product', 0, 838, 'M', 0),
(783, 230, 'product', 0, 839, 'M', 0),
(784, 230, 'product', 0, 840, 'A', 0),
(785, 230, 'product', 0, 841, 'A', 0),
(786, 231, 'product', 0, 842, 'M', 0),
(787, 231, 'product', 0, 843, 'A', 0),
(788, 231, 'product', 0, 844, 'A', 0),
(789, 232, 'product', 0, 845, 'M', 0),
(790, 232, 'product', 0, 846, 'A', 0),
(791, 233, 'product', 0, 847, 'M', 0),
(792, 234, 'product', 0, 848, 'M', 0),
(793, 235, 'product', 0, 849, 'M', 0),
(794, 236, 'product', 0, 850, 'M', 0),
(795, 237, 'product', 0, 851, 'M', 0),
(796, 237, 'product', 0, 852, 'A', 0),
(797, 237, 'product', 0, 853, 'A', 0),
(799, 238, 'product', 0, 855, 'M', 0),
(800, 239, 'product', 0, 856, 'M', 0),
(801, 242, 'product', 0, 857, 'M', 0),
(802, 243, 'product', 0, 858, 'M', 0),
(805, 17, 'variant_image', 861, 0, 'V', 0),
(806, 18, 'variant_image', 862, 0, 'V', 0),
(807, 19, 'variant_image', 863, 0, 'V', 0),
(823, 12, 'product', 0, 879, 'M', 0),
(842, 36, 'variant_image', 898, 0, 'V', 0),
(825, 37, 'variant_image', 881, 0, 'V', 0),
(826, 38, 'variant_image', 882, 0, 'V', 0),
(848, 240, 'product', 0, 904, 'M', 0),
(851, 241, 'product', 0, 907, 'M', 0),
(849, 240, 'product', 0, 905, 'A', 0),
(850, 240, 'product', 0, 906, 'A', 0),
(852, 241, 'product', 0, 908, 'A', 0),
(853, 241, 'product', 0, 909, 'A', 0),
(870, 146, 'product', 0, 926, 'M', 0),
(875, 86, 'feature_variant', 1006, 0, 'V', 0),
(876, 87, 'feature_variant', 1007, 0, 'V', 0),
(877, 88, 'feature_variant', 1008, 0, 'V', 0),
(878, 89, 'feature_variant', 1009, 0, 'V', 0),
(879, 90, 'feature_variant', 1010, 0, 'V', 0),
(880, 91, 'feature_variant', 1011, 0, 'V', 0),
(881, 92, 'feature_variant', 1012, 0, 'V', 0),
(882, 93, 'feature_variant', 1013, 0, 'V', 0),
(883, 94, 'feature_variant', 1014, 0, 'V', 0),
(884, 95, 'feature_variant', 1015, 0, 'V', 0),
(885, 96, 'feature_variant', 1016, 0, 'V', 0),
(886, 97, 'feature_variant', 1017, 0, 'V', 0),
(887, 98, 'feature_variant', 1018, 0, 'V', 0),
(888, 100, 'feature_variant', 1019, 0, 'V', 0),
(889, 101, 'feature_variant', 1020, 0, 'V', 0),
(890, 102, 'feature_variant', 1021, 0, 'V', 0),
(891, 103, 'feature_variant', 1022, 0, 'V', 0),
(892, 104, 'feature_variant', 1023, 0, 'V', 0),
(893, 105, 'feature_variant', 1024, 0, 'V', 0),
(894, 106, 'feature_variant', 1025, 0, 'V', 0),
(895, 107, 'feature_variant', 1026, 0, 'V', 0),
(896, 108, 'feature_variant', 1027, 0, 'V', 0),
(897, 109, 'feature_variant', 1028, 0, 'V', 0),
(898, 110, 'feature_variant', 1029, 0, 'V', 0),
(899, 111, 'feature_variant', 1030, 0, 'V', 0),
(900, 112, 'feature_variant', 1031, 0, 'V', 0),
(901, 113, 'feature_variant', 1032, 0, 'V', 0),
(902, 114, 'feature_variant', 1033, 0, 'V', 0),
(903, 115, 'feature_variant', 1034, 0, 'V', 0),
(904, 117, 'feature_variant', 1035, 0, 'V', 0),
(905, 116, 'feature_variant', 1036, 0, 'V', 0),
(906, 118, 'feature_variant', 1037, 0, 'V', 0),
(907, 119, 'feature_variant', 1038, 0, 'V', 0),
(908, 120, 'feature_variant', 1039, 0, 'V', 0),
(909, 121, 'feature_variant', 1040, 0, 'V', 0),
(910, 122, 'feature_variant', 1041, 0, 'V', 0),
(911, 123, 'feature_variant', 1042, 0, 'V', 0),
(912, 124, 'feature_variant', 1043, 0, 'V', 0),
(913, 125, 'feature_variant', 1044, 0, 'V', 0),
(914, 126, 'feature_variant', 1045, 0, 'V', 0),
(915, 127, 'feature_variant', 1046, 0, 'V', 0),
(916, 128, 'feature_variant', 1047, 0, 'V', 0),
(917, 129, 'feature_variant', 1048, 0, 'V', 0),
(918, 130, 'feature_variant', 1051, 0, 'V', 0),
(919, 131, 'feature_variant', 1052, 0, 'V', 0),
(920, 132, 'feature_variant', 1053, 0, 'V', 0),
(921, 133, 'feature_variant', 1054, 0, 'V', 0),
(922, 134, 'feature_variant', 1055, 0, 'V', 0),
(936, 99, 'feature_variant', 1057, 0, 'V', 0),
(937, 244, 'product', 0, 1058, 'M', 0),
(941, 245, 'product', 0, 1062, 'M', 0),
(940, 244, 'product', 0, 1061, 'A', 0),
(942, 245, 'product', 0, 1063, 'A', 0),
(943, 245, 'product', 0, 1064, 'A', 0),
(944, 246, 'product', 0, 1065, 'M', 0),
(945, 246, 'product', 0, 1066, 'A', 0),
(946, 246, 'product', 0, 1067, 'A', 0),
(947, 246, 'product', 0, 1068, 'A', 0),
(948, 135, 'feature_variant', 1069, 0, 'V', 0),
(1051, 10, 'blog', 1072, 0, 'M', 0),
(1052, 9, 'blog', 1073, 0, 'M', 0),
(1053, 8, 'blog', 1074, 0, 'M', 0),
(1066, 167, 'category', 0, 1279, 'M', 0),
(1067, 175, 'category', 0, 1280, 'M', 0),
(1068, 177, 'category', 0, 1281, 'M', 0),
(1069, 234, 'category', 0, 1282, 'M', 0),
(1070, 174, 'category', 0, 1283, 'M', 0),
(1071, 196, 'category', 0, 1284, 'M', 0),
(1072, 247, 'product', 0, 1285, 'M', 0),
(1073, 247, 'product', 0, 1286, 'A', 0),
(1074, 247, 'product', 0, 1287, 'A', 0),
(1075, 247, 'product', 0, 1288, 'A', 0),
(994, 248, 'product', 0, 1187, 'M', 0),
(995, 248, 'product', 0, 1188, 'A', 0),
(996, 248, 'product', 0, 1189, 'A', 0),
(997, 248, 'product', 0, 1190, 'A', 0),
(998, 248, 'product', 0, 1191, 'A', 0),
(993, 136, 'feature_variant', 1386, 0, 'V', 0),
(1113, 177, 'feature_variant', 1223, 0, 'V', 0),
(1126, 190, 'feature_variant', 1270, 0, 'V', 0),
(1127, 191, 'feature_variant', 1220, 0, 'V', 0),
(1133, 192, 'feature_variant', 1226, 0, 'V', 0),
(3227, 6, 'promotion', 8644, 0, 'M', 0),
(3217, 9, 'promotion', 8642, 0, 'M', 0),
(3216, 8, 'promotion', 8643, 0, 'M', 0),
(3215, 7, 'promotion', 8640, 0, 'M', 0),
(3218, 10, 'promotion', 8639, 0, 'M', 0),
(3228, 1, 'logos', 8645, 0, 'M', 0),
(3229, 2, 'logos', 8646, 0, 'M', 0),
(3230, 3, 'logos', 8647, 0, 'M', 0),
(3231, 4, 'logos', 8648, 0, 'M', 0),
(1159, 278, 'product', 0, 1396, 'A', 0),
(1160, 278, 'product', 0, 1397, 'M', 0),
(1161, 279, 'product', 0, 1398, 'M', 0),
(1162, 279, 'product', 0, 1399, 'A', 0),
(1163, 279, 'product', 0, 1400, 'A', 0),
(1164, 280, 'product', 0, 1401, 'M', 0),
(1165, 280, 'product', 0, 1402, 'A', 0),
(1166, 281, 'product', 0, 1403, 'A', 0),
(1167, 281, 'product', 0, 1404, 'M', 0),
(1168, 282, 'product', 0, 1405, 'M', 0),
(1169, 283, 'product', 0, 1406, 'M', 0),
(1170, 283, 'product', 0, 1407, 'A', 0),
(1171, 284, 'product', 0, 1406, 'M', 0),
(1172, 284, 'product', 0, 1407, 'A', 0),
(3232, 1, 'product_bundle', 8649, 0, 'M', 0),
(3233, 2, 'product_bundle', 8650, 0, 'M', 0),
(3234, 3, 'product_bundle', 8651, 0, 'M', 0),
(953, 8, 'blog', 1074, 0, 'M', 0),
(3235, 16, 'promo', 1076, 0, 'M', 0),
(3236, 18, 'promo', 1077, 0, 'M', 0),
(3237, 35, 'promo', 1300, 0, 'M', 0),
(3238, 36, 'promo', 1301, 0, 'M', 0),
(3239, 37, 'promo', 1302, 0, 'M', 0),
(3240, 38, 'promo', 1303, 0, 'M', 0),
(3241, 39, 'promo', 1304, 0, 'M', 0),
(3242, 40, 'promo', 1305, 0, 'M', 0),
(3243, 42, 'promo', 8633, 0, 'M', 0),
(3244, 47, 'promo', 8634, 0, 'M', 0),
(3245, 41, 'promo', 8632, 0, 'M', 0),
(3246, 45, 'product_reviews', 0, 908, 'A', 0),
(3247, 46, 'product_reviews', 0, 909, 'A', 0),
(3248, 23, 'product_reviews', 0, 1061, 'A', 0),
(3249, 26, 'product_reviews', 0, 1063, 'A', 0),
(3250, 27, 'product_reviews', 0, 1064, 'A', 0),
(3251, 35, 'product_reviews', 0, 1066, 'A', 0),
(3252, 36, 'product_reviews', 0, 1068, 'A', 0),
(3253, 38, 'product_reviews', 0, 1286, 'A', 0),
(3254, 39, 'product_reviews', 0, 1287, 'A', 0),
(3255, 41, 'product_reviews', 0, 1188, 'A', 0),
(3256, 42, 'product_reviews', 0, 1189, 'A', 0),
(3257, 31, 'product_reviews', 0, 594, 'A', 0),
(3258, 8, 'product_reviews', 0, 248, 'A', 0),
(3259, 11, 'product_reviews', 0, 238, 'A', 0),
(3260, 15, 'product_reviews', 0, 260, 'A', 0),
(3261, 16, 'product_reviews', 0, 675, 'A', 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]import_presets`
--

CREATE TABLE `[[dbprefix]]import_presets` (
  `preset_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `object_type` varchar(32) NOT NULL DEFAULT 'products',
  `file_extension` varchar(6) NOT NULL DEFAULT '',
  `options` text,
  PRIMARY KEY (`preset_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]import_preset_descriptions`
--

CREATE TABLE `[[dbprefix]]import_preset_descriptions` (
  `preset_id` int(11) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `preset` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`preset_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]import_preset_fields`
--

CREATE TABLE `[[dbprefix]]import_preset_fields` (
  `field_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `preset_id` int(11) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) NOT NULL DEFAULT '',
  `related_object_type` varchar(32) NOT NULL DEFAULT 'product_field',
  `related_object` varchar(255) NOT NULL DEFAULT '',
  `modifier` text,
  PRIMARY KEY (`field_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]import_preset_states`
--

CREATE TABLE `[[dbprefix]]import_preset_states` (
  `preset_id` int(11) unsigned NOT NULL DEFAULT '0',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `last_launch` int(11) unsigned NOT NULL DEFAULT '0',
  `last_status` char(1) NOT NULL DEFAULT 'X',
  `last_result` text,
  `file` varchar(255) NOT NULL DEFAULT '',
  `file_type` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`preset_id`,`company_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]installed_upgrades`
--

CREATE TABLE `[[dbprefix]]installed_upgrades` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `type` varchar(10) NOT NULL DEFAULT '',
  `name` varchar(255) NOT NULL DEFAULT '',
  `timestamp` int(11) NOT NULL DEFAULT '0',
  `description` text,
  `conflicts` longtext,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]languages`
--

CREATE TABLE `[[dbprefix]]languages` (
  `lang_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `lang_code` char(2) NOT NULL DEFAULT '',
  `name` varchar(64) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'A',
  `country_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`lang_id`),
  UNIQUE KEY `lang_code` (`lang_code`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]languages`
--

INSERT INTO `[[dbprefix]]languages` VALUES
(1, 'en', 'English', 'A', 'US');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]language_values`
--

CREATE TABLE `[[dbprefix]]language_values` (
  `lang_code` char(2) NOT NULL DEFAULT '',
  `name` varchar(128) NOT NULL DEFAULT '',
  `value` text NOT NULL,
  PRIMARY KEY (`lang_code`,`name`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]language_values`
--

INSERT INTO `[[dbprefix]]language_values` VALUES
('en', '2co_enable_fraud_verification', 'Enable support of fraud notification'),
('en', '2co_fraud_fail', 'Status for orders with failed fraud review'),
('en', '2co_fraud_wait', 'Status for orders waiting for fraud review'),
('en', '3d_secure', '3-D Secure'),
('en', '404', 'The 404 Not Found error message'),
('en', 'absolute', 'Absolute'),
('en', 'installed_addons', 'Installed add-ons'),
('en', 'browse_all_available_addons', 'Browse all available add-ons'),
('en', 'accept', 'Accept'),
('en', 'access_denied', 'Access denied'),
('en', 'event.order.status_changed.name', 'Order status changed to [status]'),
('en', 'access_denied_text', 'You don''t have permission to access the page.'),
('en', 'account', 'Account'),
('en', 'account_name', 'Account name'),
('en', 'account_number', 'Account number'),
('en', 'account_type', 'Account type'),
('en', 'acquirerid', 'Acquirer ID'),
('en', 'action', 'Action'),
('en', 'actions', 'Actions'),
('en', 'activate_menu_tab_for', 'Activate menu item for dispatch'),
('en', 'activate_selected', 'Activate selected'),
('en', 'activate_skrill_merchant_tools', 'Activate Skrill Merchant Tools'),
('en', 'activation_link', 'Activation link'),
('en', 'activation_mode', 'Activation mode'),
('en', 'active', 'Active'),
('en', 'active_categories', 'Active categories'),
('en', 'active_style', 'Active style'),
('en', 'active_products', 'Active products'),
('en', 'active_promotions', 'Active promotions'),
('en', 'act_on_behalf', 'Act on behalf of'),
('en', 'log_in_as_user', 'Log in as user'),
('en', 'add', 'Add'),
('en', 'added', 'added'),
('en', 'adding_block_to_grid', 'Adding block to grid'),
('en', 'adding_grid', 'Adding grid'),
('en', 'additional_data', 'Additional data'),
('en', 'additional_images', 'Additional images'),
('en', 'additional_options', 'Additional options'),
('en', 'additional_parameter_not_correct', 'Additional parameter is incorrect'),
('en', 'additional_popup_larger_image', 'Popup larger images of additional thumbnails'),
('en', 'additional_thumbnail', 'Additional thumbnails'),
('en', 'additional__option_thumbnail', 'Additional option thumbnail'),
('en', 'addon', 'Add-on'),
('en', 'addons', 'Add-ons'),
('en', 'addon_sql_error', 'An error in an SQL query occurred during the add-on installation. The add-on will not be installed.'),
('en', 'address', 'Address'),
('en', 'addresses', 'Addresses'),
('en', 'address_2', 'Address (line 2)'),
('en', 'address_commercial', 'Commercial'),
('en', 'address_residential', 'Residential'),
('en', 'address_type', 'Address type'),
('en', 'add_administrator', 'Add administrator'),
('en', 'add_block', 'Add block'),
('en', 'add_image_from_server', 'Add image from server'),
('en', 'add_image_from_url', 'Add image from URL'),
('en', 'add_bonus', 'Add bonus'),
('en', 'add_cart_promotion', 'Add cart promotion'),
('en', 'add_catalog_promotion', 'Add catalog promotion'),
('en', 'add_categories', 'Add categories'),
('en', 'select_categories', 'Select categories'),
('en', 'add_categories_and_close', 'Add categories and close'),
('en', 'add_category', 'Add category'),
('en', 'add_chart', 'Add chart'),
('en', 'add_combination', 'Add combination'),
('en', 'add_companies', 'Add stores'),
('en', 'add_companies_and_close', 'Add stores and close'),
('en', 'add_condition', 'Add condition'),
('en', 'add_currency', 'Add currency'),
('en', 'add_customer', 'Add customer'),
('en', 'add_elements', 'Add elements'),
('en', 'add_empty_item', 'Add empty item'),
('en', 'add_feature', 'Add feature'),
('en', 'advanced_feature_creation', 'Advanced feature creation'),
('en', 'add_field', 'Add field'),
('en', 'add_file', 'Add file'),
('en', 'add_filter', 'Add filter'),
('en', 'add_filters', 'Add filters'),
('en', 'add_filters_and_close', 'Add filters and close'),
('en', 'add_folder', 'Add folder'),
('en', 'add_global_option', 'Add global option'),
('en', 'add_grid_block', 'Add grid or block'),
('en', 'add_group', 'Add group'),
('en', 'add_item', 'Add item'),
('en', 'add_items', 'Add [items]'),
('en', 'add_language', 'Add language'),
('en', 'add_language_variable', 'Add language variable'),
('en', 'add_layout', 'Add layout'),
('en', 'add_link', 'Add link'),
('en', 'add_localization', 'Add localization'),
('en', 'add_location', 'Add location'),
('en', 'add_rate_area', 'Add rate area'),
('en', 'add_menu', 'Add menu'),
('en', 'add_new', 'Add new'),
('en', 'add_new_field', 'Add new field'),
('en', 'add_new_order', 'Adding new order'),
('en', 'add_new_variant', 'Add new variant'),
('en', 'add_variant', 'Add variant'),
('en', 'add_option', 'Add option'),
('en', 'advanced_option_creation', 'Advanced option creation'),
('en', 'add_order', 'Add order'),
('en', 'add_orders', 'Add orders'),
('en', 'add_orders_and_close', 'Add orders and close'),
('en', 'add_page', 'Add page'),
('en', 'add_pages', 'Add pages'),
('en', 'add_pages_and_close', 'Add pages and close'),
('en', 'add_payment', 'Add payment method'),
('en', 'add_payout', 'Add payout'),
('en', 'add_product', 'Add product'),
('en', 'add_products', 'Add products'),
('en', 'add_products_and_close', 'Add products and close'),
('en', 'add_products_to_section', 'Add product(s) to this section'),
('en', 'add_product_filter', 'Add product filter'),
('en', 'add_promotions', 'Add promotions'),
('en', 'add_promotion', 'Add promotion'),
('en', 'add_report', 'Add report'),
('en', 'add_section', 'Add section'),
('en', 'add_selected_to_cart', 'Add selected to cart'),
('en', 'add_shipping_method', 'Add shipping method'),
('en', 'add_site_map_section', 'Add sitemap section'),
('en', 'add_state', 'Add state'),
('en', 'add_status', 'Add status'),
('en', 'add_subcategory', 'Add subcategory'),
('en', 'new_subscribers', 'New subscribers'),
('en', 'add_subscriber', 'Add subscriber'),
('en', 'add_subscribers_from_users', 'Add subscribers from the list of users'),
('en', 'add_tab', 'Add tab'),
('en', 'add_tax', 'Add tax'),
('en', 'add_to_cart', 'Add to cart'),
('en', 'add_to_comparison_list', 'Add to comparison list'),
('en', 'add_user', 'Add user'),
('en', 'add_users', 'Add users'),
('en', 'add_users_and_close', 'Add users and close'),
('en', 'add_vendor', 'Add store'),
('en', 'admin2', 'You can not perform an import to this store because you are using an expired trial version'),
('en', 'administration', 'Administration'),
('en', 'administration_panel', 'Administration panel'),
('en', 'administrator', 'Administrator'),
('en', 'administrators', 'Administrators'),
('en', 'main_administrator', 'Main administrator'),
('en', 'storefront_admin', 'Main admin for [storefront]'),
('en', 'administrators_notified', '[count] administrators notified.'),
('en', 'admin_panel', 'Administration panel'),
('en', 'admin_text_letter_footer', 'E-shop of [company_name].'),
('en', 'administration_view', 'Settings'),
('en', 'advanced', 'Advanced'),
('en', 'advanced_search', 'Advanced search'),
('en', 'advanced_search_options', 'Advanced search options'),
('en', 'search_add_filter', 'Add filter'),
('en', 'search_range_from', 'From'),
('en', 'search_range_to', 'To'),
('en', 'dynamic_navigation_more', 'More'),
('en', 'after_full_payment', 'After full payment'),
('en', 'after_sum', 'After sum'),
('en', 'agent_id', 'Agent ID'),
('en', 'agreement_required', 'Agreement required'),
('en', 'all', 'All'),
('en', 'allowed', 'Allowed'),
('en', 'allowed_combinations', 'Allowed combinations'),
('en', 'allowed_extensions', 'Allowed extensions'),
('en', 'allowed_extensions_hint', 'Leave this field empty to allow uploading of all file types, or input allowed extensions separated by comma (e.g. jpg,bmp,gif,pdf)'),
('en', 'allow_api_access', 'Yes, allow this user to use the API'),
('en', 'api_access_for_user', 'API access for this user'),
('en', 'generate_new_api_key', 'Generate new API key'),
('en', 'please_copy_api_key', 'Please copy the API key now and keep it somewhere. Once you save the changes, this key won''t appear here again. If the key is lost, the only way to regain API access will be to generate a new key on this page.'),
('en', 'allow_return_registration', 'Allow return registration'),
('en', 'all_categories', 'All categories'),
('en', 'all_downloads', 'All downloads'),
('en', 'all_features', 'All features'),
('en', 'all_filters', 'All product filters'),
('en', 'all_pages', 'All pages'),
('en', 'all_products_have_been_updated', 'All products have been updated successfully.'),
('en', 'all_vendors', 'All stores'),
('en', 'all_storefronts_short', 'All'),
('en', 'show_all_storefronts', 'Show all storefronts'),
('en', 'show_all_storefronts_with_count', 'Show all [count] storefronts'),
('en', 'all_words', 'All of these words'),
('en', 'also_bought', 'Also bought'),
('en', 'alt_text', 'Alternative text/title'),
('en', 'alternative_text', 'Alt text'),
('en', 'american_express', 'American Express'),
('en', 'american_express_info', 'CVV is on the front of the card above the credit card number (either on the right or on the left side of the credit card).'),
('en', 'amount', 'Amount'),
('en', 'amount_decreased', 'Quantity has been decreased by'),
('en', 'amount_increased', 'Quantity has been increased by'),
('en', 'anonymous', 'Anonymous'),
('en', 'answer', 'Answer'),
('en', 'any', 'Any'),
('en', 'any_date', 'Any date'),
('en', 'any_option_combinations', 'Any option combinations'),
('en', 'any_status', 'Any status'),
('en', 'any_words', 'Any of these words'),
('en', 'any_category', 'Any category'),
('en', 'any_product', 'Any product'),
('en', 'api', 'API'),
('en', 'api_access', 'API access'),
('en', 'api_key', 'API key'),
('en', 'need_company_id', 'Company ID is required (the company_id param)'),
('en', 'api_need_correct_company_id', 'Company by passed ID not found'),
('en', 'api_need_id', 'Object ID undefined'),
('en', 'api_need_params', 'Missing parameters'),
('en', 'api_need_store', 'Store is required (the company_id param or entity stores)'),
('en', 'api_not_need_id', 'ID must not be defined'),
('en', 'api_partner', 'API partner'),
('en', 'api_password', 'API password'),
('en', 'api_shipments_not_allow_update', 'Only the tracking_number and carrier params can be updated with the setting ''Allow multiple shipments for a single order'' set'),
('en', 'api_user', 'API user'),
('en', 'api_order_couldnt_be_created', 'Order couldn''t be created'),
('en', 'api_no_shipping_methods_available', 'No shipping methods are available'),
('en', 'appearance', 'Appearance'),
('en', 'appearance_settings', 'Appearance settings'),
('en', 'appearance_type', 'Appearance type'),
('en', 'application_id', 'Application ID'),
('en', 'application_login', 'Application login'),
('en', 'apply', 'Apply'),
('en', 'apply_as_link', 'Apply as link'),
('en', 'apply_tax_to_products', 'Apply selected taxes to all products'),
('en', 'apply_to_all_languages', 'Apply to all languages'),
('en', 'apply_to_products', 'Apply to products'),
('en', 'approve', 'Approve'),
('en', 'approved', 'Approved'),
('en', 'approve_selected', 'Approve selected'),
('en', 'enter_disapproval_reason', 'Enter the reason for disapproval'),
('en', 'arabic', 'Arabic'),
('en', 'arrows', 'Arrows'),
('en', 'asc', 'asc.'),
('en', 'attention', 'Attention!'),
('en', 'audience', 'Audience'),
('en', 'authentication_failed', 'Authentication failed'),
('en', 'authentication_key', 'Authentication key'),
('en', 'authentication_password', 'Authentication password'),
('en', 'author', 'Author'),
('en', 'authorization', 'Authorization'),
('en', 'authorize_capture', 'Authorize and capture'),
('en', 'authorize_only', 'Authorize only'),
('en', 'auth_code', 'Auth code'),
('en', 'auth_info', 'Authentication information'),
('en', 'auto', 'Auto'),
('en', 'auto_set_permissions_via_ftp', 'Auto-set permissions via FTP'),
('en', 'avail', 'Available'),
('en', 'availability', 'Availability'),
('en', 'available', 'Available'),
('en', 'available_fields', 'Available fields'),
('en', 'available_for_vendor', 'Available for store'),
('en', 'available_items', 'Available items'),
('en', 'available_languages', 'Available'),
('en', 'available_views', 'Available views'),
('en', 'available_since', 'Avail since'),
('en', 'installed_themes', 'Installed theme'),
('en', 'browse_all_available_themes', 'Browse all available themes'),
('en', 'currently_in_use', 'Currently in use'),
('en', 'avail_from', 'Available from'),
('en', 'avail_till', 'Available till'),
('en', 'average', 'Average'),
('en', 'avs', 'AVS'),
('en', 'awaiting', 'Awaiting'),
('en', 'awaiting_approval', 'Awaiting approval'),
('en', 'backtrace', 'Backtrace'),
('en', 'backup', 'Backup'),
('en', 'backupping_data', 'Backing up data for'),
('en', 'backupping_schema', 'Backing up schema for'),
('en', 'backup_data', 'Backup database data'),
('en', 'backup_filename', 'Backup file name'),
('en', 'backup_files', 'Backup files'),
('en', 'backup_options', 'Backup options'),
('en', 'backup_schema', 'Backup database schema'),
('en', 'back_in_stock_notification_footer', 'Welcome to purchase!'),
('en', 'back_in_stock_notification_header', 'We are writing to inform you that the following product is back in stock in our store:'),
('en', 'balance', 'Balance'),
('en', 'balance_account', 'Account balance'),
('en', 'bank', 'Bank'),
('en', 'ground_only', 'Ground only'),
('en', 'bank_cic', 'Groupe CIC'),
('en', 'bank_cm', 'Credit Mutuel'),
('en', 'bank_obc', 'OBC'),
('en', 'bank_routing_number', 'Bank routing number'),
('en', 'bar', 'Bar'),
('en', 'base_currency', 'Base'),
('en', 'base_currency_not_deleted', 'The currency has not been deleted because it is the base currency of the store.'),
('en', 'base_price', 'Base price'),
('en', 'bestsellers', 'Bestsellers'),
('en', 'biller_code', 'Biller code'),
('en', 'billing_address', 'Billing address'),
('en', 'billing_options', 'Billing Options'),
('en', 'billing_shipping_address', 'Billing and Shipping Address'),
('en', 'bill_to', 'Bill to'),
('en', 'block', 'Block'),
('en', 'blocks', 'Blocks'),
('en', 'block_already_exists_in_grid', 'This block already exists in this grid'),
('en', 'invalid_value_for_grid_with_content', 'This value can not be set, because the content does not fit into the grid width. Edit the grid content and try again.'),
('en', 'block_breadcrumbs', 'Breadcrumbs'),
('en', 'block_breadcrumbs_description', 'Navigation breadcrumbs'),
('en', 'block_categories_description', 'Category trees'),
('en', 'block_products_description', 'Product showcase'),
('en', 'block_cart_content', 'Cart content'),
('en', 'block_cart_content_description', 'Current cart content'),
('en', 'block_categories', 'Categories'),
('en', 'block_checkout', 'Checkout'),
('en', 'block_checkout_description', 'Current order information'),
('en', 'block_content', 'Block content'),
('en', 'block_currencies', 'Currencies'),
('en', 'block_currencies_description', 'Currency selector'),
('en', 'block_disabled', 'Block was disabled for this location'),
('en', 'block_enabled', 'Block was enabled for this location'),
('en', 'block_html_block', 'HTML block'),
('en', 'block_html_block_description', 'Any HTML content'),
('en', 'block_ip_after', 'Block IP after a number of unsuccessful attempts'),
('en', 'block_languages', 'Languages'),
('en', 'block_languages_description', 'Language selector'),
('en', 'block_localizations', 'Localizations'),
('en', 'block_localizations_description', 'Localization selector'),
('en', 'block_main', 'Main'),
('en', 'block_main_description', 'Main content (loaded by controller)'),
('en', 'block_manager', 'Block manager'),
('en', 'block_manager.fixed_layout', 'Fixed width'),
('en', 'block_manager.fluid_layout', 'Fluid'),
('en', 'block_manager.full_width_layout', 'Full width'),
('en', 'block_manager.grid_columns', 'Grid columns'),
('en', 'block_manager.layout_width', 'Layout width'),
('en', 'block_manager.max_width', 'Maximal width'),
('en', 'block_manager.min_width', 'Minimal width'),
('en', 'block_manager.forbid_changing_layout_in_css_mode', 'Changing layout when the theme is converted to CSS is not permitted. Please enable LESS mode in the <a target="_blank" class="cm-post" href="[url]">Theme editor</a>.'),
('en', 'block_manager.can_not_add_product', 'Sorry, we couldn''t take you to the checkout page. It requires at least one product in cart, and we couldn''t add any. Please create a product and make it available on the storefront first.'),
('en', 'block_manager.add_layout_page', 'Add layout page'),
('en', 'block_manager.editing_layout_page', 'Editing layout page'),
('en', 'block_manager.new_layout_page', 'New layout page'),
('en', 'block_manager.layout_pages', 'Layout pages'),
('en', 'block_manager.wrappers.lite_checkout', 'Lite checkout'),
('en', 'block_manager.description_available_values_for_grid_select', 'The available values depend on the size and offset of parent and nested elements.'),
('en', 'block_lite_checkout_location', 'Checkout: Location'),
('en', 'block_lite_checkout_location_description', 'Customer''s city, state, and country'),
('en', 'block_lite_checkout_customer_sign_in', 'Checkout: Sign-In'),
('en', 'block_lite_checkout_customer_sign_in_description', 'Sign-in button'),
('en', 'customer_sign_in', 'Customer Sign-In'),
('en', 'block_lite_checkout_customer_information', 'Checkout: Customer Information'),
('en', 'block_lite_checkout_customer_information_description', 'Profile fields for customer information'),
('en', 'block_lite_checkout_customer_address', 'Checkout: Address'),
('en', 'block_lite_checkout_customer_address_description', 'Profile fields for customer address'),
('en', 'customer_address', 'Customer address'),
('en', 'block_lite_checkout_shipping_methods', 'Checkout: Shipping methods'),
('en', 'block_lite_checkout_shipping_methods_description', 'Shipping method selection'),
('en', 'block_lite_checkout_payment_methods', 'Checkout: Payment methods'),
('en', 'block_lite_checkout_payment_methods_description', 'Payment method selection'),
('en', 'block_lite_checkout_customer_billing', 'Checkout: Billing address'),
('en', 'block_lite_checkout_customer_billing_description', 'Profile fields for billing address'),
('en', 'block_lite_checkout_customer_notes', 'Checkout: Notes'),
('en', 'block_lite_checkout_customer_notes_description', 'Customer''s notes about the order'),
('en', 'block_lite_checkout_terms_and_conditions', 'Checkout: Terms and conditions'),
('en', 'block_lite_checkout_terms_and_conditions_description', 'Checkbox for accepting terms and conditions'),
('en', 'terms_and_conditions', 'Terms and conditions'),
('en', 'block_menu', 'Menu'),
('en', 'block_my_account', 'My account'),
('en', 'block_my_account_description', 'Customer profile access'),
('en', 'block_name', 'Block name'),
('en', 'block_options', 'Block options'),
('en', 'block_order', 'Block order'),
('en', 'block_our_brands', 'Brands'),
('en', 'block_our_brands_description', 'Product brands presented in the store'),
('en', 'block_pages', 'Pages'),
('en', 'block_pages_description', 'Store pages'),
('en', 'block_payment_methods', 'Payment methods'),
('en', 'block_payment_methods_description', 'Available payment methods'),
('en', 'block_products', 'Products'),
('en', 'block_product_filters', 'Product filters'),
('en', 'block_product_filters_description', 'Product filtering options'),
('en', 'block_product_filters_home', 'Product filters for home page'),
('en', 'block_product_filters_home_description', 'Product filtering options, displayed on home page'),
('en', 'block_settings', 'Block settings'),
('en', 'block_shipping_methods', 'Shipping methods'),
('en', 'block_shipping_methods_description', 'Available shipping methods'),
('en', 'block_smarty_block', 'HTML block with Smarty support'),
('en', 'block_smarty_block_description', 'Any HTML/Smarty content'),
('en', 'block_template', 'Template'),
('en', 'block_template_description', 'Block with a particular template'),
('en', 'block_text', 'Block text'),
('en', 'block_time', 'Time for which IP should be blocked'),
('en', 'block_width', 'Block width'),
('en', 'block_wrapper_updated', 'Block wrapper was updated'),
('en', 'bm_confirm', 'Performing this action will [action] this block on all the [location_name] pages. Do you want to continue?'),
('en', 'body', 'Body'),
('en', 'bonus', 'Bonus'),
('en', 'bonuses', 'Bonuses'),
('en', 'both', 'Both'),
('en', 'bought', 'Already bought'),
('en', 'bought_amount', 'Bought quantity'),
('en', 'box_height', 'Box height'),
('en', 'box_length', 'Box length'),
('en', 'box_width', 'Box width'),
('en', 'brand', 'Brand'),
('en', 'brand_type', 'Brand/Manufacturer'),
('en', 'breadcrumbs', 'Breadcrumbs'),
('en', 'broken_addon_pack', 'Incorrect add-on structure. The uploaded pack cannot be installed.'),
('en', 'broken_po_pack', 'Incorrect PO-pack structure. The uploaded pack cannot be installed.'),
('en', 'incorrect_po_pack_structure_file_not_exist', 'The structure of package that contains ".po" translation files located at <b>"[pack_path]"</b> is incorrect. The file <b>"[po_file]"</b> does not exist.'),
('en', 'browse', 'Browse...'),
('en', 'browser_upgrade_notice', '<p>We have detected that the browser you are using is not fully supported by our Admin Panel. You can view this site using your current browser but it may not display properly, and you may not be able to fully use all features.</p><br><p>Admin Panel is best viewed using the following browsers:</p><br><ul><li>&ndash; <a href="http://windows.microsoft.com/en-US/internet-explorer/products/ie/home" target="_blank">Internet Explorer 9 and above</a></li><li>&ndash; <a href="http://www.mozilla.org/en-US/" target="_blank">Mozilla Firefox (latest version)</a></li><li>&ndash; <a href="https://www.google.com/intl/en/chrome/browser/" target="_blank">Google Chrome (latest version)</a></li></ul><br><p>Click on one of the links to download the browser of your choice. Once the download has completed, install the browser by running the setup program.</p><br><p>If you cannot upgrade your browser now, you can still access Admin Panel, but you may not be able to fully use all features.<br><br><a href="[url]">Continue</a></p>'),
('en', 'browser_upgrade_notice_title', 'Browser Upgrade Notice'),
('en', 'bucket', 'Bucket'),
('en', 'bulk_category_addition', 'Bulk category addition'),
('en', 'bulk_print_invoice', 'Invoice bulk print'),
('en', 'bulk_product_addition', 'Bulk product addition'),
('en', 'button_bgcolor', 'Button background color'),
('en', 'button_text_color', 'Button text color'),
('en', 'but_change', 'Change'),
('en', 'buyer_name', 'Buyer''s name'),
('en', 'buy_in_advance', 'Buy in advance'),
('en', 'buy_now', 'Buy now'),
('en', 'by', 'by'),
('en', 'bytes', 'bytes'),
('en', 'by_fixed', 'by fixed amount'),
('en', 'by_percentage', 'by percentage of the original price'),
('en', 'C128A', 'Code 128 is a high-density barcode symbology.<br/>Used extensively worldwide.<br/>Code 128 is designed to encode 128 full ASCII characters.<br/>Code 128-A - 0-9, A-Z, ASCII control codes, special characters.<br/>Code 128-B - 0-9, A-Z, a-z, special characters.<br/>Code 128-C - 00-99 (double density encoding of numeric only data).<br/>'),
('en', 'C128B', 'Code 128 is a high-density barcode symbology.<br/>Used extensively worldwide.<br/>Code 128 is designed to encode 128 full ASCII characters.<br/>Code 128-A - 0-9, A-Z, ASCII control codes, special characters.<br/>Code 128-B - 0-9, A-Z, a-z, special characters.<br/>Code 128-C - 00-99 (double density encoding of numeric only data).<br/>'),
('en', 'C128C', 'Code 128 is a high-density barcode symbology.<br/>Used extensively worldwide.<br/>Code 128 is designed to encode 128 full ASCII characters.<br/>Code 128-A - 0-9, A-Z, ASCII control codes, special characters.<br/>Code 128-B - 0-9, A-Z, a-z, special characters.<br/>Code 128-C - 00-99 (double density encoding of numeric only data).<br/>'),
('en', 'C39', 'Known also as USS Code 39, 3 of 9.<br/>Code 39 can encode alphanumeric characters.<br/>The symbology is used in non-retail environment.<br/>Code 39 is designed to encode 26 upper case letters, 10 digits and 7 special characters.'),
('en', 'cache_cleared', 'Cache has been cleared'),
('en', 'calculate', 'Calculate'),
('en', 'calculate_shipping_cost', 'Calculate shipping cost'),
('en', 'calendar', 'Calendar'),
('en', 'canada_post_activation_error', 'To activate the Canada post shipping processor, you must have the Canadian Dollar currency enabled.'),
('en', 'cancel', 'Cancel'),
('en', 'canceled_reversal', 'Canceled reversal'),
('en', 'cancelled', 'Canceled'),
('en', 'cancel_url_target', 'Cancel URL target'),
('en', 'cannot_buy', 'You cannot buy the product with these option variants'),
('en', 'cannot_proccess_checkout', 'Your cart is empty, so you cannot proceed to checkout.'),
('en', 'cannot_proccess_checkout_without_payment_methods', 'There are no payment methods available, so you cannot proceed to checkout.'),
('en', 'cannot_remove_active_theme', 'Cannot remove the active theme'),
('en', 'cannot_write_file', 'Cannot write to the file <b>[file]</b>. Please check the file and directory permissions.'),
('en', 'cant_save_percentage_price', 'You can not use percentage value for base price.'),
('en', 'cant_upload_file', 'Couldn''t upload the file. The problem isn''t necessarily on the [product] end. If it occurs regularly, please contact your server administrator or our technical support.'),
('en', 'capture', 'Capture'),
('en', 'card', 'Card'),
('en', 'cardholder_name', 'Cardholder''s name'),
('en', 'card_number', 'Card number'),
('en', 'carousel', 'Carousel'),
('en', 'carrier', 'Carrier'),
('en', 'carrier_aup', 'Australia Post'),
('en', 'carrier_can', 'Canada Post'),
('en', 'carrier_dhl', 'DHL'),
('en', 'carrier_fedex', 'FedEx'),
('en', 'carrier_swisspost', 'SwissPost'),
('en', 'carrier_ups', 'UPS'),
('en', 'tools_carrier_ups_msg', 'To get Client ID and Client Secret, <a target="_blank" href="[url]">register an app in your UPS account</a>.'),
('en', 'carrier_upsdeprecated', 'UPS [Deprecated]'),
('en', 'tools_carrier_upsdeprecated_msg', 'This shipping method will stop working in June 2024. To keep using UPS, please set up a shipping method that uses "UPS" rather than "UPS [Deprecated]" for rate calculation.'),
('en', 'carrier_usps', 'USPS'),
('en', 'cart', 'Cart'),
('en', 'cart_content', 'Cart content'),
('en', 'cart_contents', 'Cart contents'),
('en', 'cart_info', 'Site info'),
('en', 'cart_is_empty', 'Cart is empty'),
('en', 'cart_items', 'Cart items'),
('en', 'cart_subtotal', 'Cart subtotal'),
('en', 'cash_on_delivery', 'Cash on delivery'),
('en', 'catalog', 'Catalog'),
('en', 'catalog_pages', 'Catalog pages'),
('en', 'categories', 'Categories'),
('en', 'categories_have_been_added', 'Categories have been added'),
('en', 'category', 'Category'),
('en', 'category_delimiter', 'Category delimiter'),
('en', 'category_description', 'Category description'),
('en', 'category_location', 'Category location'),
('en', 'category_name', 'Category name'),
('en', 'cdn_settings', 'CDN settings'),
('en', 'central', 'Central'),
('en', 'central_content', 'Central content'),
('en', 'certificate', 'Certificate'),
('en', 'certificate_filename', 'Certificate filename'),
('en', 'change', 'Change'),
('en', 'changed', 'Changed'),
('en', 'changes', 'Changes'),
('en', 'change_access_permission_to_config', 'Also it is recommended to change the access permissions for the config.local.php file. It should have 644 (read/write for the owner and read for others) permissions.'),
('en', 'change_addons_initialization', 'Change add-ons initialization'),
('en', 'change_language', 'Change language'),
('en', 'change_password_notification', 'Please change your password'),
('en', 'change_password_notification_body', 'Your password to access the admin panel of the [store] store was last changed [days] days ago. For security reasons, please change your password. In order to do this, please follow the link:'),
('en', 'change_permissions', 'Change permissions'),
('en', 'check_permissions', 'Check permissions'),
('en', 'change_range', 'Change range'),
('en', 'charged_amount', 'Charged amount'),
('en', 'charset', 'Character set'),
('en', 'chart', 'Chart'),
('en', 'charts', 'Charts'),
('en', 'chart_type', 'Chart type'),
('en', 'check', 'Check'),
('en', 'checkbox', 'Check box'),
('en', 'checking_account_number', 'Checking account number'),
('en', 'checkout', 'Checkout'),
('en', 'checkout_as_guest', 'Checkout as guest'),
('en', 'checkout_edp_terms_n_conditions', 'I accept the terms in the'),
('en', 'checkout_terms_n_conditions', 'Select this check box to accept the [terms_href]'),
('en', 'checkout_terms_n_conditions_name', 'Terms and Conditions'),
('en', 'checkout_terms_n_conditions_alert', 'In order to proceed, you need to accept our Terms and Conditions.'),
('en', 'terms_and_conditions_content', '<p>Please read these Terms and Conditions ("Terms", "Terms and Conditions") carefully before using the <a href="http://www.mywebsite.com">http://www.mywebsite.com</a> website and the My Mobile App mobile application (the "Service") operated by My Company ("us", "we", or "our").</p><p><strong>By accessing or using the Service you agree to be bound by these Terms. If you disagree with any part of the Terms then you may not access the Service.</strong></p><p><strong>Purchases</strong></p><p>If you wish to purchase any product or service made available through the Service ("Purchase"), you may be asked to supply certain information relevant to your Purchase including, without limitation, your ...</p><p><strong>Content</strong></p><p>Our Service allows you to post, link, store, share and otherwise make available certain information, text, graphics, videos, or other material ("Content"). You are responsible for the ...</p><p><strong>Changes</strong></p><p>We reserve the right, at our sole discretion, to modify or replace these Terms at any time. If a revision is material we will try to provide at least 30 days'' notice prior to any new terms taking effect. What constitutes a material change will be determined at our sole discretion.</p><p><strong>Contact Us</strong></p><p>If you have any questions about these Terms, please contact us.</p>'),
('en', 'check_again', 'Recheck and correct'),
('en', 'check_all', 'All'),
('en', 'check_disabled', 'Disabled'),
('en', 'check_items_text', 'To include Order statuses, Payment methods and Locations in the conditions list, check the necessary item and click on the "Save" button.'),
('en', 'sales_reports_side_bar_notes', 'To include Order statuses, Payment methods and Rate areas in the conditions list, check the necessary item and click on the "Save" button.'),
('en', 'check_none', 'None'),
('en', 'check_active', 'Active'),
('en', 'check_hidden', 'Hidden'),
('en', 'check_pending', 'Pending'),
('en', 'check_number', 'Check Number'),
('en', 'check_ssl', 'Check SSL'),
('en', 'check_uncheck_all', 'Check / uncheck all'),
('en', 'chinese', 'Chinese'),
('en', 'choose', 'Choose'),
('en', 'choose_action', 'Choose action'),
('en', 'actions.more', 'More'),
('en', 'actions.bulk_product_addition', 'Add several products'),
('en', 'actions.cdn_settings', 'CDN settings'),
('en', 'actions.cities', 'Cities'),
('en', 'actions.clear_cache', 'Clear cache'),
('en', 'actions.clear_thumbnails', 'Clear thumbnails'),
('en', 'actions.countries', 'Countries'),
('en', 'actions.datakeeper_optimize', 'Optimize database'),
('en', 'actions.destinations', 'Rate areas'),
('en', 'actions.export_found', 'Export found'),
('en', 'actions.export', 'Export'),
('en', 'actions.feature_groups', 'Feature groups'),
('en', 'actions.file_changes_detector', 'Changed core files'),
('en', 'actions.files', 'File manager'),
('en', 'actions.global_update', 'Global update'),
('en', 'actions.import', 'Import'),
('en', 'actions.languages', 'Languages'),
('en', 'actions.layouts', 'Layouts'),
('en', 'actions.live_editor', 'Edit on site'),
('en', 'actions.logs', 'Logs'),
('en', 'actions.localizations', 'Localizations'),
('en', 'actions.preview', 'Preview'),
('en', 'actions.product_subscriptions', 'Expected products'),
('en', 'actions.product_tabs', 'Product tabs'),
('en', 'actions.seo_robots', 'Robots.txt'),
('en', 'actions.shipment_statuses', 'Shipment statuses'),
('en', 'actions.states', 'States'),
('en', 'actions.templates', 'Templates'),
('en', 'actions.upload_backup', 'Upload file'),
('en', 'actions.user_group_requests', 'User group requests'),
('en', 'choose_category', 'Choose category'),
('en', 'choose_user', 'Choose user'),
('en', 'choose_your_country', 'Choose your country'),
('en', 'choose_your_store_mode', 'Please choose your licensing mode'),
('en', 'cities', 'Cities'),
('en', 'city', 'City'),
('en', 'classes', 'classes'),
('en', 'clean', 'clean'),
('en', 'cleanup_history', 'Clean up history'),
('en', 'clean_logs', 'Clear logs'),
('en', 'clean_old_logs', 'Clear logs older than [n] day|Clear logs older than [n] days'),
('en', 'clean_up_all_locations_on_import', 'Clean up locations before import'),
('en', 'clear', 'Clear'),
('en', 'clear_cache', 'Clear cache'),
('en', 'generate_cache', 'Generate cache'),
('en', 'clear_cart', 'Clear cart'),
('en', 'clear_conditions', 'Clear conditions'),
('en', 'clear_fields', 'Clear fields'),
('en', 'clear_list', 'Clear list'),
('en', 'clear_thumbnails', 'Clean up generated thumbnails'),
('en', 'clicks', 'Clicks'),
('en', 'client_id', 'Client ID'),
('en', 'clone', 'Clone'),
('en', 'clone_from', 'Clone from'),
('en', 'clone_selected', 'Clone selected'),
('en', 'clone_table', 'Clone table'),
('en', 'clone_theme', 'Clone theme'),
('en', 'clone_this_item', 'Clone this item'),
('en', 'clone_this_page', 'Clone this page'),
('en', 'close', 'Close'),
('en', 'cmcic_societe', 'Societe'),
('en', 'cname', 'CNAME'),
('en', 'code', 'Code'),
('en', 'coefficient', 'Coefficient'),
('en', 'collapse_bg_color', 'Collapse background color'),
('en', 'collapse_sublist_of_items', 'Collapse the sublist of items'),
('en', 'collapse_text_color', 'Collapse text color'),
('en', 'color', 'Color'),
('en', 'combination', 'Combination'),
('en', 'comma', 'Comma'),
('en', 'comment', 'Comment'),
('en', 'comments', 'Comments'),
('en', 'comment_hint', 'Enter your comment to appear below the option'),
('en', 'commission', 'Commission'),
('en', 'commissions', 'Commissions'),
('en', 'commissions_of_last_periods', 'Commissions of latest periods'),
('en', 'commission_rates', 'Commission rates'),
('en', 'compact_list', 'Compact list'),
('en', 'company', 'Company'),
('en', 'company_address', 'Company address'),
('en', 'company_name', 'Company name'),
('en', 'company_not_found', 'Selected company not found.'),
('en', 'company_phone', 'Company phone'),
('en', 'company_settings', 'Company settings'),
('en', 'compare', 'Compare'),
('en', 'product_comparison_list', 'Comparison list'),
('en', 'comparison_list_note', 'Go to the products comparison list'),
('en', 'compare_product_features', 'Compare product features'),
('en', 'comparison_list', 'Comparison list'),
('en', 'compatible_class', 'Compatible class'),
('en', 'completed', 'Completed'),
('en', 'compressing_backup', 'Compressing backup file'),
('en', 'compress_dump', 'Compress backup file'),
('en', 'condition', 'Condition'),
('en', 'conditions', 'Conditions'),
('en', 'configure', 'Configure'),
('en', 'confirm', 'Confirm'),
('en', 'confirmation_dialog', 'Confirmation dialog'),
('en', 'confirm_password', 'Confirm password'),
('en', 'conflicts', 'Conflicts'),
('en', 'congratulations', 'Congratulations!'),
('en', 'connection_ticket', 'Connection ticket'),
('en', 'contact_information', 'Contact information'),
('en', 'contact_us_for_price', 'Contact us for a price'),
('en', 'container_options', 'Container options'),
('en', 'content', 'Content'),
('en', 'content_alignment', 'Content alignment'),
('en', 'content_changed_for', 'This block instances have different content for'),
('en', 'continue', 'Continue'),
('en', 'continue_shopping', 'Continue shopping'),
('en', 'controller', 'Replace with'),
('en', 'converting_data_in_table', 'Converting data in table [table]'),
('en', 'copyright_shopping_cart', '[product] - Shopping Cart Software'),
('en', 'core', 'Core'),
('en', 'cost', 'Cost'),
('en', 'cost_dependences', 'Cost dependencies'),
('en', 'could_not_open_file', 'File preview is not available'),
('en', 'countries', 'Countries'),
('en', 'country', 'Country'),
('en', 'coupon', 'Coupon'),
('en', 'coupons', 'Coupons'),
('en', 'coupon_already_used', 'This coupon is already in use'),
('en', 'coupon_code', 'Coupon code'),
('en', 'cpi_hash_key', 'CPI Hash Key'),
('en', 'create', 'Create'),
('en', 'created', 'Created'),
('en', 'create_account', 'Create account'),
('en', 'create_administrator_account', 'Create administrator account'),
('en', 'create_and_close', 'Create and close'),
('en', 'create_file', 'Create file'),
('en', 'create_folder', 'Create folder'),
('en', 'create_guest_account', 'Quick checkout with no account creating required'),
('en', 'create_new_account', 'Create a permanent account and use it for checkout'),
('en', 'create_new_block', 'Create New Block'),
('en', 'create_new_order', 'Create a new order'),
('en', 'create_process_payment', 'Create and process payment'),
('en', 'create_profile', 'Create a new profile'),
('en', 'create_profile_notification_header', 'Thank you for becoming a registered user at our store. Below you will find your account information.'),
('en', 'create_table', 'Create New Table'),
('en', 'creating', 'Creating'),
('en', 'creating_table', 'Creating table'),
('en', 'creation_date', 'Creation date'),
('en', 'credit_card', 'Credit card'),
('en', 'credit_card_info', 'This number is printed in the signature area on the back of the card. It is the 3 digits AFTER the credit card number.'),
('en', 'credit_memo', 'Credit memo'),
('en', 'credit_memo_id', 'Credit memo ID'),
('en', 'cresecureapitoken', 'CRE SecureAPIToken'),
('en', 'cresecureid', 'CRE SecureID'),
('en', 'cresecure_allowed_types', 'Allowed card types'),
('en', 'csv_delimiter', 'CSV delimiter'),
('en', 'csv_file', 'CSV file'),
('en', 'currencies', 'Currencies'),
('en', 'edit_currencies', 'Edit currencies'),
('en', 'currency', 'Currency'),
('en', 'currencycode', 'Currency code'),
('en', 'currency_code_aed', 'United Arab Emirates Dirham'),
('en', 'currency_code_ang', 'ANG'),
('en', 'currency_code_ars', 'ARS'),
('en', 'currency_code_aud', 'Australian Dollar'),
('en', 'currency_code_awg', 'AWG'),
('en', 'currency_code_bgn', 'BGN'),
('en', 'currency_code_brl', 'Brazilian Real'),
('en', 'currency_code_byr', 'BYN'),
('en', 'currency_code_cad', 'Canadian Dollar'),
('en', 'currency_code_chf', 'Swiss Franc'),
('en', 'currency_code_cny', 'CNY'),
('en', 'currency_code_cyr', 'Cyprus Pound'),
('en', 'currency_code_czk', 'Czech Koruna'),
('en', 'currency_code_dkk', 'Danish Kroner'),
('en', 'currency_code_eek', 'Estonian Kroon'),
('en', 'currency_code_egp', 'EGP'),
('en', 'currency_code_eur', 'Euro'),
('en', 'currency_code_fjd', 'Fiji Dollar'),
('en', 'currency_code_frf', 'French Franc'),
('en', 'currency_code_gbp', 'UK Pound'),
('en', 'currency_code_gel', 'GEL'),
('en', 'currency_code_hkd', 'Hong Kong Dollar'),
('en', 'currency_code_hrk', 'HRK'),
('en', 'currency_code_huf', 'Hungarian Forint'),
('en', 'currency_code_ils', 'Israel New Shequel'),
('en', 'currency_code_inr', 'Indian Rupee'),
('en', 'currency_code_isk', 'Iceland Krona'),
('en', 'currency_code_jpy', 'Japanese Yen'),
('en', 'currency_code_kpw', 'North Korean Won'),
('en', 'currency_code_krw', 'South Korean Won'),
('en', 'currency_code_kwd', 'Kuwaiti Dinar'),
('en', 'currency_code_kzt', 'Kazakhstani tenge'),
('en', 'currency_code_ltl', 'Lithuanian Litas'),
('en', 'currency_code_lvl', 'Latvian Lat'),
('en', 'currency_code_mad', 'MAD'),
('en', 'currency_code_mxn', 'Mexican Peso'),
('en', 'currency_code_myr', 'Malaysian Ringgit'),
('en', 'currency_code_nok', 'Norwegian Kroner'),
('en', 'currency_code_nzd', 'New Zealand Dollar'),
('en', 'currency_code_php', 'Philippine Peso'),
('en', 'currency_code_pln', 'Polish Zlotych'),
('en', 'currency_code_png', 'Papua New Guinea Kina'),
('en', 'currency_code_ron', 'RON'),
('en', 'currency_code_rub', 'RUB'),
('en', 'currency_code_rur', 'Russian Ruble'),
('en', 'currency_code_sar', 'Saudi Riyal'),
('en', 'currency_code_sbd', 'Solomon Islands Dollar'),
('en', 'currency_code_sek', 'Sweden Kroner'),
('en', 'currency_code_sgd', 'Singapore Dollar'),
('en', 'currency_code_sit', 'Slovenian Tolar'),
('en', 'currency_code_skk', 'Slovak Koruna'),
('en', 'currency_code_thb', 'Thai Baht'),
('en', 'currency_code_top', 'Tongan Pa''anga'),
('en', 'currency_code_try', 'Turkish Lira'),
('en', 'currency_code_twd', 'New Taiwan dollar'),
('en', 'currency_code_uah', 'UAH'),
('en', 'currency_code_usd', 'US Dollar'),
('en', 'currency_code_vuv', 'Vanuatu Vatu'),
('en', 'currency_code_wst', 'Samoan Tala'),
('en', 'currency_code_xaf', 'XAF'),
('en', 'currency_code_xof', 'XOF'),
('en', 'currency_code_xpf', 'XPF'),
('en', 'currency_code_zar', 'Rand'),
('en', 'currency_deleted', 'The currency has been deleted successfully.'),
('en', 'currency_rate', 'Rate'),
('en', 'currency_rate_greater_than_null', 'Currency exchange rate should be higher than 0.'),
('en', 'currency_sign', 'Sign'),
('en', 'current_database_size', 'Current database size'),
('en', 'current_path', 'Current path'),
('en', 'text_file_editor_notice', 'You can upload and download files via <a href="[href]">File Editor</a>'),
('en', 'text_file_editor_notice_with_image_size_info', 'You can upload and download files via <a href="[href]">File Editor</a>. The maximum size of image files is [file_size] MB.'),
('en', 'text_file_editor_notice_full_link', 'You can upload and download files via [link]'),
('en', 'current_previous_period', '''Current (''[date]'') and previous period'''),
('en', 'current_period', 'Current Period'),
('en', 'current_theme', 'Current theme'),
('en', 'custom', 'Custom'),
('en', 'customer', 'Customer'),
('en', 'customers', 'Customers'),
('en', 'customers_menu_title', 'Users'),
('en', 'my_customers', 'My customers'),
('en', 'my_administrators', 'My administrators'),
('en', 'customer_details', 'Customer details'),
('en', 'customer_email', 'Customer email'),
('en', 'customer_id', 'Customer ID'),
('en', 'customer_info', 'Customer information'),
('en', 'customer_information', 'Customer information'),
('en', 'customer_notes', 'Customer notes'),
('en', 'customer_signature', 'Customer''s signature'),
('en', 'customer_text_letter_footer', 'Thank you for using our shopping cart.'),
('en', 'customize', 'Customize'),
('en', 'theme_no_styles_text', 'This theme doesn''t have styles.'),
('en', 'custom_range', 'Custom Range'),
('en', 'cutted_product_codes', 'The following product codes are too long and were cut to 32 figures:'),
('en', 'cvv2', 'CVV/CVC'),
('en', 'czech', 'Czech'),
('en', 'danish', 'Danish'),
('en', 'dashboard', 'Dashboard'),
('en', 'database', 'Database'),
('en', 'database_data_changes', 'Database data changes'),
('en', 'backup_restore', 'Backup/Restore'),
('en', 'database_structure_changes', 'Database structure changes'),
('en', 'datatrans_caa', 'Authorization with immediate settlement'),
('en', 'datatrans_noa', 'Authorization only'),
('en', 'datatrans_sign', 'Digital signature'),
('en', 'date', 'Date'),
('en', 'date_added', 'Date added'),
('en', 'date_of_birth', 'Date of birth'),
('en', 'day', 'day'),
('en', 'days', 'days'),
('en', 'db_backup_restore', 'DB Backup/Restore'),
('en', 'create_backup', 'Create backup'),
('en', 'db_name', 'Database name'),
('en', 'dear', 'Dear'),
('en', 'debit', 'Debit'),
('en', 'decimals', 'Decimals'),
('en', 'decline', 'Decline'),
('en', 'default_decline_inventory_info', 'To avoid the situation when two customers buy the same product, this status always decreases inventory.'),
('en', 'declined', 'Declined'),
('en', 'decline_selected', 'Decline selected'),
('en', 'decorator', 'Decorator'),
('en', 'decrease', 'Decrease'),
('en', 'dec_sign', 'Dec sign'),
('en', 'select_selectbox_option', 'Select option'),
('en', 'default', 'Default'),
('en', 'select_default', 'Select default'),
('en', 'default_category_view', 'Default category view'),
('en', 'default_language', 'Default language'),
('en', 'default_layout', 'Default layout'),
('en', 'default_long_options_template', 'Default template (long product option names)'),
('en', 'default_product_details_view', 'Parent ([default])'),
('en', 'default_template', 'Default template'),
('en', 'bigpicture_template', 'The big picture'),
('en', 'default_value', 'Default value'),
('en', 'default_custom.disabled', 'Disabled'),
('en', 'default_custom.custom', 'Custom...'),
('en', 'default_custom.custom_value', 'Custom ([value])'),
('en', 'default_custom.parent', 'Parent ([name])'),
('en', 'default_custom.global', 'Global ([name])'),
('en', 'default_custom.edit_parent', 'Edit parent ([name])...'),
('en', 'default_custom.edit_global', 'Edit global ([name])...'),
('en', 'global_individual.global', 'Global'),
('en', 'global_individual.individual', 'Individual'),
('en', 'global_individual.global_value_all_items', 'Global value for all items'),
('en', 'global_individual.individual_values_each_item', 'Individual values for each item'),
('en', 'global_individual.individual_tooltip', 'This setting is currently global. Click here to allow changing its value for individual items.'),
('en', 'global_individual.global_tooltip', 'The value of this setting can be changed for individual items. Click here to make this setting global.'),
('en', 'global_individual.additional_settings', 'You can hide or show some extra product settings here. A hidden setting will be global and affect all products. Look out for icon [icon] <a href="[settings_url]">in the "Settings" menu</a>.'),
('en', 'deferred', 'Deferred'),
('en', 'defined', 'Defined'),
('en', 'defined_desired_products', 'List of desired products'),
('en', 'defined_items', 'defined items'),
('en', 'delay', 'Delay (in seconds)'),
('en', 'delete', 'Delete'),
('en', 'dismiss', 'Dismiss'),
('en', 'deleted', 'Deleted'),
('en', 'deleted_product', 'DELETED PRODUCT'),
('en', 'delete_block', 'Delete block'),
('en', 'delete_confirmation', 'Are you sure you want to delete the selected items?'),
('en', 'delete_grid', 'Delete grid'),
('en', 'delete_image', 'Delete image'),
('en', 'delete_image_pair', 'Delete image pair'),
('en', 'delete_install_folder', 'Please remove the install directory.<br /><br />Keeping the install directory on the server is insecure.'),
('en', 'delete_range', 'Delete range'),
('en', 'delete_selected', 'Delete selected'),
('en', 'delete_this_category', 'Delete this category'),
('en', 'delete_this_page', 'Delete this page'),
('en', 'delivery_time', 'Delivery time'),
('en', 'demo', 'Demo'),
('en', 'demo_mode', 'Demo mode is enabled'),
('en', 'demo_mode_content_text', '<p>The cart is working in the <b>DEMO</b> mode and this functionality is disabled.</p>'),
('en', 'demo_panel.demo_store_panel', 'Demo store panel'),
('en', 'demo_panel.go_admin_panel', 'Go to Administration panel'),
('en', 'demo_panel.go_storefront', 'Go to Storefront'),
('en', 'demo_panel.demo_will_be_reset_in', 'Demo will be reset in:'),
('en', 'denied', 'Denied'),
('en', 'dependence', 'Sort by'),
('en', 'deposit_amount', 'Deposit amount'),
('en', 'desc', 'desc.'),
('en', 'description', 'Description'),
('en', 'descr_avs', 'AVS verification response'),
('en', 'descr_cvv', 'CVV2 verification response'),
('en', 'design', 'Design'),
('en', 'design_mode', 'Design mode'),
('en', 'desired_amount', 'Desired quantity'),
('en', 'destination', 'Destination'),
('en', 'detailed_description', 'Detailed description'),
('en', 'detailed_images', 'Detailed images'),
('en', 'details', 'details'),
('en', 'diff', 'File changes'),
('en', 'different_only', 'Different only'),
('en', 'directory', 'Directory'),
('en', 'direct_download', 'Direct download'),
('en', 'disable', 'Disable'),
('en', 'disabled', 'Disabled'),
('en', 'disabled_categories', 'Disabled categories'),
('en', 'disable_for', 'Disable for'),
('en', 'disable_selected', 'Disable selected'),
('en', 'disapprove', 'Disapprove'),
('en', 'disapproved', 'Disapproved'),
('en', 'disapprove_selected', 'Disapprove selected'),
('en', 'discount', 'Discount'),
('en', 'discounted_price', 'Discounted price'),
('en', 'discounts', 'Discounts'),
('en', 'discount_coupon', 'Discount coupon'),
('en', 'discount_coupon_code', 'Discount coupon code'),
('en', 'dispatch', 'Dispatch'),
('en', 'displayed_vendors', 'Displayed stores'),
('en', 'display_bottom_buttons', 'Display bottom buttons'),
('en', 'display_delete_icons', 'Display delete icons'),
('en', 'display_message', 'Display message'),
('en', 'display_on', 'Display on'),
('en', 'display_type', 'Display type'),
('en', 'display_variants_count', 'Number of displayed filter variants before scroll'),
('en', 'domains', 'Domains'),
('en', 'domestic_usps', 'Domestic U.S.P.S.'),
('en', 'done', 'Done'),
('en', 'dont_track', 'Do not track'),
('en', 'dont_use_cardinal', 'Don''t use Cardinal Centinel&reg; for 3-D Secure Payer Authentication'),
('en', 'dots', 'Dots'),
('en', 'down', 'Down'),
('en', 'download', 'Download'),
('en', 'downloadable', 'Downloadable'),
('en', 'downloadable_shipping', 'Enable shipping if downloadable'),
('en', 'downloads', 'Downloads'),
('en', 'downloads_max_left', 'Downloads (max./left)'),
('en', 'download_key_expiry', 'Download key expiry'),
('en', 'download_link_expired', 'The download link is expired or is not ready.'),
('en', 'do_not_change', 'Do not change'),
('en', 'do_not_pass_logo', 'Do not pass the shopping cart logo to the merchant'),
('en', 'do_not_use', 'Do not use'),
('en', 'drlicense_number', 'Driving License Number'),
('en', 'dropdown_horizontal', 'Dropdown horizontal'),
('en', 'dropdown_limit', 'Minimal number of items to be placed in a dropdown list.'),
('en', 'dropdown_second_level_elements', 'Second level elements'),
('en', 'dropdown_third_level_elements', 'Third level elements'),
('en', 'dropdown_vertical', 'Dropdown vertical'),
('en', 'drop_existing_data', 'Delete all existing product files before import'),
('en', 'delete_downloadable_product_files', 'Delete existing files of downloadable products'),
('en', 'delete_downloadable_product_files_tooltip', 'If you enable this setting, then importing downloadable products will delete their existing files. If the setting is disabled, the new files of downloadable products will simply be added to existing files.'),
('en', 'cant_create_backup_file', 'Cannot upload backup file. Please check permissions for the "var/backups" directory of your installation.'),
('en', 'dump_file_not_writable', 'Please set write permissions on the database backup file.'),
('en', 'duplicate', 'Duplicate transactions'),
('en', 'dutch', 'Dutch'),
('en', 'dynamic', 'Dynamic'),
('en', 'dynamic_content', 'This block content will be shown on <a href="[url]">this page</a> only.'),
('en', 'dynamic_tree_cat', 'Dynamic tree'),
('en', 'dynamic_tree_pages', 'Dynamic tree'),
('en', 'easing', 'Easing'),
('en', 'edit', 'Edit'),
('en', 'editing', 'Editing'),
('en', 'editing_block', 'Editing block'),
('en', 'editing_category', 'Editing category'),
('en', 'editing_chart', 'Editing chart'),
('en', 'editing_container', 'Editing container'),
('en', 'editing_currency', 'Editing currency'),
('en', 'editing_defined_products', 'Editing defined products'),
('en', 'editing_file', 'Editing file'),
('en', 'editing_filter', 'Editing filter'),
('en', 'editing_folder', 'Editing folder'),
('en', 'editing_grid', 'Editing grid'),
('en', 'editing_group', 'Editing group'),
('en', 'editing_item', 'Editing item'),
('en', 'editing_language', 'Editing language'),
('en', 'editing_layout', 'Editing layout'),
('en', 'editing_link', 'Editing link'),
('en', 'editing_localization', 'Editing localization'),
('en', 'editing_location', 'Editing location'),
('en', 'editing_rate_area', 'Editing rate area'),
('en', 'editing_menu', 'Editing menus'),
('en', 'editing_option', 'Editing option'),
('en', 'editing_order', 'Editing order'),
('en', 'editing_page', 'Editing page'),
('en', 'editing_payment', 'Editing payment');
INSERT INTO `[[dbprefix]]language_values` VALUES
('en', 'editing_product', 'Editing product'),
('en', 'editing_product_feature', 'Editing product feature'),
('en', 'editing_profile', 'Editing profile'),
('en', 'editing_profile_field', 'Editing profile field'),
('en', 'editing_promotion', 'Editing promotion'),
('en', 'editing_quick_menu_link', 'Editing quick menu link'),
('en', 'editing_quick_menu_section', 'Editing quick menu section'),
('en', 'editing_report', 'Editing report'),
('en', 'editing_shipping_method', 'Editing shipping method'),
('en', 'editing_sitemap_section', 'Editing sitemap section'),
('en', 'editing_status', 'Editing status'),
('en', 'editing_tab', 'Editing tab'),
('en', 'editing_tax', 'Editing tax'),
('en', 'editing_vendor', 'Editing store'),
('en', 'edition_type', 'Edition type'),
('en', 'edit_content_on_site', 'Edit content on-site'),
('en', 'edit_files', 'Can edit'),
('en', 'edit_layout', 'Edit layout'),
('en', 'edit_order', 'Edit order'),
('en', 'edit_products', 'Edit products'),
('en', 'edit_profile', 'Edit profile'),
('en', 'edit_profile_note', 'Change email, password, shipping/billing info, and other profile settings'),
('en', 'edit_report', 'Edit report'),
('en', 'edit_selected', 'Edit selected'),
('en', 'edp_access_granted', 'Now you can download the purchased products.'),
('en', 'edp_access_subj', 'Access to electronically distributed products is granted'),
('en', 'edp_enable_shipping', 'Enable shipping for downloadable products'),
('en', 'email', 'E-mail'),
('en', 'emails', 'Emails'),
('en', 'email_address', 'E-mail address'),
('en', 'email_header', 'E-mail header'),
('en', 'email_subject', 'E-mail subject'),
('en', 'empty', 'Empty'),
('en', 'empty_key_value', 'Empty table key value'),
('en', 'enable', 'Enable'),
('en', 'enabled', 'Enabled'),
('en', 'enable_cdn', 'Enable CDN'),
('en', 'enable_for', 'Enable for'),
('en', 'enable_or_disable_block', 'Activate/Deactivate Block'),
('en', 'enable_or_disable_container', 'Activate/Deactivate Container'),
('en', 'enable_or_disable_grid', 'Activate/Deactivate Grid'),
('en', 'enable_quick_view', 'Enable quick view'),
('en', 'encryption', 'Encryption'),
('en', 'encryption_key', 'Encryption Key'),
('en', 'end_date', 'End date'),
('en', 'english', 'English'),
('en', 'enter_code', 'Enter code'),
('en', 'enter_data', 'Enter data'),
('en', 'enter_email', 'Enter e-mail address'),
('en', 'enter_new_lang_code', 'Enter a new language code'),
('en', 'enter_other', 'Enter other'),
('en', 'enter_your_price', 'Enter your price'),
('en', 'entity', 'Entity'),
('en', 'entry_page', 'Global entry page'),
('en', 'entry_point', 'Entry point'),
('en', 'envelope', 'Envelope'),
('en', 'epdq_3ds_main', 'Main window'),
('en', 'epdq_3ds_popup', 'Popup'),
('en', 'error', 'Error'),
('en', 'errorCode', 'Error Code'),
('en', 'errorName', 'Error Name'),
('en', 'error_account_disabled', 'Your account is disabled. Please contact the store administration.'),
('en', 'error_count_recover_password_ekeys', 'You''ve already requested password reset. If you haven''t received an email, please try again in a few minutes.'),
('en', 'error_admin_not_created_email_already_used', 'Administrator account was not created. The email address belongs to another user. You can add the administrator for this company manually.'),
('en', 'error_ajax', 'Oops, something went wrong ([error]). Please try again.'),
('en', 'error_area_access_denied', 'You are not allowed to login to this area.'),
('en', 'error_confirmation_code_invalid', 'Sorry, the anti-bot validation has failed. Please try again.'),
('en', 'error_curl_not_exists', '<b>Warning!</b><br />Your server <b>does not</b> support the PHP cURL extension. <b>[method]</b> will not be operational. Please contact your hosting provider.'),
('en', 'error_curl_ssl_not_exists', '<b>Warning!</b><br />The PHP cURL extension is compiled <b>without</b> SSL support on your server. <b>[method]</b> will not be operational. Please contact your hosting provider.'),
('en', 'error_currency_exists', 'Currency with code <b>[code]</b> already exists'),
('en', 'error_delete_theme_company', 'One of your storefronts uses this theme. Please set another theme before deleting it.'),
('en', 'error_delete_theme_layout', 'Layout that uses this theme is set as 	default. Please set another layout as default.'),
('en', 'error_demo_mode', 'The cart is working in the <b>DEMO</b> mode and this functionality is disabled.'),
('en', 'error_empty_company_name', 'Company name cannot be empty'),
('en', 'error_exim_get_images_for_products', 'Could not import images for some of the products. Either those images don''t exist (or can''t be accessed), or the paths to those images in the imported file are incorrect.'),
('en', 'error_exim_cant_open_file', 'Cannot open uploaded file'),
('en', 'error_exim_cant_read_file', 'Cannot read uploaded file'),
('en', 'error_exim_fields_not_selected', 'No fields selected for export'),
('en', 'error_exim_file_doesnt_exist', 'File doesn''t exist'),
('en', 'error_exim_incorrect_lines', 'Your CSV file has incorrect data formatting (incorrect delimiter, missed/missing fields, etc.) in the following lines: <b>[lines]</b>'),
('en', 'error_exim_incorrent_delimiter', 'The delimiter in CSV file differs from the one selected by you'),
('en', 'error_exim_invalid_count_langs', 'Multi-language line count mismatch: different number of lines for different languages provided.'),
('en', 'error_exim_layout_required_fields', 'The following fields are mandatory and cannot be removed from the layout:'),
('en', 'error_exim_no_data_exported_new', 'No data exported. The wrong export range is probably causing this issue. <a class="cm-post" href="[url]">Clear the export range</a>, then try again'),
('en', 'error_exim_no_file_uploaded', 'No file uploaded'),
('en', 'error_exim_pattern_definition_alt_keys', 'Invalid pattern definition: alternative key is missing'),
('en', 'error_exim_pattern_definition_references', 'Invalid pattern definition: missing table references'),
('en', 'error_exim_pattern_dont_match', 'Your import file does not match the selected pattern'),
('en', 'error_exim_pattern_not_found', 'Pattern not found'),
('en', 'error_exim_pattern_required_fields', 'Your import file MUST have the following fields: <b>[fields]</b>'),
('en', 'error_hash_generation', 'Error in hash generation. Please choose another payment method.'),
('en', 'error_images_need_located_root_dir', 'Please specify the images directory within the store root directory. Put the images to import in this directory.'),
('en', 'error_image_format_not_supported', 'The image format <b>[format]</b> is not supported by GD library installed on your server. The thumbnail was not created.'),
('en', 'error_incorrect_login', 'The username or password you have entered is invalid. Please try again.'),
('en', 'error_invalid_emails', 'The following email addresses are invalid: <b>[emails]</b>'),
('en', 'error_lang_code_exists', 'The provided language ([code]) code already exists'),
('en', 'error_login_not_exists', 'The username you have entered does not match any account in our store. Please make sure you have entered the correct username and try again.'),
('en', 'error_message_not_sent', 'Message could not be sent.<br />Mailer Error:'),
('en', 'error_not_logged', 'You must log in before you can access this resource!'),
('en', 'error_no_items_selected', 'No items selected! At least one check box must be selected to perform this action.'),
('en', 'error_occured', 'Error occurred.'),
('en', 'error_occurred', 'Error occurred'),
('en', 'error_passwords_dont_match', 'The passwords do not match.'),
('en', 'error_password_content', 'The password must contain both letters and numbers.'),
('en', 'error_password_expired', 'Your password has expired. You must change your password now.'),
('en', 'error_password_expired_change', 'Your password has expired. <p><a href="[link]" class="underlined"><b>Change password &#155;&#155;</b></a></p>'),
('en', 'error_password_min_symbols', 'The password must contain at least <b>[number]</b> characters.'),
('en', 'error_password_was_used', 'Your new password must not coincide with any of those four passwords used before. Please use another password.'),
('en', 'error_permissions_not_changed', 'Cannot change permissions'),
('en', 'error_status_not_changed', 'Error while updating the status. Status was not changed.'),
('en', 'error_theme_manifest_missed', 'Theme description file ("manifest") was not found. Installation canceled.'),
('en', 'error_user_exists', 'The username or email you have chosen already exists. Please try another one.'),
('en', 'error_validator_color', 'The color code in the <b>[field]</b> field is invalid.'),
('en', 'error_validator_email', 'The email address in the <b>[field]</b> field is invalid.'),
('en', 'error_validator_integer', 'The value of the <b>[field]</b> field is invalid. It should be integer.'),
('en', 'error_validator_message', 'The value of the <b>[field]</b> field is invalid.'),
('en', 'error_validator_multiple', 'The <b>[field]</b> field does not contain the selected options.'),
('en', 'error_validator_password', 'The passwords in the <b>[field2]</b> and <b>[field]</b> fields do not match.'),
('en', 'error_validator_phone', 'The phone number in the <b>[field]</b> field is invalid. The correct format is +16175555555.'),
('en', 'error_validator_phone_mask', 'The phone number in the <b>[field]</b> field is invalid.'),
('en', 'error_validator_phone_mask_with_phone', 'The phone number <b>[phone]</b> is invalid.'),
('en', 'error_validator_phone_phone_number_with_country_selection', 'The phone number is invalid'),
('en', 'error_validator_phone_number', 'It is required to use the following format for this payment method: +16175555555.'),
('en', 'error_validator_required', 'The <b>[field]</b> field is mandatory.'),
('en', 'error_validator_zipcode', 'The ZIP / Postal code in the <b>[field]</b> field is incorrect. The correct format is [extra].'),
('en', 'error_vendor_exists', 'The company with e-mail you have chosen already exists, please try another.'),
('en', 'error_validator_ccv', 'CVV/CVC is too short.'),
('en', 'error_validator_ccv_long', 'CVV/CVC is too long.'),
('en', 'error_change_admin_data_in_frontend', 'It''s forbidden to change the admin email or password in the customer area. Please sign in using a customer account.'),
('en', 'error_exchange_rate', 'Unable to get exchange rates. Please try reloading this page in a minute.'),
('en', 'exact_phrase', 'The exact phrase'),
('en', 'excellent', 'Excellent!'),
('en', 'exception', 'Exception'),
('en', 'exceptions', 'Exceptions'),
('en', 'exceptions_type', 'Exceptions type'),
('en', 'exception_disabled', 'No variant can be selected'),
('en', 'exception_disregard', 'Any variant'),
('en', 'exception_error', 'ERROR'),
('en', 'exception_error_code', 'Error code:'),
('en', 'exception_exist', 'This exception combination already exists'),
('en', 'exception_title', 'Oops!<br />We were unable to find what you were looking for.'),
('en', 'exchange_rate', 'Live exchange rates'),
('en', 'exec', 'Execute'),
('en', 'exim_remove_additional_images', 'Clean up'),
('en', 'exit_point', 'Exit point'),
('en', 'exp', 'Exp'),
('en', 'expanded', 'Expanded'),
('en', 'expand_collapse_list', 'Expand / collapse the list of items'),
('en', 'expand_sublist_of_items', 'Expand the sublist of items'),
('en', 'expired', 'Expired'),
('en', 'expirepreauth', 'Preauthorization'),
('en', 'expirepreauth_description', 'Preauthorization hold limit in days. The maximum value is 30 days. With the "Sale" request type, leave this field empty.'),
('en', 'expiry_date', 'Expiration date'),
('en', 'export', 'Export'),
('en', 'exported_fields', 'Exported fields'),
('en', 'exported_files', 'Exported files'),
('en', 'exporting_data', 'Exporting data'),
('en', 'export_data', 'Export data'),
('en', 'export_locations', 'Export locations'),
('en', 'export_options', 'Export options'),
('en', 'export_selected', 'Export selected'),
('en', 'export_products', 'Export products'),
('en', 'extended', 'Extended'),
('en', 'extra', 'Extra'),
('en', 'extra_services', 'Extra services'),
('en', 'extra_folders', 'Extra folders'),
('en', 'fail', 'Fail'),
('en', 'failed', 'Failed'),
('en', 'fair', 'Fair'),
('en', 'false', 'False'),
('en', 'faroese', 'Faroese'),
('en', 'fast', 'Fast'),
('en', 'fax', 'Fax'),
('en', 'feature', 'Feature'),
('en', 'features', 'Features'),
('en', 'features_delimiter', 'Feature variants delimiter'),
('en', 'feature_code', 'Feature code'),
('en', 'feature_comparison', 'Feature comparison'),
('en', 'feature_category', 'Feature category'),
('en', 'feature_display_on_catalog', 'Show in product list'),
('en', 'feature_display_on_header', 'Show in header on the product details page'),
('en', 'feature_display_on_product', 'Show on the Features tab'),
('en', 'feature_hide_on_catalog', 'Hide in product list'),
('en', 'feature_hide_on_header', 'Hide in header on the product details page'),
('en', 'feature_hide_on_product', 'Hide on the Features tab'),
('en', 'feedback_is_sent_successfully', 'The feedback has been sent successfully.'),
('en', 'feedback_values', 'Feedback values'),
('en', 'field', 'Field'),
('en', 'field_editor', 'Field Editor'),
('en', 'file', 'File'),
('en', 'filename', 'File name'),
('en', 'files', 'Files'),
('en', 'sell_files', 'Files to sell'),
('en', 'filesize', 'File size'),
('en', 'files_changes', 'File changes'),
('en', 'files_directory', 'Files directory'),
('en', 'downloadable_product_files_directory', 'Directory for the files of downloadable products'),
('en', 'file_avail_after_payment', 'This file will be available after the order is paid in full.'),
('en', 'file_browser', 'File browser'),
('en', 'file_doesnt_have_key', 'This file doesn''t have a download key.'),
('en', 'file_download_limit_exceeded', 'The file cannot be downloaded because the download limit equal to [limit] is exceeded.'),
('en', 'file_is_too_large', 'File is too large. Max uploading size is [size].'),
('en', 'files_are_too_large', 'Total size of the uploaded files exceeds the maximum limit of [size].'),
('en', 'file_tree', 'File tree'),
('en', 'filling', 'Filling'),
('en', 'filter', 'Filter'),
('en', 'filters', 'Filters'),
('en', 'filter_by', 'Filter by'),
('en', 'filter_description', 'Filter description'),
('en', 'filter_name', 'Filter name'),
('en', 'filters_in_use', 'All features are already in use'),
('en', 'finance_product_code', 'Finance product code'),
('en', 'financial_state', 'Financial state'),
('en', 'find_results_with', 'Find results with'),
('en', 'finish', 'Finish'),
('en', 'finished', 'Finished'),
('en', 'finnish', 'Finnish'),
('en', 'first_name', 'First name'),
('en', 'flemish', 'Flemish'),
('en', 'folder', 'Folder'),
('en', 'folder_is_empty', 'Folder is empty'),
('en', 'footer', 'Footer'),
('en', 'for', 'for'),
('en', 'forbidden', 'Forbidden'),
('en', 'forbidden_combinations', 'Forbidden combinations'),
('en', 'forgot_password_question', 'Forgot your password?'),
('en', 'form', 'Form'),
('en', 'format', 'Format'),
('en', 'forms', 'Forms'),
('en', 'form_id', 'Form ID'),
('en', 'for_all_found_orders', 'For orders on ALL pages'),
('en', 'for_this_page_orders', 'For orders on THIS page'),
('en', 'fragile', 'Fragile'),
('en', 'free', 'Free'),
('en', 'free_products', 'Free products'),
('en', 'free_shipping', 'Free shipping'),
('en', 'french', 'French'),
('en', 'from', 'from'),
('en', 'from_date', 'Date from'),
('en', 'fulfillment_state', 'Fulfillment state'),
('en', 'full', 'Full'),
('en', 'fullauth', 'Fullauth'),
('en', 'full_description', 'Full description'),
('en', 'full_list', 'Full list'),
('en', 'full_tree_cat', 'Full tree'),
('en', 'full_tree_pages', 'Full tree'),
('en', 'full_width', 'Full width'),
('en', 'function', 'Core'),
('en', 'function_deprecated', 'Function [old_function] is deprecated and will be removed in next version. Please use [new_function] instead of it.'),
('en', 'gateway', 'Gateway'),
('en', 'gateways', 'Gateways'),
('en', 'general', 'General'),
('en', 'general_info', 'General information'),
('en', 'general_statistics', 'General statistics'),
('en', 'generate', 'Generate'),
('en', 'generate_submenu', 'Generate submenu'),
('en', 'geography', 'Geography'),
('en', 'german', 'German'),
('en', 'get_rates', 'Get rates'),
('en', 'give_coupon_subj', 'you have new promotion'),
('en', 'global', 'Global'),
('en', 'global_options', 'Global options'),
('en', 'global_status', 'Global status'),
('en', 'global_update', 'Global update'),
('en', 'global_update_description', 'Positive or negative values can be entered in the fields below (e.g. -5).'),
('en', 'go', 'Go'),
('en', 'google', 'Google'),
('en', 'google_base', 'Google Base'),
('en', 'google_base_export_notice', '<b>Note:</b> You can setup Tax and Shipping rates on the <a href="http://www.google.com/merchants/taxshippingsettings">Tax and shipping summary</a> page in your Google merchant center.'),
('en', 'goto_theme_configuration', 'Browse themes'),
('en', 'remove_theme', 'Remove theme'),
('en', 'go_back', 'Go back'),
('en', 'go_to_the_admin_homepage', 'Go to the admin homepage'),
('en', 'admin.go_to_the_homepage', 'Go to the homepage'),
('en', 'go_to_the_homepage', 'Go to the homepage'),
('en', 'grams_in_the_unit_of_weight', 'Grams in the unit of weight defined by the weight symbol'),
('en', 'graphic', 'Graphic'),
('en', 'greek', 'Greek'),
('en', 'grid', 'Grid'),
('en', 'tmpl_grid', 'Grid'),
('en', 'tmpl_grid2', 'Grid2'),
('en', 'grid_options', 'Grid options'),
('en', 'gross_total', 'Gross total'),
('en', 'group', 'Group'),
('en', 'groups', 'Groups'),
('en', 'guest', 'Guest'),
('en', 'has_credit_memo', 'Has credit memo'),
('en', 'has_invoice', 'Has invoice'),
('en', 'header', 'Header'),
('en', 'sidebar', 'Sidebar'),
('en', 'header_image', 'Header image'),
('en', 'hebrew', 'Hebrew'),
('en', 'height', 'Height'),
('en', 'hello', 'Hello'),
('en', 'help', 'Help'),
('en', 'hidden', 'Hidden'),
('en', 'hide', 'Hide'),
('en', 'hide_add_to_cart_button', 'Hide add to cart button'),
('en', 'hide_options', 'Hide options'),
('en', 'show_options', 'Show options'),
('en', 'hide_option_completely', 'Hide option completely'),
('en', 'home', 'Home'),
('en', 'home_page', 'Home page'),
('en', 'horizontal', 'Horizontal'),
('en', 'host', 'Host name'),
('en', 'host_code', 'Host code'),
('en', 'hour', 'Hour'),
('en', 'how_to_send', 'How to send?'),
('en', 'html_block', 'HTML block'),
('en', 'hungarian', 'Hungarian'),
('en', 'I25', 'Interleaved 2 of 5 is based on Standard 2 of 5 symbology.<br/>Interleaved 2 of 5 is designed to encode only 10 digits.'),
('en', 'icon', 'Icon'),
('en', 'id', 'ID'),
('en', 'identifier', 'PayBox identifier'),
('en', 'iframe_mode', 'iFrame mode'),
('en', 'illegal_item_weight', 'Illegal item weight'),
('en', 'image', 'Image'),
('en', 'images', 'Images'),
('en', 'images_directory', 'Images directory'),
('en', 'image_pair', 'Image pair'),
('en', 'image_verification', 'Image verification'),
('en', 'image_verification_body', 'Type the characters you see in the picture above.'),
('en', 'image_verification_label', 'Anti-bot validation'),
('en', 'immediately', 'Immediately'),
('en', 'import', 'Import'),
('en', 'important', 'Important'),
('en', 'importing_data', 'Importing data'),
('en', 'import_data', 'Import data'),
('en', 'import_locations', 'Import locations'),
('en', 'import_options', 'Import options'),
('en', 'in', 'In'),
('en', 'included', 'included'),
('en', 'include_cvn', 'Include CVN'),
('en', 'including_discount', 'Including discount'),
('en', 'including_tax', 'Including tax'),
('en', 'incompleted', 'Incomplete'),
('en', 'incompleted_orders', 'Incomplete orders'),
('en', 'incorrect_filling_message', 'Incorrect filling message'),
('en', 'incorrect_price_warning', 'Product has not been added to the cart. Please enter the correct price.'),
('en', 'increase', 'Increase'),
('en', 'inc_tax', 'inc tax'),
('en', 'index', 'Home page'),
('en', 'information', 'Information'),
('en', 'tip', 'Tip'),
('en', 'inner_hint', 'Inner hint'),
('en', 'input_field', 'Input field'),
('en', 'insert_block', 'Add block'),
('en', 'insert_grid', 'Add grid'),
('en', 'install', 'Install'),
('en', 'installation_id', 'Installation ID'),
('en', 'installed', 'Installed'),
('en', 'installed_languages', 'Installed'),
('en', 'installed_upgrades', 'Installed upgrades'),
('en', 'welcome_screen.administrator_info', 'To access the administrator area, use the e-mail (<b>[email]</b>) and the password you have entered earlier.'),
('en', 'welcome_screen.go_admin_panel', 'Go to the administration panel'),
('en', 'welcome_screen.go_storefront', 'Go to the storefront'),
('en', 'welcome_screen.go_settings_wizard', 'Go to the Settings wizard for basic store setup'),
('en', 'welcome_screen.knowledge_base', 'Documentation'),
('en', 'welcome_screen.run_settings_wizard', 'Run Settings wizard'),
('en', 'welcome_screen.learn_more_configuration', 'Learn more about storefront configuration in our'),
('en', 'welcome_screen.thanks', 'Thank you for choosing [product]. Happy selling!'),
('en', 'installer_complete_title', 'Installation successfully finished'),
('en', 'international_settings', 'International settings'),
('en', 'international_usps', 'International U.S.P.S.'),
('en', 'inventory', 'Inventory'),
('en', 'track_inventory', 'Track inventory'),
('en', 'track_inventory_tooltip', 'When inventory is tracked, the number of products in stock will decrease after each purchase.'),
('en', 'invitees', 'Invitees'),
('en', 'invoice', 'Invoice'),
('en', 'invoices', 'Invoices'),
('en', 'invoice_credit_memo', 'Invoice/Credit memo'),
('en', 'invoice_id', 'Invoice ID'),
('en', 'invoice_title', 'INVOICE'),
('en', 'in_progress', 'In progress'),
('en', 'in_stock', 'In stock'),
('en', 'n_in_stock_products_short', '[quantity] in stock'),
('en', 'ip', 'IP'),
('en', 'ip_address', 'IP address'),
('en', 'manager', 'Manager'),
('en', 'is_back_in_stock', 'is back in stock!'),
('en', 'is_pbp', 'Allow payment by points'),
('en', 'italian', 'Italian'),
('en', 'items', 'item(s)'),
('en', 'items_dependences', 'Items dependencies'),
('en', 'items_in_box', 'Items in a box'),
('en', 'items_in_cart', 'You have [n] item in your cart|You have [n] items in your cart'),
('en', 'n_products', '[n] product|[n] products'),
('en', 'items_per_page', 'Items per page'),
('en', 'objects_per_page', '[n] per page'),
('en', 'items_title', 'Items'),
('en', 'item_number', 'Show item number'),
('en', 'item_quantity', 'Item quantity'),
('en', 'japanese', 'Japanese'),
('en', 'join', 'Join'),
('en', 'json_error_ctrl_char', 'Control character error, possibly incorrectly encoded'),
('en', 'json_error_depth', 'The maximum stack depth has been exceeded'),
('en', 'json_error_state_mismatch', 'Invalid or malformed JSON'),
('en', 'json_error_syntax', 'Syntax error, malformed JSON'),
('en', 'json_error_unknown', 'Unknown JSON error'),
('en', 'json_error_utf8', 'Malformed UTF-8 characters, possibly incorrectly encoded'),
('en', 'key', 'Key'),
('en', 'key1_for_md5', 'Auth key 1 for md5'),
('en', 'key2_for_md5', 'Auth key 2 for md5'),
('en', 'keywords', 'Keywords'),
('en', 'korean', 'Korean'),
('en', 'label_text_color', 'Label text color'),
('en', 'landing_header', 'Your order has been received'),
('en', 'language', 'Language'),
('en', 'language_content', 'The language of content'),
('en', 'languagecode', 'Language code'),
('en', 'languages', 'Languages'),
('en', 'texts_languages', 'Texts & languages'),
('en', 'language_code', 'Language code'),
('en', 'language_variable', 'Language variable'),
('en', 'language_variables', 'Language variables'),
('en', 'last4ssn', 'Last 4 digits of Social Security Number'),
('en', 'last_24hours', 'Last 24 hours'),
('en', 'last_days', 'Last days'),
('en', 'last_month', 'Last month'),
('en', 'last_name', 'Last name'),
('en', 'last_n_days', 'Last [N] days'),
('en', 'last_order', 'Last order'),
('en', 'first_order', 'First order'),
('en', 'registration_date', 'Registration date'),
('en', 'latitude', 'Latitude'),
('en', 'layout', 'Layout'),
('en', 'layouts', 'Layouts'),
('en', 'lbl_amazon_aws_access_public_key', 'AWS access public key'),
('en', 'lbl_amazon_aws_access_secret_key', 'AWS access secret key'),
('en', 'lbl_amazon_background_color', 'Background color'),
('en', 'lbl_amazon_button_color', 'Button color'),
('en', 'lbl_amazon_button_size', 'Button size'),
('en', 'lbl_amazon_button_style', 'Amazon button style'),
('en', 'lbl_amazon_color_dark', 'Dark'),
('en', 'lbl_amazon_color_light', 'Light'),
('en', 'lbl_amazon_color_orange', 'Orange'),
('en', 'lbl_amazon_color_tan', 'Tan'),
('en', 'lbl_amazon_color_white', 'White'),
('en', 'lbl_amazon_process_order_on_failure', 'Process order on callback failure'),
('en', 'lbl_amazon_size_large', 'Large'),
('en', 'lbl_amazon_size_medium', 'Medium'),
('en', 'lbl_amazon_size_xlarge', 'X-Large'),
('en', 'left', 'Left'),
('en', 'length', 'Length'),
('en', 'less', 'less'),
('en', 'letter', 'Letter'),
('en', 'level', 'Level'),
('en', 'licence_agreement', 'License Agreement'),
('en', 'license_agreement', 'License agreement'),
('en', 'license_number', 'License number'),
('en', 'license_number_cannot_be_empty', 'License number cannot be empty'),
('en', 'limit', 'Limit'),
('en', 'line', 'Line'),
('en', 'linear', 'Linear'),
('en', 'link', 'Link'),
('en', 'linked_categories', 'Linked categories'),
('en', 'linked_products', 'Linked products'),
('en', 'links', 'Links'),
('en', 'links_thumb', 'Links thumb'),
('en', 'link_text', 'Link text'),
('en', 'link_to', 'Link to'),
('en', 'list', 'List'),
('en', 'list_objects', 'List objects'),
('en', 'list_price', 'List price'),
('en', 'list_price_decreased', 'List price has been decreased by'),
('en', 'list_price_increased', 'List price has been increased by'),
('en', 'list_price_short', 'List price'),
('en', 'list_price_short_2', 'List price'),
('en', 'list_quantity_count', 'Number of available quantities'),
('en', 'tmpl_list_without_options', 'List without options'),
('en', 'live', 'Live'),
('en', 'live_preview', 'Live preview'),
('en', 'loading', 'Loading...'),
('en', 'local', 'Local'),
('en', 'localization', 'Localization'),
('en', 'localizations', 'Localizations'),
('en', 'location', 'Location'),
('en', 'rate_area', 'Rate area'),
('en', 'locations', 'Locations'),
('en', 'rate_areas', 'Rate areas'),
('en', 'statuses_management', 'Statuses'),
('en', 'loggedin_time', 'Logged in time'),
('en', 'logging', 'Logging'),
('en', 'login', 'Login'),
('en', 'login_url', 'Login URL'),
('en', 'logos', 'Logos'),
('en', 'logo_link', 'Location (URL) of logo'),
('en', 'logs', 'Logs'),
('en', 'log_action_backup', 'backup'),
('en', 'log_action_create', 'create'),
('en', 'log_action_delete', 'delete'),
('en', 'log_action_deprecated', 'deprecated'),
('en', 'log_action_error', 'error'),
('en', 'log_action_failed_login', 'failed login'),
('en', 'log_action_http', 'http/https request'),
('en', 'log_action_login', 'sign in'),
('en', 'log_action_low_stock', 'low stock'),
('en', 'log_action_optimize', 'optimize'),
('en', 'log_action_restore', 'restore'),
('en', 'log_action_runtime', 'runtime'),
('en', 'log_action_session', 'session'),
('en', 'log_action_status', 'status change'),
('en', 'log_action_update', 'update'),
('en', 'log_type_categories', 'Categories'),
('en', 'log_type_database', 'Database'),
('en', 'log_type_general', 'general'),
('en', 'log_type_orders', 'Orders'),
('en', 'log_type_products', 'Products'),
('en', 'log_type_requests', 'Requests'),
('en', 'log_type_users', 'Users'),
('en', 'longitude', 'Longitude'),
('en', 'low_stock_subj', 'Low inventory of "[product]"'),
('en', 'mac_key', 'Mac key'),
('en', 'mailing_lists', 'Mailing lists'),
('en', 'mail_message', 'Mail message'),
('en', 'mail_subject', 'Mail subject'),
('en', 'main', 'Main'),
('en', 'mainbox_general', 'Main block (H1 heading)'),
('en', 'mainbox_simple', 'Important block (H2 heading)'),
('en', 'footer_general', 'Footer general'),
('en', 'maintenance', 'Maintenance'),
('en', 'main_category', 'Main category'),
('en', 'make_default', 'Make default'),
('en', 'manage', 'Manage'),
('en', 'manage_addons', 'Manage add-ons'),
('en', 'manage_blocks', 'Manage blocks'),
('en', 'manage_categories', 'Manage categories'),
('en', 'manage_existing_block', 'Edit Existing Blocks'),
('en', 'manage_items', 'Manage items'),
('en', 'manage_languages', 'Manage languages'),
('en', 'manage_menus', 'Manage menus'),
('en', 'manage_pages', 'Can edit'),
('en', 'manage_products', 'Manage products'),
('en', 'manage_reports', 'Manage reports'),
('en', 'manage_shippings', 'Shipping methods'),
('en', 'manage_sitemap', 'Manage sitemap'),
('en', 'manage_stores', 'Manage stores'),
('en', 'mandatory', 'Required'),
('en', 'manually', 'Manually'),
('en', 'manually_set_tax_rates', 'Manually set tax rates'),
('en', 'mark', 'Mark as resolved'),
('en', 'marketing', 'Marketing'),
('en', 'maximum_items_in_box', 'Maximum items in box'),
('en', 'max_amount', 'Total cost'),
('en', 'max_box_weight', 'Max box weight'),
('en', 'max_downloads', 'Max downloads'),
('en', 'max_item', 'Number of items'),
('en', 'max_order_qty', 'Maximum quantity to buy per product'),
('en', 'max_uploading_file_size', 'Max uploading file size'),
('en', 'max_uploading_file_size_hint', 'Leave this field empty to allow uploading of files of any size, or limit the file size ("100" is equal to 100 Kb)'),
('en', 'mb_amounts_not_match', 'The amount value received in status request differs from the original order total'),
('en', 'mb_currencies_not_match', 'The currency value received in status request differs from the store currency'),
('en', 'mb_md5_hashes_not_match', 'The md5 hash value received in status request differs from the calculated one'),
('en', 'mb_transaction_id', 'MB Transaction ID'),
('en', 'md5_checksum_failed', 'MD5 checksum failed'),
('en', 'md5_hash_value', 'MD5 hash value'),
('en', 'menu', 'Menu'),
('en', 'menus', 'Menus'),
('en', 'menu_items', 'Items for menu'),
('en', 'merchantid', 'Merchant ID'),
('en', 'merchant_email', 'Merchant Notification Email'),
('en', 'merchant_firstname', 'Merchant first name'),
('en', 'merchant_id', 'Merchant ID'),
('en', 'merchant_key', 'Merchant key'),
('en', 'merchant_lastname', 'Merchant last name'),
('en', 'merchant_login', 'Merchant login'),
('en', 'merchant_name', 'Merchant name'),
('en', 'merchant_pin', 'Merchant PIN'),
('en', 'merchant_response_was_not_received', 'No response from the merchant received. Please check this transaction manually.'),
('en', 'merchant_site_id', 'Merchant site ID'),
('en', 'merchant_warrior_api_key', 'API Key.'),
('en', 'merchant_warrior_api_passphrase', 'API Passphrase.'),
('en', 'merge', 'Merge'),
('en', 'message', 'Message'),
('en', 'messages', 'Messages'),
('en', 'meta_description', 'Meta description'),
('en', 'meta_keywords', 'Meta keywords'),
('en', 'method', 'Method'),
('en', 'minimized', 'Minimized'),
('en', 'minimum_commission_payment', 'Minimum commission payment'),
('en', 'minimum_items_in_box', 'Minimum items in box'),
('en', 'minutes', 'minute(s)'),
('en', 'min_order_qty', 'Minimum quantity to buy per product'),
('en', 'missing_variants_handling', 'Missing variants handling'),
('en', 'modifier', 'Modifier'),
('en', 'modifiers', 'Modifiers'),
('en', 'modify_profile', 'Modify Profile'),
('en', 'modify_selected', 'Modify selected'),
('en', 'month', 'Month'),
('en', 'months', 'month(s)'),
('en', 'month_name_1', 'January'),
('en', 'month_name_10', 'October'),
('en', 'month_name_11', 'November'),
('en', 'month_name_12', 'December'),
('en', 'month_name_2', 'February'),
('en', 'month_name_3', 'March'),
('en', 'month_name_4', 'April'),
('en', 'month_name_5', 'May'),
('en', 'month_name_6', 'June'),
('en', 'month_name_7', 'July'),
('en', 'month_name_8', 'August'),
('en', 'month_name_9', 'September'),
('en', 'month_name_abr_1', 'Jan'),
('en', 'month_name_abr_10', 'Oct'),
('en', 'month_name_abr_11', 'Nov'),
('en', 'month_name_abr_12', 'Dec'),
('en', 'month_name_abr_2', 'Feb'),
('en', 'month_name_abr_3', 'Mar'),
('en', 'month_name_abr_4', 'Apr'),
('en', 'month_name_abr_5', 'May'),
('en', 'month_name_abr_6', 'Jun'),
('en', 'month_name_abr_7', 'Jul'),
('en', 'month_name_abr_8', 'Aug'),
('en', 'month_name_abr_9', 'Sep'),
('en', 'more', 'More'),
('en', 'content_more', 'more'),
('en', 'more_info', 'More info'),
('en', 'more_link', '[more]'),
('en', 'more_sign_in_options', 'Back to more sign in options'),
('en', 'more_than', 'More than'),
('en', 'more_w_ellipsis', 'More...'),
('en', 'most_popular', 'Most popular'),
('en', 'most_popular_addons', 'Most popular add-ons'),
('en', 'mr', 'Mr.'),
('en', 'ms', 'Ms.'),
('en', 'tmpl_multicolumns_small', 'Multicolumns small'),
('en', 'tmpl_multicolumn_list', 'Multi-column list'),
('en', 'multiple', 'Multiple'),
('en', 'multiple_selectbox_notice', '<p>To select several items, press and hold the CTRL key and click on the required items.</p>'),
('en', 'multiupload', 'Multiupload'),
('en', 'my_account', 'My account'),
('en', 'my_account_links', 'My account links'),
('en', 'my_points', 'My points'),
('en', 'na', 'N/A'),
('en', 'name', 'Name'),
('en', 'name_short', 'Name'),
('en', 'navigation', 'Navigation'),
('en', 'navi_pages', 'Pages'),
('en', 'neighbours', 'Neighbours'),
('en', 'new', 'New'),
('en', 'newest', 'Newest'),
('en', 'new_administrator_password', 'New administrator password'),
('en', 'new_category', 'New category'),
('en', 'new_chart', 'New chart'),
('en', 'new_combination', 'New combination'),
('en', 'new_currency', 'New currency'),
('en', 'new_customer', 'New customer'),
('en', 'new_feature', 'New feature'),
('en', 'new_file', 'New file'),
('en', 'new_filter', 'New filter'),
('en', 'new_folder', 'New folder'),
('en', 'new_group', 'New group'),
('en', 'new_items', 'New item'),
('en', 'new_language', 'New language'),
('en', 'new_language_variable', 'New language variable'),
('en', 'important_language_text', 'When you hide, disable, or delete a default language of one of the storefronts, make sure to update the value of the <b>Frontend default language</b> setting in <a href="[link]">Settings → Appearance</a>.'),
('en', 'important_currency_text', 'When you hide, disable, or delete a default currency of one of the storefronts, make sure to update the value of the <b>Frontend default currency</b> setting in <a href="[link]">Settings → Appearance</a>.'),
('en', 'new_layout', 'New layout'),
('en', 'new_link', 'New link'),
('en', 'new_localization', 'New localization'),
('en', 'new_location', 'New location'),
('en', 'new_rate_area', 'New rate area'),
('en', 'new_menu', 'New menu'),
('en', 'new_option', 'New option'),
('en', 'new_page', 'New page'),
('en', 'new_payments', 'New payment method'),
('en', 'new_payout', 'New payout'),
('en', 'new_post', 'New post'),
('en', 'new_product', 'New product'),
('en', 'new_profile', 'New profile'),
('en', 'new_profile_field', 'New profile field'),
('en', 'new_profile_notification', 'New profile notification'),
('en', 'new_promotion', 'New promotion'),
('en', 'new_report', 'New report'),
('en', 'new_saved_search', 'New saved search'),
('en', 'new_section', 'New section'),
('en', 'new_shipment', 'New shipment'),
('en', 'detailed_shipment', 'Detailed shipment'),
('en', 'create_detailed_shipment', 'Create detailed shipment'),
('en', 'new_shipment_was_created', 'New shipment was created'),
('en', 'new_shipping_method', 'New shipping method'),
('en', 'new_site_map_section', 'New sitemap section'),
('en', 'new_states', 'New state(s) for the selected country'),
('en', 'new_status', 'New status'),
('en', 'new_tab', 'New tab'),
('en', 'new_tax', 'New tax'),
('en', 'new_usergroups', 'New user group(s)'),
('en', 'new_user_profile', 'New user profile'),
('en', 'new_vendor', 'New store'),
('en', 'new_zealand', 'New Zealand'),
('en', 'next', 'Next'),
('en', 'next_step', 'Next step'),
('en', 'no', 'No'),
('en', 'nocombination', 'Unfortunately this combination is not accessible'),
('en', 'none', 'None'),
('en', 'normal', 'Normal'),
('en', 'norway', 'Norway'),
('en', 'norwegian', 'Norwegian'),
('en', 'note', 'Note'),
('en', 'notes', 'Notes'),
('en', 'notice', 'Notice'),
('en', 'notice_too_many_decimals', 'You have specified [DECIMALS] decimal places for [CURRENCY]. The maximum number of supported decimal places is 2. Further values will be displayed as zeros.'),
('en', 'notice_undeliverable_products_removed', 'Undeliverable products have been removed from your cart. You may proceed with the purchase.'),
('en', 'notice_update_customer_details', 'The customer updated the email address in the profile. Select the check box to update the order details:'),
('en', 'notify_customer', 'Notify customer'),
('en', 'notify_orders_department', 'Notify orders department'),
('en', 'notify_user', 'Notify user'),
('en', 'notify_vendor', 'Notify store owner'),
('en', 'notify_when_back_in_stock', 'Notify me when this product is back in stock'),
('en', 'not_active', 'Not active'),
('en', 'not_active_file_notice', 'This file will be available for downloading only after the administrator approves them'),
('en', 'not_a_member', 'Not a member'),
('en', 'not_installed', 'Not installed'),
('en', 'not_scroll_automatically', 'Do not scroll automatically'),
('en', 'enable_link', 'Enable link'),
('en', 'no_categories_available', 'No categories available'),
('en', 'no_data', 'No data found'),
('en', 'no_data_found', 'No data found that satisfies this chart conditions'),
('en', 'no_files', 'No files'),
('en', 'no_image', 'No image'),
('en', 'no_items', 'No items defined'),
('en', 'no_items_found', 'No items found matching the search criteria'),
('en', 'no_menus', 'No menus'),
('en', 'no_products_for_shipment', 'There are no products for shipment'),
('en', 'no_products_selected', 'No products selected'),
('en', 'no_rates_for_empty_cart', '<p class="error-text" align="center">Your cart is empty and the shipping cost cannot be estimated</p>'),
('en', 'no_rates_for_empty_cart_warning', 'Your cart is empty and the shipping cost cannot be estimated'),
('en', 'no_shipping_required', 'No shipping required'),
('en', 'no_such_coupon', 'The entered code cannot be applied, because it does not meet the requirements.'),
('en', 'no_themes_available', 'No themes available'),
('en', 'no_users_found', 'No users found'),
('en', 'number', 'Number'),
('en', 'number_of_columns', 'Number of columns in the objects list'),
('en', 'object', 'Object'),
('en', 'object_does_not_exist', 'The object doesn''t exist'),
('en', 'object_exists', 'Object of the same name already exists. Do you want to overwrite it?'),
('en', 'object_not_found', 'The [object] not found'),
('en', 'of', 'of'),
('en', 'off', 'Off'),
('en', 'offline', 'Offline'),
('en', 'offset', 'Offset'),
('en', 'ok', 'OK'),
('en', 'old_price', 'Old price'),
('en', 'on', 'on'),
('en', 'once_per_customer', 'Once per customer'),
('en', 'onclick_dropdown', 'Onclick-dropdown'),
('en', 'online_only', 'Online only'),
('en', 'on_off', 'On/Off'),
('en', 'on_site_template_editing', 'On-site template editing'),
('en', 'on_site_live_editing', 'On-site live editing'),
('en', 'open', 'Open'),
('en', 'open_action', 'Open'),
('en', 'open_file_or_create_new', 'Open a file or create a new one to get started.'),
('en', 'open_in_new_window', 'Open in new window'),
('en', 'open_store', 'Open storefront'),
('en', 'optimize_database', 'Optimize database'),
('en', 'optimizing_table', 'Optimizing table'),
('en', 'options', 'Options'),
('en', 'options_for', 'Options for'),
('en', 'options_have_been_applied_to_products', 'Options have been successfully applied to the selected products'),
('en', 'options_settings', 'Options settings'),
('en', 'options_type', 'Options type'),
('en', 'option_combinations', 'Option combinations'),
('en', 'option_name', 'Option name'),
('en', 'option_unlinked', 'Global option "[option_name]" has been deactivated for the product'),
('en', 'option_variants', 'Option variants'),
('en', 'opt_currency_name', 'Show currency titles'),
('en', 'opt_currency_symbol', 'Use currency symbols instead of titles'),
('en', 'opt_language_icon', 'Flags only'),
('en', 'opt_language_name', 'Flags and language names'),
('en', 'or', 'or'),
('en', 'order', 'Order'),
('en', 'ordered_products', 'Ordered products'),
('en', 'orders', 'Orders'),
('en', 'orders_not_allow_to_change_company', 'Company has not been changed. It is not allowed to change the company when editing an order.'),
('en', 'orders_no_items', 'Use the "Add products" button above to add products to order.'),
('en', 'order_by_status', 'Order by status'),
('en', 'order_date', 'Order date'),
('en', 'order_details', 'Order details'),
('en', 'order_discount', 'Order discount'),
('en', 'order_id', 'Order ID'),
('en', 'order_info', 'Order information'),
('en', 'order_items', 'Order items'),
('en', 'order_landing_page', 'Order landing page'),
('en', 'order_management', 'Order management'),
('en', 'order_placed', 'Order placed'),
('en', 'order_prefix', 'Order prefix'),
('en', 'order_search', 'Search order'),
('en', 'order_status', 'Order status'),
('en', 'order_statuses', 'Order statuses'),
('en', 'order_total', 'Order Total'),
('en', 'order_total_not_correct', 'The paid total amount does not match the order total'),
('en', 'order_was_not_placed', 'Order was not placed'),
('en', 'only_one_order_can_be_edited_at_a_time', 'Couldn''t save changes to the order. Only one order can be edited per browser at a time. Please close any other browser tabs where you''re editing orders, and reload the tab with the order that you want to edit.'),
('en', 'original', 'Original'),
('en', 'origination', 'Origination'),
('en', 'or_saved_search', 'or any item from the saved search'),
('en', 'or_use', 'Or use'),
('en', 'others', 'Others'),
('en', 'other_addons', 'Other add-ons'),
('en', 'output', 'Output'),
('en', 'out_of_stock_actions', 'Out of stock actions'),
('en', 'out_of_stock_products', 'Out of stock'),
('en', 'override_by_dispatch', 'Override locations by dispatch'),
('en', 'override_by_this', 'Use this content for all the block instances'),
('en', 'override_product_data', 'Apply values to all the selected products'),
('en', 'owner', 'Owner'),
('en', 'p21agree', 'Please type "AGREE" or "DISAGREE" in the box provided'),
('en', 'p21agree_tooltip', 'By typing AGREE in the below box I am providing my signature as authorization to Payment21&reg; to electronically debit my account for the amount I have entered. I also understand and expressly authorize the merchant, if my eCheck payment is dishonored or returned for any reason, to electronically debit my account for the amount of the eCheck payment plus an NSF fee not to exceed the state maximum legal limit. I will print or save this page for my records. I can call +18887700850 for 24/7 support with any questions regarding this payment transaction.'),
('en', 'package', 'Package'),
('en', 'packages', 'Packages'),
('en', 'show_package_contents', 'View upgrade contents'),
('en', 'package_type', 'Package type'),
('en', 'packing_slip', 'Packing slip'),
('en', 'packing_slip_for_order', 'Packing slip for order'),
('en', 'page', 'Page'),
('en', 'pages', 'Pages'),
('en', 'page_cloned', 'The page <b>[page]</b> has been cloned successfully. Now you can edit the new page'),
('en', 'page_id', 'Page ID'),
('en', 'page_link', 'Page URL'),
('en', 'page_name', 'Page name'),
('en', 'page_not_found', 'Page Not Found'),
('en', 'page_not_found_text', 'The page you have requested cannot be found.'),
('en', 'page_title', 'Page title'),
('en', 'paid_amount', 'Paid amount'),
('en', 'param', 'Parameter'),
('en', 'parameter', 'Object to analyze'),
('en', 'parameter_name', 'Parameter name'),
('en', 'parent_category', 'Parent category'),
('en', 'parent_category_id', 'Parent category'),
('en', 'parent_item', 'Parent item'),
('en', 'parent_page', 'Parent page'),
('en', 'parent_page_id', 'Parent page'),
('en', 'partner', 'Partner'),
('en', 'passphrase', 'Pass-phrase'),
('en', 'passport_number', 'Passport number'),
('en', 'password', 'Password'),
('en', 'path_to_files', 'Full path to the "atos" files'),
('en', 'pause_delay', 'Pause delay (in seconds)'),
('en', 'payflowcolor', 'Payflow color'),
('en', 'payment', 'Payment'),
('en', 'payments', 'Payments'),
('en', 'payments.cresecure.location_notice', '<b>Please note:</b><br>1. This payment requires the https checkout option to be enabled!<br>2. By default, the Checkout location is shown to a user on payment placing. In order to show a different location, create a new location with the dispatch ''checkout.cresecure_template'' in the <a href="[url]" target="_blank">Layout manager</a>.'),
('en', 'payments.epdq.bgcolor', 'Background color'),
('en', 'payments.epdq.btn_bgcolor', 'Button background color'),
('en', 'payments.epdq.btn_textcolor', 'Button text color'),
('en', 'payments.epdq.font_type', 'Font type'),
('en', 'payments.epdq.hash_error', 'Sorry, the hash string does not match'),
('en', 'payments.epdq.instructions', '<ol><li><p>Enter the following URL in the "Technical information"→"Transaction feedback" section in the Barclaycard ePDQ admin area:</p><p>for the "accepted" and "cancelled" payments: [url]</p></li><li>Make sure that the "Timing of the request" is set to "Always online", and "Request method" is set to "POST"</li><li>Define the "SHA-OUT pass phrase" value in the ePDQ admin area as you like, then duplicate it in the "SHA-IN pass phrase" field in the "Data and origin verification" section, and also in the "Pass-phrase" field below</li><li>Make sure that the "Default operation code" option in the ePDQ admin area has the same value as the "Transaction type" option value below</li><li>Set the "Hash algorithm" parameter to "SHA-1" in the "Global security parameters" section in the Barclaycard ePDQ admin area</li></ol>'),
('en', 'payments.epdq.pspid', 'EPDQ pspid'),
('en', 'payments.epdq.tbl_bgcolor', 'Table background color'),
('en', 'payments.epdq.tbl_textcolor', 'Table text color'),
('en', 'payments.epdq.textcolor', 'Text color'),
('en', 'payments.epdq.title', 'Title'),
('en', 'payments.signin_to_checkout', '<a href=[url]>Sign in</a> to check out'),
('en', 'payments_tab1', 'Credit card'),
('en', 'payments_tab2', 'Internet Payments'),
('en', 'payments_tab3', 'Other Payment Options'),
('en', 'payment_amount', 'Payment amount'),
('en', 'payment_category', 'Payment category'),
('en', 'payment_category_note', 'Payment categories tabs will NOT be displayed if all the active payments belong to the same category'),
('en', 'payment_details', 'Payment details'),
('en', 'payment_form_url', 'Payment Form URL'),
('en', 'payment_info', 'Payment type'),
('en', 'payment_information', 'Payment information'),
('en', 'payment_instructions', 'Payment instructions'),
('en', 'payment_method', 'Payment method'),
('en', 'payment_methods', 'Payment methods'),
('en', 'payment_response_password', 'Payment Response password'),
('en', 'payment_surcharge', 'Payment surcharge'),
('en', 'payment_type', 'Payment type'),
('en', 'paypal_authentication_method', 'PayPal authentication method'),
('en', 'paypal_item_name', 'Name of the item (or a name for the Shopping Cart)'),
('en', 'paypal_security_error', 'Your order was not placed: the recipient PayPal account is wrong.'),
('en', 'pay_from_email', 'Customer email'),
('en', 'pay_order_again', 'Pay order again'),
('en', 'pay_to_email', 'Email address of the Merchant'),
('en', 'pending', 'Pending'),
('en', 'suspended', 'Suspended'),
('en', 'per', 'Per [object]'),
('en', 'percent', 'Percent'),
('en', 'period', 'Period'),
('en', 'per_item', 'Per Item'),
('en', 'per_page', 'Per Page'),
('en', 'pagination_range', '<span>[pagination.range_from]</span>–<span>[pagination.range_to]</span>&nbsp;of&nbsp;[pagination.total_items]'),
('en', 'phone', 'Phone'),
('en', 'phone1_label', 'Phone'),
('en', 'phone2_label', 'International'),
('en', 'phone2', 'International'),
('en', 'phone_mask_label', 'Phone'),
('en', 'phpinfo', 'PHP information'),
('en', 'pick_store', 'Pick a store'),
('en', 'pie', 'Pie'),
('en', 'pie_3d', 'Pie 3D'),
('en', 'pixels', 'pixels'),
('en', 'place_order', 'Place order'),
('en', 'placing_order', 'Placing the order'),
('en', 'plain', 'Plain'),
('en', 'platform', 'Platform'),
('en', 'please_be_patient', 'Please be patient'),
('en', 'please_enter_license_here', 'Enter your license number here'),
('en', 'please_select_one', 'Please, select one'),
('en', 'please_sign_in', 'Please sign in'),
('en', 'polish', 'Polish'),
('en', 'poor', 'Poor'),
('en', 'popularity', 'Popularity'),
('en', 'popup', 'Popup'),
('en', 'popup_larger_image', 'Popup larger image'),
('en', 'portugese', 'Portuguese'),
('en', 'posid', 'Pos ID'),
('en', 'position', 'Position'),
('en', 'positions_updated', 'Positions of items were updated'),
('en', 'position_short', 'Pos.'),
('en', 'postal_mail', 'Postal mail'),
('en', 'postauth', 'Postauth'),
('en', 'post_url', 'Post URL'),
('en', 'powered_by', 'Powered by'),
('en', 'po_number', 'PO number'),
('en', 'preauth', 'Preauth'),
('en', 'preauthorization', 'Preauthorization'),
('en', 'prefix', 'Prefix'),
('en', 'preshared_key', 'PreShared Key'),
('en', 'prev', 'Prev.'),
('en', 'preview', 'Preview'),
('en', 'preview_file', 'Preview file'),
('en', 'previous', 'Previous'),
('en', 'previous_month', 'Previous month'),
('en', 'previous_period', 'Previous period'),
('en', 'previous_week', 'Previous week'),
('en', 'previous_year', 'Previous year'),
('en', 'prev_page', 'Prev'),
('en', 'price', 'Price'),
('en', 'price_decreased', 'Price has been decreased by'),
('en', 'price_dec_sign_delimiter', 'Price decimal separator'),
('en', 'price_includes_tax', 'Price includes tax'),
('en', 'price_increased', 'Price has been increased by'),
('en', 'price_in_points', 'Price in points'),
('en', 'price_summary', 'Price summary'),
('en', 'pricing_inventory', 'Pricing / inventory'),
('en', 'primary', 'Primary'),
('en', 'primary_currency', 'Primary currency'),
('en', 'print_card', 'Print card'),
('en', 'print_credit_memo', 'Print credit memo'),
('en', 'print_invoice', 'Print invoice'),
('en', 'edit_invoice', 'Edit invoice'),
('en', 'remove_invoice', 'Remove invoice'),
('en', 'print_order_details', 'Print order details'),
('en', 'print_packing_slip', 'Print packing slip'),
('en', 'print_pdf_packing_slip', 'Print packing slip (pdf)'),
('en', 'print_pdf_credit_memo', 'Print credit memo (pdf)'),
('en', 'print_pdf_invoice', 'Print invoice (pdf)'),
('en', 'print_pdf_order_details', 'Print order details (pdf)'),
('en', 'print_slip', 'Print slip'),
('en', 'priority', 'Priority'),
('en', 'private', 'Private'),
('en', 'private_customer_settings', 'Private customer settings'),
('en', 'privilege', 'Privilege'),
('en', 'privileges', 'Privileges'),
('en', 'privileges.change_order_status', 'Can change statuses'),
('en', 'privileges.create_order', 'Can create orders (only if editing entire orders is allowed)'),
('en', 'privileges.backup_restore', 'Can manage'),
('en', 'privileges.delete_logs', 'Can delete'),
('en', 'privileges.delete_orders', 'Can delete'),
('en', 'privileges.edit_blocks', 'Can edit'),
('en', 'privileges.edit_order', 'Can edit entire order (select other products, payment and shipping methods, customers)'),
('en', 'privileges.edit_files', 'Edit files'),
('en', 'privileges.exim_access', 'Can manage'),
('en', 'privileges.manage_catalog', 'Can edit'),
('en', 'privileges.manage_currencies', 'Can edit'),
('en', 'privileges.manage_design', 'Can edit'),
('en', 'privileges.manage_languages', 'Can edit'),
('en', 'privileges.manage_locations', 'Can edit'),
('en', 'privileges.manage_order_statuses', 'Can edit'),
('en', 'privileges.manage_pages', 'Manage pages'),
('en', 'privileges.manage_payments', 'Can edit'),
('en', 'privileges.manage_promotions', 'Can edit'),
('en', 'privileges.manage_reports', 'Can edit'),
('en', 'privileges.manage_shipping', 'Can edit'),
('en', 'privileges.manage_sitemap', 'Can edit'),
('en', 'privileges.manage_static_data', 'Can edit'),
('en', 'privileges.manage_storage', 'Can manage'),
('en', 'privileges.manage_stores', 'Manage stores');
INSERT INTO `[[dbprefix]]language_values` VALUES
('en', 'privileges.manage_taxes', 'Can edit'),
('en', 'privileges.manage_themes', 'Can edit'),
('en', 'privileges.manage_translation', 'Can edit'),
('en', 'privileges.manage_usergroups', 'Can manage customer user groups'),
('en', 'privileges.manage_users', 'Can edit'),
('en', 'privileges.manage_email_templates', 'Can edit'),
('en', 'privileges.manage_document_templates', 'Can edit'),
('en', 'privileges.update_settings', 'Can edit'),
('en', 'privileges.update_order_details', 'Can edit minor details (select manager; edit shipments, notes, and tracking number)'),
('en', 'privileges.upgrade_store', 'Can upgrade'),
('en', 'privileges.view_catalog', 'Can view'),
('en', 'privileges.view_currencies', 'Can view'),
('en', 'privileges.view_languages', 'Can view'),
('en', 'privileges.view_locations', 'Can view'),
('en', 'privileges.view_logs', 'Can view'),
('en', 'privileges.view_orders', 'Can view'),
('en', 'privileges.view_pages', 'Can view'),
('en', 'privileges.view_payments', 'Can view'),
('en', 'privileges.view_reports', 'Can view'),
('en', 'privileges.view_settings', 'Can view'),
('en', 'privileges.view_shipping', 'Can view'),
('en', 'privileges.view_static_data', 'Can view'),
('en', 'privileges.view_stores', 'View stores'),
('en', 'privileges.view_taxes', 'Can view'),
('en', 'privileges.view_usergroups', 'Can view'),
('en', 'privileges.view_users', 'Can view'),
('en', 'privilege_sections.addons', 'Add-on privileges'),
('en', 'privilege_sections.administration', 'Administration privileges'),
('en', 'privilege_sections.cart', 'Cart'),
('en', 'privilege_sections.products', 'Product privileges'),
('en', 'privilege_sections.settings', 'Settings privileges'),
('en', 'privilege_sections.catalog', 'Catalog'),
('en', 'privilege_sections.cms', 'CMS'),
('en', 'privilege_sections.design', 'Design privileges'),
('en', 'privilege_sections.orders', 'Order privileges'),
('en', 'privilege_sections.marketing', 'Marketing privileges'),
('en', 'privilege_sections.website', 'Website privileges'),
('en', 'privilege_sections.users', 'Customer privileges'),
('en', 'privilege_sections.vendors', 'Store privileges'),
('en', 'proceed', 'Proceed'),
('en', 'proceed_to_checkout', 'Proceed to checkout'),
('en', 'proceed_to_the_next_step', 'Proceed to the next step'),
('en', 'processed', 'Processed'),
('en', 'processing', 'Processing'),
('en', 'processing_order', 'Processing order'),
('en', 'processor', 'Processor'),
('en', 'processor_description_cardsave', 'Merchant Accounts provided by Worldpay Cardsave, <a href="http://www.cardsave.net">www.cardsave.net</a><br/><br/>Email: <a href=''mailto:ecomm@cardsave.net''>ecomm@cardsave.net</a>'),
('en', 'processor_description_p21', '<b>P21 Simple API</b> enables you to accept check payments. It offers the industry''s most comprehensive suite of check image creation and clearing solutions. With Check 21, you will receive your funds within the same day by check or direct deposit.<br/><br/>To activate the Check 21 option, please contact us via email at: <a href="mailto:support@payment21.com">support@payment21.com</a> or by phone at: +18887700850 (US Toll Free) or +41717401629 (International).<br/><br/><a href="http://www.payment21.com" target="_blank">www.payment21.com</a>'),
('en', 'processor_id', 'Processor ID'),
('en', 'process_selected', 'Process selected'),
('en', 'product', 'Product'),
('en', 'products', 'Products'),
('en', 'products_menu_title', 'Products'),
('en', 'products_deprecated', 'Products (Deprecated)'),
('en', 'products2', 'Products2'),
('en', 'products_added_to_cart', 'The products were added to your cart'),
('en', 'products_number_added_to_cart', '<b>[number]</b> products were added to your cart'),
('en', 'products_amount', 'Product quantity'),
('en', 'products_bar', 'Products bar'),
('en', 'products_cost', 'Products cost'),
('en', 'products_for_shipment_not_selected', 'Products for shipment were not selected'),
('en', 'products_found', 'Products found'),
('en', 'n_products_found', '[n] product found|[n] products found'),
('en', 'products_grid', 'Products grid'),
('en', 'products_information', 'Products information'),
('en', 'products_in_cart', 'Products in cart'),
('en', 'products_links_type', 'Products links type'),
('en', 'products_required', 'Please add product(s)'),
('en', 'products_stat', 'Product statistics'),
('en', 'products_weight', 'Products weight'),
('en', 'products_were_sent', 'The products have been sent out to you. The order information is given below'),
('en', 'product_added_to_cart', 'The product was added to your cart'),
('en', 'product_name_added_to_cart', '<b>[product]</b> was added to your cart'),
('en', 'product_added_to_cl', 'The product was added to your Comparison list'),
('en', 'product_cannot_be_added', 'The product cannot be added to cart. Check if all the uploading files meet the necessary conditions'),
('en', 'product_code', 'Product code'),
('en', 'product_columns', 'Product columns'),
('en', 'product_combinations', 'Product combinations'),
('en', 'product_coming_soon', 'This product can''t be added to cart now. It will be available on [avail_date]'),
('en', 'product_coming_soon_add', 'This product will be shipped on [avail_date]'),
('en', 'product_details', 'Product details page'),
('en', 'product_details_view', 'Product details view'),
('en', 'product_details_sidebar', 'Product details'),
('en', 'customer_info_sidebar', 'Customer info'),
('en', 'product_feature_cannot_assigned', 'The feature "[feature_name]" cannot be assigned to the product "[product_name]"'),
('en', 'product_fields', 'Product fields'),
('en', 'product_groups', 'Product groups'),
('en', 'product_id', 'Product ID'),
('en', 'product_images', 'Product images'),
('en', 'product_inventory', 'Product inventory'),
('en', 'product_in_cart', 'This product is already in the cart'),
('en', 'product_in_comparison_list', 'This product is already in the comparison list'),
('en', 'product_name', 'Product name'),
('en', 'product_notification_subscribed', 'You have been subscribed to the product in stock notifications'),
('en', 'product_notification_unsubscribed', 'You have been unsubscribed from the product in stock notifications'),
('en', 'product_notification_subscription_error', 'Cannot subscribe for the product in stock notification'),
('en', 'product_options', 'Product options'),
('en', 'product_options_forbidden_combination', 'The <strong>[product]</strong> product has options that are included in the forbidden combination. The product was deleted from the cart'),
('en', 'zero_price_product_was_deleted', 'The <strong>[product]</strong> product has zero price. The product was deleted from the cart'),
('en', 'product_disabled_options', 'The product <strong>[product]</strong> has options or option variants that are not available anymore, so it was removed from cart'),
('en', 'product_s', 'Product(s)'),
('en', 'product_subscriptions', 'Product subscriptions'),
('en', 'product_summary', 'Product summary'),
('en', 'product_tabs', 'Product tabs'),
('en', 'product_type', 'Product type'),
('en', 'profile', 'Profile'),
('en', 'profiles', 'Profiles'),
('en', 'profile_activated', 'Account activated'),
('en', 'profile_details', 'Profile details'),
('en', 'profile_fields', 'Profile fields'),
('en', 'profile_info', 'Profile information'),
('en', 'profile_name', 'Profile name'),
('en', 'project_id', 'Project ID'),
('en', 'project_password', 'Project password'),
('en', 'prolongate_download_key', 'Prolong download key to'),
('en', 'promotion', 'Promotion'),
('en', 'promotions', 'Promotions'),
('en', 'promotion_bonus_discount_on_categories', 'Discount on all products in categories'),
('en', 'promotion_bonus_discount_on_products', 'Discount on products'),
('en', 'promotion_bonus_free_products', 'Free products'),
('en', 'promotion_bonus_free_shipping', 'Free shipping'),
('en', 'promotion_bonus_give_coupon', 'Give coupon'),
('en', 'promotion_bonus_give_points', 'Give points'),
('en', 'promotion_bonus_give_usergroup', 'Give user group'),
('en', 'promotion_bonus_order_discount', 'Order discount'),
('en', 'promotion_bonus_product_discount', 'Product discount'),
('en', 'promotion_cond_auto_coupons', 'Automatically generated coupon codes'),
('en', 'promotion_cond_categories', 'Categories'),
('en', 'promotion_cond_country', 'Customer country (shipping)'),
('en', 'promotion_cond_coupon_code', 'Coupon code'),
('en', 'promotion_cond_feature', 'Product feature'),
('en', 'promotion_cond_number_of_usages', 'Number of usages'),
('en', 'promotion_cond_once_per_customer', 'Once per customer'),
('en', 'promotion_cond_payment', 'Payment method'),
('en', 'promotion_cond_price', 'Product price'),
('en', 'promotion_cond_products', 'Products'),
('en', 'promotion_cond_products_number', 'Total products in the cart'),
('en', 'promotion_cond_purchased_products', 'Purchased products'),
('en', 'promotion_cond_state', 'Customer state (shipping)'),
('en', 'promotion_cond_subtotal', 'Order subtotal'),
('en', 'promotion_cond_total', 'Order total'),
('en', 'promotion_cond_total_weight', 'Total products weight in the cart'),
('en', 'promotion_cond_usergroup', 'User group'),
('en', 'promotion_cond_users', 'Users'),
('en', 'promotion_cond_zip_postal_code', 'Customer zip/postal code (shipping)'),
('en', 'promotion_cond_shipping', 'Shipping methods'),
('en', 'promotion_op_amount', 'amount'),
('en', 'promotion_op_cont', 'contains'),
('en', 'promotion_op_eq', 'equal'),
('en', 'promotion_op_gt', 'greater'),
('en', 'promotion_op_gte', 'equal or greater'),
('en', 'promotion_op_in', 'in'),
('en', 'promotion_op_lt', 'less'),
('en', 'promotion_op_lte', 'equal or less'),
('en', 'promotion_op_ncont', 'doesn''t contain'),
('en', 'promotion_op_neq', 'not equal'),
('en', 'promotion_op_nin', 'not in'),
('en', 'promo_code', 'Promo code'),
('en', 'promo_text', 'Promo text'),
('en', 'properties', 'Properties'),
('en', 'provider', 'Provider'),
('en', 'pspid', 'PSPID'),
('en', 'public', 'Public'),
('en', 'purchased_in_orders', 'Purchased in orders'),
('en', 'purchased_qty', 'Purchased qty'),
('en', 'purchasers_name', 'From'),
('en', 'qty', 'Qty'),
('en', 'qty_discounts', 'Quantity discounts'),
('en', 'qty_discount_type_tooltip', 'Fixed amount/Percentage to be taken off the price'),
('en', 'quantity', 'Quantity'),
('en', 'quantity_long', 'Quantity'),
('en', 'quantity_step', 'Quantity step'),
('en', 'query', 'Query'),
('en', 'quick_checkout', 'Quick checkout'),
('en', 'quick_links', 'Quick links'),
('en', 'quick_menu', 'Quick start menu'),
('en', 'admin_menu.add_item', 'Add item'),
('en', 'admin_menu.add_item_for_menu_title', 'Add item for menu'),
('en', 'admin_menu.add_item_title', 'Add item'),
('en', 'admin_menu.edit_item_title', 'Edit item'),
('en', 'quick_product_viewer', 'Quick product viewer'),
('en', 'quick_view', 'Quick view'),
('en', 'radiogroup', 'Radio group'),
('en', 'random', 'Random'),
('en', 'rank_number', 'Rank (''machine'') number'),
('en', 'rates_depend_on', 'Rates depend on'),
('en', 'rate_calculation', 'Rate calculation'),
('en', 'rate_calculation_manual', 'Manual (by defined location)'),
('en', 'rate_calculation_manual_by_rate_area', 'Manual (by rate areas)'),
('en', 'rate_calculation_by_customer_address', 'By customer''s address'),
('en', 'rate_calculation_realtime', 'Realtime'),
('en', 'rate_calculation_realtime_automatic', 'Real-time (automatic)'),
('en', 'rate_value', 'Rate value'),
('en', 'read', 'Read'),
('en', 'readme', 'Readme'),
('en', 'read_more_3d_secure', 'Read more about 3-D Secure'),
('en', 'reason', 'Reason'),
('en', 'reasons', 'reasons'),
('en', 'reason_text', 'Payment processor response'),
('en', 'rebuild_cache_automatically', 'Rebuild cache automatically'),
('en', 'rebuild_cache_automatically_tooltip', 'Modified files are tracked in real time (including the files modified directly on server) and re-cached. Block cache will be disabled. Store performance may be slightly affected. Recommended to disable on production.'),
('en', 'rebuild_combinations', 'Rebuild combinations'),
('en', 'recalculate', 'Recalculate'),
('en', 'recalculate_rates', 'Recalculate rates'),
('en', 'recalculate_totals', 'Recalculate totals'),
('en', 'recent_activity', 'Recent activity'),
('en', 'recent_orders', 'Recent orders'),
('en', 'recent_products', 'Recently viewed'),
('en', 'recipient', 'Recipient'),
('en', 'recipients_name', 'To'),
('en', 'recipient_description', 'Description of the Merchant'),
('en', 'recommended', 'Recommended'),
('en', 'recover_password', 'Reset password'),
('en', 'recover_password_subj', 'Password recovery'),
('en', 'recursively', 'Recursively'),
('en', 'redirect_customer_from_storefront', 'Redirect visitors of this storefront to the one that has countries to which the visitors'' IP addresses belong defined'),
('en', 'referrers', 'Referrers'),
('en', 'referrer_domain', 'Referrer domain'),
('en', 'refresh', 'Refresh'),
('en', 'refresh_packages_list', 'Refresh available upgrades'),
('en', 'refund', 'Refund'),
('en', 'refunded', 'Refunded'),
('en', 'refunded_amount', 'Refunded amount'),
('en', 'regexp', 'RegExp'),
('en', 'regexp_hint', 'If you are using the regexp checking, it is necessary to set a prompting message informing of the incorrect filling of the field, otherwise, the checking will not be performed'),
('en', 'region', 'Region'),
('en', 'regions', 'Regions'),
('en', 'register', 'Register'),
('en', 'registered', 'Registered'),
('en', 'registered_customers', 'Registered customers'),
('en', 'register_new_account', 'Register for a new account'),
('en', 'register_profile', 'Register profile'),
('en', 'registration', 'Registration'),
('en', 'regnumber', 'Registration number'),
('en', 'related_order', 'Related order'),
('en', 'release_date', 'Release date'),
('en', 'remember_me', 'Remember me'),
('en', 'remove', 'Remove'),
('en', 'remove_backup_files', 'Remove backup files'),
('en', 'remove_cc_info', 'Remove CC info'),
('en', 'remove_this_item', 'Remove this item'),
('en', 'rename', 'Rename'),
('en', 'repay_order', 'Pay order'),
('en', 'report', 'Report'),
('en', 'reports', 'Reports'),
('en', 'reports_interval_1', 'Total'),
('en', 'reports_interval_3', 'Day'),
('en', 'reports_interval_5', 'Week'),
('en', 'reports_interval_7', 'Month'),
('en', 'reports_interval_9', 'Year'),
('en', 'reports_list', 'Reports list'),
('en', 'reports_parameter_1', 'Order totals'),
('en', 'reports_parameter_10', 'Shipping costs'),
('en', 'reports_parameter_11', 'Categories'),
('en', 'reports_parameter_12', 'Products'),
('en', 'reports_parameter_13', 'Product costs'),
('en', 'reports_parameter_14', 'The number of products'),
('en', 'reports_parameter_15', 'Managers'),
('en', 'reports_parameter_2', 'The number of orders'),
('en', 'reports_parameter_3', 'Orders'),
('en', 'reports_parameter_4', 'Statuses of orders'),
('en', 'reports_parameter_5', 'Payment methods'),
('en', 'reports_parameter_6', 'Rate areas'),
('en', 'reports_parameter_7', 'Users'),
('en', 'reports_parameter_8', 'Discounts and coupons'),
('en', 'reports_parameter_9', 'Taxes'),
('en', 'request', 'Request'),
('en', 'requests_count', 'Requests count'),
('en', 'requesttype', 'Request type'),
('en', 'request_account_name', 'Requested account name'),
('en', 'required', 'Required'),
('en', 'reset', 'Reset'),
('en', 'reset_filter', 'Reset filter'),
('en', 'reset_inventory', 'Reset inventory'),
('en', 'reset_quantity_to_zero', 'Set quantity of all products to zero'),
('en', 'reset_quantity_to_zero_tooltip', 'If you enable this setting, all the products in your store will have their quantity set to 0, except for the products that have the quantity specified in the imported file.'),
('en', 'reset_password', 'Reset password'),
('en', 'resolved', 'Resolved'),
('en', 'response', 'Response'),
('en', 'restore', 'Restore'),
('en', 'restore_default', 'Use default value'),
('en', 'restore_from_repository', 'Restore from the repository'),
('en', 'ResultCode', 'ResultCode'),
('en', 'ResultDescription', 'ResultDescription'),
('en', 'return', 'Return to normal view'),
('en', 'returning_customer', 'Returning customer'),
('en', 'return_url_target', 'Return URL target'),
('en', 'reuse', 'Reuse'),
('en', 'reversed', 'Reversed'),
('en', 'revert', 'Revert'),
('en', 're_order', 'Reorder this order'),
('en', 'right', 'Right'),
('en', 'right_to_left_orientation', 'Right to left orientation'),
('en', 'risk_checking', 'Risk checking is in process. Please try reloading this page in a minute.'),
('en', 'risk_information', 'Risk information'),
('en', 'romanian', 'Romanian'),
('en', 'root_category', 'Root category'),
('en', 'root_level', 'Root level'),
('en', 'root_page', 'Root level page'),
('en', 'round_to', 'Round to'),
('en', 'routing_code', 'Routing Number'),
('en', 'runtime', 'Runtime'),
('en', 'russian', 'Russian'),
('en', 'sale', 'Sale'),
('en', 'sales', 'Sales'),
('en', 'sales_commission', 'Sales commission'),
('en', 'sales_reports', 'Sales reports'),
('en', 'same_as_source', 'same as source'),
('en', 'save', 'Save'),
('en', 'saved_search', 'Saved searches'),
('en', 'save_and_close', 'Save and close'),
('en', 'save_as', 'Save As...'),
('en', 'save_changes', 'Save changes'),
('en', 'save_discount', 'Save'),
('en', 'save_layout', 'Save layout'),
('en', 'save_layout_as', 'Save layout as'),
('en', 'save_process_payment', 'Save and process payment'),
('en', 'save_this_search_as', 'Save this search as'),
('en', 'scb_text_notice', 'Please send the following URL to the SCB support to be set as PostbackURL: <br /><b>[return_url]</b>'),
('en', 'screen', 'Screen'),
('en', 'screen_resolution', 'Screen resolution'),
('en', 'script', 'Script'),
('en', 'tmpl_scroller', 'Scroller'),
('en', 'scroller_direction', 'Auto-scroll direction'),
('en', 'search', 'Search'),
('en', 'admin_search_title', 'Search'),
('en', 'admin_search_button', 'Search'),
('en', 'admin_search_field', 'Search'),
('en', 'admin_search_general', 'Search'),
('en', 'storefront_search_button', 'Search'),
('en', 'storefront_search_field', 'Search'),
('en', 'storefront_search_label', 'Search'),
('en', 'storefront_search_general', 'Search'),
('en', 'search_again', 'Search again'),
('en', 'search_by_order', 'Search by order'),
('en', 'search_by_customer', 'Search by customer'),
('en', 'search_by_owner', 'Search by owner'),
('en', 'search_by_price', 'Search by price'),
('en', 'search_by_product_features', 'Search by product features'),
('en', 'search_by_product_filters', 'Search by product filters'),
('en', 'search_by_sku', 'Search by product code'),
('en', 'search_by_vendor', 'Search by store'),
('en', 'search_by_weight', 'Search by weight'),
('en', 'search_engine', 'Search engine'),
('en', 'search_for_pattern', 'Search for pattern'),
('en', 'search_in', 'Search in'),
('en', 'search_in_category', 'Search in category'),
('en', 'search_in_subcategories', 'Search in subcategories'),
('en', 'search_options', 'Search options'),
('en', 'search_product', 'Search product'),
('en', 'search_products', 'Search products'),
('en', 'searching_all_products', 'Searching all products'),
('en', 'search_results', 'Search results'),
('en', 'search_results_for', 'Search results for [search]'),
('en', 'search_string', 'Search string'),
('en', 'search_words', 'Search words'),
('en', 'secret_key', 'Secret key'),
('en', 'secret_string', 'Secret string'),
('en', 'secret_word', 'Secret word'),
('en', 'section', 'Section'),
('en', 'section_is_not_completed', 'Section is not completed.'),
('en', 'section_links', 'Section links'),
('en', 'section_name', 'Section name'),
('en', 'secure', 'Secure'),
('en', 'security', 'Security'),
('en', 'secure_checkout', 'Secure checkout'),
('en', 'secure_storefront_url', 'Secure storefront URL'),
('en', 'store_access_key', 'Access key to temporarily closed store'),
('en', 'secure_storefront_url_already_exists', 'The value of the <strong>Secure storefront URL</strong> parameter mentioned by you already belongs to another company.'),
('en', 'url_access_storefront', 'Use the following URL to access the storefront:<br><a href="[url]" target="_blank">[url]</a>'),
('en', 'security_settings', 'Security settings'),
('en', 'see_demo', 'See demo'),
('en', 'select', 'Select'),
('en', 'selectbox', 'Select box'),
('en', 'selected', 'Selected'),
('en', 'selected_fields', 'Selected fields'),
('en', 'selected_items', 'Selected items'),
('en', 'select_all', 'Select all'),
('en', 'select_all_product_options', 'You should select all product options'),
('en', 'select_block', 'Select block'),
('en', 'select_country', 'Select country'),
('en', 'select_customer', 'Select customer'),
('en', 'select_dates', 'Select dates'),
('en', 'period_selector_from', 'From'),
('en', 'period_selector_to', 'To'),
('en', 'select_descr_lang', 'Select the description language'),
('en', 'select_fields_to_edit', 'Select fields to edit'),
('en', 'select_file', 'Select file'),
('en', 'select_image', 'Select image'),
('en', 'select_options', 'Select options'),
('en', 'select_option_above', 'Select the previous option first'),
('en', 'select_product', 'Select product'),
('en', 'select_products', 'Select products'),
('en', 'select_profile', 'Select profile'),
('en', 'select_shipping_method', 'Select shipping method'),
('en', 'select_state', 'Select state'),
('en', 'select_tables', 'Select tables'),
('en', 'select_storefront', 'Select [store] storefront'),
('en', 'semicolon', 'Semicolon'),
('en', 'send', 'Send'),
('en', 'sender', 'Sender'),
('en', 'send_feedback', 'Help us improve [product]'),
('en', 'send_notification', 'Send notification to selected'),
('en', 'send_shipment_notification_to_customer', 'Send shipment notification to customer'),
('en', 'send_shipping_address', 'Send customer shipping address'),
('en', 'send_via', 'Send via'),
('en', 'send_via_email', 'Send via email'),
('en', 'send_via_postal_mail', 'Send via postal mail'),
('en', 'seo_meta_data', 'Meta data'),
('en', 'sequential', 'Sequential'),
('en', 'server', 'Server'),
('en', 'service_not_available', 'This service is not available.'),
('en', 'settings', 'Settings'),
('en', 'settings_wizard', 'Settings wizard'),
('en', 'settings_wizard_close_tooltip', 'Wizard will be possible to re-open in the menu ''Settings -> Settings wizard''.'),
('en', 'settings_wizard_title', 'Settings wizard: Step [current_step] of [total_steps]'),
('en', 'store_mode_menu_description', 'View and manage your licensing details.'),
('en', 'upgrade_center_menu_description', 'Get the latest versions of CS-Cart and its add-ons.'),
('en', 'import_data_menu_description', 'Import products, orders, users and more.'),
('en', 'export_data_menu_description', 'Export products, orders, users and more.'),
('en', 'languages_menu_description', 'Configure the available languages and edit any texts on your site.'),
('en', 'storage_menu_description', 'Back up your site data or restore a previous copy, manage files and CDN.'),
('en', 'settings_general', 'General'),
('en', 'settings_general_menu_description', 'Configure your company info and basic principles of how your site works.'),
('en', 'payment_methods_menu_description', 'Set up the payment options available to your customers.'),
('en', 'shipping_methods_menu_description', 'Set up shipping options, their rates and availability by location.'),
('en', 'taxes_menu_description', 'Configure what taxes you show, how you do it, and tax rates by location.'),
('en', 'storefronts_menu_description', 'Create regional or thematic branches, manage common storefront details.'),
('en', 'stores_menu_description', 'Create regional or thematic branches, manage common storefront details.'),
('en', 'profile_fields_menu_description', 'Manage information collected from customers and sellers.'),
('en', 'notifications_menu_description', 'Manage the notifications sent to customers, administrators and sellers.'),
('en', 'logs_menu_description', 'Store activity log.'),
('en', 'sync_data_manage', 'Sync data'),
('en', 'sync_data_manage_menu_description', 'Connect your store with external systems.'),
('en', 'currencies_menu_description', 'Set up the currencies in which you show the prices to customers.'),
('en', 'statuses_management_menu_description', 'Edit the possible statuses for orders, shipments, etc.'),
('en', 'share', 'Share'),
('en', 'share.congratulations_first_order', 'Congratulations on your first complete order.'),
('en', 'share.first_order_tweet', 'Wow! The first complete order in my [product]-powered store'),
('en', 'share.installation_tweet', 'I have just created an online store with [product_name]'),
('en', 'sharedsec', 'SharedSec'),
('en', 'shared_secret', 'Shared Secret'),
('en', 'sha_sign', 'SHA-1 Signature'),
('en', 'shipment', 'Shipment'),
('en', 'shipments', 'Shipments'),
('en', 'shipment_date', 'Shipment date'),
('en', 'shipment_details', 'Shipment details'),
('en', 'shipment_has_been_created', 'Shipment has been created'),
('en', 'shipment_id', 'Shipment ID'),
('en', 'shipment_info', 'Shipment information'),
('en', 'shipped', 'Shipped'),
('en', 'shipped_products', 'Shipped products'),
('en', 'shipper_number', 'Shipper number'),
('en', 'shipping', 'Shipping'),
('en', 'shippings', 'Shippings'),
('en', 'shippings.service_not_configured', 'Service is not configured'),
('en', 'shippings.service_not_found', 'Service was not found'),
('en', 'shippings.currency_not_found', 'Currency [currency] was not found'),
('en', 'shippings_taxes', 'Shipping & taxes'),
('en', 'shipping_address', 'Shipping address'),
('en', 'shipping_charges', 'Shipping charges'),
('en', 'shipping_time_and_charges', 'Shipping time and rates'),
('en', 'shipping_cost', 'Shipping cost'),
('en', 'shipping.pricing', 'Pricing'),
('en', 'shipping_estimation', 'Shipping estimation'),
('en', 'shipping_freight', 'Shipping freight'),
('en', 'shipping_information', 'Shipping information'),
('en', 'shipping_method', 'Shipping method'),
('en', 'shipping_methods', 'Shipping methods'),
('en', 'shipping_name', 'Shipping name'),
('en', 'shipping_options', 'Shipping Options'),
('en', 'shipping_properties', 'Shipping properties'),
('en', 'shipping_rates', 'Shipping rates'),
('en', 'shipping_same_as_billing', 'Are shipping and billing addresses the same?'),
('en', 'shipping_service', 'Shipping service'),
('en', 'shipping_time', 'Shipping time'),
('en', 'shipping_rate', 'Rate'),
('en', 'shipping_condition', 'Condition'),
('en', 'shipping_price_condition', 'Price condition'),
('en', 'shipping_weight_condition', 'Weight condition'),
('en', 'shipping_items_condition', 'Items condition'),
('en', 'shipping_surcharge_discount', 'Surcharge / Discount'),
('en', 'shipping_per', 'per'),
('en', 'shipping_from_value', 'From'),
('en', 'shipping_to_value', 'To'),
('en', 'shipping_and_up', 'and up'),
('en', 'shipping_item', 'item'),
('en', 'shipping_add_conditions', 'Add conditions'),
('en', 'shipping_hide_conditions', 'Hide conditions'),
('en', 'shipping_add_price_condition', 'Add price conditions'),
('en', 'shipping_add_weight_condition', 'Add weight conditions'),
('en', 'shipping_add_items_condition', 'Add items conditions'),
('en', 'shipping_remove_price_condition', 'Remove price conditions'),
('en', 'shipping_remove_weight_condition', 'Remove weight conditions'),
('en', 'shipping_remove_items_condition', 'Remove items conditions'),
('en', 'shipping_edit_rate_area', 'Edit rate area'),
('en', 'shipping_remove_rate_area', 'Remove rate area from shipping'),
('en', 'shipping_rate_range_overlap_error_message', 'Condition must not fall within existing range.'),
('en', 'shipping_rate_range_limit_error_message', 'The beginning of the range can''t be higher than the end.'),
('en', 'shipping_rate_absolute', 'Absolute ([currency])'),
('en', 'shipping_rate_percent', 'Cart percent (%)'),
('en', 'ship_dhl_height', 'Package height'),
('en', 'ship_dhl_length', 'Package length'),
('en', 'ship_dhl_site_id', 'Site ID'),
('en', 'ship_dhl_width', 'Package width'),
('en', 'ship_fedex_ancillary_endorsement', 'Ancillary Endorsements'),
('en', 'ship_fedex_ancillary_endorsement_address_correction', 'Address Service Requested'),
('en', 'ship_fedex_ancillary_endorsement_carrier_leave_if_no_response', 'Carrier Leave If No Response'),
('en', 'ship_fedex_ancillary_endorsement_change_service', 'Change Service Requested'),
('en', 'ship_fedex_ancillary_endorsement_forwarding_service', 'Forwarding Service Requested'),
('en', 'ship_fedex_ancillary_endorsement_return_delivery', 'Return Service Requested'),
('en', 'ship_fedex_customer_manifest_id', 'Customer manifest ID'),
('en', 'ship_fedex_drop_off_type', 'Drop Off Type'),
('en', 'ship_fedex_drop_off_type_regular_pickup', 'Regular pickup'),
('en', 'ship_fedex_drop_off_type_request_courier', 'Request courier'),
('en', 'ship_fedex_drop_off_type_station', 'Drop at station'),
('en', 'ship_fedex_height', 'Height (inches)'),
('en', 'ship_fedex_hub_id', 'Hub ID'),
('en', 'ship_fedex_indicia', 'Indicia'),
('en', 'ship_fedex_indicia_media_mail', 'Media Mail (Packages from 1 to 70 lbs Books, DVDs, CDs, videotapes)'),
('en', 'ship_fedex_indicia_parcel_select', 'Parcel Select (Packages from 1 to 70 lbs)'),
('en', 'ship_fedex_indicia_presorted_bound_printed_matter', 'Bound Printed Matter packages (Packages from 1 to 15 lbs Catalogs, phone books or anything permanently bound)'),
('en', 'ship_fedex_indicia_presorted_standard', 'Standard Mail packages (Packages less than 1 lb)'),
('en', 'ship_fedex_length', 'Length (inches)'),
('en', 'ship_fedex_meter_number', 'Meter number'),
('en', 'ship_fedex_package_type_fedex_10kg_box', 'FedEx 10kg Box'),
('en', 'ship_fedex_package_type_fedex_25kg_box', 'FedEx 25kg Box'),
('en', 'ship_fedex_package_type_fedex_box', 'FedEx Box'),
('en', 'ship_fedex_package_type_fedex_envelope', 'FedEx Envelope'),
('en', 'ship_fedex_package_type_fedex_pak', 'FedEx Pak'),
('en', 'ship_fedex_package_type_fedex_tube', 'FedEx Tube'),
('en', 'ship_fedex_package_type_your_packaging', 'Your packaging'),
('en', 'ship_fedex_smart_post', 'Smart Post'),
('en', 'ship_fedex_special_services', 'Special service (delivery confirmation)'),
('en', 'ship_fedex_width', 'Width (inches)'),
('en', 'ship_height', 'Package height (cm)'),
('en', 'ship_length', 'Package length (cm)'),
('en', 'ship_sp_l_acknowledgement_of_delivery', 'Acknowledgement of delivery (for registered mail only)'),
('en', 'ship_sp_l_cash_on_delivery', 'Cash on delivery (for registered mail only)'),
('en', 'ship_sp_l_personal_delivery', 'Personal delivery (for registered mail only)'),
('en', 'ship_sp_l_registered_mail', 'Registered mail'),
('en', 'ship_sp_pc_assurance', 'Assurance'),
('en', 'ship_sp_pc_cash_on_delivery', 'Cash on delivery (COD)'),
('en', 'ship_sp_pc_fragile', 'Fragile'),
('en', 'ship_sp_pc_manual_handling', 'Manual handling'),
('en', 'ship_sp_pc_personal', 'Personal'),
('en', 'ship_sp_pc_signature', 'Signature'),
('en', 'ship_sp_pp_additional_insurance', 'Additional insurance (up to CHF 3000.-)'),
('en', 'ship_sp_pp_bulky_goods', 'Bulky goods'),
('en', 'ship_sp_pp_cash_on_delivery', 'Cash on delivery (ECONOMY only)'),
('en', 'ship_sp_pp_manual_processing', 'Manual processing'),
('en', 'ship_sp_ur_additional_insurance', 'Additional insurance for URGENT goods  (up to CHF 3000.-)'),
('en', 'ship_swisspost_error_intl_delivery', 'Cannot use this shipping method for the international delivery'),
('en', 'ship_swisspost_error_private_delivery', 'Cannot use this shipping method for the private delivery'),
('en', 'ship_swisspost_heavy_package', 'The package is too heavy'),
('en', 'ship_swisspost_unable_to_open_additional_services', 'Cannot open the additional_services.csv file'),
('en', 'ship_swisspost_unable_to_open_service', 'Cannot open the [code] file'),
('en', 'ship_to', 'Ship to'),
('en', 'ship_to_another', 'Ship to a different address'),
('en', 'ship_ups_access_key', 'UPS Rates Access Key'),
('en', 'ship_ups_package_type_01', 'UPS letter/ UPS Express Envelope'),
('en', 'ship_ups_package_type_03', 'UPS Tube'),
('en', 'ship_ups_package_type_04', 'UPS Pack'),
('en', 'ship_ups_package_type_21', 'UPS Express Box'),
('en', 'ship_ups_package_type_24', 'UPS 25Kg Box'),
('en', 'ship_ups_package_type_25', 'UPS 10Kg Box'),
('en', 'ship_ups_pickup_type', 'Pickup type'),
('en', 'ship_ups_pickup_type_01', 'Daily Pickup'),
('en', 'ship_ups_pickup_type_03', 'Customer Counter'),
('en', 'ship_ups_pickup_type_06', 'One Time Pickup'),
('en', 'ship_ups_pickup_type_07', 'On Call Air'),
('en', 'ship_ups_pickup_type_11', 'Suggested Retail Rates'),
('en', 'ship_ups_pickup_type_19', 'Letter Center'),
('en', 'ship_ups_pickup_type_20', 'Air Service Center'),
('en', 'ship_ups_delivery_confirmation', 'No Signature'),
('en', 'ship_ups_delivery_confirmation_signature', 'Signature Required'),
('en', 'ship_ups_delivery_confirmation_adult_signature', 'Adult Signature Required'),
('en', 'ship_ups_use_delivery_confirmation', 'Use Delivery confirmation'),
('en', 'ship_ups_dcist_type', 'Confirmation type'),
('en', 'ship_usps_container', 'Container'),
('en', 'ship_usps_container_express', 'Container (Express)'),
('en', 'ship_usps_container_express_flat_rate_envelope', 'Flat Rate Envelope'),
('en', 'ship_usps_container_priority', 'Container (Priority Mail)'),
('en', 'ship_usps_container_priority_flat_rate_box', 'Flat Rate Box'),
('en', 'ship_usps_container_priority_flat_rate_envelope', 'Flat Rate Letter'),
('en', 'ship_usps_container_priority_lg_flat_rate_box', 'Large Flat Rate Box'),
('en', 'ship_usps_container_priority_md_flat_rate_box', 'Medium Flat Rate Box'),
('en', 'ship_usps_container_priority_nonrectangular', 'NonRectangular'),
('en', 'ship_usps_container_priority_rectangular', 'Rectangular'),
('en', 'ship_usps_container_priority_regional_a_rate_box', 'Regional Rate Box A'),
('en', 'ship_usps_container_priority_regional_b_rate_box', 'Regional Rate Box B'),
('en', 'ship_usps_container_priority_regional_c_rate_box', 'Regional Rate Box C'),
('en', 'ship_usps_container_priority_sm_flat_rate_box', 'Small Flat Rate Box'),
('en', 'ship_usps_container_priority_padded_flat_rate_envelope', 'Padded Flat Rate Envelope'),
('en', 'ship_usps_container_priority_legal_flat_rate_envelope', 'Legal Flat Rate Envelope'),
('en', 'ship_usps_container_priority_sm_flat_rate_envelope', 'Sm Flat Rate Envelope'),
('en', 'ship_usps_container_priority_window_flat_rate_envelope', 'Window Flat Rate Envelope'),
('en', 'ship_usps_container_priority_gift_card_flat_rate_envelope', 'Gift Card Flat Rate Envelope'),
('en', 'ship_usps_first_class_mail_type', 'First Class Mail Type'),
('en', 'ship_usps_first_class_mail_type_flat', 'Flat'),
('en', 'ship_usps_first_class_mail_type_parcel', 'Parcel'),
('en', 'ship_usps_intl_package_girth', 'Package girth'),
('en', 'ship_usps_intl_package_height', 'Package height'),
('en', 'ship_usps_intl_package_length', 'Package length'),
('en', 'ship_usps_intl_package_size', 'Package size'),
('en', 'ship_usps_intl_package_width', 'Package width'),
('en', 'ship_usps_machinable', 'Machinable (First-Class Mail or Standard Post)'),
('en', 'ship_usps_machinable_false', 'False'),
('en', 'ship_usps_machinable_true', 'True'),
('en', 'ship_usps_mailtype', 'Type of Mail'),
('en', 'ship_usps_mailtype_matter_for_the_blind', 'Matter for the Blind'),
('en', 'ship_usps_mailtype_postcards_or_aerogrammes', 'Postcards or Aerogrammes'),
('en', 'ship_usps_package_size', 'Package Size (length + girth, inches)'),
('en', 'ship_usps_package_size_large', 'Large (84..108)'),
('en', 'ship_usps_package_size_oversize', 'Oversize (108..130)'),
('en', 'ship_usps_package_size_regular', 'Regular (0..84)'),
('en', 'ship_usps_priority_girth', 'Priority Mail (Size:Large, Container:NonRectangular) Girth (inches)'),
('en', 'ship_usps_priority_height', 'Priority Mail (Size:Large) Height (inches)'),
('en', 'ship_usps_priority_length', 'Priority Mail (Size:Large) Length (inches)'),
('en', 'ship_usps_priority_width', 'Priority Mail (Size:Large) Width (inches)'),
('en', 'ship_usps_username', 'User ID'),
('en', 'ship_width', 'Package width (cm)'),
('en', 'short_description', 'Short description'),
('en', 'short_hour', 'h.'),
('en', 'short_list', 'Short list'),
('en', 'show', 'Show'),
('en', 'show_all', 'Show all'),
('en', 'show_items_in_line', 'Show items inline'),
('en', 'show_orders', 'Show orders'),
('en', 'show_price', 'Show price'),
('en', 'show_rate_for_destination', 'Show rates for location'),
('en', 'show_rate_for_rate_area', 'Show rates for rate area'),
('en', 'show_tab_in_popup', 'Show this tab in a popup window'),
('en', 'tmpl_sidebox_1_item', 'Side box first item'),
('en', 'sidebox_general', 'Ordinary block (H3 heading) [deprecated]'),
('en', 'sidebox_important', 'Ordinary block (H3 heading)'),
('en', 'signature', 'Signature'),
('en', 'signed_in_as', 'Signed in as'),
('en', 'sign_in', 'Sign in'),
('en', 'sign_in_as_different', 'Sign in as a different user'),
('en', 'sign_in_to_buy', 'Please sign in to buy'),
('en', 'sign_in_to_view_price', '[Sign in to view price]'),
('en', 'sign_out', 'Sign out'),
('en', 'sign_up_for_notification', 'Sign up for notification'),
('en', 'similar_only', 'Similar only'),
('en', 'simple_ultimate_companies_selector', 'Please contact the technical support'),
('en', 'simultaneous', 'Simultaneous'),
('en', 'single', 'Single'),
('en', 'single_coupon_is_allowed', 'Single discount coupon is allowed only'),
('en', 'sitemap', 'Sitemap'),
('en', 'sitemap_settings', 'Sitemap settings'),
('en', 'site_number', 'Site number (EPT)'),
('en', 'size', 'Size'),
('en', 'skiplastpage', 'Skip the last page'),
('en', 'skip_payment', 'Skip payment'),
('en', 'skrill_customer_id', 'Skrill Customer ID'),
('en', 'sku', 'CODE'),
('en', 'slovak', 'Slovak'),
('en', 'slow', 'Slow'),
('en', 'small_items', 'Small items'),
('en', 'smarty_block', 'HTML block with Smarty support'),
('en', 'sms_customer_registered', 'Customer [name] has been registered.'),
('en', 'sms_for_the_sum', 'to the amount of'),
('en', 'sms_order_placed', 'has been placed'),
('en', 'snapshot_date', 'Snapshot date'),
('en', 'sort_by', 'Sort by'),
('en', 'sort_by_null_asc', 'No sorting'),
('en', 'sort_by_popularity_asc', 'Sort by Popularity: Low to High'),
('en', 'sort_by_popularity_desc', 'Sort by Popularity'),
('en', 'sort_by_position_asc', 'Sort by Position: Low to High'),
('en', 'sort_by_position_desc', 'Sort by Position: High to Low'),
('en', 'sort_by_price_asc', 'Sort by Price: Low to High'),
('en', 'sort_by_price_desc', 'Sort by Price: High to Low'),
('en', 'sort_by_product_asc', 'Sort Alphabetically: A to Z'),
('en', 'sort_by_product_desc', 'Sort Alphabetically: Z to A'),
('en', 'sort_by_timestamp_asc', 'Oldest Items First'),
('en', 'sort_by_timestamp_desc', 'Newest Items First'),
('en', 'sort_images', 'Sort images'),
('en', 'spanish', 'Spanish'),
('en', 'specific_settings', 'Specific settings'),
('en', 'specify_url', 'Specify URL'),
('en', 'speed', 'Speed'),
('en', 'tooltip_carousel_speed', 'The time of the animation in milliseconds. The shorter the time, the faster the animation.'),
('en', 'type_to_search', 'Type to search...'),
('en', 'type_to_create', 'Type to create...'),
('en', 'type_to_search_or_click_button', 'Type to search, or click the button on the right for advanced search'),
('en', 'use_comma_enter_to_separate_variants', 'Use a comma or Enter to separate variants.'),
('en', 'enter_color_name_and_code', 'Enter color name and code. Example, "Red #ff0000"'),
('en', 'enter_category_name_and_path', 'Enter path and category name. Example, "Electronics/Computers/Laptops"'),
('en', 'object_picker.remove_all_items', 'Remove all items'),
('en', 'ssl_certificate', 'SSL certificate'),
('en', 'staff_only_notes', 'Staff only notes'),
('en', 'stage', 'Stage'),
('en', 'standard_sidebox', 'Standard side box'),
('en', 'start', 'Start'),
('en', 'start_communication', 'Start communication'),
('en', 'start_date', 'Start date'),
('en', 'start_price', 'Start price'),
('en', 'state', 'State/Province'),
('en', 'states', 'States'),
('en', 'static_block', 'Static block'),
('en', 'static_data', 'Static data'),
('en', 'static_data_use_item', 'Use the "Link text" and "URL" values from this item in the storefront'),
('en', 'statistics', 'Statistics'),
('en', 'status', 'Status'),
('en', 'status_changed', 'Status has been changed'),
('en', 'no_active_storefronts', 'No active storefronts'),
('en', 'status_changed_after_process_payment', 'Order status was set according to the payment processing result'),
('en', 'stay_connected', 'Stay Connected'),
('en', 'stay_connected_notice', 'Enter your email address to receive special offers and promotions.'),
('en', 'step_four', 'Step 4'),
('en', 'step_one', 'Step 1'),
('en', 'step_three', 'Step 3'),
('en', 'step_two', 'Step 2'),
('en', 'stop_other_rules', 'Stop other rules'),
('en', 'storage', 'Storage'),
('en', 'store', 'Store'),
('en', 'storefront', 'Storefront'),
('en', 'storefront_url', 'Storefront URL'),
('en', 'storefront_url_already_exists', 'The value of the <strong>Storefront URL</strong> parameter mentioned by you already belongs to another company.'),
('en', 'storefront_url_not_defined', 'Storefront URL not defined'),
('en', 'stores_status', 'Status'),
('en', 'storefront_status_access_key_hint', 'Even if the storefront is closed (the status set to OFF), you''ll be able to view it if you have an access key. Go to <a target="blank" href="[url]">Settings → General</a> and specify the <i>Access key to temporarily closed store</i> setting. Please note that a different key can be specified for each storefront, so make sure to select the correct storefront first. Use the key as described in the tooltip of that setting.'),
('en', 'stores', 'Stores'),
('en', 'store_mode', 'Licensing mode'),
('en', 'store_mode_changed', 'Licensing mode has been changed'),
('en', 'store_number', 'Store number'),
('en', 'store_object_denied', 'The [object_type] [object_name] is unavailable for this store.'),
('en', 'store_theme', 'Storefront theme'),
('en', 'subcategories', 'Subcategories'),
('en', 'submit', 'Submit'),
('en', 'submit_my_order', 'Submit my order'),
('en', 'subpages', 'Subpages'),
('en', 'subscribe', 'Subscribe'),
('en', 'subscriber', 'Subscriber'),
('en', 'subscribers', 'Subscribers'),
('en', 'subscriber_email', 'Subscriber email'),
('en', 'subscriptions', 'Subscriptions'),
('en', 'subtotal', 'Subtotal'),
('en', 'subtotal_sum', 'Subtotal sum'),
('en', 'suburb', 'Suburb'),
('en', 'successful', 'Successful'),
('en', 'successfully_registered', 'Successfully registered'),
('en', 'successful_login', 'You have been successfully logged in.'),
('en', 'success_registration_text', 'Congratulations! The registration was successful!<br/>Now, you have full access to all the store features. Click on "My account" to see them.'),
('en', 'suffix', 'Suffix'),
('en', 'summary', 'Summary'),
('en', 'supplier', 'Supplier'),
('en', 'suppliers', 'Suppliers'),
('en', 'supplier_id', 'Supplier'),
('en', 'surcharge', 'Surcharge'),
('en', 'surcharge_title', 'Surcharge title'),
('en', 'sweden', 'Sweden'),
('en', 'swedish', 'Swedish'),
('en', 'swing', 'Swing'),
('en', 'switch_layout', 'Switch layout'),
('en', 'layout_page', 'Layout Page'),
('en', 'layout_meta_data', 'Meta data & more'),
('en', 'symbol', 'Symbol'),
('en', 'system', 'System'),
('en', 'tab', 'Tab'),
('en', 'table', 'Table'),
('en', 'tables', 'Tables'),
('en', 'table_conditions', 'Table Conditions'),
('en', 'tabs', 'Tabs'),
('en', 'tax', 'Tax'),
('en', 'taxes', 'Taxes'),
('en', 'tax_exempt', 'Tax exempt'),
('en', 'tax_rates', 'Tax rates'),
('en', 'template', 'Template'),
('en', 'templates_tree', 'Templates tree'),
('en', 'file_editor', 'File editor'),
('en', 'file_editor_archive_contains_incorrect_paths', 'Archive contains files with incorrect paths.'),
('en', 'terminal', 'Terminal'),
('en', 'terminal_id', 'Terminal ID'),
('en', 'test', 'Test'),
('en', 'test_live_mode', 'Test/Live mode'),
('en', 'test_mode', 'Test mode'),
('en', 'text', 'Text'),
('en', 'textarea', 'Text area'),
('en', 'text_2checkout_notice', '<b>Note</b>: In order to track your 2Checkout orders with the shopping cart software you have to take these steps:<br /><br />-&nbsp;Log in to your 2Checkout account<br />-&nbsp;Click on <u>''Site management''</u> in the <u>''Account''</u> section.<br />-&nbsp;Select <b>''Given links back to my website''</b> option in the <u>''Direct Return''</u> subsection <br />-&nbsp;Set <u>''Approved URL''</u> and <u>''Pending URL''</u> to:<br /><b>[return_url]</b><br />-&nbsp;Set <u>''Secret Word''</u>. The Secret Word is known only to the seller and 2CheckOut.<br />'),
('en', 'text_2co_ins', 'Instant Notification Service (INS)'),
('en', 'text_additional_detailed_image', '(displayed in popup window)'),
('en', 'text_additional_thumbnail', '(displayed on product details page in "Additional images")'),
('en', 'addon_files_was_copied', 'The <b>"[addon]"</b> add-on files has been copied successfully'),
('en', 'text_addon_cannot_enable', 'Add-on "[addon_name]" is incompatible with the following add-ons: [addons]. It cannot be enabled'),
('en', 'text_addon_confclicts', 'Add-on "[addon_name]" is incompatible with the following add-ons: [addons]. These add-ons will be automatically disabled.'),
('en', 'text_addon_confclicts_on_install', 'Add-on "[addon_name]" is incompatible with the following add-ons: [addons]. It has not been be enabled. Enable it manually and all the incompatible add-ons will be disabled automatically.'),
('en', 'text_addon_installed', 'The <b>"[addon]"</b> add-on has been installed successfully'),
('en', 'text_addon_install_dependencies', 'The add-on cannot be installed because a dependence on the [addon] add-on is set for it. Please install the [addon] add-on first.'),
('en', 'text_addon_refreshed', 'The settings and language variables of the <b>"[addon]"</b> add-on have been updated successfully'),
('en', 'text_addon_uninstalled', 'The <b>"[addon]"</b> add-on has been uninstalled.'),
('en', 'text_addon_uninstall_dependencies', 'The add-on cannot be uninstalled because the following add-ons depend on it: [addons]'),
('en', 'text_addresses_wildcards', 'You are able to use wildcards in this field:<br /><b>''?''</b> - any single character;<b>''*''</b> - any number of characters.<br /><br /><u>Example:</u><br /><b>* street</b> &nbsp;&nbsp;(corresponds to 1st Street, 102nd Street, etc)'),
('en', 'text_admin_new_orders', 'This section shows the orders you have never viewed.'),
('en', 'text_allowed_to_upload_file_extension', 'The following file extensions are supported: <b>[ext]</b>.'),
('en', 'text_amazon_callback_url', 'Important! You must specify your store''s URL <b>[callback_url]</b> as the Merchant URL on the Amazon''s Seller Central Website (Settings > Checkout Pipeline Settings). Otherwise, you won''t be able to accept payments through Amazon Checkout in your store'),
('en', 'text_amazon_failed_order', 'No response from Amazon Checkout has been received yet, please hold on. Although the order might not be created in the store as long last, it is highly probable that it has been successfully created and processed by Amazon Checkout. Please contact the store staff and tell them the order ID as provided by Amazon'),
('en', 'text_amazon_incorrect_products_count', 'Number of products in your cart differs from the number of products in the Amazon request.'),
('en', 'text_amazon_link_message', 'For testing purposes, the Merchant URL may be the HTTP link to your store, but the live mode requires secure connection and you must use the HTTPS link. Also, remember to enable the production mode on Amazon''s Seller Central website when you are ready to go live.'),
('en', 'text_amazon_surcharge', '<b>Note:</b> According to the Amazon <a href=''https://payments.amazon.com/sdui/sdui/about?nodeId=6019'' target=''_blank''>policy</a> (B4.2), surcharges are not supported. Any surcharges you may have set will be ignored when Amazon Checkout is used.'),
('en', 'text_anonymous_checkout', 'You must be a registered user to proceed to checkout'),
('en', 'recalculate_shipping_cost', 'Recalculate shipping cost'),
('en', 'text_applied_promotions', 'Applied promotions'),
('en', 'text_are_you_sure_to_delete_file', 'Are you sure you want to delete the item?'),
('en', 'text_are_you_sure_to_proceed', 'Are you sure you want to proceed?'),
('en', 'text_atos_notice', '<b>Note:</b><br />1. Copy your certificate that you received on the disk to the [home_path] directory. Rename the certificate to certif.fr.[my_merchant_id], where [my_merchant_id] is your web site number.<br /> 2. Rename the store parameters file (parmcom.014213245611111 file) to parmcom.[my_merchant_id].<br />3. Edit the <b>pathfile</b> file in the  <b>[home_path]</b> directory<br />- Replace string ''<u>D_LOGO![some_dir]!</u>'' with ''<u>D_LOGO![http_path]/logo/!</u>''<br />- Replace string ''<u>F_DEFAULT![/some_dirs/parmcom.sogenactif]!</u>'' with ''<u>F_DEFAULT![home_path]/parmcom.sogenactif!</u>''<br />- Replace string ''<u>F_PARAM![/some_dirs/parmcom]!</u>'' with ''<u>F_PARAM![home_path]/parmcom!</u>''<br />- Replace string ''<u>F_CERTIFICATE![/some_dirs/certif]!</u>'' with ''<u>F_CERTIFICATE![home_path]/certif!</u>''<br />4. Edit the <b>parmcom.[some_number]</b> file in the <b>[home_path]</b> directory<br />- Replace string ''<u>AUTO_RESPONSE_URL![some_url]!</u>'' with ''<u>AUTO_RESPONSE_URL![auto_url]!</u>''<br />- Replace string ''<u>CANCEL_URL![some_url]!</u>'' with ''<u>CANCEL_URL![ok_url]!</u>''<br />- Replace string ''<u>RETURN_URL![some_url]!</u>'' with ''<u>RETURN_URL![ok_url]!</u>''<br />'),
('en', 'text_atos_warning', '<span style="color:#FF2222">Warning!!!</span> The path to atos files should consist of not more than 60 symbols, otherwise please copy the atos_files folder to some parent directory, e.g. to the cart core directory. Also please make sure the atos files directory has full permissions.'),
('en', 'text_authentication_failed_message', 'Your financial institution has indicated that it could not successfully authenticate this transaction. To protect against unauthorized use, this card cannot be used to complete your purchase. You may complete the purchase by selecting another form of payment.'),
('en', 'text_backup_filename_hint', 'To download this backup, click the gear icon and select Download'),
('en', 'text_backup_management_notice', 'This section allows you to manage your backup files.<br />- To restore the database, select the check box near the appropriate file name and click on Restore.<br />- To delete files, select the check boxes near the files that need to be deleted and click on Delete.<br />- To download a file to your local computer, click on the file name.'),
('en', 'text_billing_same_with_shipping', 'Billing and shipping addresses are the same'),
('en', 'text_billing_address_is_different_from_shipping', 'My billing address is different from shipping address'),
('en', 'text_block_trial_notice', 'Your 30-day evaluation period has expired. Please, buy a license ([href]) or remove the software from your server.'),
('en', 'text_cannot_create_directory', 'Cannot create the directory <b>[directory]</b>. Please check the permissions.'),
('en', 'text_cannot_create_file', 'Cannot create the file <b>[file]</b>. Please check the directory permissions.'),
('en', 'text_cannot_delete_directory', 'Cannot delete the directory <b>[directory]</b>. Please check the permissions.'),
('en', 'text_cannot_delete_file', 'Cannot delete the file <b>[file]</b>. Please check the permissions.'),
('en', 'text_cannot_rename_directory', 'Cannot rename the directory <b>[directory]</b>. Please check the permissions.'),
('en', 'text_cannot_rename_file', 'Cannot rename the file <b>[file]</b>. Please check the permissions.');
INSERT INTO `[[dbprefix]]language_values` VALUES
('en', 'text_cannot_restore_directory', 'Cannot restore the directory <b>[directory]</b> from the repository. Please check if the repository exists.'),
('en', 'text_cannot_restore_file', 'Cannot restore file <b>[file]</b> from the repository. Please check if the repository exists.'),
('en', 'text_can_be_used_once', 'This coupon can be used only once. You have already applied it.'),
('en', 'text_cart_amount_changed', 'The quantity of the product <b>[product]</b> in your cart  has been changed to allowable.'),
('en', 'text_cart_amount_corrected', 'The number of products in the inventory is not enough for your order. The quantity of the product <b>[product]</b> in your cart has been reduced to <b>[count]</b>.'),
('en', 'text_cart_empty', 'Your cart is empty'),
('en', 'text_cart_max_qty', 'Maximum quantity for "[product]" is <b>[quantity]</b>'),
('en', 'text_cart_min_qty', 'Minimum quantity for "[product]" is <b>[quantity]</b>'),
('en', 'text_cart_not_enough_inventory', 'The number of products in the inventory is not enough for your order'),
('en', 'text_cart_zero_inventory', '<b>[product]</b> has zero inventory and cannot be added to the cart'),
('en', 'text_cart_zero_inventory_and_removed', '<b>[product]</b> has zero inventory and is removed from the cart'),
('en', 'text_categories_have_been_deleted', 'Categories have been deleted successfully.'),
('en', 'text_category_delimiter', 'Category path delimiter for product main category (e.g. "Computers///Desktops")'),
('en', 'text_category_detailed_image', '(optional displayed on category details page only)'),
('en', 'text_category_has_been_deleted', 'Category, subcategories and their products have been deleted successfully.'),
('en', 'text_category_icon', '(displayed on category list and details pages)'),
('en', 'text_cc_processor_connection', 'Connecting to <b>[processor]</b>...'),
('en', 'text_cdn_check', '<strong>Attention!</strong> Please test some static URL, e.g. <a href="[url]">[url]</a>, to ensure it''s working before enabling CDN (you can enable it after storage became active). It usually takes 10-15 minutes to activate storage (the "Status" field should display "Active", refresh page for updates).'),
('en', 'text_cdn_setup', 'CDN was set up successfully.'),
('en', 'text_changes_not_saved', 'Your changes have not been saved.'),
('en', 'text_changes_saved', 'Your changes have been saved.'),
('en', 'text_change_password', 'You are now logged in to your account. Please change the password and click the "Save" button.'),
('en', 'text_checkout_new_profile_notice', 'If you are a new customer, we need to know your personal details.'),
('en', 'text_cities_wildcards', 'You are able to use wildcards in this field:<br /><b>''?''</b> - any single character;<b>''*''</b> - any number of characters.<br /><br /><u>Example:</u><br /><b>New Y*</b> &nbsp;&nbsp;(corresponds to New York, New Yark, etc)<br /><b>L?s*</b>&nbsp;&nbsp; (corresponds to Las Vegas, Los Angeles, etc..)'),
('en', 'tmpl_text_ckeditor', 'CKEditor'),
('en', 'text_click_here', 'Click here for more details'),
('en', 'text_cmcic_notice', 'Please set the following URL as the <b>CGI2</b>: <b>[postback_url]</b>'),
('en', 'text_cmpi_frame_message', 'For your security, please fill out the form below to complete your order. Do not click the Refresh or Back button, or this transaction may be interrupted or canceled.'),
('en', 'text_cmpi_go_back', 'Go back'),
('en', 'text_combination_out_of_stock', 'No products with the selected options in stock'),
('en', 'text_companies_activated', 'Selected companies have been activated'),
('en', 'text_companies_disabled', 'Selected companies have been disabled'),
('en', 'text_company_status_active_subj', 'Your company was activated.'),
('en', 'text_company_status_changed', 'Status of your company [company] was changed to [status].'),
('en', 'text_company_status_disabled_subj', 'Your company was disabled.'),
('en', 'text_conditions_cleared', 'Table conditions were cleared'),
('en', 'text_confirm_passwd_recovery', 'Please follow this link to confirm your password recovery procedure'),
('en', 'password_recovery.text_confirm', 'Somebody — hopefully you — has asked us to reset the password for your account at [site]. If it weren''t you, then feel free to ignore this message.'),
('en', 'password_recovery.link_expire', 'But if you''d like to reset the password, follow the link below. It will expire in 15 minutes'),
('en', 'text_csrf_attack', 'Access denied: Possible CSRF attack'),
('en', 'text_customer_area_logo', 'Logo for the <b>customer</b> area'),
('en', 'text_datatrans_notice', '<b>Note</b>: In order to track your Datatrans orders with the shopping cart software you have to take the following steps:<br /> <br /> -&nbsp;Log in to your Datatrans account<br /> -&nbsp;Click on the <u>''Upp Data''</u> link in the <u>''Upp Administration''</u> section.<br /> -&nbsp;Set <u>''URL Post data format''</u> to <b>''Data in HTML FORM''</b>.<br /> -&nbsp;Set <u>''URL Post''</u> to:<br /> <b>[post_url]</b><br /> -&nbsp;Click on the <u>''Security''</u> link in the <u>''Upp Administration''</u> section.<br /> -&nbsp;Select the <b>''An additional merchant identification will be send with payment messages''</b> option.<br /> -&nbsp;Generate new digital signature using the <u>''Generate new sign''</u> button.<br /> -&nbsp;Set generated value to the <u>''Digital signature''</u> field on the Datatrans payment configuration page in your store<br />'),
('en', 'text_data_changed', 'Your changes have not been saved.Press OK to continue, or Cancel to stay on the current page.'),
('en', 'text_tab_changed', 'Your changes on the current tab have not been saved. Click "OK" to continue or "Cancel" to stay on the current tab.'),
('en', 'text_decrease_points_in_use', 'The points used in the order were subtracted from user account.'),
('en', 'text_deltapay_notice', '<b>Note:</b> Please send the following information to the DeltaPay support:<br />Payment page: ''<u>[payment_url]</u>''<br />Success page: ''<u>[result_url]</u>''<br />Failure page: ''<u>[result_url]</u>''<br />Cancel page: ''<u>[result_url]</u>''<br />'),
('en', 'text_directebanking_notice', 'Set ''Success link'' to: <b>[success_url]</b><br /> Set ''Abort link'' to: <b>[abort_url]</b><br /> Add new HTTP notifications and set ''Notification URL'' to: <b>[notification_url]</b><br /> Activate input check and set ''Hash Algoritm'' to the ''SHA1''<br />'),
('en', 'text_directory_created', 'The directory <b>[directory]</b> has been successfully created.'),
('en', 'text_directory_deleted', 'The directory <b>[directory]</b> has been successfully deleted'),
('en', 'text_directory_renamed', 'The directory <b>[directory]</b> has been successfully renamed to <b>[to_directory]</b>'),
('en', 'text_directory_restored', 'The directory <b>[directory]</b> has been restored from the repository'),
('en', 'text_downloads_empty', 'Your downloads list is empty'),
('en', 'text_editing', 'Text editing'),
('en', 'text_edp_product', 'This product is electronically distributed'),
('en', 'text_ekey_not_valid', 'The confirmation link is invalid or has expired.'),
('en', 'text_email_sent', 'E-mail has been sent successfully.'),
('en', 'text_emerchantpay_notice', 'Please add these URL fields in your eMerchantPay eCommerce Payment Form configuration:<br/><br/><b>BackReturn URL:</b><br/>[backreturn_url]<br/><br/><b>Custom Approval URL:</b><br/>[notify_url]<br/><br/><b>Custom Decline URL:</b><br/>[decline_url]<br/><br/><b>Activate Notification URL:</b><br/>[process_url]'),
('en', 'text_enets_notice', 'Please send the following URL to the eNPS manager as a response URL for all the three cases (success, failure, cancel): [r_url]'),
('en', 'text_enter_filename', 'Please enter a new file name'),
('en', 'text_exim_data_exported', 'Data is exported successfully'),
('en', 'text_exim_data_imported', 'Data is imported successfully.<br />New objects - <b>[new]</b>;<br />Updated objects - <b>[exist]</b>;<br />Skipped objects - <b>[skipped]</b>;<br />Total - <b>[total]</b>.'),
('en', 'text_exim_data_imported_clear', 'Data is imported successfully.'),
('en', 'text_exim_export_notice', 'Below is a list of the fields that can be exported. The <b>highlighted</b> fields are mandatory.'),
('en', 'text_exim_import_features_note', '<h4>Product features import format</h4><code>(%Group name%) %Feature name%: %Feature type%[%Feature value%]</code>where,<dl class="dl-horizontal"><dt>%Group name%</dt><dd>the name of feature group</dd><dt>%Feature name%</dt><dd>the name of feature</dd><dt>%Feature type%</dt><dd>the feature type (C - checkbox, M - multiple checkboxes, S - text select box, N - number select box, E - extended selectbox, T - simple text, O - number, D - date)</dd><dt>%Feature value%</dt><dd>the feature value (several values can be delimited by comma)</dd></dl><p>Several features must be delimited by semicolon.</p><h5>Example:</h5><code>ISBN: T[1233423423]; Release date: D[05/05/07]; Color: S[Red]</code>'),
('en', 'text_exim_import_files_note', '<h4>File import format</h4><code>%File location%</code> where, <dl class="dl-horizontal"> <dt>%File location%</dt> <dd>can be an absolute or relative path in a server file system or a URL</dd> </dl> <p>Several files must be delimited by comma.</p> <h5>Example 1:</h5><code>file1.jpg</code><h5>Example 2:</h5><code>backup/file1.zip, images/file2.jpg</code>'),
('en', 'text_exim_import_images_note', '<h4>Image import format</h4><code>%Image location%#%Alternative text%</code> where,<br><dl class="dl-horizontal"><dt>%Image location%</dt><dd>can be an absolute or relative path in a server file system or a URL,</dd><dt>%Alternative text%<dt><dd>image alternative text</dd></dl><h5>Example 1:</h5><code>images/product_images/apples.jpg#Apples</code><h5>Example 2:</h5><code>http://www.site.com/apples.jpg#Apples</code>'),
('en', 'text_exim_import_notice', 'Below is a list of the fields that your data file can contain. The fields highlighted in bold are mandatory. If you are importing data with special symbols (commas, semicolons, etc.), please make sure you have these fields quoted.'),
('en', 'text_exim_import_options_note', '<h4>Product options import format</h4><code>%Option name%: %Option type%[{$ldelim}%Variant 1 ID%{$rdelim}%Variant 1%,{$ldelim}%Variant 2 ID%{$rdelim}%Variant 2%,{$ldelim}%Variant N ID%{$rdelim}%Variant N%]</code> where,<dl class="dl-horizontal"><dt>%Option name%</dt><dd>the name of the option,</dd><dt>%Variant N ID%</dt><dd>the id of the variant,</dd><dt>%Variant N%</dt><dd>the name of the variant. Variants must be specified if the option type is a selectbox or radiogroup only.</dd><dt>%Option type%</dt><dd>the option type, can be the following:<br><ul><li><b>S</b> - selectbox,</li><li><b>R</b> - radiogroup,</li><li><b>C</b> - checkbox,</li><li><b>I</b> - simple input,</li><li><b>T</b> - textarea.</li></ul></dd></dl><p>Several options must be delimited by semicolon.</p><h5>Examples:</h5>Simple text options:<code>Your age: I; Date of birth: I; Notes: T</code><br>Options with variants:<code>Color: S[Red, Green, Blue]; Size: R[X, XL, XXL]</code>'),
('en', 'text_exim_utf8_file_format', 'Please make sure that the file you are importing has UTF-8 charset for correct import'),
('en', 'text_expired_license', 'Unfortunately, your subscription for [product] software is over. Please renew it as soon as possible to avoid the program suspending.'),
('en', 'text_features_delimiter', 'Delimiter between variant values of a product feature.'),
('en', 'text_feedback_notice', 'The parameters that will be sent to our server to analyze the functionality and the current configuration are listed below.<br />Please note that no personal or financial information will be sent. After you get acquainted with the list of the parameters, click on "Send".<br />'),
('en', 'text_files_directory', 'Directory where product files are located. This will be used if the "File" field is specified without a path.'),
('en', 'text_file_created', 'The file <b>[file]</b> has been successfully created'),
('en', 'text_file_deleted', 'The file <b>[file]</b> has been successfully deleted'),
('en', 'text_file_renamed', 'The file <b>[file]</b> has been successfully renamed to <b>[to_file]</b>'),
('en', 'text_file_restored', 'The file <b>[file]</b> has been restored from the repository'),
('en', 'text_file_saved', 'The file <b>[file]</b> is successfully saved'),
('en', 'text_fill_the_mandatory_fields', 'You need to complete all the mandatory fields'),
('en', 'text_forbidden_file_extension', 'It is not allowed to create/upload/rename files with the <b>.[ext]</b> extension.'),
('en', 'text_forbidden_file_mime', 'It is not allowed to create/upload/rename files of the <b>[mime]</b> MIME type.'),
('en', 'text_forbidden_functionality', '<p>To use this feature, you need a [product] license.</p>'),
('en', 'upgrade_license', 'Upgrade my license'),
('en', 'need_upgrade', 'Need upgrade'),
('en', 'text_forbidden_uploaded_file_extension', 'It is not allowed to upload files with the <b>.[ext]</b> extension. Allowed extensions are: <b>[exts]</b>'),
('en', 'text_forbidden_uploaded_file_size', 'It is not allowed to upload files with size more than <b>[size]</b>'),
('en', 'text_license_required_full', 'Your current CS-Cart edition is Professional. We also offer another one, a more advanced edition—<b>Ultimate</b>. With CS-Cart Ultimate, you''ll be able to use unlimited number of storefronts and the mobile commerce app as well as the eBay Synchronization add-on and the Facebook app without additional fees. To unlock unlimited storefronts and mobile commerce, get the Ultimate license.'),
('en', 'text_license_required_storefronts', 'Add as many storefronts as you want and manage them via a single admin panel.'),
('en', 'text_license_required_facebook', 'Build your store into your Facebook page to get closer to your audience and draw more new customers.'),
('en', 'text_license_required_ebay', 'Boost your sales by selling products presented in your CS-Cart store on the world''s biggest marketplace—eBay.'),
('en', 'text_form_cresecure_notice', 'Please complete your payment below.<br />This is a secure payment page, served from a secure location.'),
('en', 'text_license_required_storefronts-title', 'Unlimited Storefronts'),
('en', 'text_license_required_facebook-title', 'Facebook App'),
('en', 'text_license_required_ebay-title', 'eBay Synchronization'),
('en', 'text_full_mode_required', '<strong>Full mode</strong> required.'),
('en', 'license_required', '[product] license required'),
('en', 'text_gate2shop_notice', '<p>Please set the following values in the Gate2Shop merchant settings:</p><p>Success, failed and canceled URL: <b>[result_url]</b></p><p>Back URL: <b>[back_url]</b></p>'),
('en', 'text_gd_not_avail', 'GD library is <b>not</b> installed on your server. Please contact your hosting provider. <br />Charts can be represented only as tables (chart type "Table").'),
('en', 'text_hsbc_notice', '<b>Client ID  -</b> Your Client ID - a decimal value between 0 and 999999999, or a valid Client alias of the form UK12345678CUR. <br /> Note, the alias is case sensitive. <br /> <b>Important note for UNIX users:</b><br /> Please make sure you have appropriate permissions for the following directory: [cart_dir] (shell command "chmod -R 755").'),
('en', 'text_ideal_basic_notice', '-&nbsp;Log in to your iDEAL account<br />-&nbsp;Click on <u>''Security''</u> in the <u>''Profile''</u> section.<br />-&nbsp;Set the option <u>''Notification''</u> to <b>''XML''</b><br />-&nbsp;Set <u>''Notification URL''</u> to:<br /><b>[return_url]</b><br />-&nbsp;Set <u>''Secret key''</u>. The Secret key is known only to the seller and iDEAL.'),
('en', 'text_images_directory', 'Directory where images are located. This will be used if an image file is specified without a path.'),
('en', 'text_invalid_url', 'You have entered an invalid URL'),
('en', 'text_items_added', 'The items were added successfully'),
('en', 'text_items_updated', 'The items were updated successfully'),
('en', 'text_payment_first_data_notice', 'Please log in to FirstData Connect 2.0 Admin, open the "Administration" tab, click on the "Connect 2.0 Setup" link.<br /> Set the following URL in the "Order Submission Form", "Confirmation Page", "Failure Page" sections: [return_url]<br />'),
('en', 'text_links', 'Text links'),
('en', 'text_login_form', '<h4>Not a registered member?</h4><p>Creating a new account is easy and takes less than a minute.</p>'),
('en', 'text_login_to_add_to_cart', 'This product cannot be added to the<br>cart because you are not logged in.'),
('en', 'text_mail_area_logo', 'Logo for <b>invoices</b>'),
('en', 'text_mandatory_fields', '<p class="mandatory-fields">The fields marked with <span class="required">*</span> are mandatory</p>'),
('en', 'text_max_limit_of_parameters', 'Maximum value of the "limit" field cannot exceed 25 unless the chart type is "Table". Limit of this chart has been corrected.'),
('en', 'text_mb_failed_order', 'No response from Skrill has been received yet, please hold on. Although the order might not be created in the store as long last, it is highly probable that it has been successfully created and processed by Skrill. Please contact the store staff and tell them the order ID as provided by Skrill'),
('en', 'text_min_order_amount_required', 'To continue checkout process your order total must exceed'),
('en', 'text_min_products_amount_required', 'To continue checkout process your order subtotal must exceed'),
('en', 'text_multiprofile_notice', 'One user can have multiple profiles. For example, one for personal orders and another for office needs.'),
('en', 'text_new_user_activation', 'The profile owned by "[user_login]" has been newly created, you should check the details of this user (if required) and activate it by using the following link:<br /><a href="[url]">[url_text]</a>'),
('en', 'text_nothing_found', 'Nothing found'),
('en', 'text_not_allowed_to_upload_file_extension', 'It is not allowed to upload files with the <b>.[ext]</b> extension here.'),
('en', 'text_not_allowed_to_upload_file_size', 'It is not allowed to upload files that exceed the maximum allowed size of [file_size] MB.'),
('en', 'text_not_valid_email', '<b>[email]</b> is not a valid e-mail address.'),
('en', 'text_no_active_promotions', 'No promotions available.'),
('en', 'text_no_conflicts', 'No conflicts found'),
('en', 'text_no_items_defined', 'No [items] defined'),
('en', 'text_no_matching_products_found', 'No products found matching the search criteria'),
('en', 'text_no_matching_results_found', 'No results match the search query'),
('en', 'text_no_orders', 'No orders found'),
('en', 'text_no_payments_needed', 'No payment information required'),
('en', 'text_no_payments_required', 'No payment required'),
('en', 'text_no_products', 'There are no products in this section'),
('en', 'text_no_products_defined', 'No products defined'),
('en', 'text_no_products_found', 'No products found'),
('en', 'selected_filters', 'Selected filters'),
('en', 'text_no_shipments_found', 'No shipments found'),
('en', 'text_no_shipping_methods', 'Sorry, it seems that we have no shipping options available for your location.<br/>Please check your shipping address and contact us if everything is okay. We''ll see what we can do about it.'),
('en', 'text_no_upgrades_available', 'No upgrades currently available'),
('en', 'text_objects_for_export', '<b>[total]</b> [name] will be exported.'),
('en', 'text_ogonedirect_notice', 'Enter SHA-1 Signature both: here and on the Ogone Configuration.<br /><br />For new Ogone accounts created since May 11th, 2010, the new SHA policy is automatically active. <br/>Please do not forget to select the "Use new SHA signature policy" checkbox.'),
('en', 'text_ogoneweb_notice', 'Please set the following URL in the Technical Information section on the Ogone Configuration as a <b>Response Url</b> for all cases ("accepted", "on hold", "uncertain", "canceled by the client", "too many rejections by the acquirer"): <b>[r_url]</b><br /> Also enter SHA-1 Signature both: here and on the Ogone Configuration. Then select Request Type: "Make this request in background and deferred".'),
('en', 'text_options_no_inventory', 'In order to create option combinations, you must have the "Inventory" check box selected for at least one product option.'),
('en', 'text_order_backordered', 'Your order has been backordered. We will contact you at the first opportunity.'),
('en', 'text_order_placed_error', 'Your order has been declined by the payment processor. Please review your information and contact store administration.'),
('en', 'text_order_placed_successfully', 'Congratulations! Your order has been successfully placed.'),
('en', 'text_order_repayed_successfully', 'Order has been repaid successfully.'),
('en', 'text_order_saved_successfully', 'Order has been saved successfully.'),
('en', 'text_order_status_notification', 'Please note that the notification of changing the status  will be sent depending on the settings of this status'),
('en', 'text_out_of_stock', 'Out of stock'),
('en', 'text_pages_cloned', 'The pages have been cloned successfully. Below the list of new pages.'),
('en', 'text_pages_have_been_deleted', 'Pages have been deleted successfully.'),
('en', 'text_page_changed', 'Are you sure you want to leave this page? Your changes have not been saved. Click on OK to continue, or on Cancel to stay on the current page.'),
('en', 'text_page_has_been_deleted', 'Page has been deleted successfully.'),
('en', 'text_page_loading', 'Loading... Your request is being processed, please wait.'),
('en', 'text_password_recovery_instructions_sent', 'Password recovery instructions have been sent to [email] address.'),
('en', 'text_pay4later_notice', '<b>Note</b>: In order to track your Deko orders with the shopping cart software, you have to take these steps:<br /><br />-&nbsp;Log in to Deko BackOffice<br />-&nbsp;Click on the <u>''Settings/Installations''</u> link in the <u>''Quick Links''</u> section.<br />-&nbsp;Set <u>''Return URL (Verified)''</u> setting to:<br /><b>[verified_url]</b><br />-&nbsp;Set <u>''Return URL (Decline)''</u> setting to:<br /><b>[decline_url]</b><br />-&nbsp;Set <u>''Return URL (Refer)''</u> setting to:<br /><b>[refer_url]</b><br />-&nbsp;Set <u>''Return URL (Cancel)''</u> setting to:<br /><b>[cancel_url]</b><br />-&nbsp;Set <u>''CSN URL''</u> setting to:<br /><b>[process_url]</b><br />-&nbsp;Click on the <u>''Save Changes''</u> button<br />'),
('en', 'text_paybox_notice', '<b>Note:</b> Please download the file modulev2.cgi from the PayBox server, copy it to the <b>[paybox_dir]</b> directory <u>in binary mode</u> and make it executable. <br />Run the following command:<br /><b><i>chmod 755 modulev2.cgi</b></i><br /><br />Also ask &#8220;Paybox&#8221; service to add the following URL to the database as &#8220;Callback URL&#8221;:<br /><b>[callback_url]</b>'),
('en', 'text_payment_have_been_deleted', 'Payment have been deleted successfully.'),
('en', 'text_payment_have_not_been_deleted', 'Payment cannot be deleted.'),
('en', 'text_paypal_processing_payment', 'Please wait while processing the payment details...'),
('en', 'text_paysitecash_debug', 'Debug Information'),
('en', 'text_paysitecash_mode', 'Mode'),
('en', 'text_paysitecash_mode_debug_off', 'OFF'),
('en', 'text_paysitecash_mode_debug_on', 'ON'),
('en', 'text_paysitecash_mode_live', 'Live'),
('en', 'text_paysitecash_mode_test', 'Test'),
('en', 'text_paysitecash_nocurrencies', 'Currency mode'),
('en', 'text_paysitecash_nocurrencies_no', 'Allow customer select any of supported currency'),
('en', 'text_paysitecash_nocurrencies_yes', 'Do not show currency selection at all'),
('en', 'text_paysitecash_notice', 'Please add these URL fields in your Paysite-cash configuration:<br/><br/><b>URL:</b><br/>[url]<br/><br/><b>Referer url:</b><br/>[ref_url]<br/><br/><b>after payment return url:</b><br/>[sucess_url]<br/><br/><b>canceled payment url:</b><br/>[cancel_url]<br/><br/><b>Backoffice confirmation url:</b><br/>[confirm_url]'),
('en', 'text_paysitecash_processor', 'Processor'),
('en', 'text_paysitecash_site_id', 'Site ID'),
('en', 'text_payway_notice', 'Please set up the following parameters in PayWay back end: <p> Browser Return URL Pre Payment: <b>[prepayment]</b><br /> Browser Return URL: <b>[return]</b><br /> Notification URL: <b>[notify]</b><br /> Notification Post Type: leave empty </p>'),
('en', 'text_permissions_changed', 'Permissions changed'),
('en', 'text_piraeus_notice', '<b>Note:</b> Please send the following information to the payment support:<br /> Website URL: ''<u>[website_url]</u>''<br /> Referrer URL: ''<u>[referrer_url]</u>''<br /> Success URL: ''<u>[success_url]</u>''<br /> Failure URL: ''<u>[failure_url]</u>''<br /> Backlink URL: ''<u>[backlink_url]</u>''<br /> IP Address: ''<u>[ip_address]</u>''<br /><br /> Response Method: ''<u>[response_method]</u>''<br /><br />'),
('en', 'text_position_updating', 'Loading... Positions are being updated, please wait.'),
('en', 'text_price_dec_sign_delimiter', 'Decimal separator for product prices.'),
('en', 'text_products_added', 'The products have been added successfully. See the list of the new products below.'),
('en', 'text_products_cloned', 'The products have been cloned successfully. Below the list of new products'),
('en', 'text_products_have_been_deleted', 'Products have been deleted successfully.'),
('en', 'text_products_updated', 'The following products have been updated:'),
('en', 'text_products_updated_successfully', 'The product(s) have been updated successfully'),
('en', 'text_product_cloned', 'The product has been cloned'),
('en', 'text_product_detailed_image', '(optional displayed in popup window)'),
('en', 'text_product_file_has_been_deleted', 'Product file has been deleted'),
('en', 'text_product_filters_were_disabled', 'The following <a href="[url]" target="_blank">product filters</a> were disabled: [filters_list].'),
('en', 'text_product_has_been_deleted', 'Product has been deleted successfully.'),
('en', 'text_product_thumbnail', '(displayed on products list and product details pages)'),
('en', 'text_profile_activated', 'Your account is now active. You may log in to your account using your credentials.'),
('en', 'text_profile_benefits', '<h4>Benefits of becoming a registered member</h4><ul><li>Log in at any time to check order statuses</li><li>Personalize your shopping</li><li>Speed up future purchases</li></ul>'),
('en', 'text_profile_details', '<h4>Profile details</h4><p>On this page you can modify your login credentials and personal data to be used during future purchases.</p><p>To keep your account secure we recommend to avoid creating passwords that use:</p><ul><li>Dictionary words in any language.</li><li>Words spelled backwards, common misspellings, and abbreviations.</li><li>Sequences or repeated characters. Examples: 12345678, 222222, abcdefg, or adjacent letters on your keyboard (qwerty).</li><li>Personal information. Your name, birthday, driver''s license, passport number, or similar information.</li></ul>'),
('en', 'text_profile_is_created', 'The account has been created successfully.'),
('en', 'text_profile_is_updated', 'The profile data has been updated successfully.'),
('en', 'text_profile_should_be_approved', 'Your account has been created successfully, but it must be activated by the store administrator before you are able to sign in.'),
('en', 'text_promotions_group_condition', 'If [set] of these conditions are [set_value]'),
('en', 'our_brands', 'Our Brands'),
('en', 'text_qty_discounts', 'Our quantity discounts'),
('en', 'text_recover_password', '<p>If you have forgotten your password, enter your email address in the field and click <i>Reset password</i>.</p><p>You will receive a new password and a link to sign in. You will be able to change the password later.</p>'),
('en', 'text_recover_password_notice', 'Enter your email address to receive a new login key and a link to sign in and change your password.'),
('en', 'text_recover_password_title', 'Reset password'),
('en', 'text_remove_additional_images', 'When importing additional images of an updated product, existing images of this product will be deleted before import'),
('en', 'text_remove_backup_files', 'Warning! If you remove the backup files, you will not be able to restore your previous installation. Ensure that the new version is working properly, and the backup database files are in a safe place.'),
('en', 'text_required_group_product', 'Please select a product for the required group [group_name]'),
('en', 'text_reset_inventory_description', 'Quantity of all products in the store will be reset.'),
('en', 'text_restore_question', 'Are you sure that you want to restore the template?'),
('en', 'text_sagepay_dir_notice', '<b>Note:</b> In order to track your Opayo orders by the shopping cart software, please enable the 3D Secure Fraud Checking Option for your Opayo VSP Direct account.'),
('en', 'text_sagepay_notice', 'Use <b>testvendor</b> as <b>Vendor Name</b> for the testing purposes<br /><p><b>PAYMENT</b> - transaction type is used to gain an authorisation from the bank, then settle that transaction early the following morning, committing the funds to be taken from your customer''s card.<br /></p><p><b>DEFERRED</b> - transactions are NOT sent to the bank for completion until you RELEASE them by logging into the Opayo VSP Admin interface, finding the transaction and clicking the Release button.</p>'),
('en', 'text_secret_key_notice', 'Please complete this field with any non-empty value. It will increase the security of transactions.'),
('en', 'text_select_fields2edit_note', 'You are able to modify several items at once. Select the check boxes corresponding to the fields you wish to edit, and click on Modify Selected.'),
('en', 'text_select_file', 'Select a file or enter a URL'),
('en', 'text_select_range', 'You can select a range to export (otherwise all [name] will be exported)'),
('en', 'text_share_product_features_tooltip', 'Attention! Some data will not be copied during this operation: the categories set in filters will be lost even if you copy all categories. Please, fix categories manually.'),
('en', 'text_share_product_filters_tooltip', 'Attention! Some data will not be copied during this operation: the categories set in features will be lost even if you copy all categories. Please, fix categories manually.'),
('en', 'text_share_promotions_tooltip', 'In order to share promotions make sure the respective products are also shared (check Share products below)'),
('en', 'text_shipping_packages_info', 'To ensure a more precise shipping rate estimation, the products have been separated into packages as defined by the product settings and the shipping method configuration. The following info is for referential use only'),
('en', 'text_shipping_rates_changed', 'Shipping rates were changed'),
('en', 'text_ship_to_billing', 'Order will be delivered to the billing address'),
('en', 'text_skrill_activate_quick_checkout_short_explanation', 'Skrill Merchant Tools enables you to take payments from credit cards, debit cards and over 60 other local payment options in over 200 countries. The highly competitive rates for this service are published on the Skrill website at www.skrill.com.'),
('en', 'text_skrill_activate_quick_checkout_short_explanation_1', 'You have sent a request for activation on the [date]. Please be aware that the verification process to use Skrill Merchant Tools could take up to 72 hours. You will be contacted by Skrill when the verification process has been completed.'),
('en', 'text_skrill_activate_quick_checkout_short_explanation_2', 'After activation Skrill will grant you access to a new section in your Skrill Account called Merchant Tools. There please choose a secret word (NOT the same as your password) and enter it in the section below to connect to Skrill. The secret word is the last step of your activation process and encrypts your payments securely. After successful submission you will be ready to use all the direct payment options of Skrill.'),
('en', 'text_skrill_currs_notice', 'If you selected a currency that is not the base one in your store, please make sure that it has the correct <a href="http://en.wikipedia.org/wiki/ISO_4217">ISO 4217 code</a> on the <a href="[link]">currencies</a> page.'),
('en', 'text_skrill_email_is_not_registered', 'Specified email address is not registered in Skrill.'),
('en', 'text_skrill_email_is_registered', 'Specified email address is registered in Skrill.'),
('en', 'text_skrill_empty_input_data', 'Some of the fields required for Quick Checkout activation are missing. Please check.'),
('en', 'text_skrill_logo_notice', 'If your HTTPS server is not set up, the logo will be passed by the HTTP protocol and users will see the "Connection Partially Encrypted" warning on the Skrill page.'),
('en', 'text_skrill_notice', 'To gain access to the international payment network of Skrill, please register <a href="[register_url]" target="_blank">here</a> for a free account if you do not have one yet.<p><strong>Attention</strong>: please save settings before validating email, secret word or activating merchant tools.</p>'),
('en', 'text_skrill_notice_register', 'To gain access to the international payment network of Skrill, please register <a href="[register_url]" target="_blank">here</a> for a free account if you do not have one yet.<p><strong>Attention</strong>: please save settings before activating merchant tools.</p>'),
('en', 'text_skrill_payment_is_not_saved', 'In order to use this feature, please save the payment method first.'),
('en', 'text_skrill_secred_word_notice', 'The secret word must be in lower case without special characters and at least 10 digits long.'),
('en', 'text_skrill_secret_word_is_correct', 'Specified secret word is correct.'),
('en', 'text_skrill_secret_word_is_incorrect', 'Your secret word is incorrect. Please choose your secret word in the Merchant Tools section of your Skrill Account and then enter it here.'),
('en', 'text_skrill_support', '<b>Support:</b> <br /><br /> Do you have questions?<br /> Contact Skrill on <a href="mailto:">ecommerce@skrill.com</a> or by phone +4408703830762.<br />'),
('en', 'text_status_is_float', 'You cannot use time interval for the "Status" parameter because this parameter is time dependent.'),
('en', 'text_storage_changed', 'Storage changed successfully'),
('en', 'text_store_mode_changed_to_full', '<strong>Full mode</strong> has been activated. In this mode, all the advanced eCommerce features are available.'),
('en', 'text_store_mode_closed', 'The store was <b>closed</b>'),
('en', 'text_store_mode_full', '<p>Full unrestricted access to all features. Enter a valid license number to activate.</p><p>This mode can be activated at any time.</p><br />'),
('en', 'text_store_mode_opened', 'The store was <b>opened</b>'),
('en', 'text_store_mode_open', 'The store was <b>opened</b>'),
('en', 'text_store_mode_trial', '<p>Full access to all features during the 30-day trial period, starting from the time of activation.</p><p>Once the 30-day trial period expires, you''ll have to <a href="[product_buy_url]" target="_blank">purchase a license</a> or enter a valid license number to be able to manage your store.</p>'),
('en', 'text_store_mode_trial_rb', 'All features are available during 30 days after download of the installation package. You don''t need to enter the license key.<br /><br />After the 30-day trial period is over, you need to buy the license or enter the license key if you already have one.<br /><br />'),
('en', 'text_tax_applied', 'The tax <b>[tax]</b> has been applied to all products'),
('en', 'text_tax_unset', 'The tax <b>[tax]</b> has been removed from all products'),
('en', 'text_template_changed', 'Your changes have not been saved.Press OK to save changes or Cancel to discard them.'),
('en', 'text_thaiepay_notice', '<p>Please set the following values in the ThaiePay merchant settings:</p><p>Return Url: <b>[return_url]</b></p><p>Status: <b>Yes (it is important!)</b></p><p>Post Back Url: <b>[postback_url]</b></p><p>Main Parameter: <b>"total" must be checked</b> - it will increase the security of transactions</p><p>Additional Parameter: it is obligatory for successful processing of transactions. For example, you can set <b>name=completed</b> and <b>value=some_secret_word</b>. Copy these values to these form fields: "Additional parameter Name" and "Additional parameter Value".</p>'),
('en', 'text_thumbnail_manual_loading', 'Thumbnails will be generated from detailed images automatically, but you can also <a id="[id]" class="[class]">upload them manually.</a>'),
('en', 'text_tinymce', 'TinyMCE'),
('en', 'text_topmenu_more', 'More [item] <i class="text-arrow">&rarr;</i>'),
('en', 'text_topmenu_view_more', 'View more <i class="text-arrow">&rarr;</i>'),
('en', 'text_track_instructions_sent', 'Access instructions were sent to your e-mail address.'),
('en', 'text_track_request', 'You requested information on the orders you placed in our store.'),
('en', 'text_track_view_all_orders', 'To view all your orders, please follow this link:'),
('en', 'text_track_view_order', 'To view order #[order] please open this link:'),
('en', 'text_transaction_cancelled', 'Transaction was canceled by the customer'),
('en', 'text_transaction_declined', 'Transaction was declined by the payment processor or was canceled by the customer'),
('en', 'text_uc_another_update_process_running', 'Possibly another upgrade process is running.<br />Please wait until it is finished.<br />If the process has finished with an error, you can remove the file [filename] and try to restart the upgrade.<br /><a href="[url]">Remove the lock file and restart the upgrade</a>'),
('en', 'text_uc_backup_database', 'The following database tables have been backed up'),
('en', 'text_uc_backup_files', 'The following files have been backed up'),
('en', 'text_uc_broken_package', 'The upgrade package seems to be broken. Please refresh packages list and try to download it again'),
('en', 'text_uc_cannot_lock_upgrade_process', 'Failed to disable upgrade process launching'),
('en', 'text_uc_cant_download_package', 'Cannot download the upgrade package'),
('en', 'text_uc_changed_files_message', 'These files have local modifications and will be backed up. Once the upgrade is complete, compare the backup files with the new files and reapply the modifications to the new files, if necessary.'),
('en', 'text_uc_check_ok', 'Your [product] version has been checked successfully. It is ready for upgrade.'),
('en', 'text_uc_conflicts', 'The following files had local modifications'),
('en', 'text_uc_db_right_needed', 'Not enough permissions to update database. Please assign the following privileges to your database user [db_user]: [priviliges].'),
('en', 'text_uc_emergency_restore', 'Attention! Please copy and save the URL below - you can use it to restore your store if upgrade fails.<br /><b>[href]</b>'),
('en', 'text_uc_failed_to_backup_tables', 'The database tables have not been backed up'),
('en', 'text_uc_failed_to_create_directory', 'Failed to create a new directory'),
('en', 'text_uc_failed_to_ftp_copy', 'FTP transfer failed'),
('en', 'text_uc_ftp_cart_directory_not_found', 'We were unable to find CS-Cart installation in the specified directory. Please make sure that you have entered the correct FTP directory.'),
('en', 'text_uc_ftp_connection_failed', 'FTP connection failed'),
('en', 'text_uc_ftp_connect_failed', 'Cannot connect to FTP server. Please check if the host name is correct'),
('en', 'text_uc_ftp_login_failed', 'Cannot log in to FTP server. Please check if username and password are correct'),
('en', 'text_uc_ftp_needed', 'FTP credentials to access the files and set proper permissions automatically'),
('en', 'text_uc_has_conflicts', 'Some of your files had local modifications. You can check them by clicking the following link'),
('en', 'text_uc_incorrect_upgrade_path', 'Wrong path to upgrade files'),
('en', 'text_uc_license_number_required', 'Please enter your [product] license number'),
('en', 'text_uc_list_of_updates_missing', 'List of upgrades is missing'),
('en', 'text_uc_non_writable_files', 'These files require write permissions set (manually or automatically via FTP)'),
('en', 'text_uc_no_enough_space_to_backup_database', 'Insufficient disk space to back up the database'),
('en', 'text_uc_no_ftp_module', 'It seems that no FTP module is installed on your server. You cannot use FTP until this module is installed'),
('en', 'text_uc_unable_to_create_upgrade_folder', 'Failed to create an upgrade folder'),
('en', 'text_uc_unable_to_parse_uc_xml', 'Failed to parse the upgrade process descriptor uc.xml'),
('en', 'text_uc_unable_to_remove_file', 'Failed to remove the file'),
('en', 'text_uc_unable_to_remove_packages_xml', 'Failed to remove the upgrade descriptor packages.xml'),
('en', 'text_uc_unable_to_remove_upgrade_lock', 'Failed to remove the upgrade lock file. Please remove the [file] file.'),
('en', 'text_uc_unable_to_update_list_of_installed_upgrades', 'Failed to update the list of installed upgrades'),
('en', 'text_uc_upgrade_completed', 'Your store has been upgraded successfully'),
('en', 'text_uc_upgrade_completed_check_and_open', '<p>Your store was closed during the upgrading procedure. We recommend you to check the work of the store after the upgrade and only then open it.</p><p>You can open the store by unchecking the Close storefront setting under Settings → General.</p>'),
('en', 'text_uc_upgrade_log_file_not_writable', 'Upgrade log file is not writable'),
('en', 'text_uc_upgrade_needed', 'You need to upgrade to version <b>[to_version]</b> before applying this upgrade package (your version is <b>[your_version]</b>).'),
('en', 'text_uc_upgrade_not_selected', 'No upgrade package is selected'),
('en', 'text_uc_upgrade_reverted', 'The upgrade has been reverted successfully'),
('en', 'text_ult_product_store_field_tooltip', 'Product owner. Only product owner can edit all fields in shared products.'),
('en', 'text_unable_to_parse_xml', 'Failed to parse XML structure'),
('en', 'text_unsupported_currency', 'The currency which is not supported by the payment system is used on the website. Please contact the store administrator regarding this issue.'),
('en', 'text_upgrade_available', 'A new version of [product] is available. If you want to upgrade to the latest version now, click <a href="[link]">here</a>.'),
('en', 'text_usergroup_activated', 'The following user groups have been activated for your account: [usergroups].'),
('en', 'text_usergroup_disactivated', 'The following user groups have been removed from your account: [usergroups].'),
('en', 'text_usergroup_request', 'Customer requested user group.'),
('en', 'text_usergroup_requested_by', 'The <b>[usergroup]</b> group was requested by [name] ([email]).'),
('en', 'text_worldpay_notice', 'Configure your Worldpay account before using the payment.<br /><br />Go to the Worldpay administration page and switch to the Installation section.<br /><br />Fill the fields as follows:<br /><br />Payment Response URL: <b>[return_url]</b><br />Payment Response Password: <b>Make up a secret word.</b> The same word must be entered in the respective field below<br />MD5 secret for transactions: <b>Make up a secret word.</b> The same word must be entered in the respective field below<br />SignatureFields: <b>instId:amount:currency:cartId</b>'),
('en', 'text_zipcodes_wildcards', 'You are able to use wildcards in this field:<br /><b>''?''</b> - any single character;<b>''*''</b> - any number of characters.<br /><br /><u>Example:</u><br /><b>98?78</b> &nbsp;&nbsp;(corresponds to 98878, 98378, 98978, etc)<br /><b>12*</b>&nbsp;&nbsp; (corresponds to 12345, 12876, 12098, etc..)'),
('en', 'theme', 'Theme'),
('en', 'themes', 'Themes'),
('en', 'theme_directory', 'Theme directory'),
('en', 'theme_editor', 'Theme editor'),
('en', 'theme_editor.background', 'Background'),
('en', 'theme_editor.backgrounds', 'Backgrounds'),
('en', 'theme_editor.background_color', 'Background color'),
('en', 'theme_editor.base_color', 'Base'),
('en', 'theme_editor.body_font', 'Body'),
('en', 'theme_editor.browse', 'Browse'),
('en', 'theme_editor.buttons_font', 'Buttons'),
('en', 'theme_editor.close', 'Close theme editor'),
('en', 'theme_editor.color', 'Color'),
('en', 'theme_editor.colors', 'Colors'),
('en', 'theme_editor.background_image', 'Background image'),
('en', 'theme_editor.color_gen_algorithm', 'Colors combination'),
('en', 'theme_editor.color_gen_analogic', 'Analogic'),
('en', 'theme_editor.color_gen_base_color', 'Base color'),
('en', 'theme_editor.color_gen_contrast', 'Contrast'),
('en', 'theme_editor.color_gen_dark_pastel', 'Dark pastel'),
('en', 'theme_editor.color_gen_default', 'Default'),
('en', 'theme_editor.color_gen_light_pastel', 'Light pastel'),
('en', 'theme_editor.color_gen_monochromatic', 'Monochromatic'),
('en', 'theme_editor.color_gen_pale', 'Pale'),
('en', 'theme_editor.color_gen_pastel', 'Pastel'),
('en', 'theme_editor.color_gen_title', 'Generate colors'),
('en', 'theme_editor.color_gen_triad', 'Triad'),
('en', 'theme_editor.color_gen_variant', 'Variation'),
('en', 'theme_editor.color_gen_vcontrast', 'Contrast'),
('en', 'theme_editor.content_bg', 'Content'),
('en', 'theme_editor.css', 'Custom CSS'),
('en', 'theme_editor.customize', 'Customize'),
('en', 'theme_editor.decorative_color', 'Decorative'),
('en', 'theme_editor.discount_label', 'Discount label'),
('en', 'theme_editor.error_style_exists', 'The style with this name is already exist. Please choose another one.'),
('en', 'theme_editor.favicon', 'Favicon'),
('en', 'theme_editor.favicon_size', 'Favicon size must be 16x16 px'),
('en', 'theme_editor.fixed', 'Fixed'),
('en', 'theme_editor.font', 'Font'),
('en', 'theme_editor.fonts', 'Fonts'),
('en', 'theme_editor.font_color', 'Font'),
('en', 'theme_editor.footer', 'Footer'),
('en', 'theme_editor.footer_text', 'Footer text'),
('en', 'theme_editor.full_width', 'Full width'),
('en', 'theme_editor.general', 'General'),
('en', 'theme_editor.general_bg', 'General'),
('en', 'theme_editor.gradient', 'Gradient'),
('en', 'theme_editor.header', 'Header'),
('en', 'theme_editor.headings_font', 'Headings'),
('en', 'theme_editor.hide_show', 'Hide/show theme editor panel'),
('en', 'theme_editor.incorrect_style_name', 'Style name can not contain the following characters: "/ # % ? * : ; { } \\ + "'),
('en', 'theme_editor.in_stock', 'In stock'),
('en', 'theme_editor.links_font', 'Links'),
('en', 'theme_editor.link_color', 'Links'),
('en', 'theme_editor.logos', 'Logos'),
('en', 'theme_editor.mail', 'Mail'),
('en', 'theme_editor_logo.mail', 'E-mails'),
('en', 'theme_editor.main', 'Main content'),
('en', 'theme_editor.max_image_size', 'The image must not be bigger than 200 kB.'),
('en', 'theme_editor.menu_color', 'Menu'),
('en', 'theme_editor.menu_links_color', 'Menu links'),
('en', 'theme_editor.middle_bg', 'Middle'),
('en', 'theme_editor.no_repeat', 'No repeat'),
('en', 'theme_editor.off', 'Off'),
('en', 'theme_editor.on', 'On'),
('en', 'theme_editor.out_of_stock', 'Out of stock'),
('en', 'theme_editor.pattern', 'Pattern'),
('en', 'theme_editor.position', 'Position'),
('en', 'theme_editor.styles', 'Styles'),
('en', 'theme_editor.style', 'Style'),
('en', 'theme_editor.color_scheme', 'Color scheme'),
('en', 'theme_editor.style_data_cannot_be_saved', 'Style data cannot be saved. You should set write permissions for <b>[theme_dir]</b> directory to fix this issue.'),
('en', 'theme_editor.style_name', 'Style name'),
('en', 'theme_editor.price', 'Price'),
('en', 'theme_editor.price_font', 'Price tag'),
('en', 'theme_editor.primary_button', 'Primary button'),
('en', 'theme_editor.tertiary_button', 'Tertiary button'),
('en', 'theme_editor.repeat', 'Repeat'),
('en', 'theme_editor.repeat_x', 'Repeat x'),
('en', 'theme_editor.repeat_y', 'Repeat y'),
('en', 'theme_editor.reset_backgrounds', 'Reset backgrounds'),
('en', 'theme_editor.reset_colors', 'Reset colors'),
('en', 'theme_editor.reset_css', 'Reset CSS'),
('en', 'theme_editor.reset_fonts', 'Reset fonts'),
('en', 'theme_editor.reset_general', 'Reset general'),
('en', 'theme_editor.reset_logos', 'Reset logos'),
('en', 'theme_editor.rounded_corners', 'Rounded corners'),
('en', 'theme_editor.scroll', 'Scroll'),
('en', 'theme_editor.secondary_button', 'Secondary button'),
('en', 'theme_editor.sidebar', 'Sidebar'),
('en', 'theme_editor.text_align', 'Text alignment'),
('en', 'theme_editor.text_close_editor', 'Are you sure to exit the theme editor?'),
('en', 'theme_editor.text_close_editor_unsaved', 'You have unsaved changes. Are you sure to exit from theme editor?'),
('en', 'theme_editor.text_reset_changes', 'All changes after last save will be reset'),
('en', 'theme_editor.theme', 'Theme'),
('en', 'theme_editor_logo.theme', 'Theme'),
('en', 'theme_editor.top_panel', 'Top panel'),
('en', 'theme_editor.top_panel_links', 'Top panel links'),
('en', 'theme_editor.top_panel_text', 'Top panel text'),
('en', 'theme_editor.transparent', 'Transparent'),
('en', 'theme_editor.upload_image', 'Upload image'),
('en', 'theme_editor.enable', 'Enable Theme editor'),
('en', 'theme_editor.system_fonts', 'System fonts'),
('en', 'theme_editor.popular_fonts', 'Popular fonts'),
('en', 'theme_editor.other_fonts', 'Other fonts'),
('en', 'theme_editor_mode', 'Theme editor mode'),
('en', 'theme_editor.checkout_selected_control_border', 'Checkout: Selected payment / shipping method border'),
('en', 'theme_editor.checkout_active_selector_border', 'Checkout: Active selector border'),
('en', 'theme_editor.checkout_control_border', 'Checkout: Payment / shipping method border'),
('en', 'theme_editor.checkout_selector_border', 'Checkout: Selector border'),
('en', 'theme_editor.checkout_input_border', 'Checkout: Field border'),
('en', 'theme_editor.checkout_selected_input_border', 'Checkout: Selected field border'),
('en', 'theme_editor.checkout_step_title', 'Checkout: Step title'),
('en', 'theme_editor.checkout_input_text', 'Checkout: Text in fields'),
('en', 'theme_editor.checkout_input_label', 'Checkout: Field label'),
('en', 'theme_editor.checkout_control_background', 'Checkout: Payment / shipping method background'),
('en', 'theme_editor.checkout_selector_background', 'Checkout: Selector background'),
('en', 'theme_editor.checkout_selected_control_background', 'Checkout: Selected payment / shipping method background'),
('en', 'theme_editor.checkout_active_selector_background', 'Checkout: Active selector background'),
('en', 'theme_editor.checkout_control_title', 'Checkout: Payment / shipping method title'),
('en', 'theme_editor.checkout_selector_title', 'Checkout: Selector title');
INSERT INTO `[[dbprefix]]language_values` VALUES
('en', 'theme_editor.checkout_control_description', 'Checkout: Payment / shipping method description'),
('en', 'theme_editor.checkout_selector_tooltip', 'Checkout: Selector tooltip'),
('en', 'theme_editor.checkout_control_label', 'Checkout: Credit card field names'),
('en', 'theme_editor.checkout_terms_background', 'Checkout: "Terms and conditions" section background'),
('en', 'theme_editor.checkout_link', 'Checkout: Link'),
('en', 'admin_panel.block_manager', 'Editing layout'),
('en', 'theme_editor.create_style_first', 'You cannot modify this parameter for default styles. Create a new one first'),
('en', 'backoffice_color_scheme.dark_mode', 'Dark theme'),
('en', 'backoffice_color_scheme.light_mode', 'Light theme'),
('en', 'backoffice_color_scheme.system_mode', 'System theme'),
('en', 'the_test_transaction', 'This is a TEST transaction'),
('en', 'this_day', 'This day'),
('en', 'this_month', 'This month'),
('en', 'this_week', 'This week'),
('en', 'this_year', 'This year'),
('en', 'ths_sign', 'Ths sign'),
('en', 'thumb', 'Thumbnail'),
('en', 'thumbnail', 'Thumbnail'),
('en', 'thumbnails', 'Thumbnails'),
('en', 'thumbnails_removed', 'Thumbnails have been removed'),
('en', 'thumbnail_width', 'Thumbnail width in scroller'),
('en', 'image_file_size_set_to_server_setting', 'Image file size set to [file_size] MB. This is the largest file size allowed by the server settings.'),
('en', 'tier_account', 'tier account'),
('en', 'time', 'Time'),
('en', 'timeout', 'Timeout'),
('en', 'Timestamp', 'Timestamp'),
('en', 'time_interval', 'Time interval'),
('en', 'time_unlimited_download', 'Time-unlimited download'),
('en', 'title', 'Title'),
('en', 'tmpl_copyright', 'Copyright information'),
('en', 'tmpl_logo', 'Store logo'),
('en', 'tmpl_payment_icons', 'Payment systems icons'),
('en', 'tmpl_quick_links', 'Quick links'),
('en', 'tmpl_search', 'Search field'),
('en', 'to', 'TO'),
('en', 'today', 'Today'),
('en', 'tools', 'Tools'),
('en', 'tools_addons_current_state', 'Current state'),
('en', 'tools_addons_no_addons', 'No add-ons'),
('en', 'tools_addons_no_third_party_addons', 'No third party add-ons'),
('en', 'tooltip', 'Tooltip'),
('en', 'container_not_used', 'This container is NOT used. "[container]" container from the default location will be used instead. Set this location as default to use this container as "[container]" for all locations.'),
('en', 'top_panel', 'Top panel'),
('en', 'total', 'Total'),
('en', 'totally_paid', 'Total paid'),
('en', 'totals', 'Totals'),
('en', 'total_amount', 'Total amount'),
('en', 'total_cost', 'Total cost'),
('en', 'total_items', 'Total items'),
('en', 'total_price', 'Total price'),
('en', 'total_product_cost', 'Total product cost'),
('en', 'total_results', 'Total results'),
('en', 'to_all_subcats', 'Apply to all subcategories'),
('en', 'to_date', 'Date through'),
('en', 'to_fixed', 'to fixed amount'),
('en', 'to_percentage', 'to percentage of the original price'),
('en', 'tpe', 'TPE'),
('en', 'track', 'Track'),
('en', 'tracking_num', 'Tracking number'),
('en', 'tracking_number', 'Tracking number'),
('en', 'tracks', 'Identifier'),
('en', 'track_my_order', 'Track my order(s)'),
('en', 'track_orders', 'Track orders'),
('en', 'track_request_subj', 'Order tracking'),
('en', 'track_without_options', 'Track without options'),
('en', 'track_with_options', 'Track with options'),
('en', 'TransactionDateTime', 'TransactionDateTime'),
('en', 'transaction_approved', 'Transaction approved'),
('en', 'transaction_cancelled', 'Transaction was canceled'),
('en', 'transaction_declined', 'Transaction declined'),
('en', 'transaction_id', 'Transaction ID'),
('en', 'transaction_datetime', 'Transaction date'),
('en', 'transaction_key', 'Transaction key'),
('en', 'transaction_password', 'Transaction password'),
('en', 'transaction_type', 'Transaction type'),
('en', 'transaction_url', 'Transaction URL'),
('en', 'translate', 'Translate'),
('en', 'translations', 'Translations'),
('en', 'edit_texts', 'Edit texts'),
('en', 'tree', 'Tree'),
('en', 'trial', 'Trial'),
('en', 'trial_mode_mve_disabled', 'Trial mode is not available anymore since you have a valid license activated for this installation'),
('en', 'trial_mode_ult_disabled', 'Trial mode cannot be activated'),
('en', 'trial_notice', 'Your store is in the Trial mode.<br /><br />When the 30-day trial period expires, you''ll have to enter a valid license number to be able to manage your store.<br /><br />To dismiss this message permanently, and to access to the Administration panel after the trial period is over, purchase a license and <a class="cm-dialog-opener cm-dialog-auto-size" data-ca-target-id="store_mode_dialog">activate the Full mode</a>.'),
('en', 'trial_expired', 'Your [product] trial period has expired'),
('en', 'text_input_license_code', 'Please enter your license number to be able to manage your store:'),
('en', 'text_buy_new_license', 'If you don''t have a license number yet, you can purchase it at our official website.'),
('en', 'buy_license', 'Purchase a license'),
('en', 'true', 'True'),
('en', 'tt_views_shippings_update_delivery_time', 'The delivery time appears next to the name of the shipping method. If you use realtime shipping rate calculation, your shipping service may provide its own delivery time. The time provided by the shipping service will be displayed instead of the time you specify here.'),
('en', 'ttc_page_title', 'Page title displayed on a browser panel.'),
('en', 'ttc_popularity', 'Product popularity rating based on how many times the storefront has been viewed, number of additions to cart and number of purchases.'),
('en', 'ttc_search_words', 'Enter a few words here, and the product will appear in the results of the built-in search for those words, even if the product name or description doesn''t have them. Separate different search words by commas.'),
('en', 'ttc_storefront_url', 'All the storefronts domain names must be associated with the same IP-address. Note: Switch to "All stores" to edit'),
('en', 'ttc_stores_status', 'ON—the storefront is open; everyone will see it. OFF—the storefront is closed; only those who have the access key will be able to see it.'),
('en', 'access_for_authorized_customers_only', 'Access for authorized customers only'),
('en', 'tts_activate_menu_tab_for', 'The menu item will be shown activated for the specified dispatch.'),
('en', 'tts_generate_submenu', 'The submenu will include child elements of the selected object.'),
('en', 'tts_link_text', 'Target URL. May be an external URL, an inner store URL or a dispatch.'),
('en', 'tts_menu_user_class', 'User-defined CSS class will be added to the menu item, so this will allow to define the menu item with its own CSS style.'),
('en', 'tt_views_block_manager_update_block_override_by_this', 'If you save the block with this option checked, the current block content value will override the content of this block everywhere it is used in the cart'),
('en', 'tt_views_block_manager_update_block_width', 'Block width works for blocks located in the group having horizontal direction, for other cases this parameter does not work.'),
('en', 'tt_views_block_manager_update_location_default', 'One location must be picked as default. Its Top and Bottom containers will be used in all locations.'),
('en', 'tt_views_cart_components_carts_search_form_online_only', 'If enabled, search results include only users who are online at the moment.'),
('en', 'tt_views_currencies_update_after_sum', 'If enabled, the symbol of the currency is shown after the sum.'),
('en', 'tt_views_currencies_update_decimals', 'Number of digits after the decimal sign.'),
('en', 'tt_views_currencies_update_dec_sign', 'Decimal separator.'),
('en', 'tt_views_currencies_update_ths_sign', 'Thousand separator.'),
('en', 'tt_views_database_manage_backup_data', 'If enabled, the database backup file includes the actual table data.'),
('en', 'tt_views_database_manage_backup_schema', 'If enabled, the database backup file keeps the table structure.'),
('en', 'tt_views_exim_export_output', 'Choose an action on the file: "Direct download" - to save the file on the local computer, "Screen" - to display the file''s contents, "Server" - to save the file on the server file system.'),
('en', 'tt_views_languages_manage_language_code', 'Two-letter code of the language.'),
('en', 'tt_views_languages_update_country', 'The flag of this country will be used as language icon.'),
('en', 'tt_views_orders_components_orders_search_form_customer_files', 'If enabled, the search results will contain the orders for which customers loaded their own files.'),
('en', 'tt_views_payments_update_surcharge_title', 'Leave empty to use the ''Payment surcharge'' as a title'),
('en', 'tt_views_payments_update_template', 'Template responsible for displaying supplementary fields for the payment method.'),
('en', 'tt_views_products_components_products_shipping_settings_items_in_box', 'Use this field to define the minimum and maximum number of product items to be shipped in a separate box. Enter a non-zero value and specify the box dimensions below.'),
('en', 'tt_views_products_components_products_shipping_settings_weight', 'Non-downloadable products with zero weight are handled as having minimal possible non-zero weight'),
('en', 'tt_views_products_update_categories', 'Categories to be displayed in the navigation breadcrumbs.'),
('en', 'tt_views_products_update_images', 'The maximum size of image files is [file_size] MB.'),
('en', 'tt_views_products_update_inventory', 'Track in stock product quantity. Enable the "Enable inventory tracking" option (Settings -> General) to modify.'),
('en', 'tt_views_products_update_list_price', 'Manufacturer suggested retail price.'),
('en', 'tt_views_products_update_out_of_stock_actions', '''Buy in advance'' lets customers buy out-of-stock products and products that will be available since a specific date. ''Sign up for notification'' works only when the product has zero or negative quantity.'),
('en', 'tt_views_product_features_update_feature_display_on_catalog', 'Show this feature on product list pages along with product description.'),
('en', 'tt_views_product_features_update_feature_display_on_product', 'If enabled, the product feature is displayed on the product details page in the storefront'),
('en', 'tt_views_product_features_update_prefix', 'An affix that precedes the product feature.'),
('en', 'tt_views_product_features_update_suffix', 'An affix that follows the product feature.'),
('en', 'tt_views_product_options_update_incorrect_filling_message', 'Message that is displayed if the entered data is incorrect.'),
('en', 'tt_views_product_options_update_inner_hint', 'A note that indicates the value to be entered.'),
('en', 'tt_views_product_options_update_inventory', 'If enabled, the option is taken into account when forming the product inventory.'),
('en', 'tt_views_product_options_update_regexp', 'Regular expression specifying a pattern to match.'),
('en', 'tt_views_promotions_update_stop_other_rules', 'If enabled, the other promotions are not applied.'),
('en', 'tt_views_sales_reports_table_time_interval', 'Periods to analyze (day, week, month, year).'),
('en', 'tt_views_sales_reports_update_table_dependence', 'Parameter to sort values by. It should relate to the Value to display param (e.g. Product costs—Total cost or Number of products—Number of items).'),
('en', 'tt_views_sales_reports_update_table_limit', 'Max number of chart components.'),
('en', 'tt_views_site_layout_logos_alt_text', 'Leave empty to use company name as alternative text.'),
('en', 'tt_views_storage_cdn_cname', 'Domain name that you want to use instead of the CloudFront domain name for the URLs for your files. You also need to create a CNAME record with your DNS service to route queries to CloudFront host (it will be displayed on this page after you enter account information).'),
('en', 'tt_views_storage_cdn_key', 'AWS Access Key ID. See <a href="https://docs.aws.amazon.com/powershell/latest/userguide/pstools-appendix-sign-up.html" target="_blank">https://docs.aws.amazon.com</a> to learn how to get key and secret key.'),
('en', 'tt_views_taxes_update_regnumber', 'Registration number of this tax in the store.'),
('en', 'turkish', 'Turkish'),
('en', 'type', 'Type'),
('en', 'type_comments_here', 'You can leave us a comment here'),
('en', 'uc_ok', 'OK'),
('en', 'uk_cookies_law', 'Cookies are used on this site to provide the best user experience. If you continue, we assume that you agree to receive cookies from this site. <span class="button button-wrap-left"><span class="button button-wrap-right"><a rel="nofollow" href="[url]">OK</a></span></span>'),
('en', 'ult_share_users_setting_disabled', 'The setting value can not be changed as identical email addresses are registered in your store.'),
('en', 'unable_delete_vendor_orders_exists', 'Unable to delete this store because there are orders containing the products of this company in the store database. To delete the account, please delete all such orders first.'),
('en', 'unable_to_assign_usergroup', 'Unable to assign the usergroup. Please contact the shop administrator.'),
('en', 'unable_to_check_license', 'Unable to check your license number'),
('en', 'unable_to_delete_setting_description', 'Unable to delete setting description: [reason]'),
('en', 'unable_to_delete_setting_variant', 'Unable to delete setting_variant: [reason]'),
('en', 'unable_to_read_resource', 'Unable to read resource: [file]'),
('en', 'unable_to_update_setting_description', 'Unable to set description: [reason]'),
('en', 'unable_to_update_setting_value', 'Unable to set value: [reason]'),
('en', 'unable_to_unpack_file', 'Unable to decompress file'),
('en', 'ungroupped_features', 'Ungrouped features'),
('en', 'uninstall', 'Uninstall'),
('en', 'unique_html_block', 'Unique HTML block'),
('en', 'unit', 'Unit'),
('en', 'united_kingdom', 'United Kingdom'),
('en', 'unit_price', 'Unit price'),
('en', 'unknown', 'Unknown'),
('en', 'unknown_server_response', 'Unknown server response'),
('en', 'unmark', 'Unmark'),
('en', 'unregistered_customer', 'Unregistered customer'),
('en', 'unregistered_customer_short', 'Unregistered'),
('en', 'unselect_all', 'Unselect all'),
('en', 'unset_tax_to_products', 'Remove selected taxes from all products'),
('en', 'unsubscribe', 'Unsubscribe'),
('en', 'up', 'Up'),
('en', 'update', 'Update'),
('en', 'update_categories', 'Update categories'),
('en', 'update_customer_info', 'Update customer information'),
('en', 'update_for_all_act', 'New value will be saved for ALL stores which share this item. Click to save it only for the owner-store.'),
('en', 'update_for_all_dis', 'New value will be saved ONLY for the owner-store. Click to save it for all stores which share this item.'),
('en', 'update_for_all_hid_act', 'Click to cancel field update.'),
('en', 'update_for_all_hid_dis', 'Click to enter a new field value to update in all stores when saving item.'),
('en', 'update_group', 'Update group'),
('en', 'update_period_expired', '<p class="text-error">Your upgrade subscription has expired, so this software upgrade cannot be installed. You can prolongate your subscription in the <a href="[url]">Customer Help Desk</a>.</p><p>Please note that it is not mandatory: you can continue using this software with no limitation even without an upgrade subscription.</p>'),
('en', 'update_products', 'Update products'),
('en', 'update_profile', 'Update profile'),
('en', 'update_profile_notification', 'Your profile has been updated.'),
('en', 'update_profile_notification_header', 'Your profile has been updated'),
('en', 'update_status', 'Update status'),
('en', 'update_text', 'Update text'),
('en', 'updating', 'Updating'),
('en', 'updating_links', 'Updating links'),
('en', 'upgrade', 'Upgrade'),
('en', 'upgrade_center', 'Upgrade center'),
('en', 'upgrade_center_permission_adjusted_properly', 'All file and folder permissions have been adjusted properly.'),
('en', 'upgrade_center.validation_issue', 'Validation issue'),
('en', 'upgrade_center.validator_fail_result', 'Validator "[validator_name]" returned fail status'),
('en', 'upgrade_center.filehash_check_failed', 'Upgrade is impossible due to file integrity check error. Please contact the technical support team.'),
('en', 'upgrade_center.upgrades_are_not_available_in_trial', 'Upgrades are available only in <strong>Full</strong> and <strong>Free</strong> licensing modes.<br /><br />The licensing mode can be changed under Settings → <a class="cm-dialog-opener cm-dialog-auto-size" data-ca-target-id="store_mode_dialog">Licensing mode</a>.'),
('en', 'upgrade_center.incompatible_third_party_addons', 'Some of your add-ons weren''t tested with this version yet. Before the upgrade, ask the developers of these add-ons if they''ll work.'),
('en', 'upgrade_center.check_addons', 'See add-ons that weren''t tested →'),
('en', 'upgrade_flash_player', 'You need to upgrade your Flash Player'),
('en', 'upgrade_is_not_avail', '<p class="text-error">This upgrade is not available for your [product] license. Please contact our <a href="[href]">support team</a> to update your license status.</p>'),
('en', 'upgrade_center.warning_msg_upgrade_is_complicated', 'The upgrade is a complicated process. It can be failed due to reasons that are beyond our control.<br> To make the upgrade of your store safer, we have prepared tips for you:'),
('en', 'upgrade_center.warning_msg_specialists', 'If you are not familiar with technical aspects of CS-Cart and the upgrade process, we strongly recommend that you <a href="[upgrade_center_specialist]" target="_blank">hire a specialist</a> or <a href="[upgrade_center_team]" target="_blank">ask our support team</a> to upgrade your store for you.'),
('en', 'upgrade_center.warning_msg_third_party_add_ons', 'The upgrade doesn''t update third-party add-ons. That''s why we recommend that you disable all the third-party add-ons before the upgrade.'),
('en', 'upgrade_center.warning_msg_test_local', 'Upgrade the test copy of your store first to make sure that the upgrade will go smoothly.'),
('en', 'upgrade_center.warning_msg_after_upgrade', 'After the upgrade, check the basic functionality of your store.'),
('en', 'upgrade_center.warning_msg_generally', 'Generally, the upgrade fails because the PHP script execution is terminated due to your server configuration. It''s essential to check the PHP script timeout settings on your server'),
('en', 'upgrade_center.warning_msg_timeout_fail', 'We DO NOT recommend to start the upgrade on your server.'),
('en', 'upgrade_center.warning_msg_timeout_check_failed', 'Your server has wrong PHP script timeout settings. This could be due to restrictions on the PHP <a href="http://php.net/manual/en/function.set-time-limit.php" target="_blank">set_time_limit</a> function or FastCGI "Timeout" options. We recommend you to contact your hosting provider in order to resolve this issue or contact our tech support team to perform the upgrade for you.'),
('en', 'upgrade_center.warning_msg_executed_php', '<p class="text-error">We have started a dummy PHP script. It will be working during 6 minutes. When the check is finished, we''ll tell you if the PHP script''s timeouts can be set correctly. If yes, then you are good to go with the upgrade. Please wait until the check is finished to be sure that your server has correct PHP timeout configuration.</p>'),
('en', 'upload', 'Upload'),
('en', 'upload_install', 'Upload & install'),
('en', 'upload_another_file', 'Upload another file'),
('en', 'upload_file', 'Upload file'),
('en', 'ups', 'United Parcel Service'),
('en', 'url', 'URL'),
('en', 'user', 'User'),
('en', 'usergroup', 'User group'),
('en', 'usergroups', 'User groups'),
('en', 'usergroup_activated', 'User group has been activated'),
('en', 'usergroup_disactivated', 'User group has been deactivated'),
('en', 'usergroup_privileges', 'User group privileges'),
('en', 'usergroup_request_by_customer', 'User group request by customer'),
('en', 'username', 'Username'),
('en', 'users', 'Users'),
('en', 'users_carts', 'Abandoned / Live carts'),
('en', 'users_carts_menu', 'Live carts'),
('en', 'user_type', 'User type'),
('en', 'user_account_info', 'User account information'),
('en', 'user_account_information', 'User account information'),
('en', 'user_cannot_be_deleted', 'Sorry, user with id [user_id] can not be deleted.'),
('en', 'user_class', 'User-defined CSS class'),
('en', 'wrapper_class', 'User-defined wrapper CSS class'),
('en', 'user_data_required', 'Please select a customer or enter data'),
('en', 'user_details_page', 'User details page'),
('en', 'user_group_requests', 'User group requests'),
('en', 'user_id', 'User ID'),
('en', 'user_info', 'User information'),
('en', 'user_pin', 'User PIN'),
('en', 'user_profile_info', 'User profile information'),
('en', 'user_settings', 'User settings'),
('en', 'use_avail_period', 'Use available period'),
('en', 'use_cardinal', 'Use Cardinal Centinel&reg; for 3-D Secure Payer Authentication'),
('en', 'use_coupons_commission', 'Coupon commission'),
('en', 'use_current_link', 'Use the current page link'),
('en', 'use_custom_view', 'Use custom view'),
('en', 'use_custom_weight_settings', 'Use custom weight settings'),
('en', 'use_existing_block', 'Use Existing Block'),
('en', 'use_existing_store', 'Copy existing storefront configuration'),
('en', 'use_negotiated_rates', 'Use negotiated rates'),
('en', 'use_new_sha_method', 'Use new SHA signature policy'),
('en', 'usps', 'U.S Postal Service'),
('en', 'usps_package_size_large', 'Large'),
('en', 'usps_package_size_regular', 'Regular'),
('en', 'usps_service_certificate_of_mailing', 'Certificate of mailing'),
('en', 'usps_service_certificate_of_mailing_for_firm_mailing_books', 'Certificate of mailing for firm mailing books'),
('en', 'usps_service_certificate_of_mailing_per_individual_article', 'Certificate of mailing per individual article'),
('en', 'usps_service_certified', 'Certified'),
('en', 'usps_service_collect_on_delivery', 'Collect on delivery'),
('en', 'usps_service_delivery_confirmation', 'USPS Tracking/Delivery confirmation'),
('en', 'usps_service_edelivery_confirmation', 'e-Delivery Confirmation'),
('en', 'usps_service_express_mail_insurance', 'Express mail insurance'),
('en', 'usps_service_insurance', 'Insurance'),
('en', 'usps_service_pick_up_on_demand', 'Pick up on demand'),
('en', 'usps_service_registered_mail', 'Registered mail'),
('en', 'usps_service_registered_without_insurance', 'Registered without insurance'),
('en', 'usps_service_registered_with_insurance', 'Registered with insurance'),
('en', 'usps_service_return_receipt', 'Return receipt'),
('en', 'usps_service_return_receipt_electronic', 'Return receipt electronic'),
('en', 'usps_service_return_receipt_for_merchandise', 'Return receipt for merchandise'),
('en', 'usps_service_signature_confirmation', 'Signature confirmation'),
('en', 'usps_size', 'Please specify the package width, height and length for Priority mail, if Package Size is Large only.'),
('en', 'valid', 'Period of validity'),
('en', 'validate_email', 'Validate E-mail'),
('en', 'validate_secret_word', 'Validate secret word'),
('en', 'valid_thru', 'Valid thru (mm/yy)'),
('en', 'value', 'Value'),
('en', 'value_to_display', 'Value to display'),
('en', 'variant', 'Variant'),
('en', 'variants', 'Variants'),
('en', 'variant_name', 'Variant name'),
('en', 'vendor', 'Store'),
('en', 'vendors', 'Stores'),
('en', 'vendor_id', 'Store ID'),
('en', 'vendor_name_field', 'Vendor name'),
('en', 'vendor_name', 'Store name'),
('en', 'vendor_pages', 'Store pages'),
('en', 'version', 'Version'),
('en', 'vertical', 'Vertical'),
('en', 'very_good', 'Very Good'),
('en', 'view', 'View'),
('en', 'viewing_feature', 'Viewing feature'),
('en', 'viewing_filter', 'Viewing filter'),
('en', 'view_all', 'view all'),
('en', 'view_all_orders', 'View all orders'),
('en', 'view_all_product_features', 'View all product features'),
('en', 'view_cart', 'View cart'),
('en', 'view_categories', 'View categories'),
('en', 'view_comparison_list', 'Comparison list'),
('en', 'view_details', 'View details'),
('en', 'view_orders', 'View orders'),
('en', 'view_page', 'View page'),
('en', 'view_product', 'View product'),
('en', 'view_products', 'View products'),
('en', 'view_product_features', 'View product features'),
('en', 'view_purchased_products', 'View purchased products'),
('en', 'view_report', 'View report'),
('en', 'view_results', 'View results'),
('en', 'view_storefront', 'View storefront'),
('en', 'view_vendor_categories', 'View store categories'),
('en', 'view_vendor_orders', 'View store orders'),
('en', 'view_vendor_products', 'View store products'),
('en', 'view_vendor_users', 'View store users'),
('en', 'visa_card_discover', 'Visa, MasterCard, Discover'),
('en', 'visited_page', 'Visited page'),
('en', 'voided', 'Voided'),
('en', 'warning', 'Warning'),
('en', 'warning_default_language_disabled', 'The default language defined in your settings has been disabled or deleted. Please update the Frontend default language value on the following page: <a href="[link]">Settings :: Appearance</a>'),
('en', 'default_language_status', 'Status of the Default language cannot be changed'),
('en', 'warning_cannot_disable_all_currencies', 'All currencies cannot be hidden or disabled. Primary currency activated.'),
('en', 'warning_default_currency_disabled', 'The default currency of one of the storefronts defined in your settings has been disabled or deleted, or its code has been changed. Please update the Frontend default currency value on the following page: <a href="[link]">Settings :: Appearance</a>'),
('en', 'default_currency_status', 'Status of the Primary currency cannot be changed'),
('en', 'warning_https_is_disabled', 'The secure connection check has failed. Please ensure that SSL certificate is installed on your server. Check out the <a href="[href]" target="_blank">Documentation article</a> for more details.'),
('en', 'warning_insecure_admin_script', 'It is strongly recommended that you rename the default <b>admin.php</b> script (check the <a href="[href]" target="_blank">Documentation</a>) for security reasons.'),
('en', 'warning_insecure_password_email', 'The password must be different from the E-mail! <p><a href="[link]" class="underlined"><b>Change password &#155;&#155;</b></a></p>'),
('en', 'warning_lanvar_incorrect_name', 'Language variable name contains unsupported characters!'),
('en', 'warning_not_deleted_default_language', 'The [lang_name] language cannot be deleted because it is the default store language'),
('en', 'warning_promotions_incorrect_condition', 'The "[condition]" condition can be used in groups with "[set_value]" conditions only.'),
('en', 'warning_store_optimization_dev', 'Auto cache update enabled.<br /><br />Modified files are tracked in real time (including the files modified directly on server) and re-cached.<br /><br />Store performance may be slightly affected. Recommended to disable on production in the <a href="[link]">Themes</a>.'),
('en', 'warning_store_optimization_dev_disabled', 'Auto cache update disabled.<br /><br />Clear compiled templates manually after modifying the theme files by following <a href="[link]">this link</a> to apply the changes.'),
('en', 'warning_subscr_email_exists', '<b>[email]</b> is already in the subscribers list'),
('en', 'warning_theme_clone_dir_exists', 'Can not clone theme, because directory you entered is already exist. Please enter another one.'),
('en', 'warning_track_orders_not_allowed', 'You are not allowed to view the details of this order.'),
('en', 'warning_track_orders_not_found', 'The E-mail/Order ID you entered doesn''t exist'),
('en', 'warning_variants_removal', 'Clicking on Save will remove product feature values.'),
('en', 'website', 'Website'),
('en', 'web_pages', 'Web pages'),
('en', 'web_site', 'Website'),
('en', 'week', 'Week'),
('en', 'weekday_0', 'Sunday'),
('en', 'weekday_1', 'Monday'),
('en', 'weekday_2', 'Tuesday'),
('en', 'weekday_3', 'Wednesday'),
('en', 'weekday_4', 'Thursday'),
('en', 'weekday_5', 'Friday'),
('en', 'weekday_6', 'Saturday'),
('en', 'weekday_abr_0', 'Sun'),
('en', 'weekday_abr_1', 'Mon'),
('en', 'weekday_abr_2', 'Tue'),
('en', 'weekday_abr_3', 'Wed'),
('en', 'weekday_abr_4', 'Thu'),
('en', 'weekday_abr_5', 'Fri'),
('en', 'weekday_abr_6', 'Sat'),
('en', 'weeks', 'week(s)'),
('en', 'weight', 'Weight'),
('en', 'weight_dependences', 'Weight dependencies'),
('en', 'weight_limit', 'Weight limit'),
('en', 'weight_modifier', 'Weight modifier'),
('en', 'weight_symbol', 'Weight symbol'),
('en', 'well_done', 'Well done!'),
('en', 'what_is_cvv2', 'What is CVV/CVC'),
('en', 'widget_code', 'Widget code'),
('en', 'widget_what_is_it', '<a href="[href]" target="_blank">What is it?</a>'),
('en', 'width', 'Width'),
('en', 'without_image', 'Without image'),
('en', 'with_contact_information', 'With contact information only'),
('en', 'world', 'World'),
('en', 'worldnettps_hash_error', 'An error occurred. Error details: Request and Response hash do not match.'),
('en', 'worldpay_secret', 'MD5 secret for transactions'),
('en', 'wrapper', 'Wrapper'),
('en', 'write', 'Write'),
('en', 'year', 'Year'),
('en', 'yes', 'Yes'),
('en', 'yesterday', 'Yesterday'),
('en', 'your_message', 'Your message'),
('en', 'your_name', 'Your name'),
('en', 'your_range', 'Your range'),
('en', 'you_have_no_permissions', 'You have no permissions'),
('en', 'you_save', 'You save'),
('en', 'zero_price_action', 'Zero price action'),
('en', 'zipcodes', 'Zip/Postal codes'),
('en', 'zip_postal_code', 'Zip/postal code'),
('en', 'zone', 'Zone'),
('en', 'zpa_ask_price', 'Ask customer to enter the price'),
('en', 'zpa_permit', 'Allow customers to add the product to cart'),
('en', 'zpa_refuse', 'Do not allow customers to add the product to cart'),
('en', 'po_file', 'Choose a file in the PO or ZIP format'),
('en', 'hidden_categories', 'Hidden categories'),
('en', 'clone_categories', 'Copy categories'),
('en', 'clone_layouts', 'Copy layouts'),
('en', 'clone_pages', 'Share pages'),
('en', 'clone_payments', 'Share payment methods'),
('en', 'clone_products', 'Share products'),
('en', 'clone_product_features', 'Share product features'),
('en', 'clone_product_filters', 'Share product filters'),
('en', 'clone_profile_fields', 'Share profile fields'),
('en', 'clone_promotions', 'Share promotions'),
('en', 'clone_settings', 'Copy settings'),
('en', 'clone_shippings', 'Share shipping methods'),
('en', 'clone_sitemap', 'Copy sitemap'),
('en', 'clone_static_data_clone', 'Copy menus'),
('en', 'text_uc_failed_to_decompress_files', 'Failed to extract files from the archive'),
('en', 'development', 'Development'),
('en', 'po_file_is_incorrect', 'PO-file <b>"[file]"</b> contains syntax errors or incorrect structure.'),
('en', 'product_option_delimiter', 'Option delimiter'),
('en', 'text_product_option_delimiter', 'Delimiter for product options within an option combination (e.g. "Color: Red, Size: Small")'),
('en', 'upload_addon', 'Upload & install add-on'),
('en', 'upload_theme', 'Upload theme'),
('en', 'install_theme_text', 'Uploading and installing a new theme is a great way to personalize your storefront. You can upload a theme by picking a [exts] format archive and clicking <strong>Upload</strong>.'),
('en', 'install_upgrade_package_text', 'You can upload an upgrade package manually from the local machine, your server, or from a remote location. Specify the location of a [exts] format archive and click <strong>Upload</strong>.'),
('en', 'non_writable_directories', 'The following directories do not have writable permissions'),
('en', 'text_set_write_permissions_for_dirs', 'You can set the write permissions for the Web server to the directories listed above or provide an FTP-access with the write permissions to these directories.'),
('en', 'ftp_server_options', 'FTP server options'),
('en', 'ftp_directory', 'FTP directory'),
('en', 'recheck', 'Re-check'),
('en', 'use_this_style', 'Use this style'),
('en', 'upload_via_ftp', 'Upload via FTP'),
('en', 'invalid_ftp_access', 'Invalid FTP access'),
('en', 'install_addon_text', 'Add-ons extend the functionality of your store. <br /> You can install an add-on by picking a [exts] format archive and clicking Upload & install.'),
('en', 'xml_error', 'XML parse error'),
('en', 'column', 'Column'),
('en', 'checking_core_version_is_not_suitable', 'Version of your cart ([version]) is not supported. Minimal: [min]. Maximal: [max].'),
('en', 'checking_core_edition_is_not_suitable', 'Edition of your cart ([current_edition]) is not supported. Required: [required_edition].'),
('en', 'checking_php_version_is_not_suitable', 'PHP version ([version]) is not supported. Minimal: [min]. Maximal: [max].'),
('en', 'checking_extension_should_be_installed', 'The [extension] extension should be installed on your server for correct add-on operation.'),
('en', 'checking_extension_should_be_removed', 'The [extension] extension should be removed from your server for correct add-on operation.'),
('en', 'checking_extension_version_is_not_suitable', 'The [extension] version ([version]) is not supported by the add-on. Minimal: [min]. Maximal: [max].'),
('en', 'scroll_per_page', 'Scroll per page'),
('en', 'payments.paypal_adv_layout', 'Layout'),
('en', 'payments.layout_a', 'Layout A'),
('en', 'payments.layout_b', 'Layout B'),
('en', 'payments.layout_c', 'Layout C'),
('en', 'payments.eway_rapidapi_rsp.header_text', 'Header text'),
('en', 'filter_by_categories', 'Filter by categories'),
('en', 'default_filter_by_location', 'No filter specified. Filter by location set as default.'),
('en', 'theme_information', 'Theme information'),
('en', 'developer', 'Developer'),
('en', 'theme_styles_and_layouts', 'Theme styles and layouts'),
('en', 'activate', 'Activate'),
('en', 'export_layout', 'Export layout'),
('en', 'import_layout', 'Import layout'),
('en', 'create_new_layout', 'Create new layout'),
('en', 'update_current_layout', 'Update current layout'),
('en', 'get_social', 'Get social'),
('en', 'uc_searchanise_disabled', 'The Searchanise add-on was automatically disabled during upgrade to avoid false search results. Activate it at any time on the <a href="[url]">Add-ons</a> page.'),
('en', 'text_store_closed', 'Sorry, the store is temporarily closed for maintenance.'),
('en', 'theme_editor.presets', 'Presets'),
('en', 'theme_editor.preset_data_cannot_be_saved', 'Preset data cannot be saved. You should set write permissions for <b>[theme_dir]</b> directory to fix this issue.'),
('en', 'theme_editor.preset_name', 'Preset name'),
('en', 'active_preset', 'Active preset'),
('en', 'theme_editor.error_preset_exists', 'The preset with this name is already exist. Please choose another one.'),
('en', 'theme_editor.incorrect_preset_name', 'Preset name can not contain the following characters: "/ # % ? * : ; { } \\ "'),
('en', 'theme_editor.convert_to_css', 'Convert to CSS'),
('en', 'theme_editor.text_convert_to_css', '<p>Generate CSS files from LESS (for manual editing).</p><p>IMPORTANT: You won''t be able to use the Theme editor to customize the storefront!</p><p><i>The original LESS files will be backed up and you will be able to restore them later</i></p>'),
('en', 'theme_editor.enable_less', 'Enable LESS'),
('en', 'theme_editor.warning_css_changes_will_be_reverted', '<p>You should switch back to LESS to be able to use the Theme editor, because it deals with LESS files instead of plain CSS.</p><p><strong>Important:</strong> All CSS files will be overwritten during the restore! Custom CSS modifications will be saved in the backup directory.</p>'),
('en', 'theme_editor.confirm_enable_less', 'Your CSS modifications will be backed up and overwritten. Are you sure to continue with the LESS restore?'),
('en', 'theme_editor.error_theme_converted_to_css', 'Compiled CSS files do not support styling. Restore LESS in the <a target="_blank" href="[url]">Theme editor</a> to be able to change styles.'),
('en', 'need_product_name', 'You have to specify product name'),
('en', 'api_required_field', 'The [field] field is required'),
('en', 'update_translation', 'Update translations'),
('en', 'po_meta_error_validating_lang_code', 'Language code in the PO file does not match that of the updated language'),
('en', 'error_class_phar_data_not_found', 'The PharData class not found. Read more: <a href="https://php.net/manual/en/class.phardata.php">https://php.net/manual/en/class.phardata.php</a>'),
('en', 'error_class_zip_archive_not_found', 'The ZipArchive class not found. Read more: <a href="https://php.net/manual/en/class.ziparchive.php">https://php.net/manual/en/class.ziparchive.php</a>'),
('en', 'error_zip_php_extension_not_installed', '"Zip" PHP extension is not installed. Please install the "Zip" PHP extension to create and extract ZIP-archives.'),
('en', 'make_archive', 'Make archive'),
('en', 'marketplace', 'Marketplace'),
('en', 'cscart_marketplace', 'CS-Cart Marketplace'),
('en', 'marketplace_find_more', 'Find more add-ons and themes in <a href="[href]" target="_blank">Marketplace</a>'),
('en', 'cscart_marketplace.search', 'Search'),
('en', 'cscart_marketplace.search_description', 'Search the Add-on Market for your business needs'),
('en', 'cscart_marketplace.buy', 'Buy'),
('en', 'cscart_marketplace.price', 'Price'),
('en', 'cscart_marketplace.list_price', 'List price'),
('en', 'cscart_marketplace.price_free', 'Free'),
('en', 'more_languages', 'More languages'),
('en', 'languages_find_more', 'If you haven''t found the language you need, check out <a href="[href]" target="_blank">our site with free language packs</a>.'),
('en', 'extract_archive', 'Extract archive'),
('en', 'seo', 'SEO'),
('en', 'text_owl', 'OwlCarousel'),
('en', 'carousel_swiper', 'Swiper'),
('en', 'bulk_print_packing_slip', 'Packing slip bulk print'),
('en', 'bulk_print_pdf', 'Invoice bulk print (PDF)'),
('en', 'text_all_categories_included', 'All categories included'),
('en', 'text_all_products_included', 'All products included'),
('en', 'usergroup_registered', 'Registered user'),
('en', 'person_name', 'Name'),
('en', 'promotions.cond_any', 'any'),
('en', 'promotions.cond_all', 'all'),
('en', 'promotions.cond_true', 'true'),
('en', 'promotions.cond_false', 'false'),
('en', 'text_select_vendor', 'Please select a store first'),
('en', 'views', 'Views'),
('en', 'first_name_and_last_name', 'First name and last name'),
('en', 's_first_name_and_last_name', 'First name and last name (for shipping)'),
('en', 'b_first_name_and_last_name', 'First name and last name (for billing)'),
('en', 'last_name_and_first_name', 'Last name and first name'),
('en', 's_last_name_and_first_name', 'Last name and first name (for shipping)'),
('en', 'b_last_name_and_first_name', 'Last name and first name (for billing)'),
('en', 'fullname', 'Full name'),
('en', 's_fullname', 'Full name (for shipping)'),
('en', 'b_fullname', 'Full name (for billing)'),
('en', 'vendor_terms', 'Vendor terms and conditions'),
('en', 'vendor_terms_field_alert', 'Vendor terms and conditions alert'),
('en', 'vendor_terms_field_terms_text', 'Vendor terms and conditions text'),
('en', 'product_must_have_owner_category', 'Product must belong to some category created by the owner company.'),
('en', 'last_year', 'Last year'),
('en', 'store_closed', 'Store closed'),
('en', 'store_closed_banner', 'Store<br/>closed'),
('en', 'copy_to_other_locations', 'Copy to other locations'),
('en', 'head_custom_html', 'Custom HTML code'),
('en', 'tt_views_block_manager_update_location_head_custom_html', 'This code will be put between the &lt;head&gt;&lt;/head&gt; tags. Use it to specify meta tags or to reference external scripts or styles.'),
('en', 'category_deletion_side_effects', 'This will delete all selected category''s products, as well as its subcategories and their products.'),
('en', 'bulk_category_deletion_side_effects', 'This will delete all selected categories'' products, as well as their subcategories and their products.'),
('en', 'restore_original', 'Restore original'),
('en', 'set_custom_configuration', 'Set custom configuration'),
('en', 'use_default_block_configuration', 'Use default block configuration'),
('en', 'private_files', 'Private files'),
('en', 'public_files', 'Public files'),
('en', 'templates', 'Templates'),
('en', 'payments.realex.referring_url', 'Please supply this URL to your Realex Payments account manager'),
('en', 'payments.globalpayments.referring_url', 'Please supply this URL to your Global Payments account manager'),
('en', 'payments.realex.referring_ip', 'Please supply the IP address of your server to your Realex Payments account manager'),
('en', 'payments.globalpayments.referring_ip', 'Please supply the IP address of your server to your Global Payments account manager'),
('en', 'payments.realex.settlement', 'Settlement'),
('en', 'payments.realex.delayed_settlement', 'Delayed settlement'),
('en', 'payments.realex.auto_settled', 'Auto-settled'),
('en', 'payments.realex.text_status_map', 'Realex to CS-Cart order status conversion map'),
('en', 'payments.globalpayments.text_status_map', 'Global Payments to [product] order status conversion map'),
('en', 'payments.realex.subaccount', 'Subaccount'),
('en', 'payments.realex.liability_shift', 'Liability Shift'),
('en', 'payments.realex.liability_shift_required', 'Liability Shift required'),
('en', 'payments.realex.3d_secure_message', '3-D Secure message'),
('en', 'payments.realex.connector_error', 'Your Realex account has been suspended. Contact Realex support for further information.'),
('en', 'payments.globalpayments.connector_error', 'Your Global Payments account has been suspended. Contact Global Payments support for further information.'),
('en', 'payments.realex.incorrect_request', 'Incorrect XML message formation or content'),
('en', 'payments.realex.realex_error', 'Error with Realex systems'),
('en', 'payments.globalpayments.globalpayments_error', 'Error with Global Payments systems'),
('en', 'payments.realex.bank_error', 'Error with bank systems'),
('en', 'payments.realex.card_lost_or_stolen', 'Card reported lost or stolen'),
('en', 'payments.realex.refferal', 'Referral by bank'),
('en', 'payments.realex.avs_postcode', 'AVS Postcode'),
('en', 'payments.realex.avs_address', 'AVS Address'),
('en', 'payments.realex.tss_result', 'TSS'),
('en', 'payments.realex.eci', 'ECI'),
('en', 'payments.realex.cavv', 'CAVV'),
('en', 'payments.realex.xid', 'XID'),
('en', 'payments.realex.result_message', 'Result message'),
('en', 'payments.realex.result_code', 'Result code'),
('en', 'payments.realex.transaction_pasref', 'Transaction PASREF'),
('en', 'payments.realex.transaction_order_id', 'Transaction Order ID'),
('en', 'payments.realex.avs.matched', 'Matched'),
('en', 'payments.realex.avs.not_matched', 'Not matched'),
('en', 'payments.realex.avs.problem_with_check', 'Problem with check'),
('en', 'payments.realex.avs.unable_to_check', 'Unable to check'),
('en', 'payments.realex.avs.partial_match', 'Partial match'),
('en', 'payments.realex.wrong_card_type', 'This payment is unavailable for this type of credit cards.'),
('en', 'payments.realex.incorrect_valid_trhu', 'Incorrect values of ''Valid thru'' fields.'),
('en', 'use_for_login', 'Login form'),
('en', 'use_for_recover', 'Recover password form'),
('en', 'use_for_register', 'Create and edit profile form'),
('en', 'use_for_checkout', 'Checkout (user information) form'),
('en', 'use_for_track_orders', 'Track my order form'),
('en', 'use_for_track_product_in_stock', 'In-stock notification subscription form'),
('en', 'seo_robots', 'robots.txt'),
('en', 'robots_title', 'Editing: robots.txt'),
('en', 'edit_robots', 'Edit robots.txt'),
('en', 'restore_robots', 'Restore the default robots.txt'),
('en', 'option_exceptions', 'Option exceptions'),
('en', 'horizontal_filters', 'Horizontal filters'),
('en', 'vendor_filters_description', ''),
('en', 'uc_broken_upgrade_connector', 'Upgrade connector [connector_id] returned incorrect data'),
('en', 'uc_downloaded_and_ready', 'Upgrade package has been downloaded and ready to install'),
('en', 'uc_connector_not_found', 'Upgrade connector not found'),
('en', 'uc_unable_to_read_schema', 'Unable to read package schema (schema.json)'),
('en', 'uc_package_schema_not_found', 'Package content schema not found'),
('en', 'uc_package_schema_is_not_json', 'Package schema is not a valid JSON'),
('en', 'uc_addon_package_forbidden_path', 'Forbidden: Add-on tries to upgrade core files ([path])'),
('en', 'uc_addon_package_migrations_forbidden', 'Package contains migrations that were not described in schema or schema has links to missing migration files'),
('en', 'uc_addon_package_languages_forbidden', 'Package contains languages that were not described in schema or schema has links to missing languages files'),
('en', 'uc_addon_package_files_do_not_match_schema', 'Package contains files that were not described in schema or schema has links to missing files'),
('en', 'uc_addon_package_pre_post_scripts_mismatch', 'Package contains pre/post scripts that were not described in schema or schema has links to missing files'),
('en', 'new_version', 'New version'),
('en', 'migrations', 'Migrations'),
('en', 'permissions_issue', 'Permissions issue'),
('en', 'text_uc_local_modification', 'Local modifications'),
('en', 'text_uc_agreed_collisions', 'I understand that my local modifications will be permanently lost during the upgrade'),
('en', 'text_uc_will_be_changed', 'Will be changed'),
('en', 'text_uc_will_be_deleted', 'Will be deleted'),
('en', 'uc_title_validators', 'Upgrade package validators'),
('en', 'uc_execute_validator', 'Execute "[validator]" validator'),
('en', 'uc_copy_files', 'Copy files'),
('en', 'uc_run_migrations', 'Run migrations'),
('en', 'uc_install_languages', 'Install languages'),
('en', 'uc_upgrade_progress', 'Upgrade progress'),
('en', 'upload_upgrade_package', 'Upload upgrade package'),
('en', 'upload_upgrade_text', 'Uploading upgrade package allows you to apply HotFixes or Add-on upgrades. You can upload an upgrade pack by picking a tgz,gz,zip format archive and clicking Upload.'),
('en', 'outside_navigation', 'Outside navigation'),
('en', 'exim_error_incorrect_feature_type', 'Incorrect feature type. Some product features were not updated.'),
('en', 'exim_error_empty_feature_name', 'Feature name is missing. Some product features were not updated.'),
('en', 'unable_to_delete_last_storefront', 'At least one storefront must remain'),
('en', 'datakeeper.run_backup_via_cron_message', 'You can run the backup automatically at certain time intervals. To do it, add the following command to <a href="https://en.wikipedia.org/wiki/Cron" target="_blank">Cron</a>:'),
('en', 'datakeeper.error_unsupported_file_type', 'File cannot be restored. Only .sql, .zip and .tgz files are allowed.'),
('en', 'datakeeper.file_cannot_be_overrided', 'Cannot write to the file <b>[file]</b>. Set the writable permissions manually or check the FTP access to your server in the <a href="[url]">"Upgrade center"</a> section'),
('en', 'uc_restore_email_body', '<p>Your store''s database and files has been backed up before the upgrade. The backup archive includes the whole database and all files except for images. The backup archive has been stored on your server: [backup_file].</p><p>Before the upgrade, your store was closed. Check if it''s running fine after the upgrade and <a href="[settings_section]">open it</a>.</p><p>If something goes wrong during the upgrade, go to your admin panel, <strong>Administration → Backup/Restore</strong>, to restore the backup.</p><p>If you can''t access your admin panel, use the following link to restore the last backup. <b>Important:</b> following this link will immediately launch the restore process. Use it only if you can''t access your admin panel! Restore the last backup:</p>'),
('en', 'uc_backup_info_subj', 'Upgrade Center: Store has been backed up and closed.'),
('en', 'uc_info_subj', 'Upgrade Center: Store has been closed.'),
('en', 'error_features_too_many_variants', 'Search by features is not available due to the excessive number of variants.'),
('en', 'upgraded_on', 'Upgraded on'),
('en', 'error_unable_to_create_thumbnail', 'Unable to create thumbnail for file "[file]": [error]'),
('en', 'cookie_is_disabled', 'For a complete shopping experience, please <a href="https://www.wikihow.com/Enable-Cookies-in-Your-Internet-Web-Browser" target="_blank">set your browser to accept cookies</a>'),
('en', 'uc_restore_email_subject', 'Upgrade center: Store has been backed up and closed.'),
('en', 'warning_zero_price_restricted_product', 'Product <b>"[product]"</b> has not been added to the cart, because it doesn''t have a price.'),
('en', 'exim_vendor_cant_create_feature', 'Vendors cannot create product features and their variants. Some product features cannot be modified.'),
('en', 'uc_migration_failed', 'An error has occured during upgrading database structure (applying migration [migration]).'),
('en', 'text_entered_html_was_sanitized', 'Some <strong>HTML tags</strong> that you have used <strong>were cut off</strong> because of the restrictions on inserting HTML tags such as &lt;object&gt;, &lt;iframe&gt;, &lt;embed&gt; and JavaScript code. That''s why the content that you''ve inserted via these tags will not be displayed.'),
('en', 'text_uc_package_installed_with_errors', 'Errors occurred during the upgrade process. Please contact technical support to investigate the problem.'),
('en', 'error_unable_to_create_backups', 'Unable to create backups.'),
('en', 'seconds_left', '[n] second left|[n] seconds left'),
('en', 'text_uc_timeout_check_success', 'Looks like your server allows to change the "max_execution_time" option from the script. You are good to go with the upgrade process.'),
('en', 'check_php_timeout', 'Check PHP script timeout'),
('en', 'i_agree_continue', 'I agree and continue'),
('en', 'upgrade_center.error_unable_to_prepare_restore', 'Unable to prepare restore script.'),
('en', 'text_cc_javascript_disabled', 'Note! Your browser has the <b>JavaScript</b> disabled. To pay for your order click'),
('en', 'cc_button_submit', 'Proceed to checkout'),
('en', 'payments.rocketgate.avs_mode', 'AVS Mode'),
('en', 'payments.rocketgate.scrub_mode', 'SCRUB Mode'),
('en', 'payments.rocketgate.ignore', 'Ignore'),
('en', 'use_for_free_shipping', 'Use for free shipping'),
('en', 'tt_views_products_components_products_shipping_settings_free_shipping', 'Products with the Free shipping option enabled will be excluded from shipping calculation if shipping method has the Use for free shipping option enabled'),
('en', 'tt_views_shippings_update_use_for_free_shipping', 'Exclude products with the enabled Free shipping option from the shipping price calculation'),
('en', 'tt_views_shippings_update_is_address_required', 'If address isn''t required, CS-Cart will treat this shipping method as "Pick-up".'),
('en', 'trash_category', 'Trash category'),
('en', 'trash_category_description', 'When a product is deleted from the last category in the store, it will be moved to this category.'),
('en', 'products_without_category', 'Products without category');
INSERT INTO `[[dbprefix]]language_values` VALUES
('en', 'products_without_category_description', 'When a product is created without a category during import, it will be placed into this category.'),
('en', 'products_without_category_notification_text', 'Some of your products currently don''t have a category. It may be harder for customers to find those products.<br /> <a href="[url]" target="_blank">Please check these products and assign them a category.</a>'),
('en', 'deleting_required_category_notification_text', 'Category "[category]" is required and can''t be deleted.'),
('en', 'upgrade_notification_title', 'Upgrade changes in [product] [version]'),
('en', 'eway_configuration_note', '<a href=''https://go.eway.io/s/article/How-do-I-setup-my-Live-eWAY-API-Key-and-Password'' target=''_blank''>How do I set up my Live eWAY API Key and Password?</a>'),
('en', 'eway_failed_to_pay', 'Failed to pay for the order. Please contact the store administration about this payment method.'),
('en', 'show_more', 'Show more'),
('en', 'show_less', 'Show less'),
('en', 'products_moved_to_trash', '[count] products were moved to <a href=''[url]'' target=''_blank''>Trash category</a>'),
('en', 'products_adopted', '[n] product had a new main category assigned to it.|[n] products had a new main category assigned to them.'),
('en', 'text_uc_addon_upgrade_completed', 'Add-on "[name]" has been upgraded successfully'),
('en', 'change_addons_initialization_description', 'To determine if a certain problem is caused by an add-on, you can disable third-party add-ons or all add-ons. Re-enable them later with one click.'),
('en', 'tools_addons_disable_all', 'Disable all add-ons'),
('en', 'tools_addons_disable_third_party', 'Disable Third-party add-ons'),
('en', 'tools_re_enable_add_ons', 'Re-enable add-ons'),
('en', 'tools_addons_installed_count', 'Installed add-ons:'),
('en', 'tools_addons_activated_count', 'Active add-ons:'),
('en', 'tools_addons_core_addons_count', 'Built-in add-ons:'),
('en', 'tools_addons_other_addons_count', 'Third-party add-ons:'),
('en', 'tools_addons_disabled_msg', 'An administrator disabled all add-ons or third-party add-ons.<br> Press the Re-enable add-ons button to initialize the add-ons that were previously active.'),
('en', 'tools_addons_additional_shipping_methods_msg', 'There may be more ways to calculate shipping rates. They''ll show up if you activate the corresponding <a href="[url]">shipping add-ons</a>.'),
('en', 'tools_addons_additional_payment_methods', 'There may be more payment processors. They''ll show up if you activate the corresponding <a href="[url]">payment add-ons</a>.'),
('en', 'tools_addons_additional_themes', 'There may be more themes. They''ll show up if you activate the corresponding <a href="[url]">theme add-ons</a>.'),
('en', 'addons_source', 'Source'),
('en', 'addon_built_in', 'Built-in'),
('en', 'addon_third_party', 'Third-party'),
('en', 'requires_upgrade', 'Requires [product] upgrade'),
('en', 'new_add_on_is_not_compatible_with_your_product', 'The new add-on is not compatible with your current version of [product]. To upgrade the add-on to the latest version, please upgrade [product] to version [version].'),
('en', 'upgrade_and_update_addon', 'Upgrade [product] and upgrade the add-on'),
('en', 'addons.upgrade_to_version', 'Upgrade to [version]'),
('en', 'addons.search_description', 'Search by add-on name, description, developer, and add-on ID.'),
('en', 'addons.show_review', 'Show review'),
('en', 'addons.show_all_reviews', 'Show all reviews'),
('en', 'addons.hide_all_reviews', 'Hide all reviews'),
('en', 'addons.show_n_reviews', 'Show [n] review|Show [n] reviews'),
('en', 'addons.n_reviews', 'review|reviews'),
('en', 'addons.out_of_five', 'out of 5'),
('en', 'addons.tap_star_to_rate_on_marketplace', 'Tap a star to rate it on the CS-Cart Marketplace.'),
('en', 'addons.write_review', 'Write a review'),
('en', 'addons.no_reviews', 'No reviews'),
('en', 'addons.stars', 'stars'),
('en', 'addons.and_half_stars', 'and a half stars'),
('en', 'n_stars', '[n] star|[n] stars'),
('en', 'addons.message', 'Message'),
('en', 'addons.name', 'Add-on name'),
('en', 'addons.support', 'Support'),
('en', 'addons.website', 'Website'),
('en', 'addons.documentation', 'Documentation'),
('en', 'addons.forum', 'Forum'),
('en', 'addons.forum_en', 'Forum (EN)'),
('en', 'addons.forum_ru', 'Forum (RU)'),
('en', 'addons.get_support', 'Get support'),
('en', 'addons.no_changelog', 'No changelog'),
('en', 'addons.no_information', 'No information'),
('en', 'subcategories_tree_cat', 'Subcategories tree'),
('en', 'settings_overwrite_title', 'The theme overwrites store settings'),
('en', 'settings_overwrite_text', '<b>[theme_name]</b> will set following settings on activation'),
('en', 'overwrite', 'Overwrite'),
('en', 'upgrade_center.skip_backup', 'Skip files and database backup'),
('en', 'uc_open_store_email_body', '<p>Before the upgrade, your store was closed. Check if it''s running fine after the upgrade and <a href="[settings_section]">open it</a>.</p>'),
('en', 'upgrade_notification_message', '<p class=''upgrade-center_notice-msg''>Copy of this message was sent to administrator''s email.</p><hr>'),
('en', 'http_transport_error_prefix_curl', 'Curl Error'),
('en', 'http_transport_error_prefix_socket', 'Socket Error'),
('en', 'curl_error_code_reference_link', 'To learn what caused the Curl error, look for your error number in <a target="_blank" href="[href]">this article</a>.'),
('en', 'n_days', '[n] day|[n] days'),
('en', 'track_on_carrier_site', 'Track on website'),
('en', 'unable_to_create_status', 'Couldn''t create a new status'),
('en', 'maximum_number_of_statuses_reached', 'You have reached the maximum number of statuses'),
('en', 'curl_error_description_curle_ssl_invalidcertstatus', 'Status returned failure when asked with CURLOPT_SSL_VERIFYSTATUS.'),
('en', 'error_unknown_archive_format', 'Unknown archive format: [ext]'),
('en', 'error_file_not_found', 'File "[file]" not found.'),
('en', 'error_file_already_exists', 'File "[file]" already exists.'),
('en', 'local_modifications', 'Local modifications'),
('en', 'local_modifications_message', 'These files had local modifications. During the upgrade a backup archive was created in the <strong>[dir]</strong> directory. You may want to check these files in the archive and reapply the modifications to your store.'),
('en', 'not_checked', 'Not checked'),
('en', 'checked', 'Checked'),
('en', 'error_filter_by_feature_exists', 'Filter by feature "[name]" already exists.'),
('en', 'error_filter_by_product_field_exists', 'Filter by product field "[name]" already exists.'),
('en', 'shipping_address_changed', 'Shipping address has been changed'),
('en', 'theme_editor_not_supported', 'This theme doesn''t support theme editor'),
('en', 'shipment_statuses', 'Shipment statuses'),
('en', 'email_templates', 'Email templates'),
('en', 'editing_email_template', 'Editing email template'),
('en', 'customer_notifications', 'Customer notifications'),
('en', 'admin_notifications', 'Administrator notifications'),
('en', 'subject', 'Subject'),
('en', 'variables', 'Variables'),
('en', 'snippets', 'Snippets'),
('en', 'code_snippets', 'Code snippets'),
('en', 'editing_email_snippet', 'Editing snippet'),
('en', 'editing_snippet', 'Editing snippet'),
('en', 'snippet_exists', 'The snippet with the chosen code already exists, please try another.'),
('en', 'document_exists', 'The document with the chosen code already exists, please try another.'),
('en', 'email_template_exists', 'The email template with the chosen code already exists, please try another.'),
('en', 'need_snippet_name', 'You have to specify valid snippet name'),
('en', 'snippets_have_been_deleted', 'Snippets have been deleted successfully.'),
('en', 'add_email_snippet', 'Add snippet'),
('en', 'add_snippet', 'Add snippet'),
('en', 'editing_document', 'Editing [name]'),
('en', 'product_info', 'Product info'),
('en', 'add_table_column', 'Add column'),
('en', 'editing_table_column', 'Editing column'),
('en', 'table_column_has_been_deleted', 'Product column has been deleted successfully.'),
('en', 'restore_default_value', 'Restore default value'),
('en', 'send_test_email', 'Send test email'),
('en', 'text_test_email_sent', 'Test email was sent to <b>[email]</b> address.'),
('en', 'editing_global_vars', 'Editing global variables'),
('en', 'global_vars', 'Global variables'),
('en', 'change_order_status_p_subj', 'Order #[order] has been processed'),
('en', 'change_order_status_p_text', 'Your order has been processed successfully.'),
('en', 'change_order_status_c_subj', 'Order #[order] has been completed'),
('en', 'change_order_status_c_text', 'Your order has been completed. Thank you for choosing us.'),
('en', 'change_order_status_o_subj', 'Order #[order] has been placed successfully'),
('en', 'change_order_status_o_text', 'Thank you for the order. You are welcome to come back!'),
('en', 'change_order_status_f_subj', 'Order #[order] failed'),
('en', 'change_order_status_f_text', 'Your order has been unsuccessful. Please contact shop administration.'),
('en', 'change_order_status_d_subj', 'Order #[order] has been declined'),
('en', 'change_order_status_d_text', 'Your order has been declined. Please contact shop administration.'),
('en', 'change_order_status_b_subj', 'Order #[order] has been backordered'),
('en', 'change_order_status_b_text', 'Your order has been backordered.'),
('en', 'change_order_status_i_subj', 'Order #[order] has been canceled'),
('en', 'change_order_status_i_text', 'Your order has been canceled. Please contact shop administration.'),
('en', 'change_order_status_default_subj', 'The status of order #[order] has been changed to [status]'),
('en', 'change_order_status_default_text', 'The status of your order has been changed to [status].'),
('en', 'email_template.activate_profile', 'User profile requires activation'),
('en', 'email_template.back_in_stock_notification', 'Back in stock notification'),
('en', 'email_template.create_profile', 'User profile creation'),
('en', 'email_template.edp_access', 'Orders: access to downloadable products'),
('en', 'email_template.give_coupon', 'Promotions: coupon'),
('en', 'email_template.low_stock', 'Product low stock notification'),
('en', 'email_template.order_notification', 'Order notification: [name]'),
('en', 'email_template.order_notification_default', 'Order notification: Default template for a new order status'),
('en', 'email_template.profile_activated', 'User account activation'),
('en', 'email_template.recover_password', 'Password recovery'),
('en', 'email_template.reminder', 'Admin password expiration'),
('en', 'email_template.shipment_products', 'Orders: products shipped'),
('en', 'email_template.track', 'Orders: tracking'),
('en', 'email_template.update_profile', 'User profile update'),
('en', 'email_template.usergroup_activation', 'User group activation'),
('en', 'email_template.usergroup_disactivation', 'User group disactivation'),
('en', 'email_template.usergroup_request', 'User group request'),
('en', 'email_template.upgrade_backup_info', 'Upgrade: restore link'),
('en', 'email_template.params.attach_order_document', 'Attach a PDF document'),
('en', 'edit_customer_notification', 'Edit the email sent to customers'),
('en', 'edit_admin_notification', 'Edit the email sent to administrators'),
('en', 'copy', 'Copy'),
('en', 'copied', 'Copied'),
('en', 'addon_uninstall_sql_error', 'An error in an SQL query occurred during the add-on uninstallation.'),
('en', 'payments.qbms.quickbooks_connection', 'QuickBooks Connection'),
('en', 'payments.qbms.configuration_required', '<p>Fill in the fields below and save the changes:<br>- App Token<br>- OAuth Consumer Key<br> - OAuth Consumer Secret</p><p>Click "Connect to QuickBooks" button that will appear instead of this message to finish payment configuration.</p>'),
('en', 'payments.qbms.app_token', 'App Token'),
('en', 'payments.qbms.oauth_consumer_key', 'OAuth Consumer Key'),
('en', 'payments.qbms.oauth_consumer_secret', 'OAuth Consumer Secret'),
('en', 'payments.qbms.oauth_client_id', 'OAuth Client Id'),
('en', 'payments.qbms.oauth_client_secret', 'OAuth Client Secret'),
('en', 'payments.qbms.token_expires', 'The token expires on <b>[date]</b> at <b>[time]</b>.'),
('en', 'payments.qbms.token_expired', 'The token has expired.'),
('en', 'payments.qbms.renew_token', 'Press "Connect to QuickBooks" to renew the token.'),
('en', 'payments.qbms.tip_fill_redirect', '<p>- In the QuickBooks application, copy the following value into the Redirect URI field:</p><p>[url]</p><p>- Click the "Connect to QuickBooks" button.</p>'),
('en', 'payments.qbms.configure_payment_method', '<p>How to configure the payment method:</p><p>1. <a target="_blank" href="https://developer.intuit.com/app/developer/qbo/docs/develop/authentication-and-authorization/oauth-2.0#obtain-oauth2-credentials-for-your-app">Obtain OAuth 2.0</a> credentials from <b>QuickBooks Online</b> application (QuickBooks Desktop won''t work).</p><p>2. Copy them to the payment method settings in [product].</p><p>3. Click "Create", then open the settings of this payment method again to finish its configuration.</p>'),
('en', 'text_money_back_guarantee', 'We offer 30-day money-back guarantee. If you don''t like our product, we''ll return you the money, no needless questions asked.'),
('en', 'admin_panel_will_be_blocked', 'Installation integrity check failed. The access to the Administration panel will be blocked within 2 days. Please contact our <a href="[href]">support team</a>'),
('en', 'text_license_is_disabled', 'The license is disabled. Please check your license status.'),
('en', 'text_license_is_invalid', 'Invalid license number. Please enter a valid license number.'),
('en', 'text_license_is_disabled_full', 'The license is disabled. Please check your license status or select a different store mode.'),
('en', 'text_license_is_invalid_full', 'Invalid license number. Please enter a valid license number or select a different store mode.'),
('en', 'shipping_tips', ''),
('en', 'error_directory_not_writable', 'Directory "[dir]" is not writable. Please check permissions for this directory of your installation.'),
('en', 'error_cannot_delete_files', 'Cannot delete files: <b>[files]</b>. Please check the permissions.'),
('en', 'feature_groups', 'Feature groups'),
('en', 'shippings.can.business_account_information', 'Business account information'),
('en', 'shippings.can.customer_number', 'Customer number'),
('en', 'ttc_shippings.can.customer_number', 'Customer number is required for commercial customers and Solutions for Small Business members to get discounted rates if parcel is mailed on behalf of customer'),
('en', 'shippings.can.contract_id', 'Contract ID'),
('en', 'ttc_shippings.can.contract_id', 'Contract ID is required to obtain discounted rates for commercial customers when the Customer number is specified. Contract ID must be omitted for Solutions for Small Business members or general business users'),
('en', 'shippings.can.api_keys', 'API keys'),
('en', 'shippings.can.username', 'Username'),
('en', 'shippings.can.password', 'Password'),
('en', 'shippings.can.options', 'Delivery options'),
('en', 'shippings.can.option_so', 'Signature'),
('en', 'shippings.can.option_cov', 'Coverage'),
('en', 'ttc_shippings.can.option_cov', 'Requires amount'),
('en', 'shippings.can.option_cov_amount', 'Coverage amount'),
('en', 'shippings.can.option_cod', 'Collect on Delivery'),
('en', 'shippings.can.option_pa18', 'Proof of Age Required - 18'),
('en', 'shippings.can.option_pa19', 'Proof of Age Required - 19'),
('en', 'shippings.can.option_hfp', 'Card for pickup'),
('en', 'shippings.can.option_dns', 'Do not safe drop'),
('en', 'shippings.can.option_lad', 'Leave at door - do not card'),
('en', 'shippings.aup.pac_api_key', 'PAC API key'),
('en', 'shippings.aup.currency_not_configured', 'To activate the Australia Post shipping processor, you must have the Australian Dollar currency enabled.'),
('en', 'licensing_and_upgrades', 'Licensing and upgrades'),
('en', 'addon_license_key_tooltip', 'Enter license key you''ve received by e-mail in order to receive the add-on upgrades.'),
('en', 'api_shipments_update_not_allowed', 'Only tracking_number, status, comments and timestamp can be updated'),
('en', 'api_shipments_status_not_correct', 'Value of status field is not correct. Allowed values: ''A'', ''P'', ''S'''),
('en', 'cannot_remove_theme_has_dependent_themes', 'The theme can''t be removed as the following themes depend on it: [dependent_themes]'),
('en', 'text_installing_theme_dependencies', 'Installing the theme dependencies: [dependencies]'),
('en', 'text_unable_to_install_theme_dependencies', 'Unable to install the theme dependencies: [dependencies]'),
('en', 'exim_cannot_create_variant_for_shareable_feature', 'You cannot create a variant for a shareable feature.'),
('en', 'warning_default_language_sharing_removed', 'The default language defined in settings has been removed for the <b>[company]</b> storefront. Please update the Frontend default language value on the following page: <a href="[link]">Settings :: Appearance</a>'),
('en', 'warning_default_currency_absent', 'Could not assign default currency for the <b>[storefront]</b> storefront. Please update the default currency value on the following page: <a href="[link]">Administration :: Currencies</a>'),
('en', 'page_url', 'Page URL'),
('en', 'tt_views_pages_components_pages_link_page_url', 'The page inner URL'),
('en', 'page_target_url', 'Target URL'),
('en', 'tt_views_pages_components_pages_link_page_target_url', 'The URL to redirect customers to'),
('en', 'shippings.fedex.freight_account_number', 'Freight account number'),
('en', 'ship_fedex_package_type_fedex_extra_large_box', 'FedEx Extra Large Box'),
('en', 'ship_fedex_package_type_fedex_large_box', 'FedEx Large Box'),
('en', 'ship_fedex_package_type_fedex_medium_box', 'FedEx Medium Box'),
('en', 'ship_fedex_package_type_fedex_small_box', 'FedEx Small Box'),
('en', 'ship_fedex_drop_off_type_business_service_center', 'Business service center'),
('en', 'ship_fedex_drop_off_type_drop_box', 'Drop box'),
('en', 'shippings.fedex.options', 'Delivery options'),
('en', 'shippings.fedex.option_broker_select_option', 'Broker select option'),
('en', 'shippings.fedex.option_call_before_delivery', 'Call before delivery'),
('en', 'shippings.fedex.option_cod', 'COD'),
('en', 'shippings.fedex.option_cod_amount', 'COD amount'),
('en', 'shippings.fedex.option_cod_collection_type', 'COD collection type'),
('en', 'shippings.fedex.option_cod_collection_type_any', 'Any'),
('en', 'shippings.fedex.option_cod_collection_type_cash', 'Cash'),
('en', 'shippings.fedex.option_cod_collection_type_guaranteed_funds', 'Guaranteed funds'),
('en', 'shippings.fedex.option_custom_delivery_window', 'Custom delivery window'),
('en', 'shippings.fedex.option_dangerous_goods', 'Dangerous goods'),
('en', 'shippings.fedex.option_dangerous_goods_options', 'Hazardous content options'),
('en', 'shippings.fedex.option_dangerous_goods_options_battery', 'Battery'),
('en', 'shippings.fedex.option_dangerous_goods_options_hazardous_materials', 'Hazardous materials'),
('en', 'shippings.fedex.option_dangerous_goods_options_orm_d', 'ORM-D'),
('en', 'shippings.fedex.option_dangerous_goods_options_limited_quantities_commodities', 'Limited quantities commodities'),
('en', 'shippings.fedex.option_dangerous_goods_options_reportable_quantities', 'Reportable quantities'),
('en', 'shippings.fedex.option_dangerous_goods_options_small_quantity_exception', 'Small quantity exception'),
('en', 'shippings.fedex.option_dangerous_goods_accessibility', 'Dangerous goods accessibility'),
('en', 'shippings.fedex.option_dangerous_goods_accessibility_accessible', 'Accessible'),
('en', 'shippings.fedex.option_dangerous_goods_accessibility_inaccessible', 'Inaccessible'),
('en', 'shippings.fedex.option_do_not_break_down_pallets', 'Do not break down pallets'),
('en', 'shippings.fedex.option_do_not_stack_pallets', 'Do not stack pallets'),
('en', 'shippings.fedex.option_dry_ice', 'Dry ice'),
('en', 'shippings.fedex.option_east_coast_special', 'East Coast special'),
('en', 'shippings.fedex.option_electronic_trade_documents', 'Electronic trade documents'),
('en', 'shippings.fedex.option_extreme_length', 'Extreme length'),
('en', 'shippings.fedex.option_food', 'Food'),
('en', 'shippings.fedex.option_fedex_one_rate', 'FedEx One Rate'),
('en', 'shippings.fedex.option_freight_guarantee', 'Freight guarantee'),
('en', 'shippings.fedex.option_freight_to_collect', 'Freight to collect'),
('en', 'shippings.fedex.option_future_day_shipment', 'Future day shipment'),
('en', 'shippings.fedex.option_hold_at_location', 'Hold at location'),
('en', 'shippings.fedex.option_home_delivery_premium', 'Home delivery Premium'),
('en', 'shippings.fedex.option_inside_delivery', 'Inside delivery'),
('en', 'shippings.fedex.option_inside_pickup', 'Inside pickup'),
('en', 'shippings.fedex.option_international_controlled_export_service', 'International controlled export service'),
('en', 'shippings.fedex.option_international_traffic_in_arms_regulations', 'International traffic in arms regulations'),
('en', 'shippings.fedex.option_liftgate_delivery', 'Liftgate delivery'),
('en', 'shippings.fedex.option_liftgate_pickup', 'Liftgate pickup'),
('en', 'shippings.fedex.option_limited_access_delivery', 'Limited access delivery'),
('en', 'shippings.fedex.option_limited_access_pickup', 'Limited access pickup'),
('en', 'shippings.fedex.option_pharmacy_delivery', 'Pharmacy delivery'),
('en', 'shippings.fedex.option_poison', 'Poison'),
('en', 'shippings.fedex.option_protection_from_freezing', 'Protection from freezing'),
('en', 'shippings.fedex.option_returns_clearance', 'Returns clearance'),
('en', 'shippings.fedex.option_saturday_delivery', 'Saturday delivery'),
('en', 'shippings.fedex.option_saturday_pickup', 'Saturday pickup'),
('en', 'shippings.fedex.option_top_load', 'Top load'),
('en', 'template_document_order_invoice', 'Invoice'),
('en', 'template_document_order_summary', 'Order summary'),
('en', 'template_document_packing_slip_default', 'Packing slip'),
('en', 'documents', 'Documents'),
('en', 'document_preview_order_not_found', 'Couldn''t find an order. Preview only works with existing data. Please create an order and use Preview again.'),
('en', 'editing_order_invoice', 'Editing invoice for order #[order_id]'),
('en', 'email_order_invoice_subject', '[company_name]: Invoice for order #[order_id]'),
('en', 'edit_and_send_invoice', 'Tweak and send invoice'),
('en', 'error_profile_field_name_exists', 'A profile field with this name already exists. Please choose another name.'),
('en', 'profile_field_name', 'Field name'),
('en', 'profile_field_name_tooltip', 'A character sequence that serves as an identifier. You can use figures from 0 to 9, symbols of the English alphabet and "_" sign.'),
('en', 'text_character_identifier_tooltip', 'A character sequence that serves as an identifier. You can use figures from 0 to 9, symbols of the English alphabet and the following signs: "-", "_", ".".'),
('en', 'core_files_have_been_modified', 'Some of your <a href="[changes_url]">core files</a>  were changed manually. That can lead to various problems, especially when upgrading to a new version of [product]. To learn more about why we advise against changing the core files, please read this <a href="[docs_url]" target="_blank" >article</a>.<br><br>[product] automatically checks for changes in core files every time you log in. To disable this check, go to <a href="[settings_url]">Settings → General</a>  and untick the Monitor changes in core files checkbox.'),
('en', 'scan_for_modified_core_files', 'Scan for changed core files'),
('en', 'last_scan_time', 'Last scan time'),
('en', 'no_modified_core_files_found', 'No changed core files found'),
('en', 'modified_core_files_found', 'Some of your core files have been changed. This may become a problem when upgrading [product] as changes in these files may be lost.'),
('en', 'file_changes_detector', 'File changes detector'),
('en', 'privileges.view_file_changes', 'Can view'),
('en', 'error_shipment_not_created', 'Couldn''t create a shipment. Please choose a carrier or enter a tracking number.'),
('en', 'my_cart', 'My cart'),
('en', 'exclusive_promotions', 'Exclusive discounts'),
('en', 'exclusive_promotions_content', 'Subscribe to our news and get a 10% discount coupon!'),
('en', 'tmpl_subscription_advanced', 'Subscription advanced form'),
('en', 'tmpl_newsletters_subscription_advanced', 'Newsletters: subscription advanced form'),
('en', 'tmpl_payment_icons_rus', 'Payment systems russian icons'),
('en', 'my_account_links_advanced', 'My account advanced'),
('en', 'api_access_has_been_enabled', 'You are free to use the API now'),
('en', 'api_access_has_been_disabled', 'From now on, you cannot use the API'),
('en', 'report_a_bug', 'Report a bug'),
('en', 'import_results', 'Import results'),
('en', 'import_errors', 'Import errors'),
('en', 'email_template_import_success_msg', 'All the email templates have been imported without errors.'),
('en', 'document_import_success_msg', 'All the documents have been imported without errors.'),
('en', 'count_document_successfully_imported', 'Documents successfully imported:'),
('en', 'count_email_template_successfully_imported', 'Email templates successfully imported:'),
('en', 'count_snippet_successfully_imported', 'Snippets successfully imported:'),
('en', 'count_document_fail_imported', 'Documents import failed:'),
('en', 'count_email_template_fail_imported', 'Email templates import failed:'),
('en', 'count_snippet_fail_imported', 'Snippets import failed:'),
('en', 'storefronts_limit_exceeded', 'The number of storefronts in your CS-Cart License has exceeded the number of purchased storefront licenses.'),
('en', 'licensed_product', 'Licensed product'),
('en', 'store_mode.free', 'Free'),
('en', 'store_mode.ultimate', 'Ultimate'),
('en', 'store_mode.enterprise', 'Enterprise'),
('en', 'product_state_description.ult.new', '<p>You can use one of these licenses: <a href="[standard_license_url]" target="_blank">[product]</a> or <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>. Both licenses allow you to use [product] without time restrictions.</p><br>'),
('en', 'product_state_description.ult', '<p>You can use the software without time restrictions now. Please note that some advanced features are available only in <a href="[ultimate_license_url]" target="_blank">[product] Ultimate.</a></p><br>'),
('en', 'product_state_description.ult.ultimate', '<p>You can use the software without time restrictions now.</p><br>'),
('en', 'product_state_description.ult.enterprise', '<p>You can use the software without time restrictions now.</p><br>'),
('en', 'product_state_description.ult.ru.new', '<p>You can use one of these licenses: <a href="[standard_license_url]" target="_blank">[product]</a> or <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>. Both licenses allow you to use [product] without time restrictions.</p><br>'),
('en', 'product_state_description.ult.ru', '<p>You can use the software without time restrictions now. Please note that some advanced features are available only in <a href="[ultimate_license_url]" target="_blank">[product] Ultimate.</a></p><br>'),
('en', 'product_state_description.ult.ru.ultimate', '<p>You can use the software without time restrictions now.</p><br>'),
('en', 'product_state_description.ult.ru.enterprise', '<p>You can use the software without time restrictions now.</p><br>'),
('en', 'product_state_description.ult.b2b.new', '<p>You can use one of these licenses: <a href="[standard_license_url]" target="_blank">[product]</a> or <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>. Both licenses allow you to use [product] without time restrictions.</p><br>'),
('en', 'product_state_description.ult.b2b', '<p>You can use the software without time restrictions now. Please note that some advanced features are available only in <a href="[ultimate_license_url]" target="_blank">[product] Ultimate.</a></p><br>'),
('en', 'product_state_description.ult.b2b.ultimate', '<p>You can use the software without time restrictions now.</p><br>'),
('en', 'product_state_description.ult.b2b.enterprise', '<p>You can use the software without time restrictions now.</p><br>'),
('en', 'text_store_mode_changed_to_ult.free', 'Your store now uses an active license of [product].'),
('en', 'text_store_mode_changed_to_ult.free_ru', 'Your store now uses an active license of [product].'),
('en', 'text_store_mode_changed_to_ult', 'Your store now uses an active license of [product].'),
('en', 'text_store_mode_changed_to_ult.ultimate', 'Your store now uses an active license of [product].'),
('en', 'text_store_mode_changed_to_ult.enterprise', 'Your store now uses an active license of [product].'),
('en', 'text_store_mode_changed_to_ult.ru', 'Your store now uses an active license of [product].'),
('en', 'text_store_mode_changed_to_ult.ru.ultimate', 'Your store now uses an active license of [product].'),
('en', 'text_store_mode_changed_to_ult.ru.enterprise', 'Your store now uses an active license of [product].'),
('en', 'text_store_mode_changed_to_ult.b2b', 'Your store now uses an active license of [product].'),
('en', 'text_store_mode_changed_to_ult.b2b.ultimate', 'Your store now uses an active license of [product].'),
('en', 'text_store_mode_changed_to_ult.b2b.enterprise', 'Your store now uses an active license of [product].'),
('en', 'ultimate_license', '[product] Ultimate'),
('en', 'ultimate_license_required', '[product] Ultimate is required for this'),
('en', 'ultimate_or_storefront_license_required', 'This action requires [product] Ultimate'),
('en', 'ultimate_or_storefront_license_required.ult.new', 'This action requires [product] Ultimate'),
('en', 'ultimate_or_storefront_license_required.ult', 'This action requires [product] Ultimate'),
('en', 'ultimate_or_storefront_license_required.ult.ultimate', 'This action requires [product] Ultimate'),
('en', 'ultimate_or_storefront_license_required.ult.b2b.new', 'This action requires [product] Ultimate'),
('en', 'ultimate_or_storefront_license_required.ult.b2b', 'This action requires [product] Ultimate'),
('en', 'ultimate_or_storefront_license_required.ult.b2b.ultimate', 'This action requires [product] Ultimate'),
('en', 'ultimate_or_storefront_license_required.ult.ru.new', 'This action requires [product] Ultimate'),
('en', 'ultimate_or_storefront_license_required.ult.ru', 'This action requires [product] Ultimate'),
('en', 'ultimate_or_storefront_license_required.ult.ru.ultimate', 'This action requires [product] Ultimate'),
('en', 'max_storefronts_reached', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'max_storefronts_reached.ult.new', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'max_storefronts_reached.ult', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'max_storefronts_reached.ult.ultimate', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'max_storefronts_reached.ult.b2b.new', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'max_storefronts_reached.ult.b2b', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'max_storefronts_reached.ult.b2b.ultimate', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'max_storefronts_reached.ult.ru.new', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'max_storefronts_reached.ult.ru', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'max_storefronts_reached.ult.ru.ultimate', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'new_text_ultimate_license_required', 'A special edition of [product] that offers an unlimited number of storefronts. If you switch to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>, you''ll never see the message about the storefront limit again.'),
('en', 'text_only_ultimate_license_required', 'A special edition called [product] Ultimate is required to perform this action. If you switch to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>, you''ll never see this message again, and you''ll also be able to create an unlimited number of storefronts.'),
('en', 'text_storefront_license_required', 'An additional storefront for your standard [product] license. Good for those who don''t intend to add a few more storefronts in the future.'),
('en', 'available_upgrades', 'Available upgrades'),
('en', 'additional_storefront_license_required', 'Additional [product] Storefront License Required'),
('en', 'text_additional_storefront_license_required', '<p>You can''t add a new storefront. The maximum number of storefronts allowed by your current license <code>[license_number]</code> is [allowed_storefronts], and you currently have [existing_storefronts].</p><p>To be able to add another storefront, please buy additional [product] Storefront License. If you want to add multiple new storefronts, buy the corresponding number of licenses.</p>'),
('en', 'storefront_license', 'Storefront License'),
('en', 'buy_new_storefront_license', 'Buy [product] Storefront License'),
('en', 'import_new_vendor', '[n] new vendor was created during the import. This vendor only has a name so far. Please edit the new vendor to add other information.|[n] new vendors were created during the import. These vendors only have names so far. Please edit the new vendors to add other information.'),
('en', 'file_changes_detector.snapshot_not_found', 'Snapshot of the clear installation was not found. Please restore <b>[dist_filename]</b>.'),
('en', 'file_changes_detector.added', 'Added'),
('en', 'file_changes_detector.changed', 'Changed'),
('en', 'file_changes_detector.deleted', 'Deleted'),
('en', 'licensing.license_error_license_is_disabled', 'The license is disabled. Please check your license status.'),
('en', 'licensing.license_error_license_is_disabled.title', 'Your [product] license has been disabled'),
('en', 'licensing.license_error_license_is_disabled.text', 'Please contact us <a href="[helpdesk_url]" target="_blank">via Customer Help Desk</a> to find out why it happened and what can be done about it. To access the admin panel right now, you can enter another valid license number, as long as it isn''t used in another store:'),
('en', 'licensing.license_error_license_is_invalid', 'Invalid license number. Please enter a valid license number.'),
('en', 'licensing.license_error_wrong_edition', 'The license does not match your store edition. Please enter a valid license number.'),
('en', 'licensing.license_error_wrong_licensing_mode', 'The license does not match your store licensing mode. Please enter a valid license number.'),
('en', 'upgrade_center.upgrade_process_failed', 'Upgrade process of your store has failed'),
('en', 'upgrade_center.apply_migration_failed', '<p>Please restore the pre-upgrade backup manually or via a link sent to your email address, then contact our technical support.</p><br><p>Tech details: Couldn''t complete migration [migration]. Reason: [error].</p><p>Completed migrations: [processed_count] out of [total_count].</p>'),
('en', 'profile_deactivated', 'Account deactivated'),
('en', 'text_profile_deactivated', 'Your account has been deactivated. Please contact us for more details.'),
('en', 'email_template.profile_deactivated', 'User account deactivation'),
('en', 'text_addon_disable_dependencies', 'The add-on cannot be disabled because the following add-ons depend on it: [addons]'),
('en', 'text_addon_enable_dependencies', 'The add-on cannot be enabled because it depends on the following add-ons: [addons]'),
('en', 'current_setting_value', 'Current value'),
('en', 'new_setting_value', 'New value'),
('en', 'overwrite_selected_settings', 'Overwrite selected settings'),
('en', 'payment_method_not_found', 'Payment method not found. It could''ve been disabled, or a technical problem occurred. Please choose a payment method and try again.'),
('en', 'shippings.ups.package_type.00', 'UNKNOWN'),
('en', 'shippings.ups.package_type.01', 'UPS Letter'),
('en', 'shippings.ups.package_type.02', 'Package'),
('en', 'shippings.ups.package_type.03', 'Tube'),
('en', 'shippings.ups.package_type.04', 'Pak'),
('en', 'shippings.ups.package_type.21', 'Express Box'),
('en', 'shippings.ups.package_type.24', '25KG Box'),
('en', 'shippings.ups.package_type.25', '10KG Box'),
('en', 'shippings.ups.package_type.30', 'Pallet'),
('en', 'shippings.ups.package_type.2a', 'Small Express Box'),
('en', 'shippings.ups.package_type.2b', 'Medium Express Box'),
('en', 'shippings.ups.package_type.2c', 'Large Express Box'),
('en', 'wrong_number_initial_order_id', 'The value you entered for the "Initial order ID value" setting is not supported. Only integers from 1 to [max_initial_order_id] are supported'),
('en', 'tt_views_shippings_components_services_ups_ship_ups_pickup_type', '<p>Select "Daily Pickup" to calculate the delivery cost according to Daily Rates.</p><p>Select "One Time Pickup", "Letter Center", or "Air Service Center" to calculate the delivery cost according to Retail Rates.</p>'),
('en', 'php_extension_missing', 'The [extension] PHP extension is not installed on your server'),
('en', 'customization', 'Customization'),
('en', 'assign_to_me', 'Assign to me'),
('en', 'customer_phone', 'Customer phone'),
('en', 'could_not_connect_to_database', 'Could not connect to database'),
('en', 'information_file_roobots', 'A robots.txt file was detected. The changes you make here won''t take effect until you delete the existing <b>robots.txt</b> file from the root directory of your store.'),
('en', 'advanced_products_search', 'Advanced products search'),
('en', 'advanced_companies_search', 'Advanced companies search'),
('en', 'advanced_storefronts_search', 'Advanced storefronts search'),
('en', 'api_wrong_user_company_relation', 'The user doesn''t exist for this store, and sharing users among stores is disabled.'),
('en', 'product_details_tabs', 'Tabs'),
('en', 'shippings.fedex.currency_is_missing', 'The rates calculated by FedEx are in [currency], and that currency doesn''t exist in your store. Please create that currency; otherwise customers won''t be able to select this shipping method.'),
('en', 'text_redactor2', 'Redactor II'),
('en', 'image_url', 'Image URL'),
('en', 'insert_image', 'Insert image'),
('en', 'view_avail_files_for_order', 'View the list of available files from order #[order_id].'),
('en', 'advanced_customer_search', 'Advanced customer search'),
('en', 'change_customer', 'Change customer'),
('en', 'on_backorder', 'On backorder'),
('en', 'invoice_heading', 'Invoice'),
('en', 'min_quantity', 'Minimum order quantity'),
('en', 'ship_downloadable', 'Enable shipping for downloadable products'),
('en', 'inventory_tracking', 'Inventory'),
('en', 'detailed_image', 'Detailed image'),
('en', 'secondary_categories', 'Secondary category'),
('en', 'override_points', 'Override points'),
('en', 'override_exchange_rate', 'Override exchange rate'),
('en', 'max_quantity', 'Maximum order quantity'),
('en', 'list_qty_count', 'List quantity count'),
('en', 'product_url', 'Product URL'),
('en', 'detailed_image_url', 'Detailed image URL'),
('en', 'box_size', 'Box size'),
('en', 'usergroup_ids', 'Usergroup ids'),
('en', 'combination_code', 'Combination code'),
('en', 'pair_type', 'Pair type'),
('en', 'lower_limit', 'Lower limit'),
('en', 'user_group', 'User group'),
('en', 'percentage_discount', 'Percentage discount'),
('en', 'feature_name', 'Feature name'),
('en', 'feature_id', 'Feature ID'),
('en', 'show_on_the_features_tab', 'Show on the features tab'),
('en', 'show_in_product_list', 'Show in product list'),
('en', 'show_in_product_header', 'Show in product header'),
('en', 'comparsion', 'Comparison'),
('en', 'variant_id', 'Variant ID'),
('en', 'feature_group', 'Feature group'),
('en', 'payment_id', 'Payment ID'),
('en', 'billing_first_name', 'Billing: first name'),
('en', 'billing_last_name', 'Billing: last name'),
('en', 'billing_address_line_2', 'Billing: address (line 2)'),
('en', 'billing_city', 'Billing: city'),
('en', 'billing_state', 'Billing: state'),
('en', 'billing_country', 'Billing: country'),
('en', 'billing_zipcode', 'Billing: zipcode'),
('en', 'shipping_first_name', 'Shipping: first name'),
('en', 'shipping_last_name', 'Shipping: last name'),
('en', 'shipping_address_line_2', 'Shipping: address (line 2)'),
('en', 'shipping_city', 'Shipping: city'),
('en', 'shipping_state', 'Shipping: state'),
('en', 'shipping_country', 'Shipping: country'),
('en', 'shipping_zipcode', 'Shipping: zipcode'),
('en', 'item_id', 'Item ID'),
('en', 'issuer_id', 'Issuer ID'),
('en', 'billing_phone', 'Billing: phone'),
('en', 'shipping_phone', 'Shipping: phone'),
('en', 'extra_fields', 'Extra fields'),
('en', 'country_code', 'Country code'),
('en', 'salt', 'Salt'),
('en', 'user_group_ids', 'User group IDs'),
('en', 'skip_creating_new_products', 'Skip creating new products'),
('en', 'text_skip_creating_new_products', 'If you enable this setting, then only the products that already exist in your database will be updated.'),
('en', 'update_existing_products_only', 'Update existing products only'),
('en', 'update_existing_products_only_tooltip', 'If you enable this setting, products that don''t exist in the database of your store will be skipped during import.'),
('en', 'updated_last', 'Updated in the last'),
('en', 'hour_or_hours', 'hour(s)'),
('en', 'api_required_fields', 'The following fields are required: [fields]'),
('en', 'api_one_of_fields_required', 'One of the following fields is required: [fields]'),
('en', 'api_invalid_value', 'Invalid value `[value]` specified for [field]'),
('en', 'api_invalid_value_w_valid_list', 'Invalid value `[value]` specified for [field]. Valid values are: [valid_list]'),
('en', 'api_empty_value', 'Empty value specified for the required [field] field.'),
('en', 'recover', 'Recover'),
('en', 'image_has_been_deleted', 'This image has been deleted'),
('en', 'delete_all_images', 'Delete all images'),
('en', 'cannot_upload_file', 'Cannot upload file'),
('en', 'ogone.sha_in', 'SHA-IN pass phrase'),
('en', 'ttc_ogone.sha_in', 'The SHA-IN pass phrase is set on the Ingenico administration panel on the <b>Data and origin verification</b> tab.'),
('en', 'ogone_web.sha_out', 'SHA-OUT pass phrase'),
('en', 'ttc_ogone_web.sha_out', 'The SHA-OUT pass phrase is set on the Ingenico administration panel on the <b>Transaction feedback</b> tab.'),
('en', 'ogone_direct.config_info', 'Enter SHA-IN pass phrase both here and on the Ingenico administation panel.<br><br>For new Ingenico accounts created since May 11th, 2010, the new SHA policy is automatically active.<br/>Please do not forget to select the "Use new SHA signature policy" checkbox.'),
('en', 'ogone_web.config_info', 'Please set the following URL in the Technical Information section on the Ingenico administation panel as the <b>URL of the merchant''s post-payment page</b> for all cases ("accepted", "on hold", "uncertain", "canceled by the client", "too many rejections by the acquirer"): <code>[r_url]</code><br>Select "Always deferred (not immediately after the payment)" for the <b>Timing of the request</b>.<br>Enter SHA-IN and SHA-OUT pass phrases both here and on the Ingenico administation panel.'),
('en', 'sort_by_null_desc', 'No sorting'),
('en', 'storefront_name', 'Storefront name'),
('en', 'storefront_name_short', 'Storefront name'),
('en', 'internal_option_name', 'Internal name'),
('en', 'internal_option_name_tooltip', 'This name is shown only in the Administration panel to help you distinguish between multiple options that have the same displayed name.'),
('en', 'internal_feature_name_tooltip', 'This name is shown only in the Administration panel to help you distinguish between multiple features that have the same displayed name.'),
('en', 'internal_feature_group_name_tooltip', 'This name is shown only in the Administration panel to help you distinguish between multiple feature groups that have the same displayed name.'),
('en', 'edit_corresponding_profile_field', 'To change the field type or variants, <a href="[URL]">edit the corresponding field in the Shipping Address section</a>.'),
('en', 'error_product_codes_length', 'The following product codes are too long and were cut off at [product_code_length] symbols:'),
('en', 'log_action_shipping', 'Shipping request'),
('en', 'email_template.shipping_error', 'Shipping: request error'),
('en', 'request_error_information_title', 'Shipping error'),
('en', 'request_error_information', 'Customers have experienced issues with receiving rates from <b>the [shipping]</b> shipping method. Please make sure that is configured properly and that the shipping rate calculation is correct'),
('en', 'press_continue_to_recover_password', 'Click <b>Continue</b> to proceed with password change.'),
('en', 'file_uploader.default_message', 'Drop files here to upload'),
('en', 'file_uploader.fallback_message', 'Your browser does not support drag''n''drop file uploads.'),
('en', 'file_uploader.fallback_text', 'Please use the fallback form below to upload your files like in the olden days.'),
('en', 'file_uploader.file_too_big', 'File is too big ({{filesize}}MB). Max filesize: {{maxFilesize}}MB.'),
('en', 'file_uploader.invalid_file_type', 'You can''t upload files of this type.'),
('en', 'file_uploader.response_error', 'Server responded with {{statusCode}} code.'),
('en', 'file_uploader.cancel_upload', 'Cancel upload'),
('en', 'file_uploader.upload_canceled', 'Upload canceled.'),
('en', 'file_uploader.cancel_upload_confirmation', 'Are you sure you want to cancel this upload?'),
('en', 'file_uploader.remove_file', 'Remove file'),
('en', 'file_uploader.remove_file_confirmation', 'Do you want to remove this image?'),
('en', 'file_uploader.max_files_exceeded', 'You can not upload any more files.'),
('en', 'file_uploader.file_size_units_tb', 'TB'),
('en', 'file_uploader.file_size_units_gb', 'GB'),
('en', 'file_uploader.file_size_units_mb', 'MB'),
('en', 'file_uploader.file_size_units_kb', 'KB'),
('en', 'file_uploader.file_size_units_b', 'b'),
('en', 'drop_images_to_upload', 'Drop images here'),
('en', 'drop_images_select_short', 'Select'),
('en', 'drop_images_select', 'Select images'),
('en', 'currency_code_afn', 'Afghan Afghani'),
('en', 'currency_code_dzd', 'Algerian Dinar'),
('en', 'currency_code_aoa', 'Angolan Kwanza'),
('en', 'currency_code_aon', 'Angolan New Kwanza'),
('en', 'currency_code_ats', 'Antillian Guilder'),
('en', 'currency_code_azn', 'Azerbaijanian Manat'),
('en', 'currency_code_bsd', 'Bahamian Dollar'),
('en', 'currency_code_bhd', 'Bahraini Dinar'),
('en', 'currency_code_bdt', 'Bangladesh Taka'),
('en', 'currency_code_bbd', 'Barbados Dollar'),
('en', 'currency_code_byn', 'Belarussian Ruble'),
('en', 'currency_code_bef', 'Belgian Franc'),
('en', 'currency_code_bzd', 'Belize Dollar'),
('en', 'currency_code_bmd', 'Bermudian Dollar'),
('en', 'currency_code_btn', 'Bhutan Ngultrum'),
('en', 'currency_code_bob', 'Bolivian Boliviano'),
('en', 'currency_code_bam', 'Bosnia and Herzegovina Convertible Marks'),
('en', 'currency_code_bwp', 'Botswana Pula'),
('en', 'currency_code_bnd', 'Brunei Dollar'),
('en', 'currency_code_bgl', 'Bulgaria Lev'),
('en', 'currency_code_bif', 'Burundi Franc'),
('en', 'currency_code_khr', 'Cambodian Riel'),
('en', 'currency_code_cve', 'Cape Verde Escudo'),
('en', 'currency_code_kyd', 'Cayman Islands Dollar'),
('en', 'currency_code_clp', 'Chilean Peso'),
('en', 'currency_code_cop', 'Colombian Peso'),
('en', 'currency_code_kmf', 'Congolese Franc'),
('en', 'currency_code_crc', 'Costa Rican Colon'),
('en', 'currency_code_cyp', 'Cyprus Pound'),
('en', 'currency_code_dem', 'Deutsche Mark'),
('en', 'currency_code_djf', 'Djibouti Franc'),
('en', 'currency_code_std', 'Dobra'),
('en', 'currency_code_dop', 'Dominican Peso'),
('en', 'currency_code_nlg', 'Dutch Guilder'),
('en', 'currency_code_xcd', 'East Caribbean Dollar'),
('en', 'currency_code_ecs', 'Ecuador Sucre'),
('en', 'currency_code_cdf', 'Congolese Franc'),
('en', 'currency_code_svc', 'El Salvador Colon'),
('en', 'currency_code_ern', 'Eritrean Nafka'),
('en', 'currency_code_etb', 'Ethiopian Birr'),
('en', 'currency_code_fkp', 'Falkland Islands Pound'),
('en', 'currency_code_fim', 'Finnish Markka'),
('en', 'currency_code_gmd', 'Gambian Dalasi'),
('en', 'currency_code_ghs', 'Ghana Cedi'),
('en', 'currency_code_gip', 'Gibraltar Pound'),
('en', 'currency_code_grd', 'Greek Drachma'),
('en', 'currency_code_gtq', 'Guatemalan Quetzal'),
('en', 'currency_code_gnf', 'Guinea Franc'),
('en', 'currency_code_gyd', 'Guyana Dollar'),
('en', 'currency_code_htg', 'Haiti Gourde'),
('en', 'currency_code_hnl', 'Honduran Lempira'),
('en', 'currency_code_idr', 'Indonesian Rupiah'),
('en', 'currency_code_irr', 'Iranian Rial'),
('en', 'currency_code_iqd', 'Iraqi Dinar'),
('en', 'currency_code_iep', 'Irish Pound'),
('en', 'currency_code_itl', 'Italian Lira'),
('en', 'currency_code_jmd', 'Jamaican Dollar'),
('en', 'currency_code_jod', 'Jordanian Dinar'),
('en', 'currency_code_kes', 'Kenyan Shilling'),
('en', 'currency_code_lak', 'Laos Kip'),
('en', 'currency_code_lbp', 'Lebanese Pound'),
('en', 'currency_code_lsl', 'Lesotho Loti (Maloti)'),
('en', 'currency_code_lrd', 'Liberian Dollar'),
('en', 'currency_code_lyd', 'Libyan Dinar'),
('en', 'currency_code_luf', 'Luxembourg Franc'),
('en', 'currency_code_mop', 'Macau Pataca'),
('en', 'currency_code_mkd', 'Macedonian (FYR) Denar'),
('en', 'currency_code_mga', 'Malagasy Ariary'),
('en', 'currency_code_mgf', 'Malagasy Franc'),
('en', 'currency_code_mwk', 'Malawi Kwacha');
INSERT INTO `[[dbprefix]]language_values` VALUES
('en', 'currency_code_mvr', 'Maldives Rufiyaa'),
('en', 'currency_code_mtl', 'Maltese Lira'),
('en', 'currency_code_mro', 'Mauritania Ouguiya'),
('en', 'currency_code_mur', 'Mauritius Rupee'),
('en', 'currency_code_mdl', 'Moldovan Leu'),
('en', 'currency_code_mnt', 'Mongolian Tugrik'),
('en', 'currency_code_mzn', 'Mozambique Metical'),
('en', 'currency_code_mmk', 'Myanmar Kyat'),
('en', 'currency_code_nad', 'Namibian Dollar'),
('en', 'currency_code_npr', 'Nepalese Rupee'),
('en', 'currency_code_rsd', 'New Serbian Dinar'),
('en', 'currency_code_nio', 'Nicaraguan Cordoba Oro'),
('en', 'currency_code_ngn', 'Nigerian Naira'),
('en', 'currency_code_pkr', 'Pakistan Rupee'),
('en', 'currency_code_pab', 'Panamanian Balboa'),
('en', 'currency_code_pgk', 'Papua New Guinea Kina'),
('en', 'currency_code_pyg', 'Paraguayan Guarani'),
('en', 'currency_code_pen', 'Peruvian Nuevo Sol'),
('en', 'currency_code_uyu', 'Peso Uruguayo'),
('en', 'currency_code_pte', 'Portugese Escudo'),
('en', 'currency_code_qar', 'Qatari Rial'),
('en', 'currency_code_omr', 'Rial Omani'),
('en', 'currency_code_rol', 'Romanian Lei'),
('en', 'currency_code_rwf', 'Rwanda Franc'),
('en', 'currency_code_csd', 'Serbian Dinar'),
('en', 'currency_code_scr', 'Seychelles Rupee'),
('en', 'currency_code_sll', 'Sierra Leone Leone'),
('en', 'currency_code_sos', 'Somalia Shilling'),
('en', 'currency_code_esp', 'Spanish Peseta'),
('en', 'currency_code_lkr', 'Sri Lanka Rupee'),
('en', 'currency_code_shp', 'St Helena Pound'),
('en', 'currency_code_sdp', 'Sudanese Pound'),
('en', 'currency_code_srd', 'Suriname Dollar'),
('en', 'currency_code_srg', 'Suriname Guilder'),
('en', 'currency_code_szl', 'Swaziland Lilangeni'),
('en', 'currency_code_syp', 'Syrian Pound'),
('en', 'currency_code_tjs', 'Tajikistan Somoni'),
('en', 'currency_code_tzs', 'Tanzanian Shilling'),
('en', 'currency_code_ttd', 'Trinidad and Tobago Dollar'),
('en', 'currency_code_tnd', 'Tunisian Dinar'),
('en', 'currency_code_trl', 'Turkish Lira'),
('en', 'currency_code_tmt', 'Turkmenistan Manat'),
('en', 'currency_code_ugx', 'Uganda Shilling'),
('en', 'currency_code_uzs', 'Uzbekistan Sum'),
('en', 'currency_code_veb', 'Venezuela Bolivar'),
('en', 'currency_code_vef', 'Venezuela Bolivar Fuerte'),
('en', 'currency_code_vnd', 'Vietnamese New Dong'),
('en', 'currency_code_yer', 'Yemeni Rial'),
('en', 'currency_code_yum', 'Yugoslavian New Dinar'),
('en', 'currency_code_zmw', 'Zambian Kwacha'),
('en', 'currency_code_zwd', 'Zimbabwe Dollar'),
('en', 'editing_order_invoice_responsive', 'Editing invoice for order'),
('en', 'responsive_admin.email_order_invoice_subject', '[company_name]: Invoice for order'),
('en', 'file_uploading_in_progress_please_wait', 'File uploading in progress. Please wait.'),
('en', 'profile_types_section_user', 'Customers and admins'),
('en', 'profile_types_section_seller', 'Vendor information'),
('en', 'profile_type', 'Profile type'),
('en', 'bulk_edit.example_of_modified_value', 'Example of the modified value'),
('en', 'bulk_edit.decrease_hint', 'To decrease the value use the "-". Example: -5'),
('en', 'bulk_edit.make_active', 'Make products active'),
('en', 'bulk_edit.make_disabled', 'Make products disabled'),
('en', 'bulk_edit.make_hidden', 'Make products hidden'),
('en', 'bulk_edit.price_and_stock', 'Price & Stock'),
('en', 'bulk_edit.what_do_these_checkboxes_mean', 'What do these checkboxes mean?'),
('en', 'bulk_edit.what_do_these_checkboxes_mean_checked', 'all the selected products belong to this category or will be assigned to it.'),
('en', 'bulk_edit.what_do_these_checkboxes_mean_unchecked', 'none of the selected products belong to this category, or they will be removed from it.'),
('en', 'bulk_edit.what_do_these_checkboxes_mean_indeterminate', 'some of the selected products belong to this category; no changes will be made.'),
('en', 'bulk_edit.unable_to_delete_all_categories', 'At least one category must be selected'),
('en', 'bulk_edit.some_products_were_omitted', 'Some products were skipped because the last remaining category can''t be removed or added for a product.'),
('en', 'bulk_edit.some_products_were_omitted_other_storefront', 'Couldn''t edit selected products. Some of the selected products belong to other storefronts; please deselect those products to be able to edit remaining ones.'),
('en', 'custom_search', 'Custom search'),
('en', 'system_environment', 'System environment'),
('en', 'product_feature.purpose', 'Purpose'),
('en', 'ttc_product_feature.purpose', 'Determines how you and your customers will be able to use this feature.'),
('en', 'product_feature.purpose.organize_catalog', 'Brand, author, etc.'),
('en', 'product_feature.purpose.organize_catalog.description', 'For features like "Brand" or "Manufacturer" (for most products), "Performer" or "Label" (for music), "Author" or "Publisher" (for books), and so on. Every variant of this feature gets its own page with an image, description, and the list of products.'),
('en', 'product_feature.purpose.find_products', 'Product search via filters'),
('en', 'product_feature.purpose.find_products.description', 'For a feature that just allows you to specify an additional property of a product (for example, "Fabric" for T-shirts). If you create a filter by that feature, customers will see that such a property exists, and will be able to search products by it.'),
('en', 'product_feature.purpose.describe_product', 'Additional information'),
('en', 'product_feature.purpose.describe_product.description', 'For cases when you just need to show some information on a product page. There are no filters for this kind of features.'),
('en', 'product_feature.feature_style', 'Feature style'),
('en', 'ttc_product_feature.feature_style', 'Determines the look of this feature on the product page.'),
('en', 'product_feature.feature_style.checkbox', 'Checkbox'),
('en', 'product_feature.feature_style.color', 'Color'),
('en', 'product_feature.filter_style.color', 'Color'),
('en', 'product_feature.feature_style.multiple_checkbox', 'Multiple checkboxes'),
('en', 'product_feature.feature_style.text', 'Text or number'),
('en', 'product_feature.feature_style.number', 'Number'),
('en', 'product_feature.feature_style.brand', 'Brand'),
('en', 'product_feature.filter_style', 'Filter type'),
('en', 'ttc_product_feature.filter_style', 'Determines the look of a filter by this feature on the product list. Filters make it easier for customers to find a product with the desired feature value. You''ll be able to create a filter after you create a feature.'),
('en', 'product_feature.filter_style.checkbox', 'Checkbox'),
('en', 'product_feature.filter_style.slider', 'Number slider'),
('en', 'product_feature.filter_style.date', 'Date selector'),
('en', 'privilege_groups.blog_and_pages', 'Blog & Pages'),
('en', 'privilege_groups.orders', 'Orders'),
('en', 'privilege_groups.order_statuses', 'Order statuses'),
('en', 'privilege_groups.other', 'Other'),
('en', 'privilege_groups.backup_restore', 'Backup/Restore'),
('en', 'privilege_groups.blocks', 'Blocks'),
('en', 'privilege_groups.currencies', 'Currencies'),
('en', 'privilege_groups.design', 'Design'),
('en', 'privilege_groups.documents', 'Documents'),
('en', 'privilege_groups.file_changes', 'File changes detector'),
('en', 'privilege_groups.files', 'Files'),
('en', 'privilege_groups.edit_on_site', 'Edit content on-site'),
('en', 'privilege_groups.email_templates', 'Email templates'),
('en', 'privilege_groups.exim', 'Import and export data'),
('en', 'privilege_groups.languages', 'Languages'),
('en', 'privilege_groups.locations', 'Rate areas'),
('en', 'privilege_groups.logs', 'Logs'),
('en', 'privilege_groups.sales_reports', 'Sales reports'),
('en', 'privilege_groups.sitemap', 'Sitemap'),
('en', 'privilege_groups.shipping', 'Shipping methods'),
('en', 'privilege_groups.payments', 'Payment methods'),
('en', 'privilege_groups.products', 'Categories, Products, Features, Filters, Options'),
('en', 'privilege_groups.promotions', 'Promotions'),
('en', 'privilege_groups.static_data', 'Static data'),
('en', 'privilege_groups.stores', 'Storefronts'),
('en', 'privilege_groups.storage', 'Storage'),
('en', 'privilege_groups.settings', 'Settings'),
('en', 'privilege_groups.taxes', 'Taxes'),
('en', 'privilege_groups.themes', 'Themes'),
('en', 'privilege_groups.users', 'Users'),
('en', 'privilege_groups.user_groups', 'User groups'),
('en', 'privilege_groups.upgrade_center', 'Upgrade center'),
('en', 'privilege.full_access', 'Full access'),
('en', 'privilege.view_access', 'Can view only'),
('en', 'privilege.no_access', 'No access'),
('en', 'privilege.custom_access', 'Custom access'),
('en', 'privilege.apply_to_all', 'Apply value to all'),
('en', 'open_hours', 'Open hours'),
('en', 'affected_email_templates', 'Email templates using this document'),
('en', 'pickup_point_not_selected', 'Sorry, we couldn''t determine your pickup point. Please choose a pickup point, so that we know where to deliver your order.'),
('en', 'no_manager_assigned', 'No manager assigned'),
('en', 'block_manager.view_layout.reset_filter', 'Edit layouts'),
('en', 'block_manager.view_layout.phone', 'Phone preview'),
('en', 'block_manager.view_layout.tablet', 'Tablet preview'),
('en', 'block_manager.view_layout.desktop', 'Desktop preview'),
('en', 'block_manager.availability.show_on', 'Show on'),
('en', 'block_manager.availability.phone', 'Phone'),
('en', 'block_manager.availability.tablet', 'Tablet'),
('en', 'block_manager.availability.desktop', 'Desktop'),
('en', 'add_as_order', 'Add as order'),
('en', 'is_address_required', 'Customer must specify his/her address'),
('en', 'go_to_admin_panel', 'Admin panel'),
('en', 'checkout.min_cart_subtotal_required', 'To continue checkout process your order subtotal must exceed [amount]'),
('en', 'lite_checkout.customer_information', 'Customer'),
('en', 'lite_checkout.personal_name', 'Full name'),
('en', 'lite_checkout.city_and_state', 'City, state'),
('en', 'lite_checkout.place_an_order_for', 'Place order ([amount])'),
('en', 'lite_checkout.delivery_note', 'Customer''s notes'),
('en', 'lite_checkout.shippings.show_all_on_map', 'Show all on map'),
('en', 'lite_checkout.nearest_station', 'Nearest station'),
('en', 'lite_checkout.select_pickup_item', 'Select a pickup point'),
('en', 'lite_checkout.choose_from_list', 'Choose from list'),
('en', 'lite_checkout.use_two_fingers_for_move_map', 'Use two fingers to move the map'),
('en', 'lite_checkout.select_your_city', 'Specify your city'),
('en', 'lite_checkout.deliver_to', 'Deliver to:'),
('en', 'lite_checkout.click_here_to_update_shipping', 'Enter city and state and click here to update shipping rates'),
('en', 'lite_checkout.shipping_method_for', 'Shipping method for [group_name]'),
('en', 'deprecated', 'Deprecated'),
('en', 'collapse_section', 'Collapse section'),
('en', 'expand_section', 'Expand section'),
('en', 'companies', 'Stores'),
('en', 'storefronts', 'Storefronts'),
('en', 'editing_storefront', 'Editing storefront'),
('en', 'creating_storefront', 'Creating storefront'),
('en', 'all_languages', 'All languages'),
('en', 'all_currencies', 'All currencies'),
('en', 'all_companies', 'All stores'),
('en', 'storefront_status', 'Status'),
('en', 'storefront_status.tooltip', 'Even if the storefront is closed (the status set to OFF), you''ll be able to view it if you have an access key. Specify the <i>Access key to temporarily closed storefront</i> below.<br/>Use http://www.example.com/index.php?store_access_key=key_value to access a closed storefront.'),
('en', 'storefront_access_key', 'Access key to temporarily closed storefront'),
('en', 'storefront_access_key.setting_notice', 'You can set the access key on the storefront editing page'),
('en', 'close_storefront', 'Close storefront'),
('en', 'close_storefront.setting_notice', 'You can open or close a storefront on the storefront editing page'),
('en', 'open_selected_storefronts', 'Open selected'),
('en', 'close_selected_storefronts', 'Close selected'),
('en', 'add_storefront', 'Add storefront'),
('en', 'storefront_status_changed.Y', 'The storefront was <b>closed</b>|The storefronts were <b>closed</b>'),
('en', 'storefront_status_changed.N', 'The storefront was <b>opened</b>|The storefronts were <b>opened</b>'),
('en', 'default_storefront', 'Default'),
('en', 'add_profile_fields', 'Add profile fields'),
('en', 'add_profile_fields_and_close', 'Add profile fields and close'),
('en', 'checkout_block_with_heading', 'Checkout block (H2 heading)'),
('en', 'notifications_center.no_notifications', 'No notifications'),
('en', 'notifications_center.notifications', 'Notifications'),
('en', 'notifications_center.section.all', 'All'),
('en', 'notifications_center.section.administration', 'Administration'),
('en', 'notifications_center.section.products', 'Products'),
('en', 'notifications_center.section.other', 'Other'),
('en', 'notifications_center.tag.administration.update', 'Update'),
('en', 'notifications_center.tag.administration.license', 'License'),
('en', 'notifications_center.tag.other', 'Other'),
('en', 'notifications_center.mark_all_as_read', 'Mark all as read'),
('en', 'notification.upgrade_available.title', 'New CS-Cart version is available'),
('en', 'notification.upgrade_available.message', 'To see what the new version brings, <a href="[link]">visit the Upgrade Center</a>.'),
('en', 'notification.addons_upgrade_available.title', 'New versions are available for your add-ons'),
('en', 'notification.addons_upgrade_available.message', 'To install these updates, <a href="[link]">visit the Upgrade Center</a>.'),
('en', 'authorize_before_order', 'Only registered customers can place an order. Please sign in to your account or register a new one.'),
('en', 'storefront_with_same_url_exists', 'A storefront with the specified URL already exists'),
('en', 'edit_layout_on_site', 'Edit layout on-site'),
('en', 'on_site_layout_editing', 'Editing layout page: [page]'),
('en', 'bottom_panel.go_to_home_page', 'Go to home page'),
('en', 'bottom_panel.go_to_dashboard', 'Go to Dashboard'),
('en', 'bottom_panel.show_bottom_admin_panel', 'Show admin toolbar'),
('en', 'bottom_panel.hide_bottom_admin_panel', 'Hide admin toolbar'),
('en', 'bottom_panel.storefront', 'Storefront'),
('en', 'bottom_panel.admin_panel', 'Admin panel'),
('en', 'bottom_panel.vendor_panel', 'Vendor panel'),
('en', 'bottom_panel.preview_mode', 'Preview'),
('en', 'bottom_panel.build_mode', 'Edit structure'),
('en', 'bottom_panel.build_mode.not_available', 'Available at the following page types: homepage, product, category, checkout.'),
('en', 'bottom_panel.theme_mode.not_available', 'Available only in your microstore or on the pages of your products and blog articles.'),
('en', 'bottom_panel.text_mode', 'Edit texts'),
('en', 'bottom_panel.theme_mode', 'Edit style'),
('en', 'bottom_panel.settings', 'Settings'),
('en', 'bottom_panel.change_theme', 'Change theme'),
('en', 'bottom_panel.edit_layout', 'Edit layout'),
('en', 'bottom_panel.edit_template', 'Edit template'),
('en', 'bottom_panel.edit_translations', 'Edit translations'),
('en', 'bottom_panel.edit_menus', 'Edit menus'),
('en', 'bottom_panel.edit_product_tabs', 'Edit product tabs'),
('en', 'bottom_panel.restore_demo', 'Restore demo'),
('en', 'bottom_panel.documentation', 'Documentation'),
('en', 'bottom_panel.help', 'Help'),
('en', 'bottom_panel.community_forums', 'Community forums'),
('en', 'bottom_panel.video_tutorials', 'Video tutorials'),
('en', 'bottom_panel.faq', 'FAQ'),
('en', 'bottom_panel.customer_help_desk', 'Contact support'),
('en', 'bottom_panel.hire_a_developers', 'Hire a developer'),
('en', 'bottom_panel.download', 'Download'),
('en', 'bottom_panel.buy_license', 'Buy license'),
('en', 'bottom_panel.trial_left', 'Remaining trial period'),
('en', 'demo_panel.theme_editor.enable', 'Edit style<br/><br/>Change the style of your store (logos, colors, fonts, and so on) and see the changes as you make them.<br/><br/>To use this functionality in your [product] store, go to Design → Themes and click "Theme editor"'),
('en', 'demo_panel.block_manager.enable', 'Edit structure<br/><br/>Change various blocks with information: show them, hide them, or move them as you see fit.<br/>This currently works at the following page types: homepage, product, category, checkout.<br/><br/>To use this functionality in your [product] store, go to Design → Themes and click "Edit layout on-site"'),
('en', 'individual', 'Individual'),
('en', 'link_an_existing_option', 'Link an existing option'),
('en', 'create_or_link_an_existing_option', 'Create or link an existing option'),
('en', 'tip.quick_select_and_close_category_selector', 'Tip: Hold ''Ctrl'' (or "⌘" on Mac) while clicking on a category name. This will add one category and close the window.'),
('en', 'checkout_select_profile_before_order', 'Please select a profile before you place the order.'),
('en', 'editing_profile_name', 'Editing profile: [name]'),
('en', 'bm.customer_information_block.warning.email_or_phome_must_be_required', 'Contact information must always have either email, or phone as a required field.'),
('en', 'bm.customer_information_block.warning.field_automaticly_added', '"[field_name]" has been added as a required field automatically.'),
('en', 'bm.customer_information_block.warning.field_marked_as_required', 'The "[field_name]" field has been marked as required.'),
('en', 'required_profile_field_description', 'The "[field_name]" profile field is required as it is used to calculate shipping rates.'),
('en', 'upgrade_notification_welcome_title', 'Welcome to [product] [version]!'),
('en', 'upgrade_notification_welcome_text', '<p class="lead">To help you get started, we’ve compiled the list of what you should check after the upgrade. The full list of changes is in the changelog.</p><p class="lead">If you ever need to check this message later, we’ve also sent a copy to [email].</p>'),
('en', 'view_changelog', 'View changelog'),
('en', 'upgrade_notification_what_check_first', 'What to check first?'),
('en', 'upgrade_notification_what_else_to_check', 'What else is there to check?'),
('en', 'cant_remove_addon_files', 'Add-on files couldn''t be removed'),
('en', 'addon_reinstall.intro', 'Looks like you are trying to install an add-on that is already installed. We can do it for you in two ways; we recommend the safe way.'),
('en', 'addon_reinstall.safe_way', '<strong>The safe way:</strong> we''ll uninstall the old add-on first, and then install the new one. The drawback is that any data and settings related to the add-on will be lost.'),
('en', 'addon_reinstall.dangerous_way', '<strong>The dangerous way:</strong> we''ll replace all the files of the add-on with new ones, but keep all the add-on''s data in the database intact. This can break the add-on, or might even break your store. Please don''t use the dangerous way, unless you absolutely know what you''re doing.'),
('en', 'addon_reinstall.dangerous_way.confirm', 'I know the risks and want to use the dangerous way.'),
('en', 'addon_reinstall.dangerous_way.action', 'Use the dangerous way'),
('en', 'addon_reinstall.safe_way.action', 'Use the safe way'),
('en', 'all_storefronts', 'All storefronts'),
('en', 'add_storefronts', 'Add storefronts'),
('en', 'add_storefronts_and_close', 'Add storefronts and close'),
('en', 'event.receiver.c', 'Customer'),
('en', 'event.receiver.a', 'Administrator'),
('en', 'event.receiver.v', 'Vendor'),
('en', 'event.transport.mail', 'E-mail'),
('en', 'event.transport.internal', 'Notifications center'),
('en', 'event.order.edp.name', 'Access to downloadable products granted'),
('en', 'event.notification_type', 'Notification type'),
('en', 'notifications', 'Notifications'),
('en', 'event.order.updated.name', 'Order was updated'),
('en', 'event.order.shipment_updated.name', 'Products were shipped'),
('en', 'purpose', 'Purpose'),
('en', 'feature_style', 'Feature style'),
('en', 'filter_style', 'Filter type'),
('en', 'all_block_types', 'All block types'),
('en', 'all_layouts', 'All layouts'),
('en', 'all_locations', 'All locations'),
('en', 'n_categories', '[n] category|[n] categories'),
('en', 'n_pages', '[n] page|[n] pages'),
('en', 'n_filters', '[n] filter|[n] filters'),
('en', 'n_profile_fields', '[n] profile field|[n] profile fields'),
('en', 'event.profile.activated.name', 'Profile was activated'),
('en', 'event.profile.deactivated.name', 'Profile was deactivated'),
('en', 'event.profile.password_reminder.name', 'Reminder about necessary password change'),
('en', 'event.profile.usergroup_request.name', 'Membership in user group was requested'),
('en', 'event.profile.updated.name', 'Profile was updated'),
('en', 'event.profile.added.name', 'Profile requires activation'),
('en', 'event.profile.created.name', 'Profile was created'),
('en', 'event.profile.usergroup_activation.name', 'User group activation'),
('en', 'event.profile.usergroup_disactivation.name', 'User group disactivation'),
('en', 'event.profile.usergroup_updated.name', 'Membership in user group was changed'),
('en', 'event.profile.password_recovery.name', 'Password recovery'),
('en', 'export_found_products', 'Export found products'),
('en', 'hello_name', 'Hello [name],'),
('en', 'checkout.email_exists.popup.title', 'You may have bought from us before'),
('en', 'checkout.email_exists.popup.message', 'An account with your email already exists. We can sign you in (password won''t be needed), or you can use another email if you''d like.'),
('en', 'checkout.email_exists.popup.cancel_btn', 'Use another email'),
('en', 'checkout.email_exists.popup.sign_in_btn', 'Sign me in'),
('en', 'auth.one_time_password.popup.title', 'Password-free sign-in'),
('en', 'auth.one_time_password.popup.message', 'We''ve sent a one-time code to <strong>[email]</strong>. Please enter it below, and we''ll sign you in without a password.'),
('en', 'auth.one_time_password.popup.input_placeholder', 'Enter the code here'),
('en', 'auth.one_time_password.popup.resend_btn', 'Resend the code'),
('en', 'auth.one_time_password.popup.sign_in_btn', 'Sign me in'),
('en', 'auth.one_time_password.notification.info_password_sent', 'We''ve sent a one-time code to [email].'),
('en', 'auth.one_time_password.notification.error_password_invalid', 'Sorry, it seems that the code you''ve entered is incorrect. It may have expired or been used already. Please check the code you''re entering or request a new code.'),
('en', 'auth.one_time_password.notification.error_password_required', 'Please enter the code to sign in.'),
('en', 'email.one_time_password.title', 'Sign in without password'),
('en', 'email.one_time_password.message', '<p>You''ve requested a one-time code to sign in to <a href="[storefront_url]">[storefront_url]</a>. Here it is:</p><p><strong><code>[password]</code></strong></p><p>Please don''t tell this code to anyone else. If you haven''t requested the code, then you can safely ignore this message. Nobody will be able to sign in to your account, unless they know your password or can view your inbox.</p>'),
('en', 'email_template.one_time_password_request', 'One-time code for password-free sign-in'),
('en', 'other_notification', 'Other'),
('en', 'see_full_templates_list', 'Can''t find a notification you''re looking for?<br/><a href="[email_template_manage]">See the full list of email templates</a><br/><a href="[internal_template_manage]">See the full list of on-site notification templates</a>'),
('en', 'other_notifications.title', 'Can''t find a notification you''re looking for?'),
('en', 'other_notifications.email_templates', 'See the full list of email templates'),
('en', 'other_notifications.internal_templates', 'See the full list of on-site notification templates'),
('en', 'internal_templates', 'On-site notification templates'),
('en', 'editing_internal_template', 'Editing on-site notification template'),
('en', 'send_test_notification', 'Send test notification'),
('en', 'count_internal_template_successfully_imported', 'On-site notification templates successfully imported:'),
('en', 'count_internal_template_fail_imported', 'On-site notification templates import failed:'),
('en', 'internal_template_import_success_msg', 'All the on-site notification templates have been imported without errors.'),
('en', 'internal_template_exists', 'The on-site notification template with the chosen code already exists, please try another.'),
('en', 'notification_template.tab.email', 'Email'),
('en', 'notification_template.tab.internal', 'On-site'),
('en', 'lite_checkout.chosen_shipping_not_avaliable', 'Sorry, we can''t get the rates for your selected shipping method. Please check your address and make sure that it is correct. If this doesn''t help, please select another shipping method or contact us.'),
('en', 'lite_checkout.not_available', 'Not available'),
('en', 'last_login', 'Last login'),
('en', 'total_orders', 'Created orders'),
('en', 'total_paid_orders', 'Paid orders'),
('en', 'total_spent_money', 'Total spend'),
('en', 'notifications_center.section.communication', 'Communication'),
('en', 'notifications_center.tag.messages', 'Messages'),
('en', 'settled_order_status', 'Consider order paid'),
('en', 'edit_on_site', 'Edit on site'),
('en', 'order_manager', 'Order manager'),
('en', 'privilege_groups.internal_templates', 'On-site notification templates'),
('en', 'privilege_groups.notification_settings', 'Notifications'),
('en', 'logo_section.theme', 'Site logo'),
('en', 'logo_section.favicon', 'Favicon'),
('en', 'logo_section.mail', 'E-mail logo'),
('en', 'show_extra_logos', 'Show extra logos'),
('en', 'hide_extra_logos', 'Hide extra logos'),
('en', 'test_rate_calculation', 'Test rate calculation'),
('en', 'calculated_rate', 'Calculated rate'),
('en', 'calculated_automatically', 'Calculated automatically'),
('en', 'additional_settings', 'Additional settings'),
('en', 'rates_calculated_info', 'Rates are calculated for [n] product that costs [price].|Rates are calculated for [n] products that cost [price].'),
('en', 'base_rate', 'Base rate'),
('en', 'price_rate_not_set', 'Price rate was not set.'),
('en', 'receivers', 'Receivers'),
('en', 'notification', 'Notification'),
('en', 'owner_company', 'Storefront'),
('en', 'block_manager.brands_per_screen', 'Brands per screen'),
('en', 'block_manager.total_displayed_brands', 'Total amount of brands displayed'),
('en', 'add_all_destinations', 'Add all'),
('en', 'block_manager.manage_layout_in_tab_not_exist_location', '<p>This [entity] currently doesn''t have an associated layout page. That''s why it uses blocks from the default layout page.<br> If you''d like to edit blocks specifically for this [entity], then:</p><p><ol><li>Go to <b><a href="[link]">Design → Layouts</a></b></li><li>Add a layout page with <b>Dispatch:</b> <code>[dispatch_value]</code>.</li><li>Switch to the <b>[entity_tab]</b> tab and make sure that the layout page is enabled for this [entity].</li><li>Save your changes and return here.</li></ol></p>'),
('en', 'block_manager.manage_layout_in_tab_unavailable_by_object_id', '<p>This [entity] currently doesn''t have an associated layout page. That''s why it uses blocks from the default layout page.<br> If you''d like to edit blocks specifically for this [entity], then:</p><p><ol><li>Edit the <b><a href="[link]">[location_name]</a></b> layout page.</li><li>Switch to the [entity_tab] tab and make sure that the layout page is enabled for this [entity].</li><li>Save your changes and return here.</li></ol></p>'),
('en', 'block_manager.manage_layout_in_tab_unavailable', 'Sorry, you can''t edit blocks for this [entity]. If you''d like to do this, please contact the main administrator. Ask him or her to check the <b>Layouts</b> tab of this [entity] in their admin panel. That will give the main admin all the necessary information.'),
('en', 'block_manager.dynamic_entity_products', 'product'),
('en', 'block_manager.dynamic_entity_categories', 'category'),
('en', 'block_manager.dynamic_entity_pages', 'page'),
('en', 'payment_processors.category.checkout', 'Checkout'),
('en', 'payment_processors.category.gateway', 'Gateways'),
('en', 'payment_processors.category.russian', 'Russian payment methods'),
('en', 'add_in_all_realtime_shippings', 'Add in all realtime shipping methods'),
('en', 'event.system.realtime_shipping_error.name', 'Realtime shipping errors'),
('en', 'profile_field_contains_information', 'Сouldn''t change the field type: someone has already submitted data in this field.'),
('en', 'text_cannot_create_file_check_file', 'Сouldn''t create the file. Please try again or choose another file.'),
('en', 'error_profile_field_code_exists', 'A profile field with this code already exists. Please choose another code.'),
('en', 'can_not_add_file_type_profile_field', 'Sorry, this page doesn''t support fields with the "File" type, and they weren''t added.'),
('en', 'day_or_days', 'day(s)'),
('en', 'feature_already_in_use', 'Couldn''t delete the feature. It is already used by your or someone else''s products.'),
('en', 'feature_variants_already_in_use', 'Couldn''t delete some feature variants. They are already used by your or someone else''s products.'),
('en', 'stop_following_rules', 'Stop following rules'),
('en', 'exim_features', 'Features (Deprecated)'),
('en', 'exim_storefront_feature_name', 'Storefront feature name'),
('en', 'exim_reset_inventory_tooltip', 'This won''t affect the products that have the quantity specified in the imported file.'),
('en', 'thank_you', 'Thank you!'),
('en', 'text_review_and_reach_out_request', 'We''ll review your application and reach out to you via email soon.'),
('en', 'system_of_measurement', 'System of measurement'),
('en', 'imperial_units', 'Imperial (in, lb)'),
('en', 'metric_units', 'Metric (cm, kg)'),
('en', 'ship_dhl_account_country', 'Account country'),
('en', 'print_documents', 'Print documents'),
('en', 'change_to_status', 'Change to [status]'),
('en', 'invoice_pdf', 'Invoice (PDF)'),
('en', 'exim_import_detailed_image', 'Detailed image (Deprecated)'),
('en', 'settings.smtp_error', 'SMTP Error'),
('en', 'sync_data', 'Sync data'),
('en', 'never', 'Never'),
('en', 'nothing_sign', '&mdash;'),
('en', 'last_sync', 'Last sync'),
('en', 'log_file', 'Log file'),
('en', 'select_developer', 'Select developer'),
('en', 'popular_developer', 'Popular developer'),
('en', 'developers', 'Developers'),
('en', 'storefronts.manage_language_availability', 'Configure the languages available on this storefront'),
('en', 'storefronts.manage_currency_availability', 'Configure the currencies available on this storefront'),
('en', 'variant_with_name_already_exist', 'Couldn''t rename feature variant "[variant]". Reason: a variant with the new name already exists.'),
('en', 'delete_default_destination_notice', 'Couldn''t delete the default rate area. It must always exist.'),
('en', 'display', 'Display'),
('en', 'create_filters', 'Create filters'),
('en', 'text_n_filters_created', 'Filters created: [n].'),
('en', 'error_n_filters_already_exists', 'Some filters ([n]) already exist.'),
('en', 'bulk_product_features_warning', 'This change won''t affect some of the selected features, because they belong to a feature group. You can assign categories to an entire feature group.'),
('en', 'view_feature_groups', 'View feature groups'),
('en', 'show_on_storefront', 'Show on Storefront'),
('en', 'parent', 'Parent'),
('en', 'attempt_to_set_itself_or_a_own_child_as_its_parent_warning', 'The parent page wasn''t changed. Reason: can''t assign child page as a parent for its own parent.'),
('en', 'bulk_attempt_to_set_itself_or_a_own_child_as_its_parent_warning', 'The parent page of some of the selected pages wasn''t changed. Reason: can''t assign child page as a parent for its own parent.'),
('en', 'visit_marketplace', 'Visit the Add-on Market'),
('en', 'view_more_addons', 'View more add-ons'),
('en', 'manual_installation', 'Manual installation'),
('en', 'downloaded_addons', 'Downloaded add-ons ([n])'),
('en', 'upgrades', 'Upgrades ([n])'),
('en', 'addon_subscriptions', 'Subscriptions ([n])'),
('en', 'addon_type', 'Add-on type'),
('en', 'third_party_addons', 'Third-party add-ons'),
('en', 'unidentified', 'Unidentified'),
('en', 'without_rating', 'Without rating'),
('en', 'has_additional_pages', 'Has additional pages'),
('en', 'favorites', 'Favorites'),
('en', 'add_addon_to_favorites', 'Add add-on to favorites'),
('en', 'remove_addon_from_favorites', 'Remove add-on from favorites'),
('en', 'new_addon', 'New add-on'),
('en', 'install_date', 'Install date'),
('en', 'compatibility', 'Compatibility'),
('en', 'installed_date', 'Installed date'),
('en', 'what_is_new', 'What''s new'),
('en', 'where_access_addon', 'Where to access this add-on'),
('en', 'addon_is_compatible', 'This add-on version is compatible with your current [product] version.'),
('en', 'addon_required_version', 'The add-on requires [version] version'),
('en', 'version_information', 'Version information'),
('en', 'show_all_developer_addons', 'Show all developer add-ons'),
('en', 'developer_page', 'Developer page'),
('en', 'show_all_category_addons', 'Show all [category] add-ons'),
('en', 'addons.other_category', 'Other'),
('en', 'updates', 'Updates'),
('en', 'actual_version', 'Actual version'),
('en', 'installed_version', 'Installed version'),
('en', 'subscription', 'Subscription'),
('en', 'license', 'License'),
('en', 'addon_reviews', 'Reviews'),
('en', 'addon_has_admin_review', 'You have left a review of the add-on'),
('en', 'addon_status', 'Add-on status'),
('en', 'verified', 'Verified'),
('en', 'verified_developer', 'Verified developer'),
('en', 'unverified', 'Unverified'),
('en', 'addons.is_enjoying_addon', 'Enjoying add-on?'),
('en', 'addons.is_enjoying_addon_name', 'Enjoying [addon]?'),
('en', 'rating', 'Rating'),
('en', 'view_in_marketplace', 'View in CS-Cart Marketplace'),
('en', 'addon_id', 'Add-on ID'),
('en', 'latest_available_version', 'Latest available version'),
('en', 'license_expires', 'License expires'),
('en', 'unsupported_browser_notice', '<p>We have detected that the browser you are using is not fully supported by our Admin Panel. You can view this site using your current browser but it may not display properly, and you may not be able to fully use all features.</p><br><p>Admin Panel is best viewed using the following browsers:</p><br><ul><li>&ndash; <a href="http://www.mozilla.org/en-US/" target="_blank">Mozilla Firefox (latest version)</a></li><li>&ndash; <a href="https://www.google.com/intl/en/chrome/browser/" target="_blank">Google Chrome (latest version)</a></li><li>&ndash; <a href="https://www.microsoft.com/en-us/edge" target="_blank">Microsoft Edge (latest version)</a></li><li>&ndash; <a href="https://www.apple.com/safari/" target="_blank">Safari (latest version)</a></li></ul><br><p>Click on one of the links to download the browser of your choice. Once the download has completed, install the browser by running the setup program.</p><br><p>If you cannot upgrade your browser now, you can still access Admin Panel, but you may not be able to fully use all features.<br><br><a href="[url]">Continue</a></p>'),
('en', 'usergroup_must_have_privileges', 'Usergroup must have at least one privilege.'),
('en', 'saved_search.set_as_default', 'Set as default'),
('en', 'saved_search.set_as_non_default', 'Set as non-default'),
('en', 'saved_search.more_short', 'More'),
('en', 'saved_search.set_as_default_confirm', 'Saved search "[name]" will open by default instead of the full list of objects. Is that what you''d like?'),
('en', 'saved_search.set_as_non_default_confirm', 'The full list of objects will open by default instead of saved search "[name]". Is that what you''d like?'),
('en', 'exim_subtotal_discount', 'Subtotal discount'),
('en', 'storefront_languages_assigned', 'The "<a href="[url]">[name]</a>" storefront had no available languages configured. All languages has been made available for it.'),
('en', 'storefront_currencies_assigned', 'The "<a href="[url]">[name]</a>" storefront had no available currencies configured. Default currency has been made available for it.'),
('en', 'storefront_all_currencies_assigned', 'The "<a href="[url]">[name]</a>" storefront had no available currencies configured. All currencies has been made available for it.'),
('en', 'storefronts_for_language_absent', 'The <b>[name]</b> language had no storefronts selected. All storefronts has been made available for it.'),
('en', 'storefronts_for_currency_absent', 'The <b>[name]</b> currency had no storefronts selected. All storefronts has been made available for it.'),
('en', 'event.product.back_in_stock.name', 'Product is back in stock'),
('en', 'core_addon', 'CS-Cart'),
('en', 'text_menus_have_been_deleted', 'Menus have been deleted successfully.'),
('en', 'addon_added_to_favorites', 'Add-on added to your favorites'),
('en', 'addon_removed_from_favorites', 'Add-on removed from your favorites'),
('en', 'contact_the_developer', 'Contact the developer'),
('en', 'message_successfully_sent_to_developer', 'Message was successfully sent to [developer]'),
('en', 'delete_subscribers', 'Delete subscribers'),
('en', 'addons.error_while_sending_review', 'Your add-on review was not posted to marketplace. Please make sure that you acquire this add-on from CS-Cart Marketplace and try again later.'),
('en', 'addons.upgrade_to_product_version', 'Upgrade to [product] [version]'),
('en', 'addons.latest_version', 'Latest released version'),
('en', 'addons.latest_available_for_installation_version', 'Latest version available for installation'),
('en', 'product_availability', 'Product availability'),
('en', 'addons.text_thank_you_for_post', 'Thank you for your post'),
('en', 'addons.text_post_pended', 'Your post will be checked before it gets published.'),
('en', 'addons.your_account_doesnt_have_this_addon', 'You can not create a add-on review because you do not have this add-on purchased in your Marketplace account.'),
('en', 'addons.you_already_posted_review', 'You can not create a add review because you already have a review that requires premoderation'),
('en', 'addons.something_went_wrong', 'Something went wrong with your request. Please try again later.'),
('en', 'addons.your_message', 'Your message'),
('en', 'addons.not_installed', 'Not installed'),
('en', 'addons.install', 'Install'),
('en', 'addons.disabled', 'Disabled'),
('en', 'addons.activate', 'Activate'),
('en', 'addons.mve_ult_or_plus_required', '[product] Plus or Ultimate required'),
('en', 'addons.ult_required', '[product] Ultimate required'),
('en', 'addons.upgrade_available', 'Upgrade available'),
('en', 'addons.upgrades', 'Upgrades'),
('en', 'addons.error_at_sending_addon_review', 'Something went wrong at sending add-on review. Please try again later.'),
('en', 'unable_delete_storefront_orders_exists', 'Unable to delete this storefront because there are orders containing the products of this storefront in the store database. To delete the storefront, please delete all such orders first.'),
('en', 'state_field_required_only_for_countries_with_regions', 'The "State" field is required for all countries with states or provinces. If you don''t have states for the customer''s country, then the field will be required at checkout only if it is required in the customer''s profile.'),
('en', 'need_storefront_id', 'Storefront ID is required (the storefront_id param)'),
('en', 'addons.multiple_dependencies_required', 'The add-on cannot be installed because it depends on the following add-ons:<ul>[addon_list]</ul> Please install these add-ons first.'),
('en', 'products_are_not_selectable_for_context_menu', 'You can not select products that belong to another storefront.'),
('en', 'product_filters_are_not_selectable_for_context_menu', 'You can not select product filters that belong to another storefront.'),
('en', 'product_options_are_not_selectable_for_context_menu', 'You can not select product options that belong to another storefront'),
('en', 'product_features_are_not_selectable_for_context_menu', 'You can not select product features that belong to another storefront.'),
('en', 'product_feature_groups_are_not_selectable_for_context_menu', 'You can not select product feature groups that belong to another storefront.'),
('en', 'removing_default_language_from_storefront', 'Sorry, we couldn''t remove the [language_name] language from storefront [storefront_name]. To remove it, please go to <b>Settings → Appearance</b> and change the <b>Frontend default language</b> for storefront [storefront_name] first.|Sorry, we couldn''t remove the [language_name] language from storefronts: [storefront_name]. To remove it, please go to <b>Settings → Appearance</b> and change the <b>Frontend default language</b> for storefronts: [storefront_name] first.'),
('en', 'sw.vendor_panel', 'Vendor panel'),
('en', 'sw.easy_admin_panel_for_vendors', 'Easy admin panel for vendors'),
('en', 'sw.product_tabs_and_properties', 'Product tabs and properties'),
('en', 'sw.branding_and_colors', 'Branding and colors'),
('en', 'create_new_product', 'Create new product'),
('en', 'import_products', 'Import products'),
('en', 'thank_you_for_registration', 'Thank you for registration!'),
('en', 'helpdesk_account.helpdesk_account', 'Help Desk account'),
('en', 'helpdesk_account.sign_in', 'Sign in'),
('en', 'helpdesk_account.sign_out', 'Sign out'),
('en', 'helpdesk_account.sign_up', 'Sign up'),
('en', 'helpdesk_account.signed_in_message', 'Signed in'),
('en', 'helpdesk_account.signed_out_message', 'Sign in with your Help Desk account to access all CS-Cart services using single account.'),
('en', 'helpdesk_account.signed_out_message.marketplace', 'Sign in with your Help Desk account to get information about newest add-on versions from Marketplace, rate and review add-ons you''ve bought, and prolong your license subscriptions.'),
('en', 'helpdesk_account.signed_out_message.marketplace_single_addon', 'Sign in with your Help Desk account to get information about newest add-on versions from Marketplace, rate and review this add-on, and prolong your license subscription.'),
('en', 'helpdesk_account.request_permissions_from_store_owner_to_manage_addons', 'You need to have the according permission from the store owner to manage add-ons.'),
('en', 'helpdesk_account.request_permissions', 'Request permissions'),
('en', 'helpdesk_account.sign_in_to_manage_addons', 'Sign in with your Help Desk account to manage add-ons.'),
('en', 'link_from_layout', 'Link blocks from layout'),
('en', 'use_for_all_new_vendors', 'Use for all new vendors'),
('en', 'show_vendor_info_if_shipping_no_required', 'Show information about vendors whose products do not require shipping'),
('en', 'sw.money_split_automaticaly_descr.ru', 'This is achieved via YooMoney for marketplaces, so each vendor must have a YooMoney account. We''ll create a payment method for you. You''ll just need to configure it, and vendors will need to provide their account information.'),
('en', 'delete_my_account', 'Delete my account'),
('en', 'delete_my_account_description', '<p>We’ll deactivate your account and remove all your personal data from it. After that you won’t be able to sign in. However, you’ll be able to register a new account with the same email address in the future. Please note that we’ll need some time to process this request, so your account won’t be deactivated immediately. If you have any comments regarding your request, please leave them in the field below.</p>'),
('en', 'email_body_anonymization_request', '<p><a href="[user_profile_url]" target="_blank">[user]</a> with the email address [customer_email] has requested the removal of personal data with the following comment:</p> <p>[comment]</p> <p>Make sure that all business with the customer (orders, return requests, etc.) is concluded. Then <a href="[user_profile_url]" target="_blank">go to the customer page in the admin panel</a> and choose the "Anonymize" action. This will remove the customer''s personal data (including email, name, etc.) everywhere in the system, while retaining the data relevant to your business (ordered products, etc). The customer will be able to register a new account with the same email.</p>'),
('en', 'email_subject_anonymization_request', 'Personal Data Removal Request: [customer_email]'),
('en', 'user_action_request_fail', 'An error has occurred during the attempt to send your request. Please try again or send a message to the following email address: <a href="mailto:[email]">[email]</a>'),
('en', 'user_action_request_success', 'Your request has been sent successfully.'),
('en', 'anonymize', 'Anonymize'),
('en', 'text_anonymize_question', 'Once you anonymize someone, all their personal information will be replaced with randomly-generated data. This action can not be undone, unless you restore the database from a backup. Are you sure you want to proceed?'),
('en', 'check_other_sources_for_personal_data', '<p>Please note that anonymization doesn''t affect any backups and logs that you might have. If necessary, please do the following:</p><ol><li>Clear the logs under <b>Administration → Logs</b>.</li><li>Secure and delete the backups you might have under <b>Administration → Backup/Restore</b>.</li></ol>'),
('en', 'user_anonymized', 'User has been anonymized.'),
('en', 'license_error_wrong_edition_build', 'The license number your site is using doesn''t match the installed software. This may get the license suspended. Please <a href="[helpdesk_url]" target="_blank">contact us via Help Desk</a>, and we''ll be able to look into it.'),
('en', 'license_error_wrong_edition_build_entered', 'The license number you''ve entered is incorrect or doesn''t suit the product. If you''re sure that the license number is correct, please <a href="[helpdesk_url]" target="_blank">contact us via Help Desk</a>, and we''ll look into it.'),
('en', 'privileges.manage_admin_usergroups', 'Can manage admin user groups (only if managing customer user groups is allowed)'),
('en', 'privilege_groups.disable_sanitize_html', 'Use advanced HTML code in content'),
('en', 'event.system.helpdesk_process_message.name', 'Notifications from CS-Cart team'),
('en', 'category_template', 'Category template'),
('en', 'exim_error_incorrect_concrete_feature_type', 'Incorrect feature type ''[feature_type]'' of the ''[feature_name]'' product feature. The product feature was skipped.'),
('en', 'product_state_description.ult.free.free', '<p>You''re using CS-Cart Free. It has all the functionality to launch your own independent online store, free of charge. If you ever need the extended functionality of CS-Cart Standard or Ultimate — such as user groups, advanced product settings, multiple storefronts, and more — please contact us.</p>'),
('en', 'product_state_description.ult.free_ru.free', '<p>You''re using CS-Cart Free. It has all the functionality to launch your own independent online store, free of charge. If you ever need the extended functionality of CS-Cart Standard or Ultimate — such as user groups, advanced product settings, multiple storefronts, and more — please contact us.</p>'),
('en', 'contact_us', 'Contact us'),
('en', 'ultimate_or_storefront_license_required.ult.free', 'This action requires [product] Ultimate'),
('en', 'ultimate_or_storefront_license_required.ult.free_ru', 'This action requires [product] Ultimate'),
('en', 'max_storefronts_reached.ult.free', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'max_storefronts_reached.ult.free_ru', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('en', 'helpdesk_account.activate_free_license_message', 'Create an account in our Help Desk system. It will allow you to upgrade your store, contact our Customer Care team, and get add-ons (both paid and free) from the CS-Cart Marketplace for add-ons and themes.'),
('en', 'helpdesk_account.activate_free_license_short_message', 'Create an account in our Help Desk to upgrade your store, receive support, and get free or paid add-ons from our Add-on Market.'),
('en', 'helpdesk_account.activate_free_license_message_send', 'An activation link for your free CS-Cart license was sent to the email: [email]'),
('en', 'no_items_for_marketplace_administrator', 'No items to show for marketplace administrator. Try to check the section as a vendor.'),
('en', 'sync_data_update_template_not_found', 'No template found for this sync provider. Please make sure the "update_template" field is filled in the "sync_data" schema.'),
('en', 'disabling_primary_currency_disallowed', 'Currency cannot be disabled as it is primary. Make a different currency primary first.'),
('en', 'product_env.released_n_years_ago', 'released <u title="[month] [year]">[n] year ago</u>|released <u title="[month] [year]">[n] years ago</u>'),
('en', 'product_env.released_n_months_ago', 'released <u title="[month] [year]">[n] month ago</u>|released <u title="[month] [year]">[n] months ago</u>'),
('en', 'product_env.released_this_month', 'released this month'),
('en', 'product_env.current_version', 'Current version'),
('en', 'product_env.available_upgrade', 'Available upgrade'),
('en', 'product_env.latest_version', 'Latest version'),
('en', 'product_env.now_running', 'You are using [release_info]'),
('en', 'product_env.can_upgrade_store', 'You can upgrade your store to [release_info]'),
('en', 'product_env.latest_product_version', 'The latest version is [release_info]'),
('en', 'product_env.dont_miss_features', 'Don''t miss all the new features!'),
('en', 'product_env.upgrade_to_latest_version', 'Upgrade to the latest version'),
('en', 'product_env.up_to_date', 'You are up to date'),
('en', 'notification_settings.profile.receivers', 'Users whose profile was changed'),
('en', 'dashboard.analytics_section_title', 'Analytics'),
('en', 'dashboard.view_reports', 'View reports'),
('en', 'dashboard.view_report', 'View report'),
('en', 'dashboard.view_all', 'View all'),
('en', 'dashboard.view', 'View'),
('en', 'dashboard.analytics_card.sales', 'Sales'),
('en', 'dashboard.analytics_card.unlimited', 'Unlimited'),
('en', 'dashboard.analytics_card.top_products', 'Top products'),
('en', 'dashboard.analytics_card.active_products', 'Active products'),
('en', 'dashboard.analytics_card.view_products', 'View products'),
('en', 'dashboard.analytics_card.products_details', 'Products details'),
('en', 'dashboard.analytics_card.out_of_stock', 'Out of stock'),
('en', 'dashboard.analytics_card.recent_orders', 'Recent orders'),
('en', 'dashboard.analytics_card.view_orders', 'View orders'),
('en', 'dashboard.analytics_card.average_order_value', 'Average order value'),
('en', 'dashboard.analytics_card.orders', 'Orders'),
('en', 'dashboard.analytics_card.activity', 'Activity'),
('en', 'dashboard.analytics_card.vendors_with_sales', 'Vendors with sales'),
('en', 'dashboard.analytics_card.view_stores', 'View storefronts'),
('en', 'dashboard.analytics_card.vendor_activity', 'Vendor activity');
INSERT INTO `[[dbprefix]]language_values` VALUES
('en', 'dashboard.analytics_card.new_vendors', 'New vendors'),
('en', 'dashboard.analytics_card.vendors_with_new_products', 'Vendors with new products'),
('en', 'dashboard.analytics_card.vendors_not_logged', 'Vendors who haven''t signed in'),
('en', 'dashboard.analytics_card.new_products', 'New products'),
('en', 'dashboard.analytics_card.stores', 'Storefronts'),
('en', 'dashboard.analytics_card.registered_customers', 'Registered customers'),
('en', 'dashboard.analytics_card.view_customers', 'View customers'),
('en', 'custom_blocks.sections.onboarding_title', 'Onboarding Guide'),
('en', 'custom_blocks.create_block', 'Create block'),
('en', 'custom_blocks.edit_block', 'Edit block'),
('en', 'custom_blocks.name', 'Name'),
('en', 'custom_blocks.url', 'URL'),
('en', 'custom_blocks.url.hint', 'A link can lead to an external site (like https://example.com) or somewhere in the vendor admin panel (use the part after "?dispatch=" from the address bar of your browser).'),
('en', 'custom_blocks.first_menu_level_url.hint', 'If you enter a link, then the menu item will lead to the specified page, and won''t open the menu section. A link can lead to an external site (like https://example.com) or somewhere in the vendor admin panel (use the part after "?dispatch=" from the address bar of your browser).'),
('en', 'custom_blocks.content', 'Content'),
('en', 'custom_blocks.use_this_space', 'Use this space for announcements that all your vendors will see. You can write a plain text or use HTML and CSS for customization.'),
('en', 'custom_blocks.dismissed_by_vendor', 'This block was dismissed by this vendor. Other vendors may still see it.'),
('en', 'custom_menu.section_has_one_visible_item', 'This section has only one visible menu item. That item will appear instead of the section.'),
('en', 'custom_menu.item_hidden_due_to_privileges', 'This vendor can''t see this menu item due to privileges. Other vendors may still see it.'),
('en', 'dashboard.todo.has_products_without_category', '<strong>[n] product</strong> doesn''t have a category. Please assign it a category, or customers might not see it.|<strong>[n] products</strong> don''t have a category. Please assign them a category, or customers might not see them.'),
('en', 'dashboard.todo.upgrade_center_core_upgrade_available', 'A new version of CS-Cart is available.'),
('en', 'dashboard.todo.upgrade_center_addons_upgrade_available', 'New versions are available for some of your add-ons.'),
('en', 'addon_market', 'Add-on Market'),
('en', 'addon_market_n', 'Add-on Market ([n])'),
('en', 'downloaded_add_ons', 'Downloaded add-ons'),
('en', 'addons_developers', 'Developers'),
('en', 'safe_smarty_block', 'HTML block with Smarty support'),
('en', 'block_safe_smarty_block', 'HTML block with Smarty support'),
('en', 'block_safe_smarty_block_description', 'Any HTML/Smarty content'),
('en', 'block_smarty_block_deprecated_notice', 'This block type is deprecated for security reasons. The block still works, but its content can''t be edited. To edit the content, create a new "HTML block with Smarty support" and copy the content from this block to the new one. After that, check if the new block works properly on the storefront—the code that is potentially dangerous might not work.'),
('en', 'themes.google_fonts_was_replaced', 'The google fonts of your styles has been replaced successfully'),
('en', 'themes.google_fonts_replace_error', 'Couldn''t replace google fonts of your styles'),
('en', 'disabled_product_not_added_to_cart', 'This product is disabled and cannot be added to the cart'),
('en', 'ship_ups_access_token', 'UPS App access token'),
('en', 'ship_ups_access_token_expiration', 'UPS App access token expiration'),
('en', 'ship_ups_client_id', 'UPS App client ID'),
('en', 'ship_ups_client_secret', 'UPS App client secret'),
('en', 'authorize', 'Authorize'),
('en', 'text_hidpi_support_enabled', 'HiDPI support is enabled'),
('en', 'hidpi.upload_high_res_image', 'I’m uploading a HiDPI image.'),
('en', 'hidpi.upload_high_res_image.tooltip', 'If this checkbox is ticked, the source image will be displayed two times downscaled. This setting only affects the displaying of the source image and not its thumbnail. If you want an image to be displayed in the original size, untick this checkbox.'),
('en', 'hidpi.restore_images', 'Image restoration'),
('en', 'hidpi.text_restore_images', 'The previous version of the HiDPI display support add-on shrank the uploaded images. There’s no need for that now. But to make your images look nice and sharp you need to click Restore.'),
('en', 'hidpi.restore_btn', 'Restore'),
('en', 'hidpi.warning_restore_images', '<strong>Attention!</strong> This procedure is non-reversible: when you revert the upgrade, the image restoration manipulations will not be reverted. So, please make sure to perform a backup. The procedure can take some time—it depends on the number of images in your store.'),
('en', 'hidpi.notice.images_were_not_restored', 'Some of the old images in your store are still low-quality. To use the highest quality possible, please <a href="[convert_url]">restore high-quality images</a>. The process is automatic.'),
('en', 'facebook', 'Facebook'),
('en', 'facebook_obj_type', 'Facebook object type'),
('en', 'fb_activities', 'Activities'),
('en', 'fb_businesses', 'Businesses'),
('en', 'fb_groups', 'Groups'),
('en', 'fb_organizations', 'Organizations'),
('en', 'fb_people', 'People'),
('en', 'fb_places', 'Places'),
('en', 'fb_products_entertainment', 'Products and Entertainment'),
('en', 'fb_websites', 'Websites'),
('en', 'text_recommendation_notes', 'Your friend has recommended this page to you. Please follow the link:'),
('en', 'sb_share', 'Share'),
('en', 'social_buttons.facebook_cookie_title', 'Facebook'),
('en', 'social_buttons.facebook_cookie_description', 'Facebook cookies enable Facebook-related functionality, such as Facebook button on the product page. Here is <a href="https://www.facebook.com/about/privacy/previous" target="_blank">Facebook privacy policy</a>.'),
('en', 'social_buttons.pinterest_cookie_title', 'Pinterest'),
('en', 'social_buttons.pinterest_cookie_description', 'Pinterest cookies enable Pinterest-related functionality, such as Pinterest button on the product page. Here is <a href="https://policy.pinterest.com/en/privacy-policy" target="_blank">Pinterest privacy policy</a>.'),
('en', 'social_buttons.twitter_cookie_title', 'Twitter'),
('en', 'social_buttons.twitter_cookie_description', 'Twitter cookies enable Twitter-related functionality, such as the Twitter button on the product page. Here is <a href="https://twitter.com/en/privacy" target="_blank">Twitter privacy policy</a>.'),
('en', 'social_buttons.vkontakte_cookie_title', 'VK'),
('en', 'social_buttons.vkontakte_cookie_description', 'VK cookies enable VK-related functionality, such as VK button on the product page. Here is <a href="https://m.vk.com/privacy" target="_blank">VK privacy policy</a>.'),
('en', 'social_buttons.yandex_cookie_title', 'Yandex'),
('en', 'social_buttons.yandex_cookie_description', 'Yandex helps us display the buttons of multiple social networks (for example, on product pages). Here is <a href="https://yandex.com/legal/confidential/" target="_blank">Yandex privacy policy</a>.'),
('en', 'paypal_checkout.paypal_checkout', 'PayPal Complete Payments'),
('en', 'paypal_checkout.paypal', 'PayPal'),
('en', 'paypal_checkout.client_id', 'App Client ID'),
('en', 'paypal_checkout.secret', 'App Secret'),
('en', 'paypal_checkout.order_id', 'Order ID in PayPal'),
('en', 'paypal_checkout.capture_id', 'Capture ID in PayPal'),
('en', 'paypal_checkout.webhook_help_message', 'Specify the following URL when configuring a webhook for your REST application:'),
('en', 'paypal_checkout.webhook', 'PayPal Complete Payments webhook: [payload]'),
('en', 'paypal_checkout.settings.account', 'Account settings'),
('en', 'paypal_checkout.settings.enable_funding', 'Funding sources to show on checkout'),
('en', 'paypal_checkout.funding.card', 'Credit or debit cards'),
('en', 'paypal_checkout.funding.credit', 'PayPal Credit'),
('en', 'paypal_checkout.funding.venmo', 'Venmo'),
('en', 'paypal_checkout.funding.sepa', 'SEPA-Lastschrift'),
('en', 'paypal_checkout.funding.bancontact', 'Bancontact'),
('en', 'paypal_checkout.funding.eps', 'eps'),
('en', 'paypal_checkout.funding.giropay', 'giropay'),
('en', 'paypal_checkout.funding.ideal', 'iDEAL'),
('en', 'paypal_checkout.funding.mybank', 'MyBank'),
('en', 'paypal_checkout.funding.p24', 'Przelewy24'),
('en', 'paypal_checkout.funding.sofort', 'Sofort'),
('en', 'paypal_checkout.settings.enable_cards', 'Cards to show on checkout'),
('en', 'paypal_checkout.card.visa', 'Visa'),
('en', 'paypal_checkout.card.mastercard', 'Mastercard'),
('en', 'paypal_checkout.card.amex', 'American Express'),
('en', 'paypal_checkout.card.discover', 'Discover'),
('en', 'paypal_checkout.card.jcb', 'JCB'),
('en', 'paypal_checkout.card.elo', 'Elo'),
('en', 'paypal_checkout.card.hiper', 'Hiper'),
('en', 'paypal_checkout.debug_id', 'PayPal Debug ID'),
('en', 'paypal_checkout.paypal_cookie_title', 'PayPal'),
('en', 'paypal_checkout.paypal_cookie_description', 'PayPal is a payment provider. It allows us to accept payments, if you choose a payment method powered by PayPal. Here is <a href="https://www.paypal.com/us/webapps/mpp/ua/privacy-full" target="_blank">PayPal privacy statement</a>.'),
('en', 'paypal_checkout.funding.paylater', 'PayPal Pay Later'),
('en', 'paypal_checkout.funding.mercadopago', 'Mercado Pago'),
('en', 'paypal_checkout.funding.blik', 'BLIK'),
('en', 'paypal_checkout.settings.style', 'Button appearance'),
('en', 'paypal_checkout.style.shape', 'Shape'),
('en', 'paypal_checkout.shape.pill', 'Pill'),
('en', 'paypal_checkout.shape.rect', 'Rectangular'),
('en', 'paypal_checkout.style.color', 'Color'),
('en', 'paypal_checkout.color.gold', 'Gold'),
('en', 'paypal_checkout.color.blue', 'Blue'),
('en', 'paypal_checkout.color.silver', 'Silver'),
('en', 'paypal_checkout.color.black', 'Black'),
('en', 'paypal_checkout.style.height', 'Height'),
('en', 'onboarding_guide.guide_title', 'Welcome to your marketplace!<br>Get ready to receive your first order'),
('en', 'onboarding_guide.sb_guide_title', 'Welcome to your online store!<br>Get ready to receive your first order'),
('en', 'onboarding_guide.completed_steps_progress', '[completed] out of [total] complete'),
('en', 'onboarding_guide.dismiss', 'Dismiss'),
('en', 'onboarding_guide.step_close', 'Close'),
('en', 'onboarding_guide.step_complete', 'Complete'),
('en', 'onboarding_guide.explore_interface_title', 'Explore the Multi-Vendor No-Code interface'),
('en', 'onboarding_guide.explore_interface_description', 'Discover how to effortlessly launch your marketplace in just 5 minutes. Learn the ins and outs of the intuitive interface and get ready to dive into the world of hassle-free marketplace creation.'),
('en', 'onboarding_guide.personalize_your_marketplace_title', 'Personalize your marketplace'),
('en', 'onboarding_guide.sb_personalize_your_marketplace_title', 'Personalize your online store'),
('en', 'onboarding_guide.personalize_your_marketplace_description', 'Choose the style of your marketplace. Provide your contact information for customers and sellers.'),
('en', 'onboarding_guide.sb_personalize_your_marketplace_description', 'Choose the style of your online store. Provide your contact information for customers.'),
('en', 'onboarding_guide.make_changes_on_the_fly_title', 'Make changes on the fly'),
('en', 'onboarding_guide.make_changes_on_the_fly_description', 'Use the no-code tools to tailor the marketplace to your needs. Edit any texts; rearrange the blocks; change the colors, fonts, and style. When you see the storefront as an admin, you can use these tools any time.'),
('en', 'onboarding_guide.sb_make_changes_on_the_fly_description', 'Use the no-code tools to tailor the online store to your needs. Edit any texts; rearrange the blocks; change the colors, fonts, and style. When you see the storefront as an admin, you can use these tools any time.'),
('en', 'onboarding_guide.theme_and_logo', 'Theme & logo'),
('en', 'onboarding_guide.business_details', 'Business details'),
('en', 'onboarding_guide.languages_and_currency', 'Languages & Currency'),
('en', 'onboarding_guide.select_theme', 'Select theme'),
('en', 'onboarding_guide.current_theme', 'Current theme'),
('en', 'onboarding_guide.custom_theme', 'Custom theme'),
('en', 'onboarding_guide.upload_logo', 'Upload logo'),
('en', 'onboarding_guide.activate', 'Activate'),
('en', 'onboarding_guide.next', 'Next'),
('en', 'onboarding_guide.back', 'Back'),
('en', 'onboarding_guide.save', 'Save'),
('en', 'onboarding_guide.edit_colors', 'Edit colors'),
('en', 'onboarding_guide.modify_colors_fonts_backgrounds', 'Modify colors, fonts, and backgrounds'),
('en', 'onboarding_guide.edit_texts', 'Edit or translate any texts'),
('en', 'onboarding_guide.edit_blocks', 'Fine-tune page layouts'),
('en', 'onboarding_guide.configure_payment_options', 'Set up payments'),
('en', 'onboarding_guide.select_payment_options', 'Choose how you plan to accept payments. Select one of the following scenarios:'),
('en', 'onboarding_guide.single_payment_with_automatic_split', 'Multi-party payment (automatic disbursements)'),
('en', 'onboarding_guide.single_payment_with_automatic_split_description', 'There are special payment methods for marketplaces: PayPal Complete Payments (Multiparty) and Stripe Connect. A customer still makes one payment for all the products; the payment method splits the money between you and sellers automatically. Note that sellers will need accounts with PayPal or Stripe as well.'),
('en', 'onboarding_guide.single_rus_payment_with_automatic_split_description', 'There are special payment methods for marketplaces: YooKassa For Marketplaces and Tinkoff Multiparty. A customer still makes one payment for all the products; the payment method splits the money between you and sellers automatically. Note that sellers will need accounts with YooKassa or Tinkoff as well.'),
('en', 'onboarding_guide.single_payment_to_you', 'Single payment to the marketplace'),
('en', 'onboarding_guide.single_payment_to_you_description', 'A customer makes one payment for all the products in the cart. The money ends up on your account, with the record of what you own to each seller. You periodically distribute the money between sellers.'),
('en', 'onboarding_guide.separate_payments_to_sellers', 'Separate payments to sellers'),
('en', 'onboarding_guide.separate_payments_to_sellers_description', 'A customer pays to each seller separately. It becomes the seller’s responsibility to pay the commission to you (we have ways for that). Sellers will be able to set up their own shipping methods and promotions.'),
('en', 'onboarding_guide.configure_payment_methods', 'Configure payment methods'),
('en', 'onboarding_guide.configure_payment_methods_description', 'CS-Cart allows you to set up various payment methods; most of them automatically process the full up-front payment. But for now, let’s set up "Cash on Delivery" just to see how it works.'),
('en', 'onboarding_guide.view_checkout_page', 'View checkout page'),
('en', 'onboarding_guide.view_checkout_page_description', 'Once configured, your payment method will appear at the checkout page:'),
('en', 'onboarding_guide.missing_products', 'Missing products'),
('en', 'onboarding_guide.create_at_least_one_product_to_proceed_to_checkout', 'Create at least one product to proceed to checkout'),
('en', 'onboarding_guide.manage_sellers', 'Manage sellers'),
('en', 'onboarding_guide.create_one_vendor', 'Add a seller'),
('en', 'onboarding_guide.create_vendor_description', 'Sellers—referred to as "vendors" in the admin panel—are essential for a marketplace. They provide products and services to customers. A seller can create an account themselves, or you can do it for them in the admin panel. Let’s add one seller via the admin panel.'),
('en', 'onboarding_guide.view_storefront', 'See sellers on the storefront'),
('en', 'onboarding_guide.view_invoice', 'View invoice'),
('en', 'onboarding_guide.logos_updated', 'Theme and email logos updated'),
('en', 'onboarding_guide.set_default_currency', 'Set default currency'),
('en', 'onboarding_guide.manage_currencies', 'Manage currencies'),
('en', 'onboarding_guide.set_default_languages', 'Set default languages'),
('en', 'onboarding_guide.manage_languages', 'Manage languages'),
('en', 'onboarding_guide.preview_an_email', 'Preview an email'),
('en', 'onboarding_guide.preview_an_email_description', 'Once you’re done, see how your data appears in an email to the new sellers who register at your marketplace.'),
('en', 'onboarding_guide.sb_preview_an_email_description', 'Once you’re done, see how your data appears in an email to the newly-registered customers.'),
('en', 'onboarding_guide.customize_vendor_panel_design', 'Customize seller panel'),
('en', 'onboarding_guide.edit_vendor_panel_style', 'Sellers work with their own dedicated control panel. You can make it look the way you need. Set its colors, edit the menu, add blocks with info to the seller''s dashboard.'),
('en', 'onboarding_guide.edit_structure', 'Edit menus and onboarding'),
('en', 'onboarding_guide.manage_products', 'Manage products'),
('en', 'onboarding_guide.manage_products_description', 'You as the marketplace owner can control all products sold on your platform. But sellers manage products through their own dashboard. See how they can add products one by one or in bulk.'),
('en', 'onboarding_guide.sb_manage_products_description', 'Products are how your online store makes money; they include commodities, services, or anything else offered for a price. You can add products one by one or in bulk.'),
('en', 'onboarding_guide.add_one_product', 'Add one product'),
('en', 'onboarding_guide.import_csv_or_xml', 'Import CSV or XML'),
('en', 'onboarding_guide.view_product_page', 'View the latest added product'),
('en', 'onboarding_guide.premoderation', 'If you do not see the created product on the storefront, you may have the <b>Vendor data premoderation</b> module enabled'),
('en', 'onboarding_guide.view_product_page_description', 'See your new products on the storefront.'),
('en', 'onboarding_guide.preview_seller_onboarding', 'Preview seller onboarding'),
('en', 'onboarding_guide.walk_the_seller_path', 'Walk the seller path'),
('en', 'onboarding_guide.customize_onboarding_process', 'Prospective sellers can request to join your marketplace on their own. See for yourself how that process works: the information they provide, the emails they receive, etc. You can adjust all of it, or even make your marketplace invite-only.'),
('en', 'onboarding_guide.set_up_commissions_and_fees', 'Configure commissions and fees'),
('en', 'onboarding_guide.set_up_seller_plans', 'Set up seller plans'),
('en', 'onboarding_guide.set_up_seller_plans_description', 'A marketplace usually earns you money from monthly fees and/or commissions from sales. Seller plans let you set the size and frequency of those payments.'),
('en', 'onboarding_guide.view_seller_plans', 'Preview seller plans'),
('en', 'onboarding_guide.view_seller_plans_description', 'See how your configured seller plans appear to your prospective sellers on the storefront.'),
('en', 'onboarding_guide.reset_onboarding', 'Reset onboarding'),
('en', 'onboarding_guide.reset', 'Reset'),
('en', 'onboarding_guide.configure_shippings_title', 'Set up shipping'),
('en', 'onboarding_guide.configure_shippings_description', 'CS-Cart provides your customers with shipping rates depending on the customer''s address and order. You can set the rules for these rates yourself, or receive rates in real time from shipping companies like UPS or DHL. You can also make shipping methods available in some locations and unavailable in others.'),
('en', 'onboarding_guide.configure_shippings_label', 'Let''s set up a shipping method called "Pickup from store" to see how it works.'),
('en', 'onboarding_guide.configure_shippings', 'Configure shipping methods'),
('en', 'help_center.help', 'Help'),
('en', 'help_center.help_center', 'Help Center'),
('en', 'help_center.growth_center', 'Growth center'),
('en', 'help_center.loading', 'Loading...'),
('en', 'help_center.no_data_relevant', 'Relevant information is not available for this section.'),
('en', 'help_center.no_data', 'Information is not available for this section.'),
('en', 'help_center.see_all_n_results', 'See all [n] results...'),
('en', 'help_center.customer_care', 'Customer Care'),
('en', 'help_center.ask', 'Ask us a question'),
('en', 'help_center.customer_care.view_all_tickets', 'View all tickets'),
('en', 'help_center.customer_care.all_tickets', 'All tickets'),
('en', 'help_center.customer_care.no_support_tickets', 'No support tickets found.'),
('en', 'help_center.customer_care.submit_ticket', 'Submit a ticket'),
('en', 'help_center.customer_care.service_unavailable', 'Your Customer Care subscription is not active'),
('en', 'help_center.customer_care.service_unavailable_description', 'Prolong the subscription to keep receiving support.'),
('en', 'help_center.customer_care.prolong_subscription', 'Prolong subscription'),
('en', 'help_center.customer_care.sign_in_text', 'Sign in with your Help Desk account <br>to contact Customer Care and see your latest tickets.'),
('en', 'help_center.customer_care.status.resolved', 'Resolved'),
('en', 'help_center.customer_care.status.open', 'Open'),
('en', 'help_center.customer_care.few_tickets_require_your_attention', 'A few tickets from Customer Care team require your attention. <a href="[url]" target="[target]">Click here to view tickets</a>'),
('en', 'sign_in_to_enter_tags', 'Sign in to enter tags'),
('en', 'tag_cloud', 'Tag cloud'),
('en', 'tags', 'Tags'),
('en', 'block_tags', 'Tags'),
('en', 'block_tags_description', 'Product tags'),
('en', 'addons.tags.add_a_tag', 'add a tag'),
('en', 'items_marked_by_tag', 'Items marked by the "[tag]" tag:'),
('en', 'tag', 'Tag'),
('en', 'add_tag', 'Add tag'),
('en', 'n_tags', '[n] tag|[n] tags'),
('en', 'rss_feed', 'RSS feed'),
('en', 'feed_title', 'Feed title'),
('en', 'feed_description', 'Feed description'),
('en', 'rss_sort_by', 'Sort items by'),
('en', 'rss_display_sku', 'Display SKU'),
('en', 'rss_display_image', 'Display image'),
('en', 'rss_display_price', 'Display gross price'),
('en', 'rss_display_original_price', 'Display net price'),
('en', 'rss_display_add_to_cart', 'Display add to cart button'),
('en', 'rss_created', 'Created'),
('en', 'rss_updated', 'Updated'),
('en', 'block_rss_feed', 'RSS feed'),
('en', 'block_rss_feed_description', 'RSS feed subscription icon'),
('en', 'addons.rss_feed.icon', 'RSS feed subscription icon'),
('en', 'news_plain', 'Plain'),
('en', 'text_signup_for_subscriptions', 'Sign up for our newsletters!'),
('en', 'tmpl_subscription', 'Newsletters: subscription form'),
('en', 'unsubscribe_link', 'Unsubscribe link'),
('en', 'ne_add_subscribers_from_users', 'Add subscribers from the list of users'),
('en', 'ne_warning_subscr_email_exists', '<b>[email]</b> is already in the subscribers list'),
('en', 'warning_subscribers_import', 'Some mailing lists from the input file could not be found in the database. Certain imported subscribers will be left unassigned.'),
('en', 'subscribers_menu_item_text', 'Subscribers'),
('en', 'block_mailing_lists', 'Newsletter subscription'),
('en', 'block_mailing_lists_description', 'Email field for newsletter subscription'),
('en', 'block_lite_checkout_newsletters', 'Checkout: Newsletters'),
('en', 'block_lite_checkout_newsletters_description', 'Ability to sign up for newsletters'),
('en', 'privileges.view_newsletters', 'Can view'),
('en', 'privileges.manage_newsletters', 'Can edit'),
('en', 'privilege_groups.newsletters', 'Newsletters'),
('en', 'warning_newsletter_no_recipients', 'Newsletter hasn''t been sent because no recipients were found matching the selected criteria.'),
('en', 'text_newsletter_sent', 'The newsletter(s) have been sent successfully.'),
('en', 'email_cannot_be_empty', 'E-mail cannot be empty'),
('en', 'sending_email_to', 'Sending email to [email]...'),
('en', 'text_subscriber_added', 'Your e-mail has been successfully added to our free e-mail updates list'),
('en', 'error_email_already_subscribed', 'Your e-mail is already subscribed.'),
('en', 'text_subscriber_removed', 'Your e-mail has been successfully removed from our free e-mail updates list'),
('en', 'text_subscriber_activated', 'Your email has been successfully activated'),
('en', 'link_message_for_test_letter', 'The link will be displayed in a live newsletter'),
('en', 'newsletters', 'Newsletters'),
('en', 'autoresponders', 'Autoresponders'),
('en', 'campaigns', 'Campaigns'),
('en', 'sent', 'Sent'),
('en', 'subscribers_num', 'Number of subscribers'),
('en', 'editing_mailing_list', 'Editing mailing list'),
('en', 'from_name', 'From name'),
('en', 'from_email', 'From email'),
('en', 'reply_to', 'Reply to'),
('en', 'register_autoresponder', 'Confirmation email'),
('en', 'no_autoresponder', 'No autoresponder'),
('en', 'newsletters.autoresponder_used_in_mailing_list', 'You are trying to change status of the autoresponder which is used in one of the mailing lists as a confirmation email. Please check and update the lists on <a target="_blank" href="[link]">this page</a>.'),
('en', 'show_on_checkout', 'Show at checkout'),
('en', 'hide_on_checkout', 'Hide at checkout'),
('en', 'addons.newsletters.show_on_registration_and_profile', 'Show on the Registration and Profile Details pages'),
('en', 'addons.newsletters.hide_on_registration_and_profile', 'Hide on the Registration and Profile Details pages'),
('en', 'show_on_separate_page', 'Show on separate page'),
('en', 'campaign_stats', 'Campaign statistics'),
('en', 'add_campaign', 'Add campaign'),
('en', 'new_campaign', 'New campaign'),
('en', 'newsletter_templates', 'Newsletter templates'),
('en', 'newsletter_autoresponders', 'Newsletter autoresponders'),
('en', 'add_newsletter', 'Add newsletter'),
('en', 'add_template', 'Add template'),
('en', 'add_autoresponder', 'Add autoresponder'),
('en', 'more_subjects', 'Random subjects (one per line)'),
('en', 'body_html', 'HTML body'),
('en', 'no_template', 'No template'),
('en', 'load', 'Load'),
('en', 'campaign', 'Campaign'),
('en', 'send_to', 'Send to'),
('en', 'add_recipients_from_users', 'Add recipients from users'),
('en', 'customers_with_abandoned', 'Customers with abandoned'),
('en', 'cart_or_wishlist', 'Cart or Wishlist'),
('en', 'which_is', 'which is'),
('en', 'days_old', 'days old'),
('en', 'send_to_test_email', 'Send to test email'),
('en', 'save_and_send', 'Save and send'),
('en', 'newsletter', 'Newsletter'),
('en', 'newsletter_template', 'Newsletter template'),
('en', 'newsletter_autoresponder', 'Newsletter autoresponder'),
('en', 'mailing_list', 'Mailing list'),
('en', 'confirmed', 'Confirmed'),
('en', 'subscribed_to', 'Subscribed to [num] lists'),
('en', 'subscribed', 'Subscribed'),
('en', 'text_success_subscription', 'You have been successfully subscribed to our free e-mail updates and promotions!'),
('en', 'text_unsubscribe_instructions', 'We respect your privacy and do not send unsolicited e-mail to users who have not requested correspondence. You have received this e-mail because you requested to receive our free updates and promotions.<br /><br /> If you wish to unsubscribe, please follow the link below:'),
('en', 'updates_subscription', 'updates and promotions subscription'),
('en', 'ult_shared_with', 'Shared with:'),
('en', 'tt_addons_newsletters_views_mailing_lists_update_from_email', 'Email of a sender.'),
('en', 'tt_addons_newsletters_views_mailing_lists_update_from_name', 'Name of a sender (e.g. company name).'),
('en', 'tt_addons_newsletters_views_mailing_lists_update_reply_to', 'Email to send replies to.'),
('en', 'tt_addons_newsletters_views_newsletters_update_more_subjects', 'If several subjects are specified, email subject is randomly picked from this list.'),
('en', 'tt_addons_newsletters_views_newsletters_update_users', 'If the message text contains the unsubscribe link, it will be empty for these users.'),
('en', 'add_mailing_lists', 'Add mailing list'),
('en', 'manage_subscribers', 'Manage subscribers'),
('en', 'new_mailing_lists', 'New mailing list'),
('en', 'newsletters.new_subscribers', 'New subscribers'),
('en', 'subscribers_promo_subject', 'Thank you for subscribing! Use the coupon code [coupon] in our special offer "[promotion]".'),
('en', 'subscribers_no_promo', 'No promotion'),
('en', 'promotion_cond_subscribed', 'Customer is subscribed'),
('en', 'addons.newsletters.email_exists_in_list', '<b>[email]</b> is already in the mailing list'),
('en', 'email_template.newsletters_newsletter', 'Newsletter'),
('en', 'email_template.newsletters_promotion', 'Newsletters: promotion'),
('en', 'activation_key', 'Activation key'),
('en', 'unsubscribe_key', 'Unsubscribe key'),
('en', 'subscribers_date', 'Subscribers date'),
('en', 'mailing_list_date', 'Mailing list date'),
('en', 'gdpr_newsletters', 'Personal data from newsletters'),
('en', 'newsletters.subscribe_to_newsletters', 'Newsletters: Subscribe to newsletters'),
('en', 'newsletters.agreement_text_short_subscribe_to_newsletters', 'I agree to have my personal data <u>processed as follows</u> and I want to subscribe for the following newsletters:'),
('en', 'newsletters.agreement_text_full_subscribe_to_newsletters', '<p>When you sign up for a specific newsletter, we ([company]) add your email address to a corresponding mailing list. While it is there, we know that we can contact you by email regarding that topic.</p> <p>You can always have your email address removed from our mailing lists. There are multiple ways to do it:</p><ul> <li>Once your account is registered, just sign in and unsubscribe from newsletters in profile settings.</li> <li>Use the “Unsubscribe” link in our newsletters that you receive.</li> <li>Send an email to [email].</li> </ul> <p>We may use a third-party email service (MailChimp and/or Mad Mimi) to send newsletters. Some members of our staff can view mailing lists with email addresses. That way they’ll be able to remove your email address from the mailing list, should you request us to do so.</p> <p>Please note that mailing lists are independent from each other. If you decide not to receive newsletters at all, you’ll have to unsubscribe from all the mailing lists. Even if you do that, you’ll still receive account-related emails (such as order status notifications, password reset emails, and more). It is essential for operating an online store.</p> <p>If you decide that you no longer want to use our store and would like to have your personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('en', 'newsletters.use_for_subscribe_form', 'Subscribe form'),
('en', 'newsletters.default_mailing_list', 'Default mailing list'),
('en', 'email_marketing.subscription_confirmed', 'Thank you for subscribing to our newsletter'),
('en', 'email_marketing.text_subscription_confirmed', 'Your subscription has been confirmed. No extra actions is required.'),
('en', 'email_marketing.subscription_pending', 'Email confirmation is required!'),
('en', 'email_marketing.text_subscription_pending', 'Thank you for subscribing to our newsletter.<p>A confirmation email has been sent to you. Please use the link in the email to confirm your subscription</p>'),
('en', 'email_marketing.confirm_subscription', 'Please confirm subscription'),
('en', 'email_marketing.text_confirm_subscription', 'We received a subscription request from you. Please confirm it:<p><a href="[href]">Click here to confirm your subscription to our newsletter</a></p>If you received this email by mistake, simply delete it. You won''t be subscribed if you don''t click the confirmation link above.'),
('en', 'email_marketing.subscription_confirmed_2', 'Subscription confirmed'),
('en', 'email_marketing.text_subscription_confirmed_2', 'Your subscription to our newsletter has been confirmed. Thank you for subscribing!'),
('en', 'email_marketing.email_subscribed', 'You were subscribed to our newsletter'),
('en', 'email_marketing.text_email_subscribed', 'Thank you for subscribing to our newsletter. <p>If at any time you wish to stop receiving our emails, <a href="[href]">click on this link to unsubscribe</a>.</p>'),
('en', 'email_marketing.email_subscribed_2optin', 'Subscription confirmed'),
('en', 'email_marketing.text_email_subscribed_2optin', 'Your subscription to our newsletter has been confirmed.<p>If at any time you wish to stop receiving our emails, <a href="[href]">click on this link to unsubscribe</a>.</p>'),
('en', 'email_marketing.unsubscribe_successful', 'Unsubscribe successful'),
('en', 'email_marketing.text_unsubscribe_successful', 'Your email has been removed from our list.'),
('en', 'email_marketing.export_all', 'Export all'),
('en', 'email_marketing.enter_api_key_and_save', 'Enter API key and save first'),
('en', 'email_marketing.warning_email_exists', '[email] is already subscribed'),
('en', 'email_marketing.new_subscriber', 'New subscriber'),
('en', 'email_marketing.sync', 'Sync'),
('en', 'email_marketing.text_subscribe', 'Subscribe to our newsletter'),
('en', 'email_marketing.tmpl_subscription', 'Email marketing: Newsletter subscription form'),
('en', 'privileges.manage_email_marketing', 'Can edit'),
('en', 'privileges.view_email_marketing', 'Can view'),
('en', 'privilege_groups.email_marketing', 'Email marketing'),
('en', 'email_marketing.error_no_list', 'Please select mailing list in add-on settings to start import'),
('en', 'email_template.email_marketing_confirmation', 'Email marketing: subscription confirmation'),
('en', 'email_template.email_marketing_welcome', 'Email marketing: welcome letter'),
('en', 'email_template.email_marketing_welcome_2optin', 'Email marketing: welcome letter (2optin)'),
('en', 'email_marketing.use_for_subscribe_form', 'Email marketing subscribe form'),
('en', 'attachments', 'Attachments'),
('en', 'new_attachment', 'New attachment'),
('en', 'add_attachment', 'Add attachment'),
('en', 'editing_attachment', 'Editing attachment'),
('en', 'attachments.attachments_need_located_root_dir', 'Please specify the attachments directory within the store root directory. Put the attachments to import in this directory.'),
('en', 'attachments.error_exim_get_attachments_for_products', 'Could not import attachments for some of the products. Either those attachments don''t exist (or can''t be accessed), or the paths to those attachments in the imported file are incorrect.'),
('en', 'advanced_import_attachments', 'Product attachments'),
('en', 'attachments.attachments_delimiter', 'Attachments delimiter'),
('en', 'attachments.attachments_delimiter.description', 'Delimiter between attachments of a product.'),
('en', 'attachments.delete_attachments', 'Delete existing attachments'),
('en', 'attachments.delete_attachments_tooltip', 'If you enable this setting, then the existing attachments of the imported products will be replaced with the attachments specified in the imported file (if no attachments are specified, the old attachments will remain). If the setting is disabled, the new attachments will simply be added to the existing attachments.'),
('en', 'attachments.attachments_directory', 'Attachments directory'),
('en', 'attachments.cant_upload_file', 'Couldn''t load file [url] for product [product]'),
('en', 'vendor_communication.messages', 'Messages'),
('en', 'vendor_communication.message_center', 'Message center'),
('en', 'vendor_communication.message_center_name', 'Message center'),
('en', 'vendor_communication.author', 'Author'),
('en', 'vendor_communication.date', 'Date'),
('en', 'vendor_communication.message', 'Message'),
('en', 'vendor_communication.contact_vendor', 'Contact vendor'),
('en', 'vendor_communication.ask_a_question', 'Ask a question'),
('en', 'vendor_communication.contact_vendor_name', 'Contact [vendor_name]'),
('en', 'vendor_communication.created_at', 'Created on'),
('en', 'vendor_communication.new_thread_created', 'Your message has been sent to <b>[vendor_name]</b>.<br/><br/>The vendor''s reply will be sent to the email address of your account. To view your message history, please <a href="[thread_url]">go to the Message Center</a> located in the "Messages" section of the "My account" menu.'),
('en', 'vendor_communication.message_sent', 'Your message has been sent to <b>[vendor_name]</b>.<br/><br/>We''ll notify you about a reply. To view your message history, please <a href="[thread_url]" target="_blank">go to the Message Center</a> located in the "Messages" section of the "My account" menu.'),
('en', 'vendor_communication.cannot_update_thread', 'Cannot update thread'),
('en', 'vendor_communication.cannot_create_thread', 'Cannot create thread'),
('en', 'email_template.vendor_communication.notify_admin', 'Ask seller a question: Admin Notification'),
('en', 'email_template.vendor_communication.notify_customer', 'Ask seller a question: Customer Notification'),
('en', 'vendor_communication.you_have_new_message', 'You have a new <a href="[thread_url]">message</a> from [message_from].'),
('en', 'vendor_communication.subject_email', 'You have a new message from [message_from]'),
('en', 'vendor_communication.thread', 'Thread #[thread_id]'),
('en', 'vendor_communication.contact_with', '#[thread_id]. Communication with [thread_company]'),
('en', 'vendor_communication.ticket', 'Thread'),
('en', 'vendor_communication.no_messages_found', 'No messages found'),
('en', 'vendor_communication.customer_name', 'Customer name'),
('en', 'vendor_communication.error_message', 'Please enter your message'),
('en', 'vendor_communication.type_message', 'Type a message...'),
('en', 'vendor_communication.you', 'You'),
('en', 'vendor_communication.order_details', 'Order details'),
('en', 'vendor_communication.import_details', 'Import details'),
('en', 'vendor_communication.thread_deleted', 'Thread has been deleted'),
('en', 'vendor_communication.threads_deleted', 'Threads have been deleted'),
('en', 'vendor_communication.cannot_delete_thread', 'Cannot delete thread'),
('en', 'vendor_communication.cannot_delete_threads', 'Cannot delete threads'),
('en', 'vendor_communication.cannot_post_message', 'Cannot post message'),
('en', 'vendor_communication.no_threads_found', 'No threads found'),
('en', 'vendor_communication.required_field_is_missing', 'The [field_name] field is required'),
('en', 'vendor_communication.invalid_thread_object_type', 'Provided thread object type is invalid'),
('en', 'vendor_communication.please_log_in_to_contact_vendor', 'Please sign in to contact the vendor'),
('en', 'privileges.manage_vendor_communication', 'Can edit'),
('en', 'privileges.view_vendor_communication', 'Can view'),
('en', 'privilege_groups.vendor_communication', 'Message center: customer-to-vendor communication'),
('en', 'vendor_communication.your_message_to_vendor_name', 'Your message to [vendor_name]'),
('en', 'vendor_communication.please_log_in_to_be_notified', 'Please sign in so that we can notify you about a reply'),
('en', 'vendor_communication', 'Message center'),
('en', 'vendor_communication.event.message_received.name', 'Customer-to-vendor: New message received'),
('en', 'vendor_communication.event.vendor_to_admin_message_received.name', 'Vendor-to-admin: New message received'),
('en', 'internal_template.vendor_communication_message_received', 'New message received'),
('en', 'vendor_communication.new_message.title', '[company_name] has a new message from [customer]'),
('en', 'vendor_communication.new_message.message', 'Click this notification to see the message'),
('en', 'vendor_communication.contact_admin', 'Contact administrator'),
('en', 'vendor_communication.communication', 'Communication'),
('en', 'vendor_communication.message_center_vendor_name', 'Message center'),
('en', 'vendor_communication.tab_vendor_to_admin', 'Vendor communication'),
('en', 'vendor_communication.tab_vendor_to_customer', 'Customer communication'),
('en', 'vendor_communication.tab_vendor_to_admin_for_vendor_panel', 'Admin communication'),
('en', 'vendor_communication.menu_item_vendor_to_admin', 'Vendor messages'),
('en', 'vendor_communication.menu_item_vendor_to_customer', 'Customer messages'),
('en', 'vendor_communication.menu_item_vendor_to_admin_for_vendor_panel', 'Admin messages'),
('en', 'vendor_communication.your_message_to_admin', 'Your message to administrator'),
('en', 'vendor_communication.some_threads_have_not_been_created', 'Some threads have not been created: [count]'),
('en', 'vendor_communication.vendor_to_admin.message_sent', 'Your message has been sent to <b>[name]</b>.<br/><br/>To view your message history, please <a href="[thread_url]">go to the Message Center</a> located in the "Vendors" menu.'),
('en', 'vendor_communication.vendor_to_customer.message_sent', 'Your message has been sent to <b>[name]</b>.<br/><br/>To view your message history, please <a href="[thread_url]">go to the Message Center</a> located in the "Customers" menu.'),
('en', 'vendor_communication.vendor_to_admin.message_list_sent', 'Your messages have been sent.<br/><br/>To view your message history, please <a href="[thread_url]">go to the Message Center</a> located in the "Vendors" menu.'),
('en', 'privilege_groups.admin_communication', 'Message center: vendor-to-admin communication'),
('en', 'customer_to_admin_communication.event.message_received.name', 'Customer-to-Admin: New message received'),
('en', 'vendor_communication.start_communication', 'Start communication'),
('en', 'privilege_groups.order_communication', 'Message center: communication with customer'),
('en', 'vendor_communication.communication_vendor_to_admin', 'Communication with vendor'),
('en', 'vendor_communication.communication_vendor_to_customer', 'Communication with customer'),
('en', 'vendor_communication.communication_vendor_to_admin_with_admin', 'Communication with administrator'),
('en', 'vendor_communication.contact_customer', 'Contact customer'),
('en', 'vendor_communication.subject', 'Subject'),
('en', 'vendor_communication.admin', 'Admin'),
('en', 'vendor_communication.your_message_to_customer', 'Your message to customer'),
('en', 'vendor_communication.event.order_message_received.name', 'Order communication: New message received'),
('en', 'vendor_communication.scroll_to_top', 'Scroll to top'),
('en', 'vendor_communication.send_message', 'Send message'),
('en', 'vendor_communication.dashboard.todo.messages_from_customers', '<strong>[n] message</strong> from customer.|<strong>[n] messages</strong> from customers.'),
('en', 'vendor_communication.dashboard.todo.messages_from_administrator', '<strong>[n] message</strong> from marketplace administration.|<strong>[n] messages</strong> from marketplace administration.'),
('en', 'vendor_communication.dashboard.todo.messages_from_vendors', '<strong>[n] message</strong> from vendor.|<strong>[n] messages</strong> from vendors.'),
('en', 'advanced_import.never', 'Never'),
('en', 'advanced_import.last_status.X', '&mdash;'),
('en', 'advanced_import.last_status.S', 'Success'),
('en', 'advanced_import.last_status.P', 'In progress'),
('en', 'advanced_import.last_status.F', 'Failure'),
('en', 'advanced_import.user_upload', 'User upload'),
('en', 'advanced_import.last_launch', 'Last import'),
('en', 'advanced_import.last_status', 'Status'),
('en', 'advanced_import.file', 'File'),
('en', 'advanced_import.has_modifiers', 'Has modifiers'),
('en', 'advanced_import.import_products', 'Import products'),
('en', 'advanced_import.import_products_w_preset', 'Import products: [preset]'),
('en', 'advanced_import.import_file', 'Import file'),
('en', 'advanced_import.fields_mapping', 'Fields mapping'),
('en', 'advanced_import.fields_mapping.description', 'This table contains the list of columns from the imported file. For each column you''d like to import, select a corresponding product property in [product]. Then check what sort of data will be imported from that column, and use modifiers to change that data, if necessary. Remember to save your changes.'),
('en', 'advanced_import.column_header', 'Column name in the imported file'),
('en', 'advanced_import.product_property', 'Product property in [product]'),
('en', 'advanced_import.first_line_import_value', 'Example of the imported value'),
('en', 'advanced_import.editing_preset', 'Editing preset: [preset]'),
('en', 'advanced_import.add_preset', 'Add preset'),
('en', 'advanced_import.new_preset', 'New import'),
('en', 'advanced_import.properties', 'Properties'),
('en', 'advanced_import.modifier', 'Modifier'),
('en', 'advanced_import.modifier_title', 'A modifier is a rule that alters values in a column'),
('en', 'advanced_import.example_imported_title', 'For example, here''s a value in the first line of your file:'),
('en', 'advanced_import.example_modified_title', 'And here is how this value will be imported:'),
('en', 'advanced_import.options', 'Options'),
('en', 'advanced_import.images_delimiter', 'Images delimiter'),
('en', 'advanced_import.images_delimiter.description', 'Delimiter between images of a product.'),
('en', 'advanced_import_images', 'Product images'),
('en', 'advanced_import.remove_images', 'Remove additional images'),
('en', 'advanced_import.import_fields', 'Import fields'),
('en', 'advanced_import.advanced_products_import', 'Products'),
('en', 'advanced_import.coming_soon', '... coming soon'),
('en', 'advanced_import.cant_load_file_for_company', 'File can''t be loaded for the specified company'),
('en', 'advanced_import.cant_load_file', 'File can''t be loaded'),
('en', 'advanced_import.uploading_file', 'Uploading file for the preset: [preset]'),
('en', 'advanced_import.previewing_fields_mapping', 'Previewing fields mapping for the preset: [preset]'),
('en', 'advanced_import.preset_not_found', 'Preset not found'),
('en', 'advanced_import.modifiers_list', 'Modifiers list'),
('en', 'advanced_import.invalid_number_of_parameters_provided', 'Invalid number of parameters provided for modifier: <b>[modifier]</b>: expected [expected_count], got [actual_count].'),
('en', 'advanced_import.invalid_function_firs_character', 'The modifier name cannot start with character <b>[character]</b>.'),
('en', 'advanced_import.unrecognized_modifier', 'The modifier <b>[modifier]</b> does not exist.'),
('en', 'advanced_import.unexpected_parameter_passed', 'Expected <b>[delimiter]</b> or <b>[closer]</b> got <b>[char]</b>.'),
('en', 'advanced_import.invalid_modifier_message', 'The modifier <b>[modifier]</b> is invalid. [message]'),
('en', 'advanced_import.modifier_number_of_parameters', 'Number of parameters'),
('en', 'advanced_import.modifiers_description', 'Use these functions in the <b>Modifier</b> column to alter the values in the fields from the imported file. Enter the functions as follows: <b>function(parameter, parameter)</b>. Please note that nesting of functions isn''t supported.'),
('en', 'advanced_import.modifiers_self_referencing_info', 'Most functions allow you to use the non-modified value of the imported field by using <b>$value</b> as a parameter. If there are any exceptions, they will be mentioned in function descriptions.'),
('en', 'advanced_import.modifier_description.sum', '<b>sum</b>&mdash;sums up two numbers provided as parameters. <ul><li>Examples:</li><ul><li><b>sum(1, 3)</b> equals <i>4</i></li> <li><b>sum(7, $value)</b> equals <i>7 + the value of the imported field</i></li></ul></ul>'),
('en', 'advanced_import.modifier_description.sub', '<b>sub</b>&mdash;subtracts the second parameter from the first. <ul><li>Examples:</li><ul><li><b>sub(3, 1)</b> equals <i>2</i></li> <li><b>sub($value, 7)</b> equals <i>the value of the imported field - 7</i></li></ul></ul>'),
('en', 'advanced_import.modifier_description.mul', '<b>mul</b>&mdash;multiplies the numbers provided as parameters. <ul><li>Examples:</li><ul><li><b>mul(3, 1)</b> equals <i>3</i></li> <li><b>mul($value, 7)</b> equals <i>the value of the imported field × 7</i></li></ul></ul>'),
('en', 'advanced_import.modifier_description.div', '<b>div</b>&mdash;divides the first parameter by the second. <ul><li>Examples:</li><ul><li><b>div(9, 3)</b> equals <i>3</i></li> <li><b>div($value, 7)</b> equals <i>the value of the imported field ÷ 7</i></li></ul></ul>'),
('en', 'advanced_import.modifier_description.concat', '<b>concat</b>&mdash;concatenates all the provided parameters. <ul><li>Examples:</li><ul><li><b>concat(''abc'', def)</b> will result in <i>abcdef</i></li> <li><b>concat(''PRODUCT_'', $value, ''_CODE'')</b> will result in <i>PRODUCT_$value_CODE</i>, but <b>$value</b> will be replaced with the the value of the imported field</li></ul></ul>'),
('en', 'advanced_import.modifier_description.replace', '<b>replace</b>&mdash;replaces all occurrences of the search string with the replacement string. <br>The order of parameters is important: <b>replace(''search'', ''replace'', ''subject'')</b>. <ul><li>Examples:</li><ul><li><b>replace(''a'', !, "banana")</b> will result in <i>b!n!n!</i></li> <li><b>replace("t-shirt", ''T-Shirt'', $value)</b> will replace every occurrence of <i>t-shirt</i> with <i>T-Shirt</i> in every entry in the column.</li></ul></ul>'),
('en', 'advanced_import.modifier_description.w_replace', '<b>w_replace</b>&mdash;replaces all occurrences of the search string with the replacement string using wildcards. <br>The order of parameters is important: <b>w_replace(''search'', ''replace'', ''subject'')</b>. <br>Supported wildcards: <b>?</b>&mdash;any single character; <b>*</b>&mdash;any number of characters to the end of the word. <ul><li>Examples</li><ul><li><b>w_replace(''banan?'', bananas, banana banans bananz)</b> will result in <i>bananas bananas bananas</i></li> <li><b>w_replace("ban*", ''bananas'', banana banans bananz)</b> will also result in <i>bananas bananas bananas</i></li></ul></ul>'),
('en', 'advanced_import.modifier_description.rand', '<b>rand</b>&mdash;generates a random number from 1 to the maximum value provided as the parameter. <ul><li>Examples:</li><ul><li><b>rand(999)</b> may result in any number from 1 to 999.</li></ul></ul>');
INSERT INTO `[[dbprefix]]language_values` VALUES
('en', 'advanced_import.modifier_description.if', '<b>if</b>&mdash;checks the expression in the first parameter. If the first parameter is <i>true</i>, the function returns the second parameter. Otherwise the function returns the third parameter.<ul><li>Examples:</li><ul><li><b>if($value>"0", "In Stock", "Out of stock")</b> will result in <i>In Stock</i> if <i>$value > 0</i> is <i>true</i>; otherwise the result will be <i>Out of stock</i></li></ul><li>Available operations for the expression are:<ul><li><b>=</b>&mdash;checks for equality: <i>if($value=100, ...)</i></li><li><b>!=</b>&mdash;checks for inequality: <i>if($value!=100, ...)</i></li><li><b>&gt;</b>&mdash;checks if the first value is greater than the second: <i>if($value&gt;100, ...)</i></li><li><b>&lt;</b>&mdash;checks if the first value is less than the second: <i>if($value&lt;100, ...)</i></li><li><b>&gt;=</b>&mdash;checks if the first value is greater than or equal to the second: <i>if($value&gt;=100, ...)</i></li><li><b>&lt;=</b>&mdash;checks if the first value is less than or equal to the second: <i>if($value&lt;=100, ...)</i></li></ul></li><li>Notes:<ul><li>If you use single ('') or double (") quotes in the first parameter, make sure that the first parameter is either wrapped in quotes entirely, or that there is no end quote in the middle of the parameter. For example, <i>if("My value"=$value, ...)</i> will not work, but <i>if("My value=$value", ...)</i> will.</ul></li></ul>'),
('en', 'advanced_import.modifier_description.case', '<b>case</b>&mdash;odd parameters are expressions, and the following even parameters are corresponding values. The function checks the expressions and returns the value corresponding to the first expression that ends up being <i>true</i>.<ul><li>Examples:</li><ul><li><b>case($value>100, "More than 100", $value>70, "More than 70", $value>20, "More than 20", $value>0, "In stock", $value=0, "Out of stock")</b> will result in <i>More than 70</i> if the <i>$value</i> in the imported file is a number between 71 and 100</li></ul><li>Notes:<ul><li>This function shares expression rules and available operations with the <b>if</b> function.</li><li>Only even numbers of parameters are supported: <b>2, 4, 6, 8</b>, etc.</li></ul></li></ul>'),
('en', 'advanced_import.modifier_self_reference_is_unsupported', 'This function doesn''t support the use of a non-modified value from the imported file.'),
('en', 'advanced_import.preset_last_view', 'Preset'),
('en', 'advanced_import.show_more', 'Show more'),
('en', 'advanced_import.show_less', 'Show less'),
('en', 'advanced_import.target_node', 'XML target node'),
('en', 'advanced_import.target_node.description', 'The full path to the XML node with the information about an imported entity. The nodes nested in the specified node will be used as columns of the imported file. Here is an example of the path: yml_catalog/shop/offers/offer'),
('en', 'advanced_import.fetching_schema_failed_check_target_node', 'Please make sure that the <b>XML target node</b> field is filled in properly.'),
('en', 'advanced_import.general_settings', 'General settings'),
('en', 'advanced_import.additional_settings', 'Additional settings'),
('en', 'advanced_import.delete_additional_images', 'Delete existing additional images'),
('en', 'advanced_import.delete_additional_images_tooltip', 'If you enable this setting, then the existing additional images of the imported products will be replaced with the images specified in the imported file (if no images are specified, the old images will remain). If the setting is disabled, the new additional images will simply be added to the existing images.'),
('en', 'advanced_import.fetching_schema_failed_check_file', 'Before you can run the import, please make sure that:<ul><li>You have created the import preset by using the Create button. If you see Save instead of Create, then you''ve already done that.</li><li>You have specified the correct XML target node on the File tab and saved the preset.</li><li>You have matched the imported information with the product properties in CS-Cart on the Fields mapping tab and saved the preset.</li></ul>If you see this message, you haven''t completed point 1 or 2.'),
('en', 'advanced_import.test_import', 'Perform test import'),
('en', 'advanced_import.test_import_tooltip', 'If you enable this setting, only the first [n] product will be processed.|If you enable this setting, only the first [n] products will be processed.'),
('en', 'advanced_import.import_strategy', 'Import strategy'),
('en', 'advanced_import.import_strategy_tooltip', 'If you select "Update existing products only", products that don''t exist in the database of your store will be skipped during import.<br>If you select "Create new products only", products that exist in the database of your store will be skipped during import.'),
('en', 'advanced_import.import_all', 'Import all products from the file'),
('en', 'advanced_import.create_new_products_only', 'Create new products only'),
('en', 'advanced_import.cant_save_preset_invalid_modifiers', 'The preset can''t be saved because it contains invalid modifiers'),
('en', 'advanced_import.some_product_properties_not_found', 'Some previously mapped product properties are no longer available. For example, this can happen when you disable a product feature.'),
('en', 'advanced_import.missing_parameters_list_closer', 'The expected <b>[closer]</b> after the parameters list is missing.'),
('en', 'advanced_import.run_import_via_cron_message', 'You can run the import automatically at certain time intervals. To do it, add the following command to CRON:'),
('en', 'advanced_import.cannot_detect_csv_delimiter', 'Cannot detect delimiter automatically. Please specify the correct delimiter manually in the additional settings on the "File" tab.'),
('en', 'advanced_import.incorrect_delimiter', 'Specified (or auto detected) delimiter seems to be incorrect. Please specify the correct delimiter manually in the additional settings on the "File" tab.'),
('en', 'advanced_import.file_will_be_deleted_are_you_sure_to_proceed', 'Deleting this import preset will also delete the file attached to it. Are you sure you want to proceed?'),
('en', 'advanced_import.common_preset', 'All vendors'),
('en', 'advanced_import.your_presets', 'Vendor''s presets'),
('en', 'advanced_import.common_presets', 'Marketplace presets'),
('en', 'advanced_import.file_not_loaded', 'File was not loaded. Please reload the page and try again.'),
('en', 'advanced_import.local_file_selected', 'Local file selected'),
('en', 'advanced_import.text_popup_file_editor_notice_full_link', 'You can upload and download files via <a class="advanced-import-file-editor-opener" data-target-input-id="[target]">[link_text]</a>'),
('en', 'advanced_import.text_popup_file_editor_notice_with_image_size_info', 'You can upload and download files via <a class="advanced-import-file-editor-opener" data-target-input-id="[target]">[link_text]</a>. The maximum size of image files is [file_size] MB.'),
('en', 'advanced_import.text_allowed_to_upload_file_extension_with_image_size_info', 'The following file extensions are supported: <b>[ext]</b>. The maximum size of image files is [file_size] MB.'),
('en', 'advanced_import.file_extension_was_not_supported_by_owner', 'Couldn''t use your file [name]. This import preset only allows the following extensions: [ext].'),
('en', 'advanced_import.save_selected_file', 'Save selected file'),
('en', 'advanced_import.fields_delimiter', 'XML node delimiter'),
('en', 'advanced_import.fields_delimiter.description', 'Delimiter between similar nodes.'),
('en', 'advanced_import.link_to_file', 'Link to file'),
('en', 'advanced_import.export_example', 'Export example'),
('en', 'advanced_import.cant_export_example', 'The example file can not be exported. Fill the fields mapping of current preset.'),
('en', 'advanced_import.archive_with_images', 'Archive with images'),
('en', 'advanced_import.step_map_fields', 'Next step: map fields'),
('en', 'geo_maps.select_your_city', 'Select your city'),
('en', 'geo_maps.your_city', 'Your city'),
('en', 'geo_maps.location_detection_disabled', 'Your location could not be determined. Try enabling the location services on your device or disabling the tracking protection.'),
('en', 'block_geo_maps_customer_location', 'Customer location'),
('en', 'block_geo_maps_customer_location_description', 'Current city and city selection form'),
('en', 'geo_maps.shipping_address_on_map', 'Shipping address on map'),
('en', 'geo_maps.cannot_select_location', 'This location couldn''t be selected due to technical reasons. If you encounter any difficulties when placing an order, please contact us.'),
('en', 'geo_maps.shipping_time_and_rates', 'Shipping time and rates'),
('en', 'geo_maps.shipping_group_pickup', 'Pick-up'),
('en', 'geo_maps.shipping_group_delivery', 'Shipping'),
('en', 'geo_maps.from_pickup_points', '[shipping], [n] pickup point|[shipping], [n] pickup points'),
('en', 'geo_maps.shipping_about', 'about'),
('en', 'geo_maps.shipping_from', 'from'),
('en', 'geo_maps.shipping_time', 'Shipping time'),
('en', 'geo_maps.no_shippings', 'Sorry, we couldn''t find any shipping options for your location. Please contact us, and we''ll see what we can do about it.'),
('en', 'geo_maps.no_shippings_short', 'Shipping to your location isn''t available.'),
('en', 'geo_maps.text_settings_google_api_notice', 'Learn more about setting up API key <a target="_blank" href="https://docs.cs-cart.com/4.10.x/user_guide/addons/maps_and_geolocation/#configuration">in the documentation</a>.'),
('en', 'geo_maps.settings_is_configured_correctly_notice', 'If you see the map here, everything is configured correctly, and the maps are working on the map provider end.'),
('en', 'geo_maps.google_maps_cookie_title', 'Google Maps'),
('en', 'geo_maps.google_maps_cookie_description', 'Google Maps is a service that allows us to show the maps and various locations on those maps, or automatically determine your location. Here is <a href="https://policies.google.com/privacy" target="_blank">Google privacy policy;</a> we also recommend Google''s concise and comprehensive <a href="https://support.google.com/maps/answer/10400210" target="_blank">note on privacy</a>.'),
('en', 'geo_maps.yandex_maps_cookie_title', 'Yandex Maps'),
('en', 'geo_maps.yandex_maps_cookie_description', 'Yandex Maps is a service that allows us to show the maps and various locations on those maps, or automatically determine your location. Here is <a href="https://yandex.com/legal/confidential/" target="_blank">Yandex privacy policy</a>.'),
('en', 'gift_certificates.actions.gift_certificate_statuses', 'Gift certificate statuses'),
('en', 'gift_certificate', 'Gift certificate'),
('en', 'gift_certificates', 'Gift certificates'),
('en', 'gift_certificate_info', 'Gift certificate info'),
('en', 'gift_certificate_verification', 'Gift certificate verification'),
('en', 'gift_cert_code', 'Gift certificate code'),
('en', 'gift_cert_debit', 'Debit balance'),
('en', 'gift_cert_from', 'From'),
('en', 'gift_cert_to', 'To'),
('en', 'promotion_bonus_gift_certificate', 'Gift certificate'),
('en', 'purchase_gift_certificate', 'Purchase Gift Certificate'),
('en', 'text_gift_certificate_logo', 'Logo for <b>gift certificates</b>'),
('en', 'text_gift_cert_amount_alert', 'Amount should be between [min] and [max]'),
('en', 'text_gift_cert_has_been_deleted', 'Gift certificate has been deleted successfully.'),
('en', 'error_gift_cert_code', 'The gift certificate code you entered is invalid. Please try again.'),
('en', 'gift_add_products', 'Add products for a gift'),
('en', 'gift_comment', 'Message'),
('en', 'certificate_verification', 'Validate/Redeem gift certificate'),
('en', 'detailed_info', 'Detailed information'),
('en', 'history', 'History'),
('en', 'gift_certificate_statuses', 'Gift certificate statuses'),
('en', 'gift_certificates.recipient_email', 'Recipient email'),
('en', 'text_gift_cert_applied', 'Gift certificate has been applied'),
('en', 'certificate_already_used', 'This gift certificate is already in use'),
('en', 'certificate_code_not_available', 'Gift certificate cannot be applied. Please contact the store administration.'),
('en', 'certificate_code_not_valid', 'Gift certificate code is not valid'),
('en', 'warning_gift_cert_deny', 'The following gift certificates have been deleted or cancelled by administrator and have been removed from your cart: [codes]. Please contact the store administrator or try another one.'),
('en', 'text_gift_cert_cannot_delete', 'Gift certificate [code] cannot be deleted because it is used in order(s) [ids].'),
('en', 'gift_cert_amount_changed', 'Gift certificate amount has been changed.'),
('en', 'purchased', 'Purchased'),
('en', 'used', 'Used'),
('en', 'create_gift_certificate_for_customer', 'Create Gift Certificate for this customer'),
('en', 'gift_certificate_created', 'Gift Certificate has been created'),
('en', 'related_gift_cert', 'Related gift certificates'),
('en', 'add_gift_certificate', 'Add gift certificate'),
('en', 'gift_certificate_status', 'Gift certificate status'),
('en', 'current_amount', 'Current amount'),
('en', 'mail', 'Mail'),
('en', 'statuses', 'statuses'),
('en', 'new_certificate', 'New certificate'),
('en', 'editing_certificate', 'Editing certificate'),
('en', 'shop_now', 'Shop now'),
('en', 'theme_editor.gift_cert', 'Gift Certificate'),
('en', 'theme_editor_logo.gift_cert', 'Gift Certificate'),
('en', 'promo_code_or_certificate', 'Gift certificate or promo code'),
('en', 'gift_certificate_added_to_cart', 'Gift certificate was added to your cart'),
('en', 'gift_certificates_verify', 'Gift certificate verification'),
('en', 'block_gift_certificates_verify', 'Gift certificate verification'),
('en', 'block_gift_certificates_verify_description', 'Gift certificate input and validation'),
('en', 'gift_cert_error_amount', 'Amount should not be higher than [max] and less than [min]'),
('en', 'privileges.manage_gift_certificates', 'Can edit'),
('en', 'privilege_groups.gift_certificates', 'Gift certificates'),
('en', 'change_gift_certificate_status', 'Change gift certificate status to'),
('en', 'gift_cert_with_products', 'Purchasing products and gift certificates together is impossible. Please, place the current order and repeat your attempt.'),
('en', 'gc_redeem_and_add_free_products', 'Redeem & add free products to cart'),
('en', 'email_template.gift_certificates_notification', 'Gift certificate'),
('en', 'template_document_gift_certificate_default', 'Gift certificates: default'),
('en', 'document_preview_gift_certificate_not_found', 'Couldn''t find a gift certificate. Preview only works with existing data. Please create a gift certificate and use Preview again.'),
('en', 'gift_certificates.certificate_purchase_form', 'Gift certificate purchase form'),
('en', 'gift_certificates.event.gift_certificate.status_changed.name', 'Gift certificate status changed to [status]'),
('en', 'gift_certificates.event.gift_certificate.updated.name', 'Gift certificate updated'),
('en', 'logo_section.gift_cert', 'Gift certificate logo'),
('en', 'store_locator_menu_description', 'Set up locations for pick up and manage inventory by location.'),
('en', 'store_locator.actions.store_locator', 'Stores'),
('en', 'view_on_map', 'View on map'),
('en', 'get_api_key', 'Obtaining an API Key'),
('en', 'block_store_locator', 'Store locator'),
('en', 'store_locator', 'Stores & pickup points'),
('en', 'block_store_locator_description', 'Store locator block'),
('en', 'text_address_not_found', 'Address not found'),
('en', 'select_coordinates', 'Select coordinates'),
('en', 'set', 'Set'),
('en', 'editing_store_location', 'Editing store location'),
('en', 'new_store_location', 'New store location'),
('en', 'add_store_location', 'Add store location'),
('en', 'coordinates', 'Coordinates'),
('en', 'latitude_short', 'lat'),
('en', 'longitude_short', 'long'),
('en', 'all_stores', 'All stores'),
('en', 'privileges.manage_store_locator', 'Can edit'),
('en', 'privilege_groups.store_locator', 'Store locator'),
('en', 'privileges.view_store_locator', 'Can view'),
('en', 'store_locator.text_pickup_instruction', 'The "Customer pick-up" shipping method offers a customer to choose a store to pick up a product from. The stores can be created in the "Store location" add-on<br /><b>Store creation:</b> <a href="[store_locator]">Store location</a>'),
('en', 'store_locator.select_stores', 'Select stores'),
('en', 'store_locator.pick_up_points', 'Pick-up points'),
('en', 'store_locator.stores_position', 'The "Position" field in the store settings'),
('en', 'store_locator.shipping_position', 'Order selected in the shipping method settings'),
('en', 'store_locator.selected_fields', 'Selected stores'),
('en', 'store_locator.available_fields', 'Available stores'),
('en', 'store_locator.display_ml', 'Map and list'),
('en', 'store_locator.display_l', 'List'),
('en', 'store_locator.display_m', 'Map'),
('en', 'store_locator.display', 'Locations list view on the checkout page'),
('en', 'store_locator.pickup', 'Pickup'),
('en', 'store_locator.pickup_avail', 'Available for pick-up'),
('en', 'store_locator.work_time', 'Working hours'),
('en', 'carrier_store_locator', 'Pickup'),
('en', 'destination_nothing_found', 'No suitable destination has been found'),
('en', 'stores_nothing_found', 'No stores have been found'),
('en', 'pickup', 'Pickup'),
('en', 'pickup_id', 'Pickup ID'),
('en', 'pickup_avail', 'Pickup avail'),
('en', 'pickup_surcharge', 'Pickup surcharge'),
('en', 'pickup_address', 'Pickup address'),
('en', 'pickup_phone', 'Pickup phone'),
('en', 'pickup_time', 'Pickup time'),
('en', 'pickup_destinations_ids', 'Pickup destinations ids'),
('en', 'store_locator.show_pickup_points_only', 'Hide places where I can''t pick up my order'),
('en', 'store_locator.stores_and_pickup_points', 'Stores and pickup points'),
('en', 'store_locator.surcharge_changes_hint', 'In previous versions, the surcharge was added to the standard rates that were specified for a shipping method. Now this surcharge isn''t taken into account during shipping rate calculation. We left it here for your convenience, so that you could see it and adjust the rates on the shipping method editing page accordingly.'),
('en', 'store_locator.main_destination', 'Located in rate area'),
('en', 'tt_addons_store_locator_views_store_locator_update_store_locator.main_destination', 'Determines the shipping rates for this pickup point. The rates are specified on the shipping method editing page. If you don''t select a rate area for a pickup point, then the pickup point won''t appear at checkout.'),
('en', 'store_locator.show_to', 'Show to'),
('en', 'show_to', 'Show to'),
('en', 'tt_addons_store_locator_views_store_locator_update_store_locator.show_to', 'Allows you to offer this pickup point to the residents of other rate areas at checkout.'),
('en', 'store_locator.shipping_price_from', 'from [price]'),
('en', 'store_locator.use_two_fingers_for_move_map', 'Use two fingers to move the map'),
('en', 'store_locator.scroll_to_top', 'Scroll to top'),
('en', 'store_locator.no_rate_area', 'No rate area'),
('en', 'store_locator.name', 'Name'),
('en', 'store_locator.pickup_locations', 'Pickup Locations'),
('en', 'store_locator.any_rate_area', 'Any rate area'),
('en', 'store_locator.pickup_from_store', 'Pickup from store'),
('en', 'store_locator.any_vendor', 'Any vendor'),
('en', 'store_locator.any', 'Any'),
('en', 'store_locator.shipping_price_from_to', 'from [from_price] to [to_price]'),
('en', 'product_variations.product_type', 'Product type'),
('en', 'product_variations.product_type.catalog_item', 'Catalog item'),
('en', 'product_variations.product_type.variation_of_catalog_item', 'Variation of a catalog item'),
('en', 'product_variations.belongs_to_catalog_item', 'Belongs to catalog item:'),
('en', 'product_variations.variations', 'Variations'),
('en', 'product_variations.variation_of_product', 'Variation of catalog item <a href="[url]">[product]</a>'),
('en', 'product_variations.group_code', 'Variation group'),
('en', 'product_variations.group_code.placeholder', 'Set custom group code here'),
('en', 'product_variations.group_code.description', 'Use the group code on a product editing page or during import to add the product to this group as a variation. A group code can contain only digits, Latin characters, and the following signs: "-" and "_".'),
('en', 'product_variations.group_code.link', 'Add to variation group'),
('en', 'product_variations.add_variations', 'Add variations'),
('en', 'product_variations.link_existing', 'Use existing products'),
('en', 'product_variations.create_new', 'Create new products'),
('en', 'product_variations.add_variations_description', 'Add variations to generate a group of similar products that differ in color, size, etc. Or add this product to an existing group by entering the group code.'),
('en', 'product_variations.manage', 'Manage variations'),
('en', 'product_variations.edit_features', 'Edit features'),
('en', 'product_variations.delete', 'Disband group'),
('en', 'product_variations.remove_variation', 'Remove variation from group'),
('en', 'product_variations.delete_product', 'Delete product'),
('en', 'product_variations.mark_main_product', 'Set as default variation'),
('en', 'product_variations.no_available_features', 'This product doesn''t have features that allow grouping products. Please make sure that:<ol><li>You have created at least one feature with <b>Purpose:</b> <i>Variations as separate products</i> or <i>Variations as one product</i>.</li><li>You have specified the value of that feature for the product.</li></ol><a href=[manage_features_href]>Manage features</a>'),
('en', 'product_feature.purpose.group_catalog_item', 'Variations as separate products'),
('en', 'product_feature.purpose.group_catalog_item.description', 'For cases when a few similar products differ visibly by a feature, and have different names (for example, multiple "Color" variants of a T-shirt). These products will appear as separate positions in the catalog. Customers will also be able to select the desired feature value on the product page. To achieve this, <b>set up variations for products with this feature</b>.'),
('en', 'product_feature.feature_style.dropdown', 'Drop-down list'),
('en', 'product_feature.feature_style.dropdown_images', 'Images'),
('en', 'product_feature.feature_style.dropdown_labels', 'Text labels'),
('en', 'product_feature.purpose.group_variation_catalog_item', 'Variations as one product'),
('en', 'product_feature.purpose.group_variation_catalog_item.description', 'For cases when a few similar products differ by a feature, but have the same name and similar appearance (for example, multiple "Size" variants of a T-shirt). These products will occupy a single position in the catalog. Customers will be able to select the desired feature value on the product page. To achieve this, <b>set up variations for products with this feature</b>.'),
('en', 'product_variations.warning.before_edit_variations_save_product', 'Before you can edit variations, please save the product.'),
('en', 'product_variations.error.group_not_found', 'Variation group #[id] not found'),
('en', 'product_variations.error.product_not_found_in_group', 'Product #[product_id] not found in variation group "[group_code]"'),
('en', 'product_variations.error.cannot_mark_main_product_child_product', 'Product #[product_id] in group "[group_code]" isn''t a variation, so it can''t become default for a catalog item'),
('en', 'product_variations.error.generate_combinations_is_empty', 'Couldn''t generate variations. Please specify the values of features to generate variations.'),
('en', 'product_variations.error.generate_products_is_empty', 'No new products were created'),
('en', 'product_variations.error.product_not_found', 'Product #[product_id] not found'),
('en', 'product_variations.error.group_not_found_by_product', 'Couldn''t find variation group for #[product_id] "[product]"'),
('en', 'product_variations.error.feature_combination_is_invalid_for_product', 'Wrong combination of features for product #[product_id] "[product]"'),
('en', 'product_variations.error.product_ids_empty', 'Products couldn''t be found'),
('en', 'product_variations.select_variation', 'Select a Variation'),
('en', 'product_variations.error.group_code_is_required', 'Variation group code must be specified'),
('en', 'product_variations.error.group_code_is_invalid', 'Couldn''t set this code for variation group. A group code can contain only digits, Latin characters, and the following signs: "-" and "_"'),
('en', 'product_variations.error.group_code_is_duplicate', 'The specified variation group code is already in use'),
('en', 'product_variations.error.features_is_empty', 'Features couldn''t be found'),
('en', 'product_variations.error.no_available_products', 'No suitable products were found'),
('en', 'product_variations.error.product_has_not_required_features', 'Product #[product_id] "[product]" doesn''t have the required features to become a variation. Please set feature values for that product.'),
('en', 'product_variations.error.product_with_features_combination_exits', 'Product #[product_id] "[product]" has the exact same combination of feature values as a variation that already exists in the group.'),
('en', 'product_variations.error.product_company_does_not_match_to_group_company.ult', 'Product #[product_id] "[product]" can''t be added to the variation group because all products in a variation group must belong to the same storefront.'),
('en', 'product_variations.error.product_company_does_not_match_to_group_company.mve', 'Product #[product_id] "[product]" can''t be added to the variation group because all products in a variation group must belong to the same vendor.'),
('en', 'product_variations.variations_filling', 'Variations'),
('en', 'product_variations.variations_list', 'Variations'),
('en', 'variations_in_stock', 'Only "in stock" products'),
('en', 'product_variations.hide_add_to_wishlist_button', 'Hide add to wish list button'),
('en', 'product_variations.variations_list_block_name', 'Variations list'),
('en', 'product_variations.variations_list_tab_name', 'View all variations as list'),
('en', 'product_variations.show_variation_thumbnails', 'Show variation thumbnails'),
('en', 'product_variations.show_product_code', 'Show product code'),
('en', 'product_variations.exim.result_notice', 'Data is imported successfully.<br />New products - <b>[new]</b>;<br />Updated products - <b>[exist]</b>;<br />Skipped products - <b>[skipped]</b>;<br />Total - <b>[total]</b>;<br />Created variations - <b>[variation_created]</b>;<br />Updated variations - <b>[variation_updated]</b>;<br />Disbanded variations - <b>[variation_removed]</b>.'),
('en', 'variation_group_id', 'Variation group ID'),
('en', 'variation_group_code', 'Variation group code'),
('en', 'variation_parent_product_id', 'Variation parent product ID'),
('en', 'variation_sub_group_id', 'Variation sub group ID'),
('en', 'product_variations.feature_used_by_variation_group.tooltip', 'This feature is used by variation group [code]. To choose a different value of this feature for a product, switch to the "Variations" tab of the product editing page. New values can be added on the feature editing page.'),
('en', 'product_variations.variations_naming_strategy.key_value', 'Color: Red, Size: Small'),
('en', 'product_variations.variations_naming_strategy.value', 'Red, Small'),
('en', 'product_variations.feature_can_be_deleted', 'Couldn''t delete a feature or its variant because at least one variation group is based on it. Please delete <a href="[href]">these products</a> or disband their product groups, and try again.'),
('en', 'product_variations.notice.old_product_variations_exists', 'Your store still has old product variations. They currently appear as separate products, without the ability to switch between them. To make them work as before the upgrade, <a href="[convert_url]">convert old variations to new variations</a>. It''s easy and automatic.'),
('en', 'product_variations.notice.is_old_product_variation', 'This product is an old variation that hasn''t been converted yet. To make it work as before the upgrade, <a href="[convert_url]">convert old variations to new variations</a>.'),
('en', 'variation_set_as_default', 'Variation set as default'),
('en', 'product_variations.cant_edit_feature_categories', 'Couldn''t restrict the feature''s availability in categories. <a href="[href]">Some product variations with that feature</a> are still available in the categories where you tried to restrict the feature. Please remove the variation groups from those categories and try again.'),
('en', 'product_variations.too_many_combinations', 'Sorry, there are too many possible variations that can be generated. To prevent heavy load, we won''t display them here. Please create the products with the right feature values manually or via import, and add them to the group.'),
('en', 'product_variations.generator.features.placeholder', 'Search for features that can generate variations'),
('en', 'product_variations.generator.warning.new_features_add', 'You can add a new feature if you disband the group in the actions menu and create variations again.'),
('en', 'product_variations.generator.feature_variants.placeholder', 'Type to search'),
('en', 'product_variations.generator.feature_variants.add_all_variants', 'Add all variants'),
('en', 'product_variations.generator.table.title', 'Modify the variations to be created:'),
('en', 'product_variations.generator.create_btn', 'Create [n] variation|Create [n] variations'),
('en', 'product_variations.allow_own_features_setting_changing', 'You''ve disabled the <b>Allow own feature values for child variations</b> setting. Please export <a href="[url]">all your default variations</a> (use "Export found products" in the gear button) and reimport them. This will apply their feature values to existing child variations.'),
('en', 'product_variations.allow_own_images_setting_changing', 'You''ve disabled the <b>Allow own images for child variations</b> setting. Please export <a href="[url]">all your default variations</a> (use "Export found products" in the gear button) and reimport them. This will apply their images to existing child variations.'),
('en', 'product_variations.add_all_variants', 'Add all variants'),
('en', 'product_variations.error.not_available_feature_purpose', 'Couldn''t create variation group based on these features; please use the features with the purpose that is eligible for creating variations (group_catalog_item or group_variation_catalog_item).'),
('en', 'product_variations.error.cannot_set_as_default_out_of_stock', 'Couldn''t set variation #[product_id] as default, because it is out of stock. A variation that is in stock was used as default instead.'),
('en', 'product_variations.error.variations_as_separate_products_exceeds_the_limit', 'You’re trying to add more products than allowed by your plan limits. <b>[available_count]</b> products could be added.'),
('en', 'product_variations.error.limit_creating_new_products_exhausted_with_url', 'You can’t add more products at this time. You may need to <a href="[url_upgrade_plan]" target="_blank">upgrade the plan</a> before adding new products.'),
('en', 'product_variations.error.limit_creating_new_products_exhausted', 'You can’t add more products at this time. You may need to upgrade the plan before adding new products.'),
('en', 'product_variations.too_many_combinations_display', 'There are too many possible variations to preview them here. But you can still create them, if they don''t exist already.'),
('en', 'error_validator_recaptcha', 'Please confirm you are not a robot.'),
('en', 'recaptcha_settings_notice', '<p>The instructions on how to get the <b>site key</b> and <b>secret</b> are available <b><a target="_blank" href="https://developers.google.com/recaptcha/docs/start">here</a></b>.</p>'),
('en', 'recaptcha.text_settings_notice', '<p>The instructions on how to get the <b>site key</b> and <b>secret</b> are available <b><a target="_blank" href="https://developers.google.com/recaptcha/intro">here</a></b>.<br>Please note that the add-on currently supports only <b>Google reCAPTCHA v2: Checkbox</b> and <b>Google reCAPTCHA v3</b></p>'),
('en', 'recaptcha.text_forbidden_countries_notice', '<p>Google reCAPTACHA will be disabled for the selected countries. Instead, visitors from those countries will be asked to type a few symbols they see on the screen.</p>'),
('en', 'recaptcha.error_recaptcha_v3_failed', 'Sorry, the anti-bot validation has failed. If you''re seeing this message, please contact us and let us know about it.'),
('en', 'recaptcha.recaptcha_v2', 'reCAPTCHA v2'),
('en', 'recaptcha.recaptcha_v3', 'reCAPTCHA v3'),
('en', 'recaptcha.none', 'none'),
('en', 'recaptcha.recaptcha_cookie_title', 'Google reCAPTCHA'),
('en', 'recaptcha.recaptcha_cookie_description', 'Google reCAPTCHA is a service that provides anti-bot protection and verifies that site visitors are humans. Here is <a href="https://policies.google.com/privacy" target="_blank">Google privacy policy</a>; we also recommend Google''s concise and comprehensive <a href="https://support.google.com/maps/answer/10400210" target="_blank">note on privacy</a>.'),
('en', 'product_bundles.tab_title', 'Bundles with this product'),
('en', 'product_bundles.product_bundles', 'Product bundles'),
('en', 'product_bundles.promo_image', 'Promo image'),
('en', 'product_bundles.display_in_promotions', 'Display in promotions'),
('en', 'product_bundles.bundle_products', 'Bundle products'),
('en', 'product_bundles.price_for_all', 'Price for all'),
('en', 'product_bundles.share_discount', 'Share discount'),
('en', 'product_bundles.product_bundle_name', 'Bundle name'),
('en', 'product_bundles.products_in_bundle', 'Products in bundle'),
('en', 'product_bundles.total_cost', 'Total cost'),
('en', 'product_bundles.add_new_bundle', 'Add new bundle'),
('en', 'product_bundles.delete_product_in_bundle', 'The <b>[bundle_name]</b> bundle was disabled, because of the products from this bundle was deleted.|The <b>[bundle_name]</b> bundle were disabled, because one of the products from these bundles was deleted.'),
('en', 'product_bundles.new_bundle', 'New bundle'),
('en', 'product_bundles.active_bundles', 'Active bundles'),
('en', 'product_bundles.specify_features', 'Specify features'),
('en', 'product_bundles.any_variation', 'Any variation'),
('en', 'product_bundles.specify_options', 'Specify options'),
('en', 'product_bundles.total_list_price', 'Total list price'),
('en', 'product_bundles.order_discount', 'Order discount'),
('en', 'product_bundles.add_all_to_cart', 'Add all to cart'),
('en', 'product_bundles.sign_in_to_view_price', 'Sign in to view price'),
('en', 'product_bundles.bundle_details', 'Bundle details'),
('en', 'product_bundles.search_in_products', 'Bundles with product'),
('en', 'product_bundles.internal_feature_name_tooltip', 'This name is shown only in the Administration panel to help you distinguish between multiple product bundles that have the same displayed name.'),
('en', 'product_bundles.show_on_product_page', 'Show on products page'),
('en', 'product_bundles.confirm_text_on_empty_bundle', 'Are you sure you want to create a bundle without products?'),
('en', 'product_bundles.confirm_text_with_one_product_bundle', 'Are you sure you want to create a bundle with 1 product?'),
('en', 'product_bundles.specify_options_first', 'Product options should be specified'),
('en', 'privileges.view_product_bundles', 'Can view'),
('en', 'privileges.manage_product_bundles', 'Can edit'),
('en', 'privilege_groups.product_bundles', 'Product bundles'),
('en', 'block_product_bundles', 'Product bundles'),
('en', 'block_product_bundles_description', 'Product bundles form'),
('en', 'product_bundles.template_product_bundles', 'Product bundles'),
('en', 'rma.actions.request_statuses', 'RMA request statuses'),
('en', 'returned_products', 'Returned products'),
('en', 'rma_return', 'Return'),
('en', 'no_return_requests_found', 'No return requests found'),
('en', 'returned_product', 'Returned product'),
('en', 'returns', 'Returns'),
('en', 'returns_info', 'Returns info'),
('en', 'return_info', 'Return information'),
('en', 'order_returns', 'Order returns'),
('en', 'return_registration', 'Request a replacement or a refund'),
('en', 'return_requests', 'Return requests'),
('en', 'return_status', 'Return status'),
('en', 'return_period', 'Return period'),
('en', 'what_you_would_like_to_do', 'What would you like to do'),
('en', 'rma_notify_supplier', 'Notify supplier'),
('en', 'add_reason', 'Add reason'),
('en', 'new_reason', 'New reason'),
('en', 'type_comment', 'Type comments here'),
('en', 'return_requests_note', 'Go to the list of your return requests'),
('en', 'privileges.manage_rma', 'Can edit'),
('en', 'privilege_groups.rma', 'Return merchandise authorization (RMA)'),
('en', 'rma.text_return_change_warning', 'The status of return request will change from [old_status] to [new_status].'),
('en', 'returnable', 'Returnable'),
('en', 'returnable_product', 'Returnable product'),
('en', 'rma_request_statuses', 'RMA request statuses'),
('en', 'return_products_information', 'Return products information'),
('en', 'declined_products_information', 'Declined products information'),
('en', 'rma_reasons', 'RMA reasons'),
('en', 'rma_actions', 'RMA actions'),
('en', 'rma', 'RMA'),
('en', 'return_period_days', 'Return period (days)'),
('en', 'all_actions', 'All actions'),
('en', 'decline_products', 'Decline products'),
('en', 'create_gift_certificate', 'Create gift certificate'),
('en', 'accept_products', 'Accept products'),
('en', 'rma.recalculate_order', 'Recalculate order'),
('en', 'rma.manually_recalculate_order', 'Set the new order total manually'),
('en', 'rma.dont_recalculate_order', 'Don''t recalculate order'),
('en', 'delete_this_return', 'Delete this return'),
('en', 'update_totals_and_inventory', 'Update totals and inventory'),
('en', 'request_statuses', 'request statuses'),
('en', 'email_template.rma_slip_notification', 'RMA slip'),
('en', 'template_document_rma_packing_slip_default', 'Return request: packing slip'),
('en', 'document_preview_return_request_not_found', 'Couldn''t find a return request. Preview only works with existing data. Please create a return request and use Preview again.'),
('en', 'event.rma.status_changed.name', 'Return request status changed to [status]'),
('en', 'rma.choose_change_return_status', 'What to do with the order'),
('en', 'rma.please_confirm_decision', 'Please confirm your decision.'),
('en', 'rma.order_total_will_changed', 'The order total will be set to'),
('en', 'rma.shipping_costs_will_changed', 'Shipping costs will be set to'),
('en', 'rma.return_action', 'Return'),
('en', 'blog.new_post', 'New blog post'),
('en', 'blog.editing_post', 'Editing blog post'),
('en', 'blog', 'Blog'),
('en', 'blog.add_post', 'Add blog post'),
('en', 'blog.recent_posts', 'Blog: recent posts'),
('en', 'blog.recent_posts_scroller', 'Blog: recent posts scroller'),
('en', 'blog.view_post', 'View post'),
('en', 'recent_blog_posts', 'Recent blog posts'),
('en', 'blog.posts', 'Posts'),
('en', 'blog.post', 'Post'),
('en', 'block_blog', 'Recent posts'),
('en', 'block_vendor_blog', 'Vendor recent posts'),
('en', 'blog.text_links', 'Blog: text links'),
('en', 'blog.read_more', 'Read more'),
('en', 'post_description', 'Post description'),
('en', 'ttc_post_description', 'Use the &lt;!--CUT--&gt; tag (switch to source code to insert it) to hide part of the post. Only the part above the tag is shown in the list of all posts.<br /><br />Make sure to <strong>close all HTML tags</strong> above the &lt;!--CUT--&gt; tag!'),
('en', 'blog_functionality_notes', '<p>Use this page to manage your blog. This is how you should organize your blog posts:</p><ul><li>Blog is a usual post that has the <b>Root level page</b> as the Parent page.</li><li>Choose <b>Blog</b> as the Parent page for your blog posts.</li></ul>'),
('en', 'n_posts', '[n] post|[n] posts'),
('en', 'sort_by_bestsellers_asc', 'Sort by Bestselling: Low to High'),
('en', 'sort_by_bestsellers_desc', 'Sort by Bestselling'),
('en', 'sort_by_on_sale_asc', 'Sort by discount: Low to High'),
('en', 'sort_by_on_sale_desc', 'Sort by discount: High to Low'),
('en', 'sales_amount', 'Sales amount'),
('en', 'bestselling', 'Bestselling'),
('en', 'on_sale', 'On sale'),
('en', 'similar', 'Similar'),
('en', 'percent_range', 'Price range (in % of the main product''s price)'),
('en', 'similar_category', 'Of the same category'),
('en', 'similar_subcats', 'Consider subcategories'),
('en', 'similar_in_stock', 'Only “in stock” products'),
('en', 'final_sale', 'Final sale'),
('en', 'seo.actions.redirects_manager', '301 redirects'),
('en', 'controller_description', 'If you want to specify a SEO-name for the URL, e.g. http://example.com/index.php?dispatch=<b>categories.catalog</b>, you need to enter the "<b>categories.catalog</b>" value into the "<b>The value of the "dispatch" parameter from the URL</b>" field and specify the SEO name in the "<b>SEO name</b>" field.'),
('en', 'seo_name', 'SEO name'),
('en', 'warning_seo_urls_disabled', 'SEO-friendly URLs are disabled. Check your web server and URL manipulation engine settings.'),
('en', 'dispatch_value', 'Dispatch value'),
('en', 'url_dispatch_part', 'The value of the "dispatch" parameter from the URL'),
('en', 'new_rule', 'New rule'),
('en', 'seo_add_rule', 'Add rule'),
('en', 'seo_rules', 'SEO rules'),
('en', 'seo_page_title', 'page [n]'),
('en', 'privileges.manage_seo_rules', 'Can edit'),
('en', 'privilege_groups.seo', 'SEO'),
('en', 'privileges.view_seo_rules', 'Can view'),
('en', 'seo.redirects_manager', '301 redirects'),
('en', 'seo.old_url', 'Old URL'),
('en', 'seo.new_url', 'New URL'),
('en', 'seo.new_redirect', 'New Redirect'),
('en', 'seo.add_redirect', 'Add redirect'),
('en', 'seo.error_old_url_exists', 'The URL you''re redirecting from is already exist'),
('en', 'seo.rich_snippets', 'Google rich snippets preview'),
('en', 'seo.rich_snippets_rating', 'Rating'),
('en', 'seo.rich_snippets_reviews', '[n] review|[n] reviews'),
('en', 'seo.create_redirect', 'Create redirect from old URL'),
('en', 'seo.error_incorrect_url', 'Incorrect format for <b>[url]</b> URL. For example, if your URL is <b>http://example.com/path/to/object</b>, you need to enter <b>/path/to/object</b>'),
('en', 'tt_addons_seo_views_seo_redirects_manage_seo.old_url', 'For example, if your URL is <b>http://example.com/path/to/object</b>, you need to enter <b>/path/to/object</b>'),
('en', 'seo.important_language_text', '<b>Warning!</b> The <b>SEO</b> add-on is currently configured to use a single URL for all languages. If you hide, disable, or delete a default language of one of the storefronts, the SEO URLs will be changed.'),
('en', 'seo.product_feature.feature_code.notice', 'A suitable code can help this feature appear with the product in search engines. Supported codes:'),
('en', 'seo.brand', 'Brand'),
('en', 'seo.feature_code.brand.description', 'Name used by an organization or business person for labeling a product'),
('en', 'seo.isbn', 'ISBN'),
('en', 'seo.feature_code.isbn.description', 'International Standard Book Number'),
('en', 'seo.gtin', 'GTIN'),
('en', 'seo.feature_code.gtin.description', 'Global Trade Item Number'),
('en', 'seo.MPN', 'MPN'),
('en', 'seo.feature_code.mpn.description', 'Manufacturer Part Number'),
('en', 'seo.storefront_frontend_default_language_warning', 'The <a href="[link]">SEO</a> add-on is currently configured to use a single URL for all languages. If you change a default language of this storefront, the SEO URLs will be changed.'),
('en', 'seo.secondary_storefront_frontend_default_language_warning', 'The <a href="[link]">SEO</a> add-on is currently configured to use a single URL for all languages using the default language of the default storefront. If you change the default language of the selected storefront, the SEO URLs will not be changed.'),
('en', 'seo.default_storefront_frontend_default_language_warning', 'The <a href="[link]">SEO</a> add-on is currently configured to use a single URL for all languages. If you change a default language of the default storefront, the SEO URLs will be changed for all storefronts.'),
('en', 'seo.error_at_creation_seo_name', 'The following SEO name already exists in your store: <b>[names]</b>. <p> The following SEO name was used instead: <b>[new_names]</b>.|The following SEO names already exist in your store: <b>[names]</b>. The following SEO names were used instead: <b>[new_names]</b>.'),
('en', 'seo.error_incorrect_seo_name', 'The following SEO name had incorrect format: <b>[names]</b>. <p> The following SEO name was used instead: <b>[new_names]</b>.|The following SEO names had incorrect format: <b>[names]</b>. The following SEO names were used instead: <b>[new_names]</b>.'),
('en', 'reward_points', 'Reward points'),
('en', 'reward_points_log', 'Reward points log'),
('en', 'promotion_cond_reward_points', 'Points on user account'),
('en', 'points', 'Points'),
('en', 'points_in_use', 'Points in use'),
('en', 'points_in_use_lower', 'points in use'),
('en', 'points_lower', 'points'),
('en', 'points_in_use_lowercase', '[n] point in use|[n] points in use'),
('en', 'points_lowercase', '[n] point|[n] points'),
('en', 'points_to_use', 'Points to use'),
('en', 'point_payment', 'Point payment'),
('en', 'point_price', 'Price in points'),
('en', 'text_increase_points_in_use', 'The points used in the order were added to user account.'),
('en', 'text_points_used_in_order', 'Points were used in order'),
('en', 'text_point_in_account', 'You have'),
('en', 'pay_by_points', 'Allow payment by points'),
('en', 'override_per', 'Override global PER'),
('en', 'override_gc_points_brief', 'Override global/category points'),
('en', 'text_points_exceed_points_on_account', 'The number of the points entered by you exceeds the number of points at your account.'),
('en', 'text_points_exceed_points_that_can_be_applied', 'The number of points entered by you exceeds the number of points that can be applied to this order.'),
('en', 'text_points_cannot_applied_because_subtotal_redeemed', 'Points cannot be applied because the subtotal is completely redeemed.'),
('en', 'text_cannot_apply_points_to_this_order_because_total', 'Unfortunately, you cannot apply points to this order, because the total cost is zero.'),
('en', 'text_cannot_apply_points_to_this_order_because_user', 'Unfortunately, you cannot apply points to this order, because you do not have enough points at the account.'),
('en', 'text_order_status_has_not_been_changed', 'The order status has not been changed, because the user did not have enough points.'),
('en', 'price_in_points_increased', 'Price in points has been increased by'),
('en', 'price_in_points_decreased', 'Price in points has been decreased by'),
('en', 'earned_points', 'Points earned per product'),
('en', 'override_g_points', 'Override global point value for all products in this category'),
('en', 'amount_type', 'Amount type'),
('en', 'maximum', 'Maximum'),
('en', 'earned_point_modifier', 'Earned point modifier'),
('en', 'override_gc_points', 'Override global/category point value for this product'),
('en', 'view_user_points', 'View user points'),
('en', 'log', 'Log'),
('en', 'subtract', 'Subtract'),
('en', 'change_points', 'Change points'),
('en', 'add_subtract_points', 'Add & subtract points'),
('en', 'cleanup_log', 'Cleanup log'),
('en', 'we_would_like_to_inform', 'We would like to inform you that'),
('en', 'reward_points_subj_added_to', '[n] point have been added to your account.|[n] points have been added to your account.'),
('en', 'reward_points_subj_subtracted_from', '[n] point have been subtracted from your account.|[n] points have been subtracted from your account.'),
('en', 'privileges.manage_reward_points', 'Can edit'),
('en', 'privilege_groups.reward_points', 'Reward points'),
('en', 'email_template.reward_points_notification', 'Reward points'),
('en', 'grant_point', 'Grant reward points'),
('en', 'google_analytics.google_analytics_cookies_title', 'Google Analytics'),
('en', 'google_analytics.google_analytics_cookies_description', 'Google Analytics is a service that provides us with website analytics: the number of unique visitors, the most and least popular pages, etc. Here is <a href="https://support.google.com/analytics/answer/6004245" target="_blank">Google Analytics statement on privacy</a>.'),
('en', 'google_analytics.google_ads_cookies_title', 'Google Ads'),
('en', 'google_analytics.google_ads_cookies_description', 'Google Ads is a service that allows us to make personalized offers for you. This permission allows us to set cookies and send some of your data related to advertising to Google. Here is <a href="https://safety.google/privacy/ads-and-data/" target="_blank">how Google handles ad-related data</a>.'),
('en', 'facebook_pixel.facebook_pixel_cookies_title', 'Facebook Pixel'),
('en', 'facebook_pixel.facebook_pixel_cookies_description', 'Facebook Pixel is a tool that allows us to measure ad efficiency by tracking that the browser or device that received the ad also visited a product page, added product to cart, or placed an order. Here is <a href="https://www.facebook.com/about/privacy/previous" target="_blank">Facebook privacy policy</a>.'),
('en', 'privileges.manage_call_requests', 'Can edit'),
('en', 'privileges.view_call_requests', 'Can view'),
('en', 'privilege_groups.call_requests', 'Call requests'),
('en', 'call_requests', 'Call requests'),
('en', 'call_requests.request_call', 'Request call'),
('en', 'call_requests.buy_now_with_one_click', 'Buy now with 1-click'),
('en', 'call_requests.error_validate_call_form', 'Please enter your email or phone number'),
('en', 'call_requests.request_recieved', 'We have received your request! Our manager will contact you soon.'),
('en', 'call_requests.order_placed', 'We have received your request! The order #[order_id] has been successfully created. Our manager will contact you soon.'),
('en', 'call_requests.phone_from_settings', 'Phone from settings'),
('en', 'call_requests.enter_phone_or_email_text', 'Please enter your phone number or email (for our manager to contact you)'),
('en', 'call_requests.status.new', 'New'),
('en', 'call_requests.status.in_progress', 'In progress'),
('en', 'call_requests.status.completed', 'Completed'),
('en', 'call_requests.status.no_answer', 'No answer'),
('en', 'call_requests.responsible', 'Responsible'),
('en', 'call_requests.notes', 'Notes'),
('en', 'call_requests.requested_product', 'Requested product'),
('en', 'call_requests.convenient_time', 'Convenient time'),
('en', 'call_requests.awaiting_call', 'Awaiting call'),
('en', 'call_requests.order_exists', 'Order exists'),
('en', 'call_requests.person_name_and_phone', 'Name and phone'),
('en', 'call_requests.no_name_specified', 'No name specified');
INSERT INTO `[[dbprefix]]language_values` VALUES
('en', 'call_requests.use_for_call_requests', 'Call request and buy now with one click form'),
('en', 'block_call_request', 'Call request'),
('en', 'block_call_request_description', 'Store phone number and form for requesting a call'),
('en', 'tmpl_call_request', 'Call request form'),
('en', 'call_requests.text_call_request', 'Customer [customer] is <a href="[href]">awaiting your call</a> on [phone_number].'),
('en', 'call_requests.text_call_request_call_time', 'The convenient call time is between [time_from] and [time_to].'),
('en', 'call_requests.text_buy_with_one_click_request', 'Сustomer [customer] is <a href="[href]">awaiting your call</a> on [phone_number], regarding the purchase of the product <a href="[product_href]">[product_name]</a>.'),
('en', 'call_requests.error_validator_phone', 'The phone number in the <b>[field]</b> field is invalid.'),
('en', 'email_template.call_requests_buy_with_one_click', 'Call requests: buy with one click notification'),
('en', 'email_template.call_requests_call_request', 'Call requests: call request notification'),
('en', 'call_request.work_time', 'Mon-Fr 9a.m.-6p.m.'),
('en', 'call_requests.request_call_request_form', 'Call requests: request form'),
('en', 'call_requests.agreement_text_full_request_call_request_form', '<p>We ([company]) will use the data you provide here to contact you regarding your call request or order. That data will remain in our system, visible to our staff (or the relevant vendor), until you withdraw your consent. If you’d like to have your personal data removed, send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('en', 'call_requests.agreement_text_short_request_call_request_form', 'I agree to have my personal data <u>processed as follows.</u>'),
('en', 'gdpr_call_requests', 'Personal data from call requests'),
('en', 'call_requests.event.request_created.name', 'Call requests: request created'),
('en', 'call_requests.event.request_about_product_created.name', 'Call requests: request about product created'),
('en', 'call_requests.dashboard.analytics_card.recent_call_requests', 'Recent call requests'),
('en', 'call_requests.dashboard.analytics_card.view_call_requests', 'View call requests'),
('en', 'use_for_form_builder', 'Custom forms'),
('en', 'new_form', 'New form'),
('en', 'editing_form', 'Editing form'),
('en', 'form_builder', 'Form builder'),
('en', 'form_submit_text', 'Form submit text'),
('en', 'email_to', 'E-mail to'),
('en', 'add_form', 'Add form'),
('en', 'base', 'Base'),
('en', 'multiple_checkboxes', 'Multiple checkboxes'),
('en', 'multiple_selectbox', 'Multiple selectbox'),
('en', 'separator', 'Separator'),
('en', 'special', 'Special'),
('en', 'countries_list', 'Countries list'),
('en', 'states_list', 'States list'),
('en', 'referer', 'Referer'),
('en', 'email_template.form_builder_form', 'Contact form'),
('en', 'addons.form_builder.form_fields', 'Form fields'),
('en', 'addons.form_builder.form_name', 'Form name'),
('en', 'addons.form_builder.other_subject', 'Other subject (specify below)'),
('en', 'addons.form_builder.email_subject_field', 'E-mail subject field'),
('en', 'ttc_addons.form_builder.email_subject_field', 'Fields of type "Select box" or "Input field" can be used'),
('en', 'please_enable_the_add_on_to_see_barcode', 'Please enable the add-on to see a code example.'),
('en', 'use_for_polls', 'Polls'),
('en', 'tmpl_polls_central', 'Central'),
('en', 'tmpl_polls_side', 'Side box'),
('en', 'polls_answers_with_comments', 'Answers with comments'),
('en', 'polls_have_completed', 'You have already completed this poll.'),
('en', 'polls_total_votes', 'Total votes'),
('en', 'polls', 'Polls'),
('en', 'new_poll', 'New poll'),
('en', 'editing_poll', 'Editing poll'),
('en', 'text_you_have_already_filled_this_poll', 'You have already completed this poll'),
('en', 'block_polls', 'Polls'),
('en', 'poll', 'Poll'),
('en', 'questions', 'Questions'),
('en', 'poll_statistics', 'Poll statistics'),
('en', 'add_polls_and_close', 'Add polls and close'),
('en', 'add_polls', 'Add polls'),
('en', 'required_not_answered', 'You should answer all the mandatory questions'),
('en', 'thanks_for_voting', 'Thank you for taking time to complete this poll.'),
('en', 'poll_show_results', 'Poll results visible to'),
('en', 'poll_results_nobody', 'nobody'),
('en', 'poll_results_voted', 'voted users'),
('en', 'poll_results_everybody', 'everybody (in a pop-up)'),
('en', 'poll_header', 'Poll header'),
('en', 'poll_footer', 'Poll footer'),
('en', 'poll_results', 'Poll message'),
('en', 'new_question', 'New question'),
('en', 'add_question', 'Add question'),
('en', 'editing_question', 'Editing question'),
('en', 'add_poll', 'Add poll'),
('en', 'polls_total_submited', 'Total number of submitted poll forms'),
('en', 'polls_total_completed', 'Number of poll forms completed in full'),
('en', 'polls_first_submited', 'First poll form submitted'),
('en', 'polls_last_submited', 'Last poll form submitted'),
('en', 'statistics_by_questions', 'Statistics by questions'),
('en', 'view_answers', 'View answers'),
('en', 'polls_votes', 'Votes'),
('en', 'answers', 'Answers'),
('en', 'question_text', 'Question text'),
('en', 'select_single_type', 'Select single option'),
('en', 'select_one_or_more_type', 'Select one or more options'),
('en', 'text_answer_type', 'Provide a textual answer'),
('en', 'answer_text', 'Answer text'),
('en', 'text_box', 'Text box'),
('en', 'tt_addons_polls_hooks_pages_tabs_content_post_poll_results', 'Message that is displayed in the storefront after the poll is completed.'),
('en', 'n_polls', '[n] poll|[n] polls'),
('en', 'access_restrictions', 'Access restrictions'),
('en', 'add_ips', 'Add IPs'),
('en', 'new_ips', 'New IPs'),
('en', 'add_domains', 'Add domains'),
('en', 'new_domains', 'New domains'),
('en', 'add_emails', 'Add e-mail addresses'),
('en', 'new_emails', 'New e-mail addresses'),
('en', 'new_credit_card', 'New credit card'),
('en', 'add_credit_card', 'Add credit card'),
('en', 'privileges.manage_access_restrictions', 'Can edit'),
('en', 'privilege_groups.access_restrictions', 'Access restrictions'),
('en', 'domain', 'Domain'),
('en', 'warning_of_ip_adding', 'The entered IP address <b>[entered_ip]</b> forbids access to the administration panel from your computer (your IP is <b>[your_ip]</b>).'),
('en', 'text_cc_number_is_blocked', 'The credit card number <b>[cc_number]</b> is blocked by the administrator. Please contact the store administrator or try another one.'),
('en', 'text_not_valid_ip', '<b>[ip]</b> is not a valid ip address.'),
('en', 'text_not_valid_domain', '<b>[domain]</b> is not a valid domain name.'),
('en', 'text_not_valid_cc_number', '<b>[cc_number]</b> is not a valid credit card number.'),
('en', 'text_email_is_blocked', 'The e-mail address <b>[email]</b> is blocked by the administrator. Please contact the store administrator or try another one.'),
('en', 'text_ips_denied', 'You are not allowed to access this area'),
('en', 'text_ip_blocked_failed_login', 'The IP was blocked after [number] unsuccessful logins'),
('en', 'text_ip_is_blocked', 'Your IP address is blocked.'),
('en', 'store_admin', 'Store administrator'),
('en', 'your_ip_added', 'Your IP address <b>[ip]</b> has been added to the access restrictions table.'),
('en', 'your_ip_enabled', 'Your IP address <b>[ip]</b> has been enabled in the access restrictions table.'),
('en', 'your_ip_removed', 'Your IP address <b>[ip]</b> has been removed from the access restrictions table.'),
('en', 'ip_from', 'IP from'),
('en', 'ip_to', 'IP to'),
('en', 'text_access_notice', 'You can use the wildcards for the "Domain", "E-mail" and "Credit Card" tabs: <br /><b>*</b> - can represent any number of characters, including zero<br /><b>?</b> - can represent any single character.'),
('en', 'ips', 'IPs'),
('en', 'make_permanent', 'Make permanent'),
('en', 'credit_card_number', 'Credit card number'),
('en', 'banners.new_banner', 'New banner'),
('en', 'banners.editing_banner', 'Editing banner'),
('en', 'add_banner', 'Add banner'),
('en', 'banner', 'Banner'),
('en', 'banners', 'Banners'),
('en', 'banner_code', 'Banner code'),
('en', 'banner_code_for_some_products', 'Banner code for some products'),
('en', 'manage_banners', 'Manage banners'),
('en', 'block_banners', 'Banners'),
('en', 'block_banners_description', 'Visual and text banners'),
('en', 'privileges.view_banners', 'Can view'),
('en', 'privileges.manage_banners', 'Can edit'),
('en', 'privilege_groups.banners', 'Banners'),
('en', 'add_banners', 'Add banners'),
('en', 'add_banners_and_close', 'Add banners and close'),
('en', 'graphic_banner', 'Graphic banner'),
('en', 'text_banner', 'Text banner'),
('en', 'conversion', 'Conversion'),
('en', 'banner_details_notes', 'After you create a banner here, you should use the <strong>Layout editor</strong> to add it to the storefront.<br /><br />Go to <a href="[layouts_href]" target="_blank">Design → Layouts</a>, switch to the location where you want the banner to appear, and add a new block with type <strong>Banners</strong>.<br /><br />In this block settings, go to the <strong>Content</strong> tab, pick the <strong>Manual</strong> filling, and click on the <strong>Add banners</strong> button.<br /><br />You will see the list of all the banners in your store. Pick the one(s) you need and click on the <strong>Add banners and close</strong> button.<br /><br />Finally, click on the <strong>Create</strong> button to save your changes.'),
('en', 'n_banners', '[n] banner|[n] banners'),
('en', 'use_for_discussion', 'Comments and reviews forms'),
('en', 'discussion_title_category', 'Reviews'),
('en', 'discussion_title_giftreg', 'Guestbook'),
('en', 'discussion_title_order', 'Communication'),
('en', 'discussion_title_page', 'Comments'),
('en', 'discussion_title_product', 'Reviews'),
('en', 'discussion_title_return', 'Communication'),
('en', 'no_posts_found', 'No posts found'),
('en', 'your_rating', 'Your rating'),
('en', 'comments_and_reviews', 'Comments and reviews'),
('en', 'discussion.comments_and_reviews_menu', 'Comments'),
('en', 'discussion_title_home_page', 'Testimonials'),
('en', 'text_enabled_testimonials_notice', 'Testimonials are disabled. To enable, please go to <a href="[link]">Comments and reviews: options</a> and select the "Communication", "Rating" or "Communication and Rating" value in "Testimonials" field.'),
('en', 'discussion_title_company', 'Reviews'),
('en', 'communication_and_rating', 'Communication and Rating'),
('en', 'communication', 'Communication'),
('en', 'cant_find_thread', 'Thread can not be found.'),
('en', 'error_already_posted', 'You have posted in this discussion already'),
('en', 'text_thank_you_for_post', 'Thank you for your post'),
('en', 'text_post_pended', 'Your post will be checked before it gets published.'),
('en', 'discussion', 'Comments and reviews'),
('en', 'text_new_post_notification', 'This is a notification of a new post to'),
('en', 'text_approval_notice', 'This post needs approving'),
('en', 'latest_reviews', 'Latest comments & reviews'),
('en', 'comment_by', 'Comment by'),
('en', 'and', 'and'),
('en', 'add_post', 'Add post'),
('en', 'not_approved', 'Not approved'),
('en', 'discussion_manager', 'Comments and reviews'),
('en', 'testimonials', 'Testimonials'),
('en', 'privileges.view_discussions', 'Can view'),
('en', 'privileges.manage_discussions', 'Can edit'),
('en', 'privilege_groups.discussions', 'Comments and reviews'),
('en', 'block_testimonials', 'Testimonials'),
('en', 'block_testimonials_description', 'User testimonials'),
('en', 'sort_by_rating_asc', 'Sort by rating: Low to High'),
('en', 'sort_by_rating_desc', 'Sort by rating'),
('en', 'reviews', 'review|reviews'),
('en', 'write_review', 'Write a review'),
('en', 'discussion_tab_products', 'Product Reviews'),
('en', 'discussion_tab_categories', 'Category Reviews'),
('en', 'discussion_tab_pages', 'Page Comments'),
('en', 'discussion_tab_orders', 'Order Communication'),
('en', 'discussion_tab_home_page', 'Testimonials'),
('en', 'discussion_tab_companies', 'Company Reviews'),
('en', 'email_template.discussion_notification', 'Comments and reviews notification'),
('en', 'show_rating', 'Show review rating'),
('en', 'gdpr_discussions_data', 'Personal data from discussion'),
('en', 'discussion.add_new_review', 'Discussion: new review'),
('en', 'discussion.agreement_text_full_add_new_review', '<p>Your name will appear next to your review or comment, visible to everyone. We ([company]) also save your IP address as a security precaution, but in can only be viewed by our staff. It will remain in our system until you withdraw your consent. If you’d like to have your personal data removed, send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('en', 'discussion.agreement_text_short_add_new_review', 'I agree to have my personal data <u>processed as follows.</u>'),
('en', 'discussion.please_log_in_to_write_a_review', 'Please sign in to write a review'),
('en', 'discussion.you_have_to_buy_product_before_writing_review', 'You can''t write a review for this product. Customers can write reviews only for the products they bought. If you actually bought this product from us, but are still seeing this message, please contact us.'),
('en', 'discussion.you_have_to_buy_from_vendor_before_writing_review', 'You can''t write a review for this vendor. Customers can write reviews for a vendor only after they buy something from that vendor. If you actually placed an order with this vendor, but are still seeing this message, please contact us.'),
('en', 'discussion.event.products.new_post', 'Products: new review posted'),
('en', 'discussion.event.testimonials.new_post', 'Testimonials: new review posted'),
('en', 'discussion.event.orders.new_post', 'Order communication: new message added'),
('en', 'discussion.event.categories.new_post', 'Categories: new review posted'),
('en', 'discussion.event.pages.new_post', 'Pages: new comment posted'),
('en', 'discussion.event.vendors.new_post', 'Vendors: new review posted'),
('en', 'wt_watermarks', 'Watermarks'),
('en', 'wt_graphic_watermark', 'Graphic watermark'),
('en', 'wt_text_watermark', 'Text watermark'),
('en', 'wt_watermark_vertical_position', 'Watermark vertical position'),
('en', 'wt_watermark_horizontal_position', 'Watermark horizontal position'),
('en', 'wt_watermark_position', 'Watermark position'),
('en', 'wt_watermark_image', 'Watermark image'),
('en', 'wt_watermark_text', 'Watermark text'),
('en', 'wt_font', 'Font'),
('en', 'wt_font_color', 'Font color'),
('en', 'wt_font_size_icon', 'Font size (thumbnail)'),
('en', 'wt_font_size_detailed', 'Font size (larger image)'),
('en', 'wt_watermark_icon', 'Thumbnail watermark'),
('en', 'wt_watermark_detailed', 'Popup larger image watermark'),
('en', 'wt_fail_apply_graphic_watermark', 'Failed to apply the watermark to [image_type]. The watermark image is not added.'),
('en', 'wt_icons', 'thumbnails'),
('en', 'wt_detailed', 'popup larger images'),
('en', 'wt_images_access_description', 'To deny access to your original images, please add the following instructions to the ''.htaccess'' file in the ''images'' directory of your installation. It will protect your original images. Even if an original image is opened, the corresponding watermarked image will be show instead.'),
('en', 'wt_watermarks_access_description', 'To generate watermarked images automatically even if they are requested not from your store pages, please add the ''.htaccess'' file with the following instructions to the ''images/watermarked'' directory of your installation.'),
('en', 'wt_access_note', 'Please note, if you disable or uninstall the ''Watermarks'' add-on, you should remove these instructions from ''.htaccess'' files manually. Otherwise category and product images will be unavailable.'),
('en', 'wt_access_warning', 'Watermark creating is disabled. If there are any "Rewrite watermarks rules" instructions in the "images/.htaccess" file, you should remove them manually. Otherwise category and product images will be unavailable.'),
('en', 'wt_images_access_info', 'Images access'),
('en', 'product_reviews.use_for_reviews', 'Comments and reviews forms'),
('en', 'product_reviews.title_giftreg', 'Guestbook'),
('en', 'product_reviews.title', 'Reviews'),
('en', 'product_reviews.no_reviews_found', 'No reviews found'),
('en', 'product_reviews.your_rating', 'Your rating'),
('en', 'product_reviews.comments_and_reviews', 'Comments and reviews'),
('en', 'product_reviews.rating', 'Rating'),
('en', 'product_reviews.date', 'Date'),
('en', 'product_reviews.error_already_posted', 'You have posted in this review already'),
('en', 'product_reviews.text_thank_you_for_post', 'Thank you for your post'),
('en', 'product_reviews.text_review_pended', 'Your review will be checked before it gets published.'),
('en', 'product_reviews.reviews', 'Reviews: [n]'),
('en', 'product_reviews.n_reviews', 'review|reviews'),
('en', 'product_reviews.text_new_post_notification', 'This is a notification of a new post to product'),
('en', 'product_reviews.text_new_reply_notification', 'This is a notification of a new reply to your product review'),
('en', 'product_reviews.text_approval_notice', 'This review needs approving'),
('en', 'product_reviews.latest_reviews', 'Latest reviews'),
('en', 'product_reviews.comment_by', 'Comment by'),
('en', 'product_reviews.and', 'and'),
('en', 'product_reviews.approve', 'Approve'),
('en', 'product_reviews.disapprove', 'Disapprove'),
('en', 'product_reviews.approved', 'Approved'),
('en', 'product_reviews.not_approved', 'Not approved'),
('en', 'product_reviews.manager', 'Comments and reviews'),
('en', 'privileges.view_product_reviews', 'Can view'),
('en', 'privileges.manage_product_reviews', 'Can edit'),
('en', 'privilege_groups.product_reviews', 'Product reviews'),
('en', 'product_reviews.product_reviews', 'Product reviews'),
('en', 'product_reviews.menu_title', 'Reviews'),
('en', 'product_reviews.write_review', 'Write a review'),
('en', 'email_template.product_reviews_notification', 'Product reviews: New review notification'),
('en', 'email_template.product_reviews_reply_notification', 'Product reviews: Reply notification'),
('en', 'product_reviews.show_rating', 'Show review rating'),
('en', 'product_reviews.show_reviews', 'Show reviews'),
('en', 'product_reviews.show_review', 'Show review'),
('en', 'product_reviews.show_n_reviews', 'Show [n] review|Show [n] reviews'),
('en', 'product_reviews.scroll_to_reviews', 'Scroll to reviews'),
('en', 'product_reviews.show_review_images', 'Show review images'),
('en', 'product_reviews.scroll_to_review_images', 'Scroll to review images'),
('en', 'gdpr_product_reviews', 'Personal data from reviews'),
('en', 'product_reviews.add_new_review', 'reviews: new review'),
('en', 'product_reviews.agreement_text_full_add_new_review', '<p>Your name will appear next to your review or comment, visible to everyone. We ([company]) also save your IP address as a security precaution, but in can only be viewed by our staff. It will remain in our system until you withdraw your consent. If you’d like to have your personal data removed, send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('en', 'product_reviews.terms_n_conditions', 'Select this check box to accept the [terms_href]'),
('en', 'product_reviews.terms_n_conditions_name', 'Terms and Conditions'),
('en', 'product_reviews.terms_and_conditions_content', '<p>Please read these Terms and Conditions ("Terms", "Terms and Conditions") carefully before using the <a href="http://www.mywebsite.com">http://www.mywebsite.com</a> website and the My Mobile App mobile application (the "Service") operated by My Company ("us", "we", or "our").</p><p><strong>By accessing or using the Service you agree to be bound by these Terms. If you disagree with any part of the Terms then you may not access the Service.</strong></p><p><strong>Purchases</strong></p><p>If you wish to purchase any product or service made available through the Service ("Purchase"), you may be asked to supply certain information relevant to your Purchase including, without limitation, your ...</p><p><strong>Content</strong></p><p>Our Service allows you to post, link, store, share and otherwise make available certain information, text, graphics, videos, or other material ("Content"). You are responsible for the ...</p><p><strong>Changes</strong></p><p>We reserve the right, at our sole discretion, to modify or replace these Terms at any time. If a revision is material we will try to provide at least 30 days'' notice prior to any new terms taking effect. What constitutes a material change will be determined at our sole discretion.</p><p><strong>Contact Us</strong></p><p>If you have any questions about these Terms, please contact us.</p>'),
('en', 'product_reviews.moderation_rules', 'Before submitting a review, make sure that it does not violate the moderation rules: it does not contain links to third-party resources and insults.'),
('en', 'product_reviews.agreement_text_short_add_new_review', 'I agree to have my personal data <u>processed as follows.</u>'),
('en', 'product_reviews.please_log_in_to_write_a_review', 'Please sign in to write a review'),
('en', 'product_reviews.you_have_to_buy_product_before_writing_review', 'You can''t write a review for this product. Customers can write reviews only for the products they bought. If you actually bought this product from us, but are still seeing this message, please contact us.'),
('en', 'product_reviews.event.new_post', 'New review posted'),
('en', 'product_reviews.event.new_reply', 'New reply was added to review'),
('en', 'product_reviews.helpfulness', 'Helpfulness'),
('en', 'product_reviews.vote_up', 'Vote up'),
('en', 'product_reviews.vote_down', 'Vote down'),
('en', 'sort_by_product_review_timestamp_desc', 'Sort by date: Newest to Oldest'),
('en', 'sort_by_product_review_timestamp_asc', 'Sort by date: Oldest to Newest'),
('en', 'sort_by_helpfulness_asc', 'Helpful last'),
('en', 'sort_by_helpfulness_desc', 'Helpful first'),
('en', 'sort_by_rating_value_desc', 'Sort by rating: High to Low'),
('en', 'sort_by_rating_value_asc', 'Sort by rating: Low to High'),
('en', 'product_reviews.advantages', 'Advantages'),
('en', 'product_reviews.disadvantages', 'Disadvantages'),
('en', 'product_reviews.comments', 'Comments'),
('en', 'product_reviews.comment', 'Comment'),
('en', 'product_reviews.disabled', 'Disabled'),
('en', 'product_reviews.vendor', 'Vendor'),
('en', 'product_reviews.vendor_reply', 'Vendor reply'),
('en', 'product_reviews.type_message', 'Type a message...'),
('en', 'product_reviews.verified_purchase', 'Verified purchase'),
('en', 'product_reviews.reviews_lower', 'reviews'),
('en', 'product_reviews.review', 'Review'),
('en', 'product_reviews.write_your_review', 'Write your review'),
('en', 'product_reviews.add_images', 'Add a photo'),
('en', 'product_reviews.write_review_anonymously', 'Write your review anonymously'),
('en', 'product_reviews.submit_review', 'Submit review'),
('en', 'product_reviews.with_photo', 'With photo'),
('en', 'product_reviews.without_photo', 'Without photo'),
('en', 'product_reviews.customer_photos', 'Customer photos'),
('en', 'product_reviews.review_status', 'Review status'),
('en', 'product_reviews.star', 'star'),
('en', 'product_reviews.stars', 'stars'),
('en', 'product_reviews.n_stars', '[n] star|[n] stars'),
('en', 'product_reviews.out_of_five', 'out of 5'),
('en', 'product_reviews.review_this_product', 'Review this product'),
('en', 'product_reviews.review_this_product_description', 'Share your thoughts with other customers'),
('en', 'product_reviews.reply', 'Reply'),
('en', 'product_reviews.first_and_last_name', 'First and last name'),
('en', 'product_reviews.text_thank_you_for_review', 'Thank you for your review'),
('en', 'product_reviews.excellent', 'Excellent!'),
('en', 'product_reviews.very_good', 'Very Good'),
('en', 'product_reviews.average', 'Average'),
('en', 'product_reviews.fair', 'Fair'),
('en', 'product_reviews.poor', 'Poor'),
('en', 'product_reviews.five_star_icon', '★★★★★'),
('en', 'product_reviews.four_star_icon', '★★★★'),
('en', 'product_reviews.three_star_icon', '★★★'),
('en', 'product_reviews.two_star_icon', '★★'),
('en', 'product_reviews.one_star_icon', '★'),
('en', 'product_reviews.product_details', 'Product details'),
('en', 'product_reviews.rating_4_and_up', 'Rating 4+'),
('en', 'product_reviews.event.new_post.title', 'New review posted for a product'),
('en', 'product_reviews.event.new_post.message', 'A new review has been posted for product [product]. Click this notification to see the review.'),
('en', 'product_reviews.copy_old_reviews_warning', 'You have product reviews in the old "Comments and reviews" add-on. While that add-on is installed, you''ll be able copy those reviews to the new "Product reviews" add-on <a class="cm-post" href="[url]">in its settings</a>.'),
('en', 'product_reviews.copy_old_reviews_notice', '<h4 class="subheader hand" data-toggle="collapse" data-target="#collapsable_addon_product_reviews_notice">Copy reviews from the "Comments and reviews" add-on<span class="icon-caret-down"></span></h4><div id="collapsable_addon_product_reviews_notice" class="in collapse" style="height: auto;"><ol><li>Only reviews that have both a score and a user''s comment will be copied. Go to your products and check the “Reviews" setting on the "Add-ons" tab. You might have to allow communication and rating first.</li><li>A review without a score or without a comment will not be copied. To transfer it, you must first manually add the missing score or comment by editing the review.</li><li>While the old "Comments and reviews" add-on is installed, the reviews won''t be removed from there. That way, you can choose to move to "Product reviews" whenever all your reviews are ready.</li><li>If you ever need to copy the reviews from the old add-on again in the future, just uninstall and reinstall the "Product reviews" add-on. This will remove all its reviews from the database, and you''ll be able to import the reviews from the "Comments and reviews" add-on again.</li></ol><a class="cm-post btn btn-primary" href="[url]">Copy product reviews</a></div>'),
('en', 'product_reviews.update_reply', 'Update reply'),
('en', 'product_reviews.add_reply', 'Add reply'),
('en', 'product_reviews.max_number_image_message', 'A review can have up to [max_image_number] images.'),
('en', 'product_reviews.uploader_drop_zone_description', 'Drop images here'),
('en', 'product_reviews.uploader_drop_zone_info', 'Photo up to [max_size]'),
('en', 'product_reviews.admin_reply', 'Administrator reply'),
('en', 'product_reviews.company_reply', '[company_name] reply'),
('en', 'product_reviews.hide_name', 'Hide my name in the review'),
('en', 'product_reviews.product_is_rated_n_out_of_five_stars', 'The product is rated [n] out of 5 stars'),
('en', 'product_reviews.click_to_see_reviews', 'Click to see the reviews'),
('en', 'product_reviews.split_reviews_for_variations_as_separate_products', 'Split reviews for variations as separate products'),
('en', 'privileges.create_product_reviews', 'Can create'),
('en', 'product_reviews.upgrade_notification.title_administators_add_ability_create_product_reviews', 'Administrators can now create product reviews'),
('en', 'product_reviews.upgrade_notification.message_administators_add_ability_create_product_reviews', 'Previously, administrators could edit existing product reviews in the admin panel, but couldn''t post new ones. We''ve changed that: now the administrators who could edit reviews can add new reviews on the "Reviews" tab of the product editing page. Note that this change doesn''t affect vendors'' administrators in CS-Cart Multi-Vendor in any way. The most that they can do is leave a reply to a product review.<br><br>You can keep the old behavior if you''d like. Through user groups, you can now allow administrators to create or edit reviews (or do both of those things).<br><br><a target="_blank" href="[usergroups_url]" class="btn">Set administrator privileges</a>'),
('en', 'product_reviews.exim_error_incorrect_field_value', 'Specified [field] ''[value]'' was not found. The product review with comment ''[comment]'' was skipped.'),
('en', 'product_reviews.exim_error_empty_field', 'The value of the <b>[field]</b> field can not be empty. The product review with comment ''[comment]'' was skipped.'),
('en', 'product_reviews', 'Product reviews'),
('en', 'images_delimiter', 'Images delimiter'),
('en', 'text_images_delimiter', 'Images path delimiter for product review images (e.g. "Image1.png///Image2.png")'),
('en', 'add_to_wishlist', 'Add to wish list'),
('en', 'clear_wishlist', 'Clear wish list'),
('en', 'view_wishlist', 'View wish list'),
('en', 'wishlist_content', 'Wish list content'),
('en', 'wishlist', 'Wish list'),
('en', 'wishlist_short', 'Wish list'),
('en', 'wishlist_note', 'Go to your wishlist'),
('en', 'text_failed_gift_certificate_addition', 'Failed to add the certificate. Make sure the summary amount is not zero.'),
('en', 'text_gift_cert_added_to_wishlist', 'The gift certificate has been added to the wish list'),
('en', 'product_added_to_wl', 'The product was added to your Wish list'),
('en', 'product_in_wishlist', 'This product is already in the wish list'),
('en', 'wishlist_products', 'Wish list products'),
('en', 'google_sitemap.text_regenerate', 'If products, categories, etc. were added or changed, please <a class="cm-ajax cm-comet btn btn-primary" href="[regenerate_url]">Regenerate a sitemap</a><br /><br /> [sitemap_available_in_customer]'),
('en', 'google_sitemap.text_auto_regenerate', 'You can run the regeneration of the site map automatically at certain time intervals. To do it, add the following command to CRON:'),
('en', 'google_sitemap.text_select_storefront', 'To generate a sitemap, please select storefront first.'),
('en', 'sitemap_available_in_customer', 'Sitemap is available by this link: <a href="[sitemap_url]">[sitemap_url]</a><br /><br />Sitemap can be reached by the URL <a href="[http_location]/sitemap.xml">[http_location]/sitemap.xml</a>'),
('en', 'always', 'Always'),
('en', 'hourly', 'Hourly'),
('en', 'daily', 'Daily'),
('en', 'weekly', 'Weekly'),
('en', 'monthly', 'Monthly'),
('en', 'yearly', 'Yearly'),
('en', 'google_sitemap.generate_map', 'The sitemap is not generated yet. Please go to add-on settings and press "Regenerate a sitemap" button'),
('en', 'google_sitemap.map_generated', 'The sitemap was generated successfully'),
('en', 'google_sitemap.export_progress_entry', '[storefront]: [object]'),
('en', 'required_products', 'Required products'),
('en', 'required_products_added', 'The following required product(s) were added to your cart'),
('en', 'required_products_out_of_stock', 'This product cannot be added to your cart, because following required product(s) are out of stock:'),
('en', 'data_feeds', 'Data feeds'),
('en', 'data_feed', 'Data feed'),
('en', 'export_by_cron', 'Export by cron'),
('en', 'export_by_cron_to', 'Export by cron to'),
('en', 'add_new_datafeed', 'New data feed'),
('en', 'add_datafeed', 'Add data feed'),
('en', 'datafeed_name', 'Data feed name'),
('en', 'save_directory', 'Server directory'),
('en', 'ftp_url', 'FTP server'),
('en', 'ftp_url_hint', 'The format is: FTPHOST[:PORT][/DIRECTORY]. Example: ftp.yourhost.com:21/home/username/folder'),
('en', 'ftp_user', 'FTP username'),
('en', 'ftp_pass', 'FTP password'),
('en', 'fields', 'Fields'),
('en', 'field_name', 'Field name'),
('en', 'field_type', 'Field type'),
('en', 'map_fields', 'Fields mapping'),
('en', 'update_datafeed', 'Editing data feed'),
('en', 'datafeed.description', 'Only the products that meet <strong>all</strong> of the conditions below will be exported:'),
('en', 'export_cron_hint', 'Use the following line to run the script according to schedule'),
('en', 'exported_items', 'Exported items'),
('en', 'ftp_connection_problem', 'Unable connect to FTP server. Please, check FTP connection information'),
('en', 'categories_in', 'Categories in'),
('en', 'products_in', 'Products in'),
('en', 'local_export', 'Download'),
('en', 'upload_to_ftp', 'Upload to FTP server'),
('en', 'cron_export', 'Cron export settings'),
('en', 'export_to_server', 'Export to server'),
('en', 'export_to_ftp', 'FTP server options'),
('en', 'ftp', 'FTP'),
('en', 'check_server_export_settings', 'Check server export settings'),
('en', 'exclude_disabled_products', 'Exclude disabled products'),
('en', 'data_feeds.exclude_shared_products', 'Exclude shared products'),
('en', 'general_settings', 'General settings'),
('en', 'enclosure', 'Enclosure'),
('en', 'data_feed.error_exim_no_data_exported', 'No data exported'),
('en', 'data_feeds.text_tooltip_field_name', 'The name of the column in the data feed file.'),
('en', 'data_feeds.text_tooltip_field_type', 'The type of data from your store which will be exported to this column of the data feed file.'),
('en', 'price_list', 'Price list'),
('en', 'generating_pdf', 'Generating PDF. Please, be patient...'),
('en', 'generating_xls', 'Generating XLS. Please, be patient...'),
('en', 'price_list_ziparchive_not_installed', 'Impossible to create XML price list. Please add zip support in PHP on your server. Follow <a href="http://www.php.net/manual/en/zip.installation.php">http://www.php.net/manual/en/zip.installation.php</a>.'),
('en', 'price_list.text_select_storefront', 'To generate a price list, please select storefront first.'),
('en', 'price_list.text_regenerate', '<p>If products, categories or selected fields were added or changed, please regenerate a price list:<br />[buttons]</p><p>Generated price lists are available by these links<br/>[links]</p>'),
('en', 'janrain_general_info', '<p>Get these values and configure social login at <a href="http://janrain.com" target="_blank">janrain.com</a></p>'),
('en', 'janrain_social_login', 'Social login'),
('en', 'janrain_need_update_profile', 'The "Password" field and some other mandatory fields are empty at the moment. Please update your profile.'),
('en', 'janrain_cant_create_profile', 'Unfortunately, we failed to create a customer and log in to the store due to one of the following reasons:<br />- You logged in to our store earlier using some other OpenID provider in which the same email is used.<br />- You have already registered in our store using your email.<br />Please contact the store owner to resolve the problems.'),
('en', 'janrain.janrain_cookies_title', 'Janrain'),
('en', 'janrain.janrain_cookies_description', 'Janrain is a service that allows you to sign into the website with your accounts from various social networks. It was acquired by Akamai in 2019; here is <a href="https://www.akamai.com/site/en/documents/akamai/akamai-privacy-statement.pdf" target="_blank">Akamai privacy statement</a>.'),
('en', 'catalog_mode', 'Catalog Mode'),
('en', 'text_catalog_mode_zero_price_action_notice', 'In order that the "Buy now" button could be displayed on the product details page, please set "Zero price action" as "Allow customers to add the product to cart".'),
('en', 'buy_now_url', 'Buy Now URL'),
('en', 'hybrid_auth_menu_description', 'Connect users via Facebook, Twitter, Google, etc.'),
('en', 'hybrid_auth', 'Social login'),
('en', 'hybrid_auth.linked_provider', 'Linked'),
('en', 'hybrid_auth.not_linked_provider', 'Not linked'),
('en', 'hybrid_auth.providers', 'Providers'),
('en', 'hybrid_auth.add_provider', 'Add provider'),
('en', 'hybrid_auth.new_provider', 'New provider'),
('en', 'hybrid_auth.editing_provider', 'Editing provider'),
('en', 'hybrid_auth.callback_url', 'Callback URL'),
('en', 'hybrid_auth.social_login', 'Or sign-in with another identity provider'),
('en', 'hybrid_auth.unspecified_error', 'Unspecified error'),
('en', 'hybrid_auth.configuration_error', 'Hybriauth configuration error'),
('en', 'hybrid_auth.provider_error_configuration', 'Provider not properly configured'),
('en', 'hybrid_auth.wrong_provider', 'Unknown or disabled provider'),
('en', 'hybrid_auth.missing_credentials', 'Missing provider application credentials'),
('en', 'hybrid_auth.failed_auth', 'Authentication failed. The user has canceled the authentication or the provider refused the connection'),
('en', 'hybrid_auth.connecting_provider', 'Contacting <b>[provider]</b>. Please wait...'),
('en', 'hybrid_auth.cant_create_profile', 'Unfortunately, we failed to create a customer and log in to the store due to one of the following reasons:<br />- You logged in to our store earlier using some other OpenID provider in which the same email is used.<br />- You have already registered in our store using your email.<br />Please contact the store owner to resolve the problems.'),
('en', 'hybrid_auth.password_generated', 'We are glad to inform you that you have been successfully registered in the store. A password was generated for you'),
('en', 'hybrid_auth.change_password', 'You can change your password here'),
('en', 'hybrid_auth.link_provider', 'Social network accounts'),
('en', 'hybrid_auth.text_link_provider', 'Assign your social network account to this one and use it to log in'),
('en', 'hybrid_auth.text_user_is_already_link', 'This social network account is already being used'),
('en', 'hybrid_auth.connect_social', 'Connect social account'),
('en', 'hybrid_auth.connect_social_title', 'Such user already exists'),
('en', 'hybrid_auth.text_connect_social', '<p>The user with the e-mail specified during social login already exists.</p><p>If you want to assign a social network account to the registered user, please log in.</p>'),
('en', 'hybrid_auth.specify_email', 'Specify email'),
('en', 'hybrid_auth.specify_email_title', 'The e-mail was not specified.'),
('en', 'hybrid_auth.text_specify_email', '<p>When logging through the social network the e-mail was not specified.</p><p>Please enter your e-mail and click Continue.</p>'),
('en', 'public_key', 'Public key'),
('en', 'paypal_seamless', 'Use seamless checkout'),
('en', 'paypal_sandbox', 'Test mode'),
('en', 'privileges.manage_providers', 'Can edit'),
('en', 'privileges.view_providers', 'Can view'),
('en', 'privilege_groups.social_login', 'Social login'),
('en', 'hybrid_auth.instruction_facebook', 'Use the application ID and Secret key that you''ve received after creating an application on <a href=''https://developers.facebook.com/apps'' target=''_blank''>Facebook Developers</a>.'),
('en', 'hybrid_auth.instruction_facebook_login', 'Use the application ID and Secret key that you''ve received after creating an application on <a href="https://developers.facebook.com/apps" target="_blank">Facebook Developers</a>. After that copy the value of the <b>Valid OAuth redirect URIs</b> field to the corresponding setting of the <b>Facebook Login</b> product in your Facebook application.'),
('en', 'hybrid_auth.instruction_google', 'Use ID and Secret key that you''ve received after creating a project on <a href=''https://code.google.com/apis/console/?pli=1'' target=''_blank''>Google</a>.'),
('en', 'hybrid_auth.instruction_paypal', 'Use the application ID and Secret key that you''ve received after creating an application on <a href=''https://developer.paypal.com/developer/applications'' target=''_blank''>PayPal Developers</a>.'),
('en', 'hybrid_auth.instruction_twitter', 'Use ID (Consumer key) and Secret key that you''ve received after creating an application on <a href=''https://apps.twitter.com/'' target=''_blank''>Twitter</a>.'),
('en', 'hybrid_auth.instruction_yahoo', 'Use ID (Identificator) and Secret key that you''ve received after creating an application on <a href=''https://developer.yahoo.com/apps/create/'' target=''_blank''>Yahoo</a>.'),
('en', 'hybrid_auth.instruction_live', 'Use the application ID and Secret key that you''ve received after adding an application on <a href=''https://account.live.com/developers/applications/create'' target=''_blank''>Live</a>.'),
('en', 'hybrid_auth.instruction_linkedin', 'Use ID (Consumer key) and Secret key that you''ve received after creating an application on <a href=''https://www.linkedin.com/developer/apps'' target=''_blank''>LinkedIn Developers</a>.'),
('en', 'hybrid_auth.instruction_foursquare', 'Use the application ID and Secret key that you''ve received after creating an application on <a href=''https://foursquare.com/developers/apps'' target=''_blank''>Fousquare</a>.'),
('en', 'email_template.hybrid_auth_create_profile', 'Create user profile via social login'),
('en', 'hybrid_auth.provider_not_found', 'Provider [provider] not found'),
('en', 'hybrid_auth.facebook_oauth_redirect_uris', 'Valid OAuth redirect URIs'),
('en', 'hybrid_auth.live_redirect_urls', 'Redirect URLs'),
('en', 'hybrid_auth.linkedin_api_version', 'API version'),
('en', 'ttc_hybrid_auth.linkedin_api_version', 'LinkedIn <a target="_blank" href="https://docs.microsoft.com/en-us/linkedin/consumer/integrations/self-serve/migration-faq?context=linkedin/consumer/context">deprecated API v1</a>, but old apps still use it. If you''re configuring LinkedIn app for the first time now, use API v2. Old LinkedIn apps configured some time ago may still be using v1.'),
('en', 'hybrid_auth.linkedin_api_v1', 'v1'),
('en', 'hybrid_auth.linkedin_api_v2', 'v2'),
('en', 'hybrid_auth.instruction_paypal_application', 'Use the application ID and Secret key that you''ve received after creating an application on <a href=''https://developer.paypal.com/developer/applications'' target=''_blank''>PayPal Developers</a>. Please enable all Personal Profile scope attributes and at least one scope attribute in Address and in Account Information in your PayPal application settings.'),
('en', 'privileges.manage_zapier_hooks', 'Can edit'),
('en', 'privileges.view_zapier_hooks', 'Can view'),
('en', 'privilege_groups.zapier_hooks', 'Zapier hooks'),
('en', 'zapier.text_settings_general', 'Learn more about setting up integration <a target="_blank" href="[docs_url]user_guide/addons/zapier/index.html">in the documentation</a>.'),
('en', 'price_per_unit', 'Price per unit'),
('en', 'unit_name', 'Unit name'),
('en', 'unit_name_field_description', 'For example, ''ml'' or ''g'' without quotes.'),
('en', 'units_in_product', 'Units in product'),
('en', 'units_in_product_field_description', 'Required for automatic calculation of price per unit.'),
('en', 'show_price_per_x_units', 'Show price per X units'),
('en', 'show_price_per_x_units_field_description', 'For cases when you want to show price ''per 250 ml'' instead of ''per ml''.'),
('en', 'gdpr.gdpr_user_data', 'GDPR user data'),
('en', 'gdpr_user_data', 'User personal data'),
('en', 'gdpr_user_profiles', 'Personal data from user profiles'),
('en', 'gdpr_product_subscriptions', 'Personal data from product subscriptions'),
('en', 'gdpr_agreements', 'Personal data from GDPR agreements'),
('en', 'gdpr.anonymize', 'Anonymize'),
('en', 'gdpr.text_anonymize_question', 'Once you anonymize someone, all their personal information will be replaced with randomly-generated data. This action can not be undone, unless you restore the database from a backup. Are you sure you want to proceed?'),
('en', 'gdpr.view_and_edit', 'View and edit'),
('en', 'gdpr_orders_data', 'Personal data from orders'),
('en', 'gdpr.full_agreement', 'Full agreement text'),
('en', 'gdpr.short_agreement', 'Short agreement text'),
('en', 'gdpr.checkout.place_order.personal_data_processing', 'Checkout: Place order: Personal data processing'),
('en', 'gdpr.checkout.place_order.agreement_text_full_personal_data_processing', '<p>We ([company]) send account-related emails (such as order status notifications, password reset emails, and more) to the provided email address. For that reason we need to store your email address while you remain our customer.</p> <p>We use the information in the billing/shipping address section and may send it to a shipping or payment method provider to:</p> <ul> <li>Determine what shipping and payment methods are available for your location. </li> <li>Complete the payment or shipping process via the provider that you choose at checkout when you submit the order.</li> </ul> <p>Some members of our staff and/or vendors who sell products in our store and use its administration panel may be able to access your data. We value your privacy, so the access to data is provided on a need-to-know basis in order to operate the store. For example, a vendor only receives your data if you ordered something from them, so that the vendor can fulfil that order.</p> <p>If you decide that you no longer want to use our store and would like to have your personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('en', 'gdpr.checkout.place_order.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows.</u>'),
('en', 'gdpr.user.registration.personal_data_processing', 'Customer: registration'),
('en', 'gdpr.user.registration.agreement_text_full_personal_data_processing', '<p>Email addresses distinguish customers from each other. You sign in to the store by entering the email address and the password you provide here.</p> <p>We ([company]) also send account-related emails (such as order status notifications, password reset emails, and more) to the provided email address. For that reason we need to store your email address while you remain our customer.</p> <p>Other profile fields that may or not be present on this page are stored alongside your email address. We may use this information to contact you, if the necessity arises.</p> <p>Some members of our staff and/or vendors who sell products in our store and use its administration panel may be able to access your data. We value your privacy, so the access to data is provided on a need-to-know basis in order to operate the store. For example, a vendor only receives your data if you ordered something from them, so that the vendor can fulfil that order.</p> <p>If you decide that you no longer want to use our store and would like to have your personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('en', 'gdpr.user.registration.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows.</u>'),
('en', 'gdpr.profiles.update.personal_data_processing', 'Profiles: update'),
('en', 'gdpr.profiles.update.agreement_text_full_personal_data_processing', '<p>Email addresses distinguish customers from each other. You sign in to the store by entering the email address and the password you provide here.</p> <p>We ([company]) also send account-related emails (such as order status notifications, password reset emails, and more) to the provided email address. For that reason we need to store your email address while you remain our customer.</p> <p>Other profile fields that may or not be present on this page are stored alongside your email address. We may use this information to contact you, if the necessity arises.</p> <p>We use the information in the billing/shipping address section and may send it to a shipping or payment method provider to:</p> <ul> <li>Determine what shipping and payment methods are available for your location.</li> <li>Complete the payment or shipping process via the provider that you choose at checkout when you submit the order.</li> </ul> <p>Some members of our staff and/or vendors who sell products in our store and use its administration panel may be able to access your data. We value your privacy, so the access to data is provided on a need-to-know basis in order to operate the store. For example, a vendor only receives your data if you ordered something from them, so that the vendor can fulfil that order.</p> <p>If you decide that you no longer want to use our store and would like to have your personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p> '),
('en', 'gdpr.profiles.update.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows.</u>'),
('en', 'gdpr.vendor.apply.personal_data_processing', 'Vendor: apply for vendor');
INSERT INTO `[[dbprefix]]language_values` VALUES
('en', 'gdpr.vendor.apply.agreement_text_full_personal_data_processing', '<p>Because vendors sell products in our marketplace, we ([company]) have to request certain information about them. For example, the company name and description of a vendor are shown to customers and serve to distinguish vendors from each other; the address is used for shipping rate calculation.</p> <p>However, we also request some personal data, such as first name/last name and emails address. Those are necessary for creating a vendor’s administrator account in our system. Vendors work with the marketplace through such accounts. Email addresses are necessary because they distinguish administrators from each other. You sign in to the store by entering the email address you provide here. Names are necessary because a single vendor can have multiple administrators—it is easier to handle accountability that way.</p> <p>We also send account-related emails (such as order status notifications, password reset emails, and more) to the provided email address. For that reason we need to store your email address while you remain our customer. If you decide that you no longer want to work with our marketplace and would like to have personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('en', 'gdpr.vendor.apply.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows.</u>'),
('en', 'gdpr.products.subscribe.personal_data_processing', 'Products: subscribe'),
('en', 'gdpr.products.subscribe.agreement_text_full_personal_data_processing', '<p>We ([company]) will add your email address to a special mailing list for this product. Once the product is in stock, you’ll get an email about it automatically, and your email address will be removed from the product’s mailing list.</p> <p>The data will be visible to some members of our staff. If you’d like to have your personal data removed, send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('en', 'gdpr.products.subscribe.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows.</u>'),
('en', 'gdpr.checkout.profiles_update.personal_data_processing', 'Checkout: profiles update'),
('en', 'gdpr.checkout.profiles_update.agreement_text_full_personal_data_processing', '<p>We ([company]) send account-related emails (such as order status notifications, password reset emails, and more) to the provided email address. For that reason we need to store your email address while you remain our customer.</p> <p>We use the information in the billing/shipping address section and may send it to a shipping or payment method provider to:</p> <ul> <li>Determine what shipping and payment methods are available for your location. </li> <li>Complete the payment or shipping process via the provider that you choose at checkout when you submit the order.</li> </ul> <p>Some members of our staff and/or vendors who sell products in our store and use its administration panel may be able to access your data. We value your privacy, so the access to data is provided on a need-to-know basis in order to operate the store. For example, a vendor only receives your data if you ordered something from them, so that the vendor can fulfil that order.</p> <p>If you decide that you no longer want to use our store and would like to have your personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('en', 'gdpr.checkout.profiles_update.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows</u>.'),
('en', 'gdpr.export_to_xml', 'Export to XML'),
('en', 'gdpr.agreement_required_error', 'Your agreement is required to proceed.'),
('en', 'gdpr.user_anonymized', 'User has been anonymized.'),
('en', 'gdpr.check_other_sources_for_personal_data', '<p>Please note that anonymization doesn''t affect any backups and logs that you might have. If necessary, please do the following:</p><ol><li>Clear the logs under <b>Administration → Logs</b>.</li><li>Secure and delete the backups you might have under <b>Administration → Backup/Restore</b>.</li></ol>'),
('en', 'gdpr.cookie_consent', 'Cookie consent'),
('en', 'gdpr.cookie_consent_message', '<p>This website uses cookies (small pieces of data saved on your computer). Some cookies are added by the website itself: they help to show you the content of your cart, keep you signed in once you enter your email and password, preserve your preferences, and do a lot of other useful things. We use these cookies only to make the site work properly for you. Even your agreement to our use of cookies is stored as a cookie.</p><p>Other cookies may be used by third-party services (such as PayPal, YouTube, Google Maps, Facebook, etc.) to store the data about how you use those third-party services on the website. We have no control over how third parties use cookies, but those cookies are also important for proper functioning of the website. For example, some of the PayPal functionality may not work without PayPal cookies.</p><p>Without cookies, many things can go wrong. That''s why we ask that you agree to cookies being used before you proceed. If you don''t want any cookies but would like to continue using the website, please configure your browser to block cookies, and then you''ll be able to "agree" to their use, while we won''t treat that as your consent.</p>'),
('en', 'gdpr.cookie_consent_accept', 'I agree'),
('en', 'gdpr.cookie_consent_decline', 'No, take me out of here'),
('en', 'gdpr.uk_cookies_law', 'Cookies are used on this site to provide the best user experience. If you continue, we assume that you agree to receive cookies from this site.'),
('en', 'block_gdpr', 'GDPR'),
('en', 'gdpr', 'GDPR'),
('en', 'block_gdpr_description', 'Allows registered users to request their personal data or anonymization'),
('en', 'gdpr.user_profile_actions_description', '<p>As customers interact with the store, they provide personal data for various purposes. When you place an order, we need to know where to ship it; when you subscribe for an email newsletter, we need to know where to send it, and so on. We keep this data organized, so that you always could:</p> <ol> <li>Request that we send you all your personal data. In that case we’ll send you an XML file by email. That file will contain all your personal data we have.</li> <li>Request to be forgotten. In that case your account will be deactivated, and all your personal data will be removed. If necessary, you’ll be able to register a new account with the same email address in the future.</li> </ol> <p>Please note that we’ll need some time to process either of those requests. We may contact you regarding your request by email or through other means.</p>'),
('en', 'gdpr.send_my_data', 'Send me my data'),
('en', 'gdpr.send_my_data_description', '<p>We’ll send you an XML file with all your personal data we have. Please note that we’ll need some time to process this request, so the email with your XML file won’t be sent immediately. If you have any comments regarding your request, please leave them in the field below.</p>'),
('en', 'gdpr.email_subject_personal_data_request', 'Personal Data Copy Request: [customer_email]'),
('en', 'gdpr.email_body_personal_data_request', '<p><a href="[user_profile_url]" target="_blank">[user]</a> with the email address [customer_email] has requested a copy of personal data with the following comment:</p> <p>[comment]</p> <p>Click the link at the beginning of this message and use the corresponding button on the customer profile page in the Administration panel to get the data in the XML format. After that, send the XML file to the customer.</p>'),
('en', 'gdpr.remove_my_data', 'Remove my data'),
('en', 'gdpr.remove_my_data_description', '<p>We’ll deactivate your account and remove all your personal data from it. After that you won’t be able to sign in. However, you’ll be able to register a new account with the same email address in the future. Please note that we’ll need some time to process this request, so your account won’t be deactivated immediately. If you have any comments regarding your request, please leave them in the field below.</p>'),
('en', 'gdpr.email_subject_anonymization_request', 'Personal Data Removal Request: [customer_email]'),
('en', 'gdpr.email_body_anonymization_request', '<p><a href="[user_profile_url]" target="_blank">[user]</a> with the email address [customer_email] has requested the removal of personal data with the following comment:</p> <p>[comment]</p> <p>Click the link at the beginning of this message and use the corresponding button on the customer profile page in the Administration panel to anonymize the customer.</p> <p>Please note that <b>this action will replace all the personal data of the customer</b> with randomly generated data. It’s best to make sure that all business with the customer (such as orders and return requests) is concluded before you do that.</p>'),
('en', 'gdpr.user_action_request_success', 'Your request has been sent successfully.'),
('en', 'gdpr.user_action_request_fail', 'An error has occurred during the attempt to send your request. Please try again or send a message to the following email address: <a href="mailto:[email]">[email]</a>'),
('en', 'gdpr.agreement_variables_hint', '<p>The texts of the agreements listed below may have <b>[email]</b> or <b>[company]</b> in them. Those are placeholders that will be automatically replaced with actual data when customers see the agreements. If you only have one storefront, the data for the placeholders will be taken from <a href="[company_settings_url]" target="_blank">Settings → Company</a>. If you have multiple storefronts, the data will be taken from the settings of the storefront that a customer visits:</p><ul><li><b>[company]</b> will be taken from <i>Company name</i>.</li><li><b>[email]</b> will be taken from <i>User department e-mail address</i>.</li></ul>'),
('en', 'gdpr.agreement_variables_hint_mve', '<p>The texts of the agreements listed below may have <b>[email]</b> or <b>[company]</b> in them. Those are placeholders that will be automatically replaced with actual data when customers see the agreements. The data for placeholders will be taken from <a href="[company_settings_url]" target="_blank">Settings → Company</a>:</p><ul><li><b>[company]</b> will be taken from <i>Company name</i>.</li><li><b>[email]</b> will be taken from <i>User department e-mail address</i>.</li></ul>'),
('en', 'gdpr.strictly_necessary_cookies_title', 'Strictly necessary cookies'),
('en', 'gdpr.strictly_necessary_cookies_description', 'These cookies are essential for the website to work properly. For example, they let you place an order, or help the site remember that you''ve signed into your account. That''s why they can''t be disabled through the site. You can configure your browser to disable even these cookies, but important parts of the site won''t work without them.'),
('en', 'gdpr.performance_cookies_title', 'Performance cookies'),
('en', 'gdpr.performance_cookies_description', 'These cookies allow us to see how the website works. The information that these cookies help to collect is anonymous; it is typically presented in numbers. For example, these cookies help us see how often errors occur, how many unique visitors we have, or how long each page is viewed on average. Thanks to these cookies, we can improve the site for you.'),
('en', 'gdpr.functional_cookies_title', 'Functional cookies'),
('en', 'gdpr.functional_cookies_description', 'These cookies enable additional functionality at the website. They may be set by third-party providers whose services we''ve added to the website. Those services may include many things, like maps, geolocation for preliminary shipping rate calculation, or the ability to sign in with your social network account. Without functional cookies, the parts of the site associated with these services may not work properly.'),
('en', 'gdpr.marketing_cookies_title', 'Marketing cookies'),
('en', 'gdpr.marketing_cookies_description', 'These cookies are used by our advertising partners. They help them to measure promotion efficiency and serve you ads that are more relevant and less repetitive. This is usually achieved by remembering the browser and device that saw the ad. Turning these cookies off won''t reduce the number of ads you see on the internet, but will make them less personalized.'),
('en', 'gdpr.eway_cookies_title', 'eWAY'),
('en', 'gdpr.eway_cookies_description', 'eWAY is a payment provider. It allows us to accept payments, if you choose a payment method powered by eWAY. Here is <a href="https://www.eway.com.au/privacy-policy/" target="_blank">eWAY privacy policy</a>.'),
('en', 'gdpr.klaro_privacy_policy_title', 'You can find out more in this document: {privacyPolicy}.'),
('en', 'gdpr.klaro_privacy_policy_name', 'Privacy policy'),
('en', 'gdpr.klaro_service', 'service'),
('en', 'gdpr.klaro_services', 'services'),
('en', 'gdpr.klaro_accept_all', 'Accept all'),
('en', 'gdpr.klaro_accept_selected', 'Accept selected'),
('en', 'gdpr.klaro_close', 'Close'),
('en', 'gdpr.klaro_consent_modal_description', 'Here you can assess and customize the services (and their respective cookies) that we''d like to use on this website. You''re in charge! Enable or disable services as you see fit.'),
('en', 'gdpr.klaro_consent_modal_title', 'Cookies we would like to use'),
('en', 'gdpr.klaro_consent_notice_change_description', 'There were changes since your last visit, please renew your consent.'),
('en', 'gdpr.klaro_consent_notice_title', 'Cookie Consent'),
('en', 'gdpr.klaro_consent_notice_description', 'Hi! Could we please enable some additional services that require cookies? You can always change or withdraw your consent later.'),
('en', 'gdpr.klaro_consent_notice_learn_more', 'Let me choose'),
('en', 'gdpr.klaro_consent_notice_testing', 'Testing mode!'),
('en', 'gdpr.klaro_contextual_consent_accept_always', 'Always'),
('en', 'gdpr.klaro_contextual_consent_accept_once', '''Yes'''),
('en', 'gdpr.klaro_contextual_consent_description', 'Do you want to load external content supplied by {title}?'),
('en', 'gdpr.klaro_decline', 'I decline'),
('en', 'gdpr.klaro_ok', 'That''s ok'),
('en', 'gdpr.klaro_powered_by', 'Realized with Klaro!'),
('en', 'gdpr.klaro_service_purpose', 'purpose'),
('en', 'gdpr.klaro_service_purposes', 'purposes'),
('en', 'gdpr.klaro_service_required_description', 'This service is always required'),
('en', 'gdpr.disable_all_description', 'Use this switch to enable or disable all services.'),
('en', 'gdpr.disable_all_title', 'Enable or disable all services'),
('en', 'gdpr.opt_out_description', 'This service is enabled by default (but you can opt out)'),
('en', 'gdpr.opt_out_title', '(opt-out)'),
('en', 'gdpr.klaro_service_required_title', '(always required)'),
('en', 'gdpr.cookie_consent_texts', 'Cookie consent texts'),
('en', 'gdpr.site_functionality_cookies_title', 'Site functionality'),
('en', 'gdpr.site_functionality_cookies_description', 'These cookies serve the essential functions of the site. For example, they help the site remember that you put something in the cart or signed into your account.'),
('en', 'shopify_import.shopify_products_import', 'Shopify products'),
('en', 'shopify_import.sync_data_name', 'Import products from Shopify'),
('en', 'shopify_import.choose_import_mode', 'Choose import mode'),
('en', 'shopify_import.import_for_all_vendors', 'I''m launching my marketplace and setting up products for all vendors to use'),
('en', 'shopify_import.import_for_specific_vendor', 'I''m importing these products for a specific vendor'),
('en', 'shopify_import.depends_on_common_products_addon', 'This option needs <a href="[link]">Common products for vendors</a> add-on to be installed'),
('en', 'shopify_import.invalid_csv_file_format', 'Uploaded CSV-file has invalid format or empty. Only files exported from Shopify supported.'),
('en', 'shopify_import.products_without_sku', 'The SKU value is missing for some products. These products are always imported as new objects.'),
('en', 'shopify_import.last_status.S', 'Success'),
('en', 'shopify_import.last_status.F', 'Failure');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]localizations`
--

CREATE TABLE `[[dbprefix]]localizations` (
  `localization_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `custom_weight_settings` char(1) NOT NULL DEFAULT 'Y',
  `weight_symbol` varchar(255) NOT NULL DEFAULT '',
  `weight_unit` decimal(12,2) NOT NULL DEFAULT '0.00',
  `is_default` char(1) NOT NULL DEFAULT 'N',
  `status` char(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`localization_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]localization_descriptions`
--

CREATE TABLE `[[dbprefix]]localization_descriptions` (
  `localization_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `localization` varchar(255) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  KEY `localisation_id` (`localization_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]localization_elements`
--

CREATE TABLE `[[dbprefix]]localization_elements` (
  `element_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `localization_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `element` varchar(36) NOT NULL DEFAULT '',
  `element_type` char(1) NOT NULL DEFAULT 'S',
  `position` smallint(5) NOT NULL DEFAULT '0',
  PRIMARY KEY (`element_id`),
  KEY `c_avail` (`localization_id`),
  KEY `element` (`element`,`element_type`),
  KEY `position` (`position`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]lock_keys`
--

CREATE TABLE `[[dbprefix]]lock_keys` (
  `key_id` varchar(64) NOT NULL,
  `token` varchar(64) NOT NULL,
  `expiry_at` int(11) unsigned NOT NULL,
  PRIMARY KEY (`key_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]logos`
--

CREATE TABLE `[[dbprefix]]logos` (
  `logo_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `layout_id` int(11) NOT NULL DEFAULT '0',
  `style_id` varchar(50) NOT NULL DEFAULT '',
  `company_id` int(11) NOT NULL DEFAULT '0',
  `type` varchar(32) NOT NULL DEFAULT '',
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`logo_id`),
  KEY `type` (`type`,`company_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=5 ;

--
-- Dumping data for table `[[dbprefix]]logos`
--

INSERT INTO `[[dbprefix]]logos` VALUES
(1, 1, 'Bright_theme', 1, 'theme', 1),
(2, 1, 'Bright_theme', 1, 'favicon', 1),
(3, 1, 'Bright_theme', 1, 'mail', 1),
(4, 0, '', 0, 'gift_cert', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]logs`
--

CREATE TABLE `[[dbprefix]]logs` (
  `log_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `type` varchar(16) NOT NULL DEFAULT '',
  `event_type` char(1) NOT NULL DEFAULT 'N',
  `action` varchar(16) NOT NULL DEFAULT '',
  `object` char(1) NOT NULL DEFAULT '',
  `content` text,
  `backtrace` text,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`log_id`),
  KEY `object` (`object`),
  KEY `type` (`type`,`action`),
  KEY `idx_timestamp` (`timestamp`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `[[dbprefix]]logs`
--
-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]mailing_lists`
--

CREATE TABLE `[[dbprefix]]mailing_lists` (
  `list_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `from_email` varchar(64) NOT NULL DEFAULT '',
  `from_name` varchar(128) NOT NULL DEFAULT '',
  `reply_to` varchar(64) NOT NULL DEFAULT '',
  `show_on_checkout` tinyint(3) unsigned NOT NULL DEFAULT '0',
  `show_on_registration` tinyint(3) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'D',
  `register_autoresponder` mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`list_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]mailing_lists`
--

INSERT INTO `[[dbprefix]]mailing_lists` VALUES
(1, 0, 'no-reply@example.com', 'Acme', 'no-reply@example.com', 1, 1, 'A', 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]menus`
--

CREATE TABLE `[[dbprefix]]menus` (
  `menu_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `status` char(1) NOT NULL DEFAULT 'A',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`menu_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=5 ;

--
-- Dumping data for table `[[dbprefix]]menus`
--

INSERT INTO `[[dbprefix]]menus` VALUES
(1, 'A', 1),
(2, 'A', 1),
(3, 'A', 1),
(4, 'A', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]menus_descriptions`
--

CREATE TABLE `[[dbprefix]]menus_descriptions` (
  `menu_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `name` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`menu_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]menus_descriptions`
--

INSERT INTO `[[dbprefix]]menus_descriptions` VALUES
(1, 'en', 'Quick links'),
(2, 'en', 'Main menu'),
(3, 'en', 'Shop (footer)'),
(4, 'en', 'Create orders (footer)');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]newsletters`
--

CREATE TABLE `[[dbprefix]]newsletters` (
  `newsletter_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `campaign_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `sent_date` int(11) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'A',
  `type` char(1) NOT NULL DEFAULT 'N',
  `mailing_lists` varchar(255) NOT NULL DEFAULT '',
  `users` text,
  `abandoned_type` varchar(10) NOT NULL DEFAULT 'both',
  `abandoned_days` int(11) NOT NULL DEFAULT '0',
  `abandoned_company_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`newsletter_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=3 ;

--
-- Dumping data for table `[[dbprefix]]newsletters`
--

INSERT INTO `[[dbprefix]]newsletters` VALUES
(1, 0, 0, 'A', 'N', '', NULL, 'both', 0, 0),
(2, 0, 0, 'A', 'T', '', NULL, 'both', 0, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]newsletter_batch_recipients`
--

CREATE TABLE `[[dbprefix]]newsletter_batch_recipients` (
  `send_list_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `newsletter_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `list_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `subscriber_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `email` varchar(128) NOT NULL DEFAULT '',
  `send_key` varchar(128) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`send_list_id`),
  KEY `send_key` (`send_key`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]newsletter_campaigns`
--

CREATE TABLE `[[dbprefix]]newsletter_campaigns` (
  `campaign_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'D',
  PRIMARY KEY (`campaign_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]newsletter_descriptions`
--

CREATE TABLE `[[dbprefix]]newsletter_descriptions` (
  `newsletter_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `newsletter` varchar(255) NOT NULL DEFAULT '',
  `newsletter_multiple` text,
  `body_html` mediumtext,
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`newsletter_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]newsletter_descriptions`
--

INSERT INTO `[[dbprefix]]newsletter_descriptions` VALUES
(1, 'Xbox One is coming!', '', 'The groundbreaking nextgen gaming console is already coming to the stores. Be the first to order this extraordinary gadget!', 'en'),
(2, 'Sample layout', '', '<h2>Hello,</h2>\r\n\r\n[your text]\r\n\r\nThank you!\r\nYou can unsubscribe from the newsletter by using this link:\r\n%UNSUBSCRIBE_LINK\r\n\r\n%COMPANY_NAME.', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]newsletter_links`
--

CREATE TABLE `[[dbprefix]]newsletter_links` (
  `link_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `campaign_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `newsletter_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `url` varchar(255) NOT NULL DEFAULT '',
  `clicks` mediumint(8) unsigned DEFAULT NULL,
  PRIMARY KEY (`link_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]notifications`
--

CREATE TABLE `[[dbprefix]]notifications` (
  `notification_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` int(11) unsigned NOT NULL DEFAULT '0' COMMENT 'Notification receiver',
  `title` varchar(256) NOT NULL DEFAULT '' COMMENT 'Notification title',
  `message` text NOT NULL COMMENT 'Notification text',
  `severity` char(1) NOT NULL DEFAULT 'N' COMMENT 'Notification severity: E(rror), W(arning), N(otice), I(nfo)',
  `section` varchar(128) NOT NULL DEFAULT 'other' COMMENT 'Section of the Notifications center to display the notification in',
  `tag` varchar(32) NOT NULL DEFAULT 'other' COMMENT 'Tag of the notifications',
  `area` char(1) NOT NULL DEFAULT 'A' COMMENT 'Area to display the notification in',
  `action_url` varchar(256) NOT NULL DEFAULT '' COMMENT 'Dispatch to open when clicking on the notification',
  `is_read` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT 'Whether the notification has been read',
  `pinned` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Whether the notification has been pinned',
  `remind` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Determines if a remind notification is needed',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0' COMMENT 'Time when the notification was created',
  PRIMARY KEY (`notification_id`),
  KEY `idx_user_id` (`user_id`),
  KEY `idx_user_id_area` (`user_id`,`area`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Stores notifications of the Notifications center' AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]notification_event_receivers`
--

CREATE TABLE `[[dbprefix]]notification_event_receivers` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `event_id` varchar(128) NOT NULL COMMENT 'The notification group ID',
  `method` varchar(64) NOT NULL DEFAULT 'user_id' COMMENT 'Receiver search method: user_id — User ID, usergroup_id — Usergroup ID, email — e-mail',
  `criterion` varchar(128) NOT NULL COMMENT 'Criterion to use with the specified method to search a receiver',
  `receiver` varchar(15) NOT NULL DEFAULT 'A' COMMENT 'Receiver of notification message: C - Customer, A - Administrator, V - Vendor',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]notification_group_receivers`
--

CREATE TABLE `[[dbprefix]]notification_group_receivers` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `group_id` varchar(128) NOT NULL COMMENT 'Notification group ID',
  `method` varchar(64) NOT NULL DEFAULT 'user_id' COMMENT 'Receiver search method: user_id — User ID, usergroup_id — Usergroup ID, email — e-mail',
  `criterion` varchar(128) NOT NULL COMMENT 'Criterion to use with the specified method to search a receiver',
  `receiver` varchar(15) NOT NULL DEFAULT 'A' COMMENT 'Receiver of notification message: C - Customer, A - Administrator, V - Vendor',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=10 ;

--
-- Dumping data for table `[[dbprefix]]notification_group_receivers`
--

INSERT INTO `[[dbprefix]]notification_group_receivers` VALUES
(1, 'orders', 'order_manager', 'order_manager', 'A'),
(2, 'orders', 'user_id', '1', 'A'),
(3, 'users', 'user_id', '1', 'A'),
(4, 'system', 'user_id', '1', 'A'),
(5, 'vendor_communication', 'user_id', '1', 'A'),
(6, 'rma', 'user_id', '1', 'A'),
(7, 'call_requests', 'user_id', '1', 'A'),
(8, 'discussion', 'user_id', '1', 'A'),
(9, 'product_reviews.product_reviews', 'user_id', '1', 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]notification_settings`
--

CREATE TABLE `[[dbprefix]]notification_settings` (
  `event_id` varchar(100) NOT NULL,
  `transport_id` varchar(50) NOT NULL,
  `receiver` varchar(15) NOT NULL COMMENT 'Receiver of notification message: C - Customer, A - Administrator, V - Vendor',
  `is_allowed` tinyint(3) DEFAULT '0' COMMENT '0 - will NOT be sent, 1 - will BE sent',
  PRIMARY KEY (`event_id`,`transport_id`,`receiver`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]orders`
--

CREATE TABLE `[[dbprefix]]orders` (
  `order_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `is_parent_order` char(1) NOT NULL DEFAULT 'N',
  `parent_order_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `issuer_id` mediumint(8) unsigned DEFAULT NULL,
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `total` decimal(12,2) NOT NULL DEFAULT '0.00',
  `subtotal` decimal(12,2) NOT NULL DEFAULT '0.00',
  `discount` decimal(12,2) NOT NULL DEFAULT '0.00',
  `subtotal_discount` decimal(12,2) NOT NULL DEFAULT '0.00',
  `payment_surcharge` decimal(12,2) NOT NULL DEFAULT '0.00',
  `shipping_ids` varchar(255) NOT NULL DEFAULT '',
  `shipping_cost` decimal(12,2) NOT NULL DEFAULT '0.00',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'O',
  `notes` text,
  `details` text,
  `promotions` text,
  `promotion_ids` varchar(255) NOT NULL DEFAULT '',
  `firstname` varchar(32) NOT NULL DEFAULT '',
  `lastname` varchar(32) NOT NULL DEFAULT '',
  `company` varchar(255) NOT NULL DEFAULT '',
  `b_firstname` varchar(128) NOT NULL DEFAULT '',
  `b_lastname` varchar(128) NOT NULL DEFAULT '',
  `b_address` varchar(255) NOT NULL DEFAULT '',
  `b_address_2` varchar(255) NOT NULL DEFAULT '',
  `b_city` varchar(64) NOT NULL DEFAULT '',
  `b_county` varchar(32) NOT NULL DEFAULT '',
  `b_state` varchar(32) NOT NULL DEFAULT '',
  `b_country` char(2) NOT NULL DEFAULT '',
  `b_zipcode` varchar(32) NOT NULL DEFAULT '',
  `b_phone` varchar(128) NOT NULL DEFAULT '',
  `s_firstname` varchar(128) NOT NULL DEFAULT '',
  `s_lastname` varchar(128) NOT NULL DEFAULT '',
  `s_address` varchar(255) NOT NULL DEFAULT '',
  `s_address_2` varchar(255) NOT NULL DEFAULT '',
  `s_city` varchar(64) NOT NULL DEFAULT '',
  `s_county` varchar(32) NOT NULL DEFAULT '',
  `s_state` varchar(32) NOT NULL DEFAULT '',
  `s_country` char(2) NOT NULL DEFAULT '',
  `s_zipcode` varchar(32) NOT NULL DEFAULT '',
  `s_phone` varchar(128) NOT NULL DEFAULT '',
  `s_address_type` varchar(32) NOT NULL DEFAULT '',
  `phone` varchar(128) NOT NULL DEFAULT '',
  `fax` varchar(128) NOT NULL DEFAULT '',
  `url` varchar(32) NOT NULL DEFAULT '',
  `email` varchar(128) NOT NULL DEFAULT '',
  `payment_id` mediumint(8) NOT NULL DEFAULT '0',
  `tax_exempt` char(1) NOT NULL DEFAULT 'N',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `ip_address` varbinary(40) NOT NULL DEFAULT '',
  `repaid` int(11) NOT NULL DEFAULT '0',
  `validation_code` varchar(20) NOT NULL DEFAULT '',
  `localization_id` mediumint(8) NOT NULL,
  `profile_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `updated_at` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`order_id`),
  KEY `timestamp` (`timestamp`),
  KEY `user_id` (`user_id`),
  KEY `promotion_ids` (`promotion_ids`),
  KEY `status` (`status`),
  KEY `shipping_ids` (`shipping_ids`),
  KEY `company_id` (`company_id`),
  KEY `idx_updated_at` (`updated_at`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=98 ;

--
-- Dumping data for table `[[dbprefix]]orders`
--

INSERT INTO `[[dbprefix]]orders` VALUES
(28, 'N', 0, 1, NULL, 3, '917.99', '917.99', '0.00', '0.00', '0.00', '1', '0.00', 1380175269, 'C', '', '', 'a:0:{}', '', 'David', 'Tenant', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '+16175555555', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '+16175555555', '', '+16175555555', '', '', 'davdavid@example.com', 1, 'N', 'en', '95.104.192.183', 0, '', 0, 2, 1, 0),
(29, 'N', 0, 1, NULL, 3, '529.99', '529.99', '0.00', '0.00', '0.00', '', '0.00', 1380223340, 'C', '', '', 'a:0:{}', '', 'David', 'Tenant', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', '', '', '', '', 'davdavid@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(35, 'N', 0, 1, NULL, 3, '25.00', '25.00', '0.00', '0.00', '0.00', '', '0.00', 1380299995, 'C', '', '', 'a:0:{}', '', 'David', 'Tenant', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', '', '', '', '', 'davdavid@example.com', 3, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(36, 'N', 0, 1, NULL, 3, '12.99', '12.99', '0.00', '0.00', '0.00', '', '0.00', 1380442732, 'C', '', '', 'a:0:{}', '', 'David', 'Tenant', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', '', '', '', '', 'davdavid@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(37, 'N', 0, 1, NULL, 3, '39.99', '39.99', '0.00', '0.00', '0.00', '', '0.00', 1380523085, 'C', '', '', 'a:0:{}', '', 'David', 'Tenant', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', '', '', '', '', 'davdavid@example.com', 1, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(38, 'N', 0, 1, NULL, 3, '200.00', '200.00', '0.00', '0.00', '0.00', '', '0.00', 1380608061, 'B', '', '', 'a:0:{}', '', 'David', 'Tenant', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', '', '', '', '', 'davdavid@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(39, 'N', 0, 1, NULL, 3, '249.00', '249.00', '0.00', '0.00', '0.00', '', '0.00', 1380701115, 'C', '', '', 'a:0:{}', '', 'David', 'Tenant', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', 'David', 'Tenant', 'Glasgow, Lanarkshire G2 1DS', '', 'Glasgow', '', 'GLAS', 'GB', '141 332', '', '', '', '', '', 'davdavid@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(40, 'N', 0, 1, NULL, 3, '299.99', '299.99', '0.00', '0.00', '0.00', '', '0.00', 1380748356, 'C', '', '', 'a:0:{}', '', 'Sergey', 'Maxeev', '', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', '', '+79235456683', '', '', 'sebastian@example.com', 1, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(41, 'N', 0, 1, NULL, 3, '100.00', '100.00', '0.00', '0.00', '0.00', '', '0.00', 1380832402, 'C', '', '', 'a:0:{}', '', 'Sergey', 'Maxeev', '', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', '', '+79235456683', '', '', 'sebastian@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(42, 'N', 0, 1, NULL, 3, '59.99', '59.99', '0.00', '0.00', '0.00', '', '0.00', 1380962932, 'C', '', '', 'a:0:{}', '', 'Sergey', 'Maxeev', '', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', '', '+79235456683', '', '', 'sebastian@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(43, 'N', 0, 1, NULL, 3, '499.99', '499.99', '0.00', '0.00', '0.00', '', '0.00', 1381045614, 'C', '', '', 'a:0:{}', '', 'Sergey', 'Maxeev', '', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', '', '+79235456683', '', '', 'sebastian@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(44, 'N', 0, 1, NULL, 3, '220.00', '220.00', '0.00', '0.00', '0.00', '', '0.00', 1381126041, 'B', '', '', 'a:0:{}', '', 'Sergey', 'Maxeev', '', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', '', '+79235456683', '', '', 'sebastian@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(45, 'N', 0, 1, NULL, 3, '749.95', '749.95', '0.00', '0.00', '0.00', '', '0.00', 1381195430, 'C', '', '', 'a:0:{}', '', 'Sergey', 'Maxeev', '', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', '', '+79235456683', '', '', 'sebastian@example.com', 3, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(46, 'N', 0, 1, NULL, 3, '1199.99', '1199.99', '0.00', '0.00', '0.00', '', '0.00', 1381305105, 'I', '', '', 'a:0:{}', '', 'Sergey', 'Maxeev', '', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', '', '+79235456683', '', '', 'sebastian@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(47, 'N', 0, 1, NULL, 3, '299.99', '299.99', '0.00', '0.00', '0.00', '', '0.00', 1381351227, 'C', '', '', 'a:0:{}', '', 'Sergey', 'Maxeev', '', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', '', '+79235456683', '', '', 'sebastian@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(48, 'N', 0, 1, NULL, 3, '1059.98', '1059.98', '0.00', '0.00', '0.00', '', '0.00', 1381453574, 'F', '', '', 'a:0:{}', '', 'Sergey', 'Maxeev', '', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', '', '+79235456683', '', '', 'sebastian@example.com', 1, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(49, 'N', 0, 1, NULL, 3, '262.93', '262.93', '0.00', '0.00', '0.00', '', '0.00', 1381519339, 'C', '', '', 'a:0:{}', '', 'Sergey', 'Maxeev', '', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', '', '+79235456683', '', '', 'sebastian@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(50, 'N', 0, 1, NULL, 3, '1524.45', '1499.00', '0.00', '0.00', '0.00', '1', '25.45', 1381588344, 'D', 'Please, deliver it in the first part of day', '', 'a:0:{}', '', 'Sergey', 'Maxeev', '', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', 'Sergey', 'Maxeev', 'Moskovskaya street, 65-12', '', 'Moscow', '', 'MOS', 'RU', '657849', '+79235456683', '', '+79235456683', '', '', 'sebastian@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(51, 'N', 0, 1, NULL, 3, '157.95', '129.95', '0.00', '0.00', '0.00', '1', '28.00', 1381719156, 'C', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(52, 'N', 0, 1, NULL, 3, '198.00', '170.00', '0.00', '0.00', '0.00', '1', '28.00', 1381756224, 'C', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(53, 'N', 0, 1, NULL, 3, '80.99', '47.99', '0.00', '0.00', '0.00', '1', '33.00', 1381851877, 'C', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(54, 'N', 0, 1, NULL, 3, '323.00', '295.00', '0.00', '0.00', '0.00', '1', '28.00', 1381982790, 'D', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(55, 'N', 0, 1, NULL, 3, '1098.00', '1070.00', '0.00', '0.00', '0.00', '1', '28.00', 1382051938, 'C', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(56, 'N', 0, 1, NULL, 3, '297.00', '269.00', '0.00', '0.00', '0.00', '1', '28.00', 1382136365, 'C', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(57, 'N', 0, 1, NULL, 3, '92.99', '29.99', '0.00', '0.00', '0.00', '1', '63.00', 1382206809, 'C', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(58, 'N', 0, 1, NULL, 3, '5723.00', '5695.00', '0.00', '0.00', '0.00', '1', '28.00', 1382294314, 'C', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(59, 'N', 0, 1, NULL, 3, '3523.00', '3495.00', '0.00', '0.00', '0.00', '1', '28.00', 1382427272, 'F', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(60, 'N', 0, 1, NULL, 3, '677.95', '649.95', '0.00', '0.00', '0.00', '1', '28.00', 1382464846, 'C', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 1, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(61, 'N', 0, 1, NULL, 3, '479.99', '479.99', '0.00', '0.00', '0.00', '', '0.00', 1382546287, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(62, 'N', 0, 1, NULL, 3, '504.98', '504.98', '0.00', '0.00', '0.00', '', '0.00', 1382680410, 'P', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 1, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(63, 'N', 0, 1, NULL, 3, '99.97', '99.97', '0.00', '0.00', '0.00', '', '0.00', 1382720383, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(64, 'N', 0, 1, NULL, 3, '2509.95', '2509.95', '0.00', '0.00', '0.00', '', '0.00', 1382794973, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 1, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(65, 'N', 0, 1, NULL, 3, '630.00', '630.00', '0.00', '0.00', '0.00', '', '0.00', 1382890766, 'F', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(66, 'N', 0, 1, NULL, 3, '5695.00', '5695.00', '0.00', '0.00', '0.00', '', '0.00', 1382992994, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 3, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(67, 'N', 0, 1, NULL, 3, '4595.00', '4595.00', '0.00', '0.00', '0.00', '', '0.00', 1383051922, 'C', '', '', 'a:0:{}', '', 'Oliver', 'Kahn', '', 'Oliver', 'Kahn', 'Bodestraße 1-3', '', 'Berlin', '', 'BER', 'DE', '10178', '+4930266424242', 'Oliver', 'Kahn', 'Bodestraße 1-3', '', 'Berlin', '', 'BER', 'DE', '10178', '+4930266424242', '', '+4930266424242', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(68, 'N', 0, 1, NULL, 3, '509.99', '509.99', '0.00', '0.00', '0.00', '', '0.00', 1383141667, 'B', '', '', 'a:0:{}', '', 'Oliver', 'Kahn', '', 'Oliver', 'Kahn', 'Bodestraße 1-3', '', 'Berlin', '', 'BER', 'DE', '10178', '+4930266424242', 'Oliver', 'Kahn', 'Bodestraße 1-3', '', 'Berlin', '', 'BER', 'DE', '10178', '+4930266424242', '', '+4930266424242', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(69, 'N', 0, 1, NULL, 3, '2349.97', '2349.97', '0.00', '0.00', '0.00', '', '0.00', 1383242472, 'C', '', '', 'a:0:{}', '', 'Oliver', 'Kahn', '', 'Oliver', 'Kahn', 'Bodestraße 1-3', '', 'Berlin', '', 'BER', 'DE', '10178', '+4930266424242', 'Oliver', 'Kahn', 'Bodestraße 1-3', '', 'Berlin', '', 'BER', 'DE', '10178', '+4930266424242', '', '+4930266424242', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(70, 'N', 0, 1, NULL, 3, '599.98', '599.98', '0.00', '0.00', '0.00', '', '0.00', 1383380053, 'C', '', '', 'a:0:{}', '', 'Oliver', 'Kahn', '', 'Oliver', 'Kahn', 'Bodestraße 1-3', '', 'Berlin', '', 'BER', 'DE', '10178', '+4930266424242', 'Oliver', 'Kahn', 'Bodestraße 1-3', '', 'Berlin', '', 'BER', 'DE', '10178', '+4930266424242', '', '+4930266424242', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(71, 'N', 0, 1, NULL, 3, '265.00', '265.00', '0.00', '0.00', '0.00', '', '0.00', 1383430639, 'P', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(72, 'N', 0, 1, NULL, 3, '115.00', '115.00', '0.00', '0.00', '0.00', '', '0.00', 1383529091, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(73, 'N', 0, 1, NULL, 3, '150.00', '150.00', '0.00', '0.00', '0.00', '', '0.00', 1383638802, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(74, 'N', 0, 1, NULL, 3, '286.44', '286.44', '0.00', '0.00', '0.00', '', '0.00', 1383685670, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 1, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(75, 'N', 0, 1, NULL, 3, '1599.80', '1599.80', '0.00', '0.00', '0.00', '', '0.00', 1383778149, 'I', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(76, 'N', 0, 1, NULL, 3, '3299.97', '3299.97', '0.00', '0.00', '0.00', '', '0.00', 1383870848, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(77, 'N', 0, 1, NULL, 3, '897.86', '897.86', '0.00', '0.00', '0.00', '', '0.00', 1383940992, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(78, 'N', 0, 1, NULL, 3, '1799.94', '1799.94', '0.00', '0.00', '0.00', '', '0.00', 1384065192, 'P', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 3, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(79, 'N', 0, 1, NULL, 3, '972.00', '972.00', '0.00', '0.00', '0.00', '', '0.00', 1384101839, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(80, 'N', 0, 1, NULL, 3, '998.00', '998.00', '0.00', '0.00', '0.00', '', '0.00', 1384223348, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(81, 'N', 0, 1, NULL, 3, '2994.86', '2994.86', '0.00', '0.00', '0.00', '', '0.00', 1384330152, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(82, 'N', 0, 1, NULL, 3, '749.95', '749.95', '0.00', '0.00', '0.00', '', '0.00', 1384411211, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(83, 'N', 0, 1, NULL, 3, '1048.99', '1048.99', '0.00', '0.00', '0.00', '', '0.00', 1384483388, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(84, 'N', 0, 1, NULL, 3, '3299.97', '3299.97', '0.00', '0.00', '0.00', '', '0.00', 1384527446, 'P', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(85, 'N', 0, 1, NULL, 3, '897.86', '897.86', '0.00', '0.00', '0.00', '', '0.00', 1384653017, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(86, 'N', 0, 1, NULL, 3, '1799.94', '1799.94', '0.00', '0.00', '0.00', '', '0.00', 1384707943, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 3, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(87, 'N', 0, 1, NULL, 3, '972.00', '972.00', '0.00', '0.00', '0.00', '', '0.00', 1384822028, 'D', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(89, 'N', 0, 1, NULL, 3, '2994.86', '2994.86', '0.00', '0.00', '0.00', '', '0.00', 1384931643, 'O', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(90, 'N', 0, 1, NULL, 3, '749.95', '749.95', '0.00', '0.00', '0.00', '', '0.00', 1384987673, 'I', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(91, 'N', 0, 1, NULL, 3, '1048.99', '1048.99', '0.00', '0.00', '0.00', '', '0.00', 1385076316, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(92, 'N', 0, 1, NULL, 3, '677.95', '649.95', '0.00', '0.00', '0.00', '1', '28.00', 1719988502, 'C', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 1, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(93, 'N', 0, 1, NULL, 3, '150.00', '150.00', '0.00', '0.00', '0.00', '', '0.00', 1719988902, 'O', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(94, 'N', 0, 1, NULL, 3, '297.00', '269.00', '0.00', '0.00', '0.00', '1', '28.00', 1719989902, 'C', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(95, 'N', 0, 1, NULL, 3, '1799.94', '1799.94', '0.00', '0.00', '0.00', '', '0.00', 1720074902, 'C', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 3, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(96, 'N', 0, 1, NULL, 3, '972.00', '972.00', '0.00', '0.00', '0.00', '', '0.00', 1720074902, 'P', '', '', 'a:0:{}', '', 'Customer', 'Customer', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '', '', '', '', '', 'customer@example.com', 2, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0),
(97, 'N', 0, 1, NULL, 3, '677.95', '649.95', '0.00', '0.00', '0.00', '1', '28.00', 1720074902, 'O', '', '', 'a:0:{}', '', 'George', 'Nills', '', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', 'George', 'Nills', '60 Centre Street #5', '', 'New York', '', 'NY', 'US', '01342', '+16463863600', '', '+16463863600', '', '', 'dsds@example.com', 1, 'N', 'en', '127.0.0.1', 0, '', 0, 2, 1, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_data`
--

CREATE TABLE `[[dbprefix]]order_data` (
  `order_data_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `order_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `type` char(1) NOT NULL DEFAULT '',
  `data` longblob NOT NULL,
  PRIMARY KEY (`order_data_id`),
  UNIQUE KEY `idx_order_id_type` (`order_id`,`type`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=242 ;

--
-- Dumping data for table `[[dbprefix]]order_data`
--

INSERT INTO `[[dbprefix]]order_data` VALUES
(1, 28, 'R', 's:3:"USD";'),
(2, 28, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(3, 29, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(4, 29, 'R', 's:3:"USD";'),
(5, 35, 'R', 's:3:"USD";'),
(6, 35, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(7, 36, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(8, 36, 'R', 's:3:"USD";'),
(9, 37, 'R', 's:3:"USD";'),
(10, 37, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(11, 38, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(12, 38, 'R', 's:3:"USD";'),
(13, 39, 'R', 's:3:"USD";'),
(14, 39, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(15, 40, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(16, 40, 'R', 's:3:"USD";'),
(17, 41, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(18, 41, 'R', 's:3:"USD";'),
(19, 42, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(20, 42, 'R', 's:3:"USD";'),
(21, 43, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(22, 43, 'R', 's:3:"USD";'),
(23, 44, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(24, 44, 'R', 's:3:"USD";'),
(25, 45, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(26, 45, 'R', 's:3:"USD";'),
(27, 46, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(28, 46, 'R', 's:3:"USD";'),
(29, 47, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(30, 47, 'R', 's:3:"USD";'),
(31, 48, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(32, 48, 'R', 's:3:"USD";'),
(33, 49, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(34, 49, 'R', 's:3:"USD";'),
(35, 50, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"54";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:0;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:100;a:4:{s:6:"amount";s:3:"100";s:5:"value";d:25.449999999999999;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449999999999999;s:10:"group_name";s:7:"CS-Cart";}}'),
(36, 50, 'R', 's:3:"USD";'),
(37, 51, 'R', 's:3:"USD";'),
(38, 51, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:14.359999999999999;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:11.81;s:1:"S";d:2.5499999999999998;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:1:{s:10:"3592732382";b:1;}}}}}'),
(39, 51, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(40, 52, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(41, 52, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:15.280000000000001;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:12.73;s:1:"S";d:2.5499999999999998;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:2:{s:9:"677409494";b:1;s:10:"4283906614";b:1;}}}}}'),
(42, 52, 'R', 's:3:"USD";'),
(43, 53, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:33;s:10:"group_name";s:7:"CS-Cart";}}'),
(44, 53, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:7.3600000000000003;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:4.3600000000000003;s:1:"S";d:3;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:1:{s:10:"2467687626";b:1;}}}}}'),
(45, 53, 'R', 's:3:"USD";'),
(46, 54, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:29.370000000000001;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:26.82;s:1:"S";d:2.5499999999999998;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:1:{s:10:"2703461960";b:1;}}}}}'),
(47, 54, 'R', 's:3:"USD";'),
(48, 54, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(49, 55, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(50, 55, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:99.819999999999993;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:97.269999999999996;s:1:"S";d:2.5499999999999998;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:2:{s:10:"3172189513";b:1;s:10:"1521215566";b:1;}}}}}'),
(51, 55, 'R', 's:3:"USD";'),
(52, 56, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(53, 56, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:27;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:24.449999999999999;s:1:"S";d:2.5499999999999998;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:1:{s:10:"3260818684";b:1;}}}}}'),
(54, 56, 'R', 's:3:"USD";'),
(55, 57, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:8.4600000000000009;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:2.73;s:1:"S";d:5.7300000000000004;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:1:{s:10:"2195660588";b:1;}}}}}'),
(56, 57, 'R', 's:3:"USD";'),
(57, 57, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:63;s:10:"group_name";s:7:"CS-Cart";}}'),
(58, 58, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(59, 58, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:520.27999999999997;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:517.73000000000002;s:1:"S";d:2.5499999999999998;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:1:{s:10:"4283388740";b:1;}}}}}'),
(60, 58, 'R', 's:3:"USD";'),
(61, 59, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:320.28000000000003;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:317.73000000000002;s:1:"S";d:2.5499999999999998;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:6:{s:10:"1159954462";b:1;s:10:"3308380389";b:1;s:10:"3260818684";b:1;s:10:"3042645098";b:1;s:10:"3421137111";b:1;s:10:"3994858278";b:1;}}}}}'),
(62, 59, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(63, 59, 'R', 's:3:"USD";'),
(64, 60, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(65, 60, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:61.640000000000001;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:59.090000000000003;s:1:"S";d:2.5499999999999998;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:1:{s:10:"4163016541";b:1;}}}}}'),
(66, 60, 'R', 's:3:"USD";'),
(67, 61, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(68, 61, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:43.640000000000001;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:43.640000000000001;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:9:"342509608";b:1;}}}}}'),
(69, 61, 'R', 's:3:"USD";'),
(70, 62, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(71, 62, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:45.909999999999997;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:45.909999999999997;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:3:{s:10:"3816757317";b:1;s:9:"169655664";b:1;s:10:"2054572543";b:1;}}}}}'),
(72, 62, 'R', 's:3:"USD";'),
(73, 63, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(74, 63, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:9.0899999999999999;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:9.0899999999999999;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:3:{s:10:"2660368260";b:1;s:10:"1770303465";b:1;s:10:"1860791280";b:1;}}}}}'),
(75, 63, 'R', 's:3:"USD";'),
(76, 64, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(77, 64, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:228.18000000000001;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:228.18000000000001;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:4:{s:10:"2628381300";b:1;s:10:"4065481614";b:1;s:10:"3849671376";b:1;i:47022039;b:1;}}}}}'),
(78, 64, 'R', 's:3:"USD";'),
(79, 65, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(80, 65, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:57.270000000000003;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:57.270000000000003;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:10:"3210050320";b:1;}}}}}'),
(81, 65, 'R', 's:3:"USD";'),
(82, 66, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(83, 66, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:517.73000000000002;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:517.73000000000002;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:10:"4283388740";b:1;}}}}}'),
(84, 66, 'R', 's:3:"USD";'),
(85, 67, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(86, 67, 'R', 's:3:"USD";'),
(87, 68, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(88, 68, 'R', 's:3:"USD";'),
(89, 69, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(90, 69, 'R', 's:3:"USD";'),
(91, 70, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(92, 70, 'R', 's:3:"USD";'),
(93, 71, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(94, 71, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:24.09;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:24.09;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:3:{s:10:"4283906614";b:1;s:9:"822274303";b:1;s:9:"677409494";b:1;}}}}}'),
(95, 71, 'R', 's:3:"USD";'),
(96, 72, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(97, 72, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:10.449999999999999;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:10.449999999999999;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:3:{s:10:"4283906614";b:1;s:9:"822274303";b:1;s:9:"677409494";b:1;}}}}}'),
(98, 72, 'R', 's:3:"USD";'),
(99, 73, 'R', 's:3:"USD";'),
(100, 73, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(101, 73, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:13.640000000000001;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:13.640000000000001;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:10:"3636250333";b:1;}}}}}'),
(102, 74, 'R', 's:3:"USD";'),
(103, 74, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(104, 74, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:26.039999999999999;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:26.039999999999999;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:13:{s:10:"2338935559";b:1;s:10:"4235092881";b:1;s:10:"1825668608";b:1;s:10:"1446436389";b:1;s:9:"556920499";b:1;s:10:"3477049247";b:1;s:10:"3090726665";b:1;s:10:"2243091253";b:1;s:9:"482052751";b:1;s:9:"467029654";b:1;s:10:"2195660588";b:1;s:9:"643574442";b:1;s:10:"4124585914";b:1;}}}}}');
INSERT INTO `[[dbprefix]]order_data` VALUES
(105, 75, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(106, 75, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:145.44;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:145.44;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:10:"2836788418";b:1;}}}}}'),
(107, 75, 'R', 's:3:"USD";'),
(108, 76, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(109, 76, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:300;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:300;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:9:"319261745";b:1;}}}}}'),
(110, 76, 'R', 's:3:"USD";'),
(111, 77, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(112, 77, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:81.620000000000005;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:81.620000000000005;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:4:{s:10:"2583444381";b:1;s:10:"3390371295";b:1;s:10:"1394451557";b:1;s:10:"1416650876";b:1;}}}}}'),
(113, 77, 'R', 's:3:"USD";'),
(114, 78, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(115, 78, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:163.63;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:163.63;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:2:{s:10:"4072008611";b:1;s:10:"3961824982";b:1;}}}}}'),
(116, 78, 'R', 's:3:"USD";'),
(117, 79, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(118, 79, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:88.359999999999999;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:88.359999999999999;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:10:"1061624811";b:1;}}}}}'),
(119, 79, 'R', 's:3:"USD";'),
(120, 80, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(121, 80, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:90.730000000000004;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:90.730000000000004;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:10:"3125424156";b:1;}}}}}'),
(122, 80, 'R', 's:3:"USD";'),
(123, 81, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(124, 81, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:272.25999999999999;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:272.25999999999999;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:6:{s:10:"1792750741";b:1;s:10:"2473281379";b:1;s:10:"2366072709";b:1;s:10:"4033496702";b:1;s:10:"3864289797";b:1;s:10:"3947455183";b:1;}}}}}'),
(125, 81, 'R', 's:3:"USD";'),
(126, 82, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:68.180000000000007;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:68.180000000000007;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:10:"1364924988";b:1;}}}}}'),
(127, 82, 'R', 's:3:"USD";'),
(128, 82, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(129, 83, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(130, 83, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:95.359999999999999;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:95.359999999999999;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:2:{s:9:"500958211";b:1;s:10:"2372082066";b:1;}}}}}'),
(131, 83, 'R', 's:3:"USD";'),
(132, 84, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(133, 84, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:300;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:300;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:9:"319261745";b:1;}}}}}'),
(134, 84, 'R', 's:3:"USD";'),
(135, 85, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(136, 85, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:81.620000000000005;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:81.620000000000005;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:4:{s:10:"2583444381";b:1;s:10:"3390371295";b:1;s:10:"1394451557";b:1;s:10:"1416650876";b:1;}}}}}'),
(137, 85, 'R', 's:3:"USD";'),
(138, 86, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(139, 86, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:163.63;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:163.63;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:2:{s:10:"4072008611";b:1;s:10:"3961824982";b:1;}}}}}'),
(140, 86, 'R', 's:3:"USD";'),
(141, 87, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(142, 87, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:88.359999999999999;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:88.359999999999999;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:10:"1061624811";b:1;}}}}}'),
(143, 87, 'R', 's:3:"USD";'),
(144, 89, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(145, 89, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:272.25999999999999;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:272.25999999999999;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:6:{s:10:"1792750741";b:1;s:10:"2473281379";b:1;s:10:"2366072709";b:1;s:10:"4033496702";b:1;s:10:"3864289797";b:1;s:10:"3947455183";b:1;}}}}}'),
(146, 89, 'R', 's:3:"USD";'),
(147, 90, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:68.180000000000007;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:68.180000000000007;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:10:"1364924988";b:1;}}}}}'),
(148, 90, 'R', 's:3:"USD";'),
(149, 90, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(150, 91, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(151, 91, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:95.359999999999999;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:95.359999999999999;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:2:{s:9:"500958211";b:1;s:10:"2372082066";b:1;}}}}}'),
(152, 91, 'R', 's:3:"USD";'),
(153, 92, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(154, 92, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:61.640000000000001;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:59.090000000000003;s:1:"S";d:2.5499999999999998;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:1:{s:10:"4163016541";b:1;}}}}}'),
(155, 92, 'R', 's:3:"USD";'),
(156, 93, 'R', 's:3:"USD";'),
(157, 93, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(158, 93, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:13.640000000000001;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:13.640000000000001;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:10:"3636250333";b:1;}}}}}'),
(159, 94, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(160, 94, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:27;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:24.449999999999999;s:1:"S";d:2.5499999999999998;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:1:{s:10:"3260818684";b:1;}}}}}'),
(161, 94, 'R', 's:3:"USD";'),
(162, 95, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(163, 95, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:163.63;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:163.63;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:2:{s:10:"4072008611";b:1;s:10:"3961824982";b:1;}}}}}'),
(164, 95, 'R', 's:3:"USD";'),
(165, 96, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(166, 96, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:88.359999999999999;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:88.359999999999999;s:1:"S";i:0;s:5:"items";a:2:{s:1:"S";a:0:{}s:1:"P";a:1:{s:10:"1061624811";b:1;}}}}}'),
(167, 96, 'R', 's:3:"USD";'),
(168, 97, 'L', 'a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"55";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:40;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:30;a:4:{s:6:"amount";s:2:"30";s:5:"value";d:10;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:50;a:4:{s:6:"amount";s:2:"50";s:5:"value";d:5;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}s:1:"I";a:2:{i:0;a:4:{s:6:"amount";s:1:"0";s:5:"value";d:23;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}i:10;a:4:{s:6:"amount";s:2:"10";s:5:"value";d:15;s:4:"type";s:1:"F";s:8:"per_unit";s:1:"N";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}'),
(169, 97, 'T', 'a:1:{i:6;a:8:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:6:"10.000";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:61.640000000000001;s:11:"description";s:3:"VAT";s:7:"applies";a:3:{s:1:"P";d:59.090000000000003;s:1:"S";d:2.5499999999999998;s:5:"items";a:2:{s:1:"S";a:1:{i:0;a:1:{i:1;b:1;}}s:1:"P";a:1:{s:10:"4163016541";b:1;}}}}}'),
(170, 97, 'R', 's:3:"USD";'),
(171, 50, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"3994858278";a:23:{s:10:"product_id";i:60;s:12:"product_code";s:10:"O0060X7Y9Y";s:7:"product";s:11:"AVIC-Z130BT";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:1499;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"328";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"384";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:63:"http://localhost/git/work/images/detailed/0/AVIC-Z130BT_reg.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:63:"http://localhost/git/work/images/detailed/0/AVIC-Z130BT_reg.jpg";s:13:"absolute_path";s:66:"/Users/alexions/www/git/work/images/detailed/0/AVIC-Z130BT_reg.jpg";s:13:"relative_path";s:30:"detailed/0/AVIC-Z130BT_reg.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3994858278";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"AVIC-Z130BT";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1499;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:1499;s:13:"display_price";d:1499;}}s:12:"package_info";a:7:{s:1:"C";d:1499;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"3994858278";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:1499;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Sergey";s:8:"lastname";s:6:"Maxeev";s:7:"address";s:25:"Moskovskaya street, 65-12";s:9:"address_2";N;s:4:"city";s:6:"Moscow";s:6:"county";N;s:5:"state";s:3:"MOS";s:7:"country";s:2:"RU";s:7:"zipcode";s:6:"657849";s:5:"phone";s:12:"+79235456683";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:18:"Russian Federation";s:11:"state_descr";s:19:"Moskovskaja oblast''";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(172, 51, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"3592732382";a:23:{s:10:"product_id";i:212;s:12:"product_code";s:10:"P0212CTOEA";s:7:"product";s:53:"Panasonic KX-MB2000 24PPM 3-in-1 Monochrome Laser MFP";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:129.949;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"705";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"761";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:84:"http://localhost/git/work/images/detailed/0/0120b3d3-82ef-4d27-8d43-9d75b4db19a1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"700";s:7:"image_y";s:3:"525";s:15:"http_image_path";s:84:"http://localhost/git/work/images/detailed/0/0120b3d3-82ef-4d27-8d43-9d75b4db19a1.jpg";s:13:"absolute_path";s:87:"/Users/alexions/www/git/work/images/detailed/0/0120b3d3-82ef-4d27-8d43-9d75b4db19a1.jpg";s:13:"relative_path";s:51:"detailed/0/0120b3d3-82ef-4d27-8d43-9d75b4db19a1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3592732382";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:53:"Panasonic KX-MB2000 24PPM 3-in-1 Monochrome Laser MFP";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:129.949;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:129.949;s:13:"display_price";d:129.949;}}s:12:"package_info";a:7:{s:1:"C";d:129.949;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"3592732382";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:129.949;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(173, 52, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:3:{s:9:"822274303";a:23:{s:10:"product_id";i:12;s:12:"product_code";s:10:"U0012O5AF0";s:7:"product";s:10:"100g Pants";s:6:"amount";i:1;s:15:"product_options";a:2:{i:9;s:2:"17";i:2;s:1:"6";}s:5:"price";d:30;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"808";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"864";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/173283_01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/173283_01.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/173283_01.jpg";s:13:"relative_path";s:24:"detailed/0/173283_01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"822274303";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:2:{i:9;s:2:"17";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:10:"100g Pants";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"9";s:10:"product_id";s:2:"12";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"17";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:17:"Black/White/White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:2:"12";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:30;s:13:"display_price";d:30;}s:9:"677409494";a:23:{s:10:"product_id";i:11;s:12:"product_code";s:10:"Z0011CZSNI";s:7:"product";s:17:"Collegiate 72 Tee";s:6:"amount";i:1;s:15:"product_options";a:2:{i:1;s:1:"1";i:2;s:1:"6";}s:5:"price";d:30;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"210";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"266";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/X32444_01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"2000";s:7:"image_y";s:4:"2000";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/X32444_01.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/X32444_01.jpg";s:13:"relative_path";s:24:"detailed/0/X32444_01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"677409494";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:2:{i:1;s:1:"1";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:17:"Collegiate 72 Tee";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"1";s:10:"product_id";s:2:"11";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:1:"1";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:2:"11";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:30;s:13:"display_price";d:30;}s:10:"4283906614";a:23:{s:10:"product_id";i:7;s:12:"product_code";s:10:"A0007DQ1TL";s:7:"product";s:14:"Trefoil Hoodie";s:6:"amount";i:2;s:15:"product_options";a:2:{i:10;s:2:"36";i:2;s:1:"6";}s:5:"price";d:55;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"827";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"883";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/X41181_01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"2400";s:7:"image_y";s:4:"2400";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/X41181_01.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/X41181_01.jpg";s:13:"relative_path";s:24:"detailed/0/X41181_01.jpg";}}s:15:"original_amount";s:1:"2";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4283906614";s:6:"amount";s:1:"2";}s:5:"extra";a:10:{s:15:"product_options";a:2:{i:10;s:2:"36";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:14:"Trefoil Hoodie";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:55;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:2:"10";s:10:"product_id";s:1:"7";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"36";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:23:"GreyHeather/Core Energy";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"7";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:2;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:55;s:13:"display_price";d:55;}}s:12:"package_info";a:7:{s:1:"C";d:170;s:1:"W";s:4:"0.01";s:1:"I";i:4;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:3:{s:9:"822274303";i:1;s:9:"677409494";i:1;s:10:"4283906614";i:2;}s:6:"amount";i:4;s:6:"weight";d:0.100;s:4:"cost";i:170;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}');
INSERT INTO `[[dbprefix]]order_data` VALUES
(174, 53, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2467687626";a:23:{s:10:"product_id";i:233;s:12:"product_code";s:10:"H023315I7E";s:7:"product";s:38:"Crystal Lake Warm Weather Sleeping Bag";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:47.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"791";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"847";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/2000004455_500.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/2000004455_500.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/2000004455_500.jpg";s:13:"relative_path";s:29:"detailed/0/2000004455_500.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2467687626";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:38:"Crystal Lake Warm Weather Sleeping Bag";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:47.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:47.990;s:13:"display_price";d:47.990;}}s:12:"package_info";a:7:{s:1:"C";d:47.990;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2467687626";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:47.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:33;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:3;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:33;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(175, 54, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2703461960";a:23:{s:10:"product_id";i:213;s:12:"product_code";s:10:"R0213E2U6B";s:7:"product";s:37:"Intel® Boxed Intel® Core™ i7-2600";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:295;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"708";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"764";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/imageservice.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1732";s:7:"image_y";s:4:"2182";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/imageservice.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/imageservice.jpg";s:13:"relative_path";s:27:"detailed/0/imageservice.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2703461960";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:37:"Intel® Boxed Intel® Core™ i7-2600";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:295;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:295;s:13:"display_price";d:295;}}s:12:"package_info";a:7:{s:1:"C";d:295;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2703461960";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:295;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(176, 55, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:2:{s:10:"3172189513";a:23:{s:10:"product_id";i:107;s:12:"product_code";s:10:"F01072HXUI";s:7:"product";s:39:"Montblanc Classic Collection Money Clip";s:6:"amount";i:2;s:15:"product_options";a:0:{}s:5:"price";d:465;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"451";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"507";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/03804_l.ashx.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/03804_l.ashx.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/03804_l.ashx.jpg";s:13:"relative_path";s:27:"detailed/0/03804_l.ashx.jpg";}}s:15:"original_amount";s:1:"2";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3172189513";s:6:"amount";s:1:"2";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:39:"Montblanc Classic Collection Money Clip";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:465;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:2;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:465;s:13:"display_price";d:465;}s:10:"1521215566";a:23:{s:10:"product_id";i:109;s:12:"product_code";s:10:"C01099FRFC";s:7:"product";s:64:"Montblanc Contemporary Collection Key Ring with Montblanc emblem";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:140;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"453";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"509";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:61:"http://localhost/git/work/images/detailed/0/101796_l.ashx.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:61:"http://localhost/git/work/images/detailed/0/101796_l.ashx.jpg";s:13:"absolute_path";s:64:"/Users/alexions/www/git/work/images/detailed/0/101796_l.ashx.jpg";s:13:"relative_path";s:28:"detailed/0/101796_l.ashx.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1521215566";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:64:"Montblanc Contemporary Collection Key Ring with Montblanc emblem";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:140;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:140;s:13:"display_price";d:140;}}s:12:"package_info";a:7:{s:1:"C";d:1070;s:1:"W";s:4:"0.01";s:1:"I";i:3;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:2:{s:10:"3172189513";i:2;s:10:"1521215566";i:1;}s:6:"amount";i:3;s:6:"weight";d:0.100;s:4:"cost";i:1070;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(177, 56, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"3260818684";a:23:{s:10:"product_id";i:54;s:12:"product_code";s:10:"I0054QMMPO";s:7:"product";s:13:"TS-W3002D2|D4";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:269;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"307";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"363";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:66:"http://localhost/git/work/images/detailed/0/TS-W3002D2D4_large.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1024";s:7:"image_y";s:4:"1024";s:15:"http_image_path";s:66:"http://localhost/git/work/images/detailed/0/TS-W3002D2D4_large.jpg";s:13:"absolute_path";s:69:"/Users/alexions/www/git/work/images/detailed/0/TS-W3002D2D4_large.jpg";s:13:"relative_path";s:33:"detailed/0/TS-W3002D2D4_large.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3260818684";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:13:"TS-W3002D2|D4";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:269;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:269;s:13:"display_price";d:269;}}s:12:"package_info";a:7:{s:1:"C";d:269;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"3260818684";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:269;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(178, 57, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2195660588";a:23:{s:10:"product_id";i:195;s:12:"product_code";s:10:"I0195ZFDB8";s:7:"product";s:38:"Crossroads Guitar Festival 2010 (2DVD)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:29.989;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"672";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"728";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:66:"http://localhost/git/work/images/detailed/0/603497948727.sml_0.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:66:"http://localhost/git/work/images/detailed/0/603497948727.sml_0.jpg";s:13:"absolute_path";s:69:"/Users/alexions/www/git/work/images/detailed/0/603497948727.sml_0.jpg";s:13:"relative_path";s:33:"detailed/0/603497948727.sml_0.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2195660588";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:38:"Crossroads Guitar Festival 2010 (2DVD)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:29.989;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:29.989;s:13:"display_price";d:29.989;}}s:12:"package_info";a:7:{s:1:"C";d:29.989;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2195660588";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:29.989;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:63;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:5.730;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:63;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(179, 58, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"4283388740";a:23:{s:10:"product_id";i:122;s:12:"product_code";s:10:"J01223DYAH";s:7:"product";s:40:"Evolution SST.2 XO Complete Bike 10SPD12";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:5695;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"477";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"533";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/CB-evolution.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"936";s:7:"image_y";s:3:"612";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/CB-evolution.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/CB-evolution.jpg";s:13:"relative_path";s:27:"detailed/0/CB-evolution.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4283388740";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:40:"Evolution SST.2 XO Complete Bike 10SPD12";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:5695;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:5695;s:13:"display_price";d:5695;}}s:12:"package_info";a:7:{s:1:"C";d:5695;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"4283388740";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:5695;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(180, 60, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"4163016541";a:23:{s:10:"product_id";i:126;s:12:"product_code";s:10:"F01262AH0T";s:7:"product";s:19:"Casio PRIZM fx-CG10";s:6:"amount";i:5;s:15:"product_options";a:0:{}s:5:"price";d:129.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"486";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"542";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"529";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:13:"relative_path";s:29:"detailed/0/fx-cg10_xlarge.jpg";}}s:15:"original_amount";s:1:"5";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4163016541";s:6:"amount";s:1:"5";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:19:"Casio PRIZM fx-CG10";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:129.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:5;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:129.990;s:13:"display_price";d:129.990;}}s:12:"package_info";a:7:{s:1:"C";d:649.950;s:1:"W";s:4:"0.01";s:1:"I";i:5;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"4163016541";i:5;}s:6:"amount";i:5;s:6:"weight";d:0.100;s:4:"cost";d:649.950;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(181, 62, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:3:{s:9:"169655664";a:23:{s:10:"product_id";i:230;s:12:"product_code";s:10:"B0230S7Q0V";s:7:"product";s:13:"2011 Pit Boss";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:125;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"783";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"839";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:89:"http://localhost/git/work/images/detailed/0/url_uploaded_file_13287871234f33aeb3d0793.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:89:"http://localhost/git/work/images/detailed/0/url_uploaded_file_13287871234f33aeb3d0793.jpg";s:13:"absolute_path";s:92:"/Users/alexions/www/git/work/images/detailed/0/url_uploaded_file_13287871234f33aeb3d0793.jpg";s:13:"relative_path";s:56:"detailed/0/url_uploaded_file_13287871234f33aeb3d0793.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"169655664";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:13:"2011 Pit Boss";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:125;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:125;s:13:"display_price";d:125;}s:10:"2054572543";a:23:{s:10:"product_id";i:235;s:12:"product_code";s:10:"N02351Q6BY";s:7:"product";s:36:"Everglades Cold Weather Sleeping Bag";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:79.989;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"793";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"849";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/2000004467_500.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/2000004467_500.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/2000004467_500.jpg";s:13:"relative_path";s:29:"detailed/0/2000004467_500.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2054572543";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"Everglades Cold Weather Sleeping Bag";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:79.989;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:79.989;s:13:"display_price";d:79.989;}s:10:"3816757317";a:23:{s:10:"product_id";i:236;s:12:"product_code";s:10:"A0236BQ31M";s:7:"product";s:46:"WeatherMaster Screened 6 Tent With Hinged Door";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:299.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"794";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"850";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/2000001597_500.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/2000001597_500.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/2000001597_500.jpg";s:13:"relative_path";s:29:"detailed/0/2000001597_500.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3816757317";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:46:"WeatherMaster Screened 6 Tent With Hinged Door";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:299.990;s:13:"display_price";d:299.990;}}s:12:"package_info";a:7:{s:1:"C";d:504.980;s:1:"W";s:4:"0.01";s:1:"I";i:3;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:3:{s:9:"169655664";i:1;s:10:"2054572543";i:1;s:10:"3816757317";i:1;}s:6:"amount";i:3;s:6:"weight";d:0.100;s:4:"cost";d:504.980;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(182, 64, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:4:{s:10:"4065481614";a:23:{s:10:"product_id";i:177;s:12:"product_code";s:10:"J0177S9SI3";s:7:"product";s:15:"CG BLACK DRIVER";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:400;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"641";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"697";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:59:"http://localhost/git/work/images/detailed/0/blkdrv_hero.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"800";s:7:"image_y";s:3:"800";s:15:"http_image_path";s:59:"http://localhost/git/work/images/detailed/0/blkdrv_hero.jpg";s:13:"absolute_path";s:62:"/Users/alexions/www/git/work/images/detailed/0/blkdrv_hero.jpg";s:13:"relative_path";s:26:"detailed/0/blkdrv_hero.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4065481614";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:15:"CG BLACK DRIVER";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:400;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:400;s:13:"display_price";d:400;}i:47022039;a:23:{s:10:"product_id";i:186;s:12:"product_code";s:10:"N01868E9SB";s:7:"product";s:18:"CG Black Staff Bag";s:6:"amount";i:4;s:15:"product_options";a:0:{}s:5:"price";d:299.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"661";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"717";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:80:"http://localhost/git/work/images/detailed/0/8ad650de56e5e2272b240d3a6c171545.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"800";s:7:"image_y";s:3:"800";s:15:"http_image_path";s:80:"http://localhost/git/work/images/detailed/0/8ad650de56e5e2272b240d3a6c171545.jpg";s:13:"absolute_path";s:83:"/Users/alexions/www/git/work/images/detailed/0/8ad650de56e5e2272b240d3a6c171545.jpg";s:13:"relative_path";s:47:"detailed/0/8ad650de56e5e2272b240d3a6c171545.jpg";}}s:15:"original_amount";s:1:"4";s:21:"original_product_data";a:2:{s:7:"cart_id";i:47022039;s:6:"amount";s:1:"4";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:18:"CG Black Staff Bag";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:4;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:299.990;s:13:"display_price";d:299.990;}s:10:"3849671376";a:23:{s:10:"product_id";i:188;s:12:"product_code";s:10:"M0188MVCYL";s:7:"product";s:45:"NEW Wilson Staff Fifty Elite Yellow Golf Ball";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:10;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"663";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"719";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:76:"http://localhost/git/work/images/detailed/0/50Elite_Yellow_12ball_Render.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:76:"http://localhost/git/work/images/detailed/0/50Elite_Yellow_12ball_Render.jpg";s:13:"absolute_path";s:79:"/Users/alexions/www/git/work/images/detailed/0/50Elite_Yellow_12ball_Render.jpg";s:13:"relative_path";s:43:"detailed/0/50Elite_Yellow_12ball_Render.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3849671376";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"NEW Wilson Staff Fifty Elite Yellow Golf Ball";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:10;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:10;s:13:"display_price";d:10;}s:10:"2628381300";a:23:{s:10:"product_id";i:181;s:12:"product_code";s:10:"A0181ZSJSS";s:7:"product";s:26:"Women''s Bloom Complete Set";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:899.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"651";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"707";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:64:"http://localhost/git/work/images/detailed/0/bloom_berry_set1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"800";s:7:"image_y";s:3:"800";s:15:"http_image_path";s:64:"http://localhost/git/work/images/detailed/0/bloom_berry_set1.jpg";s:13:"absolute_path";s:67:"/Users/alexions/www/git/work/images/detailed/0/bloom_berry_set1.jpg";s:13:"relative_path";s:31:"detailed/0/bloom_berry_set1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2628381300";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:26:"Women''s Bloom Complete Set";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:899.990;s:13:"display_price";d:899.990;}}s:12:"package_info";a:7:{s:1:"C";d:2509.949;s:1:"W";s:4:"0.01";s:1:"I";i:7;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:4:{s:10:"4065481614";i:1;i:47022039;i:4;s:10:"3849671376";i:1;s:10:"2628381300";i:1;}s:6:"amount";i:7;s:6:"weight";d:0.100;s:4:"cost";d:2509.949;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}');
INSERT INTO `[[dbprefix]]order_data` VALUES
(183, 70, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2490902739";a:23:{s:10:"product_id";i:237;s:12:"product_code";s:10:"B0237HI9M0";s:7:"product";s:21:"Elite Evanston 8 Tent";s:6:"amount";i:2;s:15:"product_options";a:0:{}s:5:"price";d:299.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"795";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"851";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/2000004674_500.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/2000004674_500.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/2000004674_500.jpg";s:13:"relative_path";s:29:"detailed/0/2000004674_500.jpg";}}s:15:"original_amount";s:1:"2";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2490902739";s:6:"amount";s:1:"2";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Elite Evanston 8 Tent";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:2;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:299.990;s:13:"display_price";d:299.990;}}s:12:"package_info";a:7:{s:1:"C";d:599.980;s:1:"W";s:4:"0.01";s:1:"I";i:2;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2490902739";i:2;}s:6:"amount";i:2;s:6:"weight";d:0.100;s:4:"cost";d:599.980;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Oliver";s:8:"lastname";s:4:"Kahn";s:7:"address";s:15:"Bodestraße 1-3";s:9:"address_2";N;s:4:"city";s:6:"Berlin";s:6:"county";N;s:5:"state";s:3:"BER";s:7:"country";s:2:"DE";s:7:"zipcode";s:5:"10178";s:5:"phone";s:14:"+4930266424242";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:7:"Germany";s:11:"state_descr";s:6:"Berlin";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(184, 71, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:4:{s:9:"822274303";a:23:{s:10:"product_id";i:12;s:12:"product_code";s:10:"U0012O5AF0";s:7:"product";s:10:"100g Pants";s:6:"amount";i:1;s:15:"product_options";a:2:{i:9;s:2:"17";i:2;s:1:"6";}s:5:"price";d:30;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"808";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"864";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/173283_01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/173283_01.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/173283_01.jpg";s:13:"relative_path";s:24:"detailed/0/173283_01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"822274303";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:2:{i:9;s:2:"17";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:10:"100g Pants";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"9";s:10:"product_id";s:2:"12";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"17";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:17:"Black/White/White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:2:"12";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:30;s:13:"display_price";d:30;}s:9:"677409494";a:23:{s:10:"product_id";i:11;s:12:"product_code";s:10:"Z0011CZSNI";s:7:"product";s:17:"Collegiate 72 Tee";s:6:"amount";i:1;s:15:"product_options";a:2:{i:1;s:1:"1";i:2;s:1:"6";}s:5:"price";d:30;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"210";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"266";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/X32444_01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"2000";s:7:"image_y";s:4:"2000";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/X32444_01.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/X32444_01.jpg";s:13:"relative_path";s:24:"detailed/0/X32444_01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"677409494";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:2:{i:1;s:1:"1";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:17:"Collegiate 72 Tee";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"1";s:10:"product_id";s:2:"11";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:1:"1";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:2:"11";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:30;s:13:"display_price";d:30;}s:10:"3636250333";a:23:{s:10:"product_id";i:15;s:12:"product_code";s:10:"H0015EXYM6";s:7:"product";s:39:"Nike Chambray Super Runner Men''s Jacket";s:6:"amount";i:1;s:15:"product_options";a:1:{i:2;s:1:"6";}s:5:"price";d:150;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"224";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"280";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/452499_010_A.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"900";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/452499_010_A.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/452499_010_A.jpg";s:13:"relative_path";s:27:"detailed/0/452499_010_A.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3636250333";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:1:{i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:39:"Nike Chambray Super Runner Men''s Jacket";s:10:"company_id";s:1:"2";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:150;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:1:{i:0;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:2:"15";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:150;s:13:"display_price";d:150;}s:10:"4283906614";a:23:{s:10:"product_id";i:7;s:12:"product_code";s:10:"A0007DQ1TL";s:7:"product";s:14:"Trefoil Hoodie";s:6:"amount";i:1;s:15:"product_options";a:2:{i:10;s:2:"36";i:2;s:1:"6";}s:5:"price";d:55;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"827";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"883";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/X41181_01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"2400";s:7:"image_y";s:4:"2400";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/X41181_01.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/X41181_01.jpg";s:13:"relative_path";s:24:"detailed/0/X41181_01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4283906614";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:2:{i:10;s:2:"36";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:14:"Trefoil Hoodie";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:55;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:2:"10";s:10:"product_id";s:1:"7";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"36";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:23:"GreyHeather/Core Energy";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"7";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:55;s:13:"display_price";d:55;}}s:12:"package_info";a:7:{s:1:"C";d:265;s:1:"W";s:4:"0.01";s:1:"I";i:4;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:4:{s:9:"822274303";i:1;s:9:"677409494";i:1;s:10:"3636250333";i:1;s:10:"4283906614";i:1;}s:6:"amount";i:4;s:6:"weight";d:0.100;s:4:"cost";i:265;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(185, 72, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:3:{s:9:"822274303";a:23:{s:10:"product_id";i:12;s:12:"product_code";s:10:"U0012O5AF0";s:7:"product";s:10:"100g Pants";s:6:"amount";i:1;s:15:"product_options";a:2:{i:9;s:2:"17";i:2;s:1:"6";}s:5:"price";d:30;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"808";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"864";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/173283_01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/173283_01.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/173283_01.jpg";s:13:"relative_path";s:24:"detailed/0/173283_01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"822274303";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:2:{i:9;s:2:"17";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:10:"100g Pants";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"9";s:10:"product_id";s:2:"12";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"17";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:17:"Black/White/White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:2:"12";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:30;s:13:"display_price";d:30;}s:9:"677409494";a:23:{s:10:"product_id";i:11;s:12:"product_code";s:10:"Z0011CZSNI";s:7:"product";s:17:"Collegiate 72 Tee";s:6:"amount";i:1;s:15:"product_options";a:2:{i:1;s:1:"1";i:2;s:1:"6";}s:5:"price";d:30;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"210";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"266";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/X32444_01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"2000";s:7:"image_y";s:4:"2000";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/X32444_01.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/X32444_01.jpg";s:13:"relative_path";s:24:"detailed/0/X32444_01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"677409494";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:2:{i:1;s:1:"1";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:17:"Collegiate 72 Tee";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"1";s:10:"product_id";s:2:"11";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:1:"1";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:2:"11";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:30;s:13:"display_price";d:30;}s:10:"4283906614";a:23:{s:10:"product_id";i:7;s:12:"product_code";s:10:"A0007DQ1TL";s:7:"product";s:14:"Trefoil Hoodie";s:6:"amount";i:1;s:15:"product_options";a:2:{i:10;s:2:"36";i:2;s:1:"6";}s:5:"price";d:55;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"827";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"883";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/X41181_01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"2400";s:7:"image_y";s:4:"2400";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/X41181_01.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/X41181_01.jpg";s:13:"relative_path";s:24:"detailed/0/X41181_01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4283906614";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:2:{i:10;s:2:"36";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:14:"Trefoil Hoodie";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:55;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:2:"10";s:10:"product_id";s:1:"7";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"36";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:23:"GreyHeather/Core Energy";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"7";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:55;s:13:"display_price";d:55;}}s:12:"package_info";a:7:{s:1:"C";d:115;s:1:"W";s:4:"0.01";s:1:"I";i:3;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:3:{s:9:"822274303";i:1;s:9:"677409494";i:1;s:10:"4283906614";i:1;}s:6:"amount";i:3;s:6:"weight";d:0.100;s:4:"cost";i:115;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}');
INSERT INTO `[[dbprefix]]order_data` VALUES
(186, 74, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:13:{s:10:"2338935559";a:23:{s:10:"product_id";i:199;s:12:"product_code";s:10:"Y0199F6AC6";s:7:"product";s:37:"B.B. King - Original Greatest Hits CD";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:29.98;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"677";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"733";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:66:"http://localhost/git/work/images/detailed/0/bbk_originalhitscd.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:66:"http://localhost/git/work/images/detailed/0/bbk_originalhitscd.jpg";s:13:"absolute_path";s:69:"/Users/alexions/www/git/work/images/detailed/0/bbk_originalhitscd.jpg";s:13:"relative_path";s:33:"detailed/0/bbk_originalhitscd.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2338935559";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:37:"B.B. King - Original Greatest Hits CD";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:29.98;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:29.98;s:13:"display_price";d:29.98;}s:10:"4235092881";a:23:{s:10:"product_id";i:198;s:12:"product_code";s:10:"K01984N7PI";s:7:"product";s:124:"B.B. King One Kind Favor CD Grammy Award Winning CD Manufacturer: Geffen Records Sku: BBK-11ONEKINDFAVORCD  Reviewed 2 times";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:17.989;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"676";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"732";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:74:"http://localhost/git/work/images/detailed/0/bbk_onekindfavorcdcover_sm.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:74:"http://localhost/git/work/images/detailed/0/bbk_onekindfavorcdcover_sm.jpg";s:13:"absolute_path";s:77:"/Users/alexions/www/git/work/images/detailed/0/bbk_onekindfavorcdcover_sm.jpg";s:13:"relative_path";s:41:"detailed/0/bbk_onekindfavorcdcover_sm.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4235092881";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:124:"B.B. King One Kind Favor CD Grammy Award Winning CD Manufacturer: Geffen Records Sku: BBK-11ONEKINDFAVORCD  Reviewed 2 times";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:17.989;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:17.989;s:13:"display_price";d:17.989;}s:10:"1446436389";a:23:{s:10:"product_id";i:201;s:12:"product_code";s:10:"V02011EWI8";s:7:"product";s:36:"Beethoven Piano Concertos Nos. 1 & 2";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:12.67;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"679";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"735";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:89:"http://localhost/git/work/images/detailed/0/url_uploaded_file_13287720374f3373c6eef1f.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:89:"http://localhost/git/work/images/detailed/0/url_uploaded_file_13287720374f3373c6eef1f.jpg";s:13:"absolute_path";s:92:"/Users/alexions/www/git/work/images/detailed/0/url_uploaded_file_13287720374f3373c6eef1f.jpg";s:13:"relative_path";s:56:"detailed/0/url_uploaded_file_13287720374f3373c6eef1f.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1446436389";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"Beethoven Piano Concertos Nos. 1 & 2";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:12.67;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:12.67;s:13:"display_price";d:12.67;}s:9:"482052751";a:23:{s:10:"product_id";i:192;s:12:"product_code";s:10:"E01923M6DA";s:7:"product";s:33:"Black and White America (CD Pack)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:15;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"669";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"725";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:59:"http://localhost/git/work/images/detailed/0/lenny_cover.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:59:"http://localhost/git/work/images/detailed/0/lenny_cover.jpg";s:13:"absolute_path";s:62:"/Users/alexions/www/git/work/images/detailed/0/lenny_cover.jpg";s:13:"relative_path";s:26:"detailed/0/lenny_cover.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"482052751";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:33:"Black and White America (CD Pack)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:15;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:15;s:13:"display_price";d:15;}s:10:"2195660588";a:23:{s:10:"product_id";i:195;s:12:"product_code";s:10:"I0195ZFDB8";s:7:"product";s:38:"Crossroads Guitar Festival 2010 (2DVD)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:29.989;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"672";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"728";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:66:"http://localhost/git/work/images/detailed/0/603497948727.sml_0.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:66:"http://localhost/git/work/images/detailed/0/603497948727.sml_0.jpg";s:13:"absolute_path";s:69:"/Users/alexions/www/git/work/images/detailed/0/603497948727.sml_0.jpg";s:13:"relative_path";s:33:"detailed/0/603497948727.sml_0.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2195660588";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:38:"Crossroads Guitar Festival 2010 (2DVD)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:29.989;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:29.989;s:13:"display_price";d:29.989;}s:10:"2243091253";a:23:{s:10:"product_id";i:191;s:12:"product_code";s:10:"Q0191PBM44";s:7:"product";s:40:"Esperanza Spalding - Radio Music Society";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:11.98;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"668";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"724";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/02xrms-cd.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"300";s:7:"image_y";s:3:"300";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/02xrms-cd.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/02xrms-cd.jpg";s:13:"relative_path";s:24:"detailed/0/02xrms-cd.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2243091253";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:40:"Esperanza Spalding - Radio Music Society";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:11.98;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:11.98;s:13:"display_price";d:11.98;}s:9:"467029654";a:23:{s:10:"product_id";i:196;s:12:"product_code";s:10:"I0196BBF6I";s:7:"product";s:40:"Feeding the Monkies At Ma Maison (Zappa)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:17;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"673";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"729";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:73:"http://localhost/git/work/images/detailed/0/feedingthemonkies_frntLRG.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:73:"http://localhost/git/work/images/detailed/0/feedingthemonkies_frntLRG.jpg";s:13:"absolute_path";s:76:"/Users/alexions/www/git/work/images/detailed/0/feedingthemonkies_frntLRG.jpg";s:13:"relative_path";s:40:"detailed/0/feedingthemonkies_frntLRG.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"467029654";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:40:"Feeding the Monkies At Ma Maison (Zappa)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:17;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:17;s:13:"display_price";d:17;}s:10:"1825668608";a:23:{s:10:"product_id";i:197;s:12:"product_code";s:10:"A019737E4S";s:7:"product";s:24:"Guitar Man Album Artwork";s:6:"amount";i:2;s:15:"product_options";a:0:{}s:5:"price";d:14.98;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"674";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"730";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:89:"http://localhost/git/work/images/detailed/0/url_uploaded_file_13287662164f335d096a3ce.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"650";s:7:"image_y";s:3:"650";s:15:"http_image_path";s:89:"http://localhost/git/work/images/detailed/0/url_uploaded_file_13287662164f335d096a3ce.jpg";s:13:"absolute_path";s:92:"/Users/alexions/www/git/work/images/detailed/0/url_uploaded_file_13287662164f335d096a3ce.jpg";s:13:"relative_path";s:56:"detailed/0/url_uploaded_file_13287662164f335d096a3ce.jpg";}}s:15:"original_amount";s:1:"2";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1825668608";s:6:"amount";s:1:"2";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:24:"Guitar Man Album Artwork";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:14.98;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:2;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:14.98;s:13:"display_price";d:14.98;}s:9:"556920499";a:23:{s:10:"product_id";i:200;s:12:"product_code";s:10:"X02002U30A";s:7:"product";s:38:"John Rutter - The Colours of Christmas";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:26.920;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"678";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"734";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:89:"http://localhost/git/work/images/detailed/0/url_uploaded_file_13287719184f33734f6b3e9.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1426";s:7:"image_y";s:4:"1413";s:15:"http_image_path";s:89:"http://localhost/git/work/images/detailed/0/url_uploaded_file_13287719184f33734f6b3e9.jpg";s:13:"absolute_path";s:92:"/Users/alexions/www/git/work/images/detailed/0/url_uploaded_file_13287719184f33734f6b3e9.jpg";s:13:"relative_path";s:56:"detailed/0/url_uploaded_file_13287719184f33734f6b3e9.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"556920499";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:38:"John Rutter - The Colours of Christmas";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:26.920;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:26.920;s:13:"display_price";d:26.920;}s:10:"3477049247";a:23:{s:10:"product_id";i:202;s:12:"product_code";s:10:"T0202OTGXT";s:7:"product";s:76:"New Year''s Concert 2011 Diverse Klassik Welser-moest / Wiener Philharmoniker";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:34.68;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"680";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"736";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:54:"http://localhost/git/work/images/detailed/0/cover1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:54:"http://localhost/git/work/images/detailed/0/cover1.jpg";s:13:"absolute_path";s:57:"/Users/alexions/www/git/work/images/detailed/0/cover1.jpg";s:13:"relative_path";s:21:"detailed/0/cover1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3477049247";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:76:"New Year''s Concert 2011 Diverse Klassik Welser-moest / Wiener Philharmoniker";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:34.68;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:34.68;s:13:"display_price";d:34.68;}s:10:"3090726665";a:23:{s:10:"product_id";i:203;s:12:"product_code";s:10:"R02034W1ZL";s:7:"product";s:72:"New Year''s Concert 2012 Diverse Wr.Philharmoniker / Jansons,M. / Wr.Sän";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:34.68;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"681";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"737";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:77:"http://localhost/git/work/images/detailed/0/cover113287723384f3374f2d5491.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:77:"http://localhost/git/work/images/detailed/0/cover113287723384f3374f2d5491.jpg";s:13:"absolute_path";s:80:"/Users/alexions/www/git/work/images/detailed/0/cover113287723384f3374f2d5491.jpg";s:13:"relative_path";s:44:"detailed/0/cover113287723384f3374f2d5491.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3090726665";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:72:"New Year''s Concert 2012 Diverse Wr.Philharmoniker / Jansons,M. / Wr.Sän";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:34.68;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:34.68;s:13:"display_price";d:34.68;}s:9:"643574442";a:23:{s:10:"product_id";i:204;s:12:"product_code";s:10:"B0204ZOC1I";s:7:"product";s:43:"The Police - The Stewart Copeland Anthology";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:14.99;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"682";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"738";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:54:"http://localhost/git/work/images/detailed/0/5OCD09.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:54:"http://localhost/git/work/images/detailed/0/5OCD09.jpg";s:13:"absolute_path";s:57:"/Users/alexions/www/git/work/images/detailed/0/5OCD09.jpg";s:13:"relative_path";s:21:"detailed/0/5OCD09.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"643574442";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:43:"The Police - The Stewart Copeland Anthology";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:14.99;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:14.99;s:13:"display_price";d:14.99;}s:10:"4124585914";a:23:{s:10:"product_id";i:194;s:12:"product_code";s:10:"P01947A0SW";s:7:"product";s:23:"U218 Singles (U2TCD020)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:10.6;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"671";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"727";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:56:"http://localhost/git/work/images/detailed/0/U2TCD020.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1500";s:7:"image_y";s:4:"1500";s:15:"http_image_path";s:56:"http://localhost/git/work/images/detailed/0/U2TCD020.jpg";s:13:"absolute_path";s:59:"/Users/alexions/www/git/work/images/detailed/0/U2TCD020.jpg";s:13:"relative_path";s:23:"detailed/0/U2TCD020.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4124585914";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:23:"U218 Singles (U2TCD020)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:10.6;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:10.6;s:13:"display_price";d:10.6;}}s:12:"package_info";a:7:{s:1:"C";d:286.440;s:1:"W";s:4:"0.01";s:1:"I";i:14;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:13:{s:10:"2338935559";i:1;s:10:"4235092881";i:1;s:10:"1446436389";i:1;s:9:"482052751";i:1;s:10:"2195660588";i:1;s:10:"2243091253";i:1;s:9:"467029654";i:1;s:10:"1825668608";i:2;s:9:"556920499";i:1;s:10:"3477049247";i:1;s:10:"3090726665";i:1;s:9:"643574442";i:1;s:10:"4124585914";i:1;}s:6:"amount";i:14;s:6:"weight";d:0.100;s:4:"cost";d:286.440;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:20;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:1.820;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:20;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(187, 75, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2836788418";a:23:{s:10:"product_id";i:142;s:12:"product_code";s:10:"H0142DQBME";s:7:"product";s:16:"Yamaha TSX-130WH";s:6:"amount";i:4;s:15:"product_options";a:0:{}s:5:"price";d:399.949;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"532";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"588";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/p95910z.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/p95910z.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/p95910z.jpg";s:13:"relative_path";s:22:"detailed/0/p95910z.jpg";}}s:15:"original_amount";s:1:"4";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2836788418";s:6:"amount";s:1:"4";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:16:"Yamaha TSX-130WH";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:399.949;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:4;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:399.949;s:13:"display_price";d:399.949;}}s:12:"package_info";a:7:{s:1:"C";d:1599.8;s:1:"W";s:4:"0.01";s:1:"I";i:4;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2836788418";i:4;}s:6:"amount";i:4;s:6:"weight";d:0.100;s:4:"cost";d:1599.8;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(188, 76, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:9:"319261745";a:23:{s:10:"product_id";i:220;s:12:"product_code";s:10:"P0220KHOS3";s:7:"product";s:31:"Series 7 Chronos 14” Notebook";s:6:"amount";i:3;s:15:"product_options";a:0:{}s:5:"price";d:1099.99;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"727";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"783";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:70:"http://localhost/git/work/images/detailed/0/700Z-side_back_open-01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"900";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:70:"http://localhost/git/work/images/detailed/0/700Z-side_back_open-01.jpg";s:13:"absolute_path";s:73:"/Users/alexions/www/git/work/images/detailed/0/700Z-side_back_open-01.jpg";s:13:"relative_path";s:37:"detailed/0/700Z-side_back_open-01.jpg";}}s:15:"original_amount";s:1:"3";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"319261745";s:6:"amount";s:1:"3";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:31:"Series 7 Chronos 14” Notebook";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1099.99;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:3;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:1099.99;s:13:"display_price";d:1099.99;}}s:12:"package_info";a:7:{s:1:"C";d:3299.970;s:1:"W";s:4:"0.01";s:1:"I";i:3;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:9:"319261745";i:3;}s:6:"amount";i:3;s:6:"weight";d:0.100;s:4:"cost";d:3299.970;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(189, 78, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:2:{s:10:"4072008611";a:23:{s:10:"product_id";i:190;s:12:"product_code";s:10:"O019015C2L";s:7:"product";s:36:"AF-S DX NIKKOR 10-24mm f/3.5-4.5G ED";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:899.950;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"667";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"723";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:54:"http://localhost/git/work/images/detailed/0/2181_1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:3:"816";s:15:"http_image_path";s:54:"http://localhost/git/work/images/detailed/0/2181_1.jpg";s:13:"absolute_path";s:57:"/Users/alexions/www/git/work/images/detailed/0/2181_1.jpg";s:13:"relative_path";s:21:"detailed/0/2181_1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4072008611";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"AF-S DX NIKKOR 10-24mm f/3.5-4.5G ED";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.950;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:899.950;s:13:"display_price";d:899.950;}s:10:"3961824982";a:23:{s:10:"product_id";i:163;s:12:"product_code";s:10:"W0163ME90H";s:7:"product";s:42:"NX200 20.3 Megapixel Compact System Camera";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:899.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"571";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"627";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:69:"http://localhost/git/work/images/detailed/0/NX200_F4_B_1024x768_6.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:3:"819";s:15:"http_image_path";s:69:"http://localhost/git/work/images/detailed/0/NX200_F4_B_1024x768_6.jpg";s:13:"absolute_path";s:72:"/Users/alexions/www/git/work/images/detailed/0/NX200_F4_B_1024x768_6.jpg";s:13:"relative_path";s:36:"detailed/0/NX200_F4_B_1024x768_6.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3961824982";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:42:"NX200 20.3 Megapixel Compact System Camera";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:899.990;s:13:"display_price";d:899.990;}}s:12:"package_info";a:7:{s:1:"C";d:1799.940;s:1:"W";s:4:"0.01";s:1:"I";i:2;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:2:{s:10:"4072008611";i:1;s:10:"3961824982";i:1;}s:6:"amount";i:2;s:6:"weight";d:0.100;s:4:"cost";d:1799.940;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(190, 79, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"1061624811";a:23:{s:10:"product_id";i:214;s:12:"product_code";s:10:"K02149B2ZX";s:7:"product";s:11:"ASUS CP6130";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:972;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"709";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"765";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:76:"http://localhost/git/work/images/detailed/0/P_50013287768924f3386bc5fe80.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:76:"http://localhost/git/work/images/detailed/0/P_50013287768924f3386bc5fe80.jpg";s:13:"absolute_path";s:79:"/Users/alexions/www/git/work/images/detailed/0/P_50013287768924f3386bc5fe80.jpg";s:13:"relative_path";s:43:"detailed/0/P_50013287768924f3386bc5fe80.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1061624811";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"ASUS CP6130";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:972;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:972;s:13:"display_price";d:972;}}s:12:"package_info";a:7:{s:1:"C";d:972;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"1061624811";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:972;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}');
INSERT INTO `[[dbprefix]]order_data` VALUES
(191, 80, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"3125424156";a:23:{s:10:"product_id";i:240;s:12:"product_code";s:10:"E0240Y27BE";s:7:"product";s:59:"Apple® - iPad® with Retina® display Wi-Fi - 64GB - Black";s:6:"amount";i:2;s:15:"product_options";a:2:{i:11;s:2:"43";i:10;s:2:"39";}s:5:"price";d:499;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"848";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"904";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/ipad-black-1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"536";s:7:"image_y";s:3:"742";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/ipad-black-1.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/ipad-black-1.jpg";s:13:"relative_path";s:27:"detailed/0/ipad-black-1.jpg";}}s:15:"original_amount";s:1:"2";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3125424156";s:6:"amount";s:1:"2";}s:5:"extra";a:10:{s:15:"product_options";a:2:{i:11;s:2:"43";i:10;s:2:"39";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:59:"Apple® - iPad® with Retina® display Wi-Fi - 64GB - Black";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:499;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:2:"11";s:10:"product_id";s:3:"240";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"C";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"43";s:11:"option_name";s:15:"3G Connectivity";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:2:"No";}i:1;a:22:{s:9:"option_id";s:2:"10";s:10:"product_id";s:3:"240";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"39";s:11:"option_name";s:15:"Memory capacity";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:4:"16GB";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:2;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:499;s:13:"display_price";d:499;}}s:12:"package_info";a:7:{s:1:"C";d:998;s:1:"W";s:4:"0.01";s:1:"I";i:2;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"3125424156";i:2;}s:6:"amount";i:2;s:6:"weight";d:0.100;s:4:"cost";i:998;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(192, 81, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:6:{s:10:"3947455183";a:23:{s:10:"product_id";i:167;s:12:"product_code";s:10:"H0167T7K2E";s:7:"product";s:25:"D3100 + 18-55 VR Lens Kit";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:549.950;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"597";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"653";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/25472_1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/25472_1.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/25472_1.jpg";s:13:"relative_path";s:22:"detailed/0/25472_1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3947455183";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:25:"D3100 + 18-55 VR Lens Kit";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:549.950;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:549.950;s:13:"display_price";d:549.950;}s:10:"4033496702";a:23:{s:10:"product_id";i:74;s:12:"product_code";s:10:"S0074AE6U7";s:7:"product";s:7:"Droid 3";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:524.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"377";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"433";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:67:"http://localhost/git/work/images/detailed/0/21Y7tnPMVHL._SX220_.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:67:"http://localhost/git/work/images/detailed/0/21Y7tnPMVHL._SX220_.jpg";s:13:"absolute_path";s:70:"/Users/alexions/www/git/work/images/detailed/0/21Y7tnPMVHL._SX220_.jpg";s:13:"relative_path";s:34:"detailed/0/21Y7tnPMVHL._SX220_.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4033496702";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:7:"Droid 3";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:524.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:524.990;s:13:"display_price";d:524.990;}s:10:"2473281379";a:23:{s:10:"product_id";i:30;s:12:"product_code";s:10:"H00305TUE7";s:7:"product";s:14:"GO 2535 TM WTE";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:349.949;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"254";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"310";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:75:"http://localhost/git/work/images/detailed/0/mount_angle_500_tcm137-7794.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:75:"http://localhost/git/work/images/detailed/0/mount_angle_500_tcm137-7794.jpg";s:13:"absolute_path";s:78:"/Users/alexions/www/git/work/images/detailed/0/mount_angle_500_tcm137-7794.jpg";s:13:"relative_path";s:42:"detailed/0/mount_angle_500_tcm137-7794.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2473281379";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:14:"GO 2535 TM WTE";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:349.949;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:349.949;s:13:"display_price";d:349.949;}s:10:"1792750741";a:23:{s:10:"product_id";i:229;s:12:"product_code";s:10:"V0229W5J8F";s:7:"product";s:24:"HP 2711x 27" LED Monitor";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:299.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"782";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"838";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:59:"http://localhost/git/work/images/detailed/0/xp600aa_300.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:59:"http://localhost/git/work/images/detailed/0/xp600aa_300.jpg";s:13:"absolute_path";s:62:"/Users/alexions/www/git/work/images/detailed/0/xp600aa_300.jpg";s:13:"relative_path";s:26:"detailed/0/xp600aa_300.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1792750741";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:24:"HP 2711x 27" LED Monitor";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:299.990;s:13:"display_price";d:299.990;}s:10:"3864289797";a:23:{s:10:"product_id";i:132;s:12:"product_code";s:10:"S0132PANHE";s:7:"product";s:25:"Samsung Galaxy Player 5.0";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:269.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"507";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"563";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:69:"http://localhost/git/work/images/detailed/0/WiFi_Galaxy5_front3_4.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"800";s:7:"image_y";s:3:"800";s:15:"http_image_path";s:69:"http://localhost/git/work/images/detailed/0/WiFi_Galaxy5_front3_4.jpg";s:13:"absolute_path";s:72:"/Users/alexions/www/git/work/images/detailed/0/WiFi_Galaxy5_front3_4.jpg";s:13:"relative_path";s:36:"detailed/0/WiFi_Galaxy5_front3_4.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3864289797";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:25:"Samsung Galaxy Player 5.0";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:269.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:269.990;s:13:"display_price";d:269.990;}s:10:"2366072709";a:23:{s:10:"product_id";i:9;s:12:"product_code";s:10:"F0009ORD06";s:7:"product";s:45:"Toshiba 42TL515U 42" Class 1080P 3D LED HD TV";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:999.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"205";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"261";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:65:"http://localhost/git/work/images/detailed/0/led-tv-42TL515-01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"715";s:7:"image_y";s:3:"496";s:15:"http_image_path";s:65:"http://localhost/git/work/images/detailed/0/led-tv-42TL515-01.jpg";s:13:"absolute_path";s:68:"/Users/alexions/www/git/work/images/detailed/0/led-tv-42TL515-01.jpg";s:13:"relative_path";s:32:"detailed/0/led-tv-42TL515-01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2366072709";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"Toshiba 42TL515U 42" Class 1080P 3D LED HD TV";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:999.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:999.990;s:13:"display_price";d:999.990;}}s:12:"package_info";a:7:{s:1:"C";d:2994.860;s:1:"W";s:4:"0.01";s:1:"I";i:6;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:6:{s:10:"3947455183";i:1;s:10:"4033496702";i:1;s:10:"2473281379";i:1;s:10:"1792750741";i:1;s:10:"3864289797";i:1;s:10:"2366072709";i:1;}s:6:"amount";i:6;s:6:"weight";d:0.100;s:4:"cost";d:2994.860;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(193, 82, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"1364924988";a:23:{s:10:"product_id";i:205;s:12:"product_code";s:10:"Y0205HGGEI";s:7:"product";s:28:"DIR-657 HD Media Router 1000";s:6:"amount";i:5;s:15:"product_options";a:0:{}s:5:"price";d:149.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"683";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"739";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:61:"http://localhost/git/work/images/detailed/0/DIR-657_front.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1224";s:7:"image_y";s:4:"1224";s:15:"http_image_path";s:61:"http://localhost/git/work/images/detailed/0/DIR-657_front.jpg";s:13:"absolute_path";s:64:"/Users/alexions/www/git/work/images/detailed/0/DIR-657_front.jpg";s:13:"relative_path";s:28:"detailed/0/DIR-657_front.jpg";}}s:15:"original_amount";s:1:"5";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1364924988";s:6:"amount";s:1:"5";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:28:"DIR-657 HD Media Router 1000";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:149.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:5;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:149.990;s:13:"display_price";d:149.990;}}s:12:"package_info";a:7:{s:1:"C";d:749.950;s:1:"W";s:4:"0.01";s:1:"I";i:5;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"1364924988";i:5;}s:6:"amount";i:5;s:6:"weight";d:0.100;s:4:"cost";d:749.950;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(194, 83, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:2:{s:10:"2372082066";a:23:{s:10:"product_id";i:227;s:12:"product_code";s:10:"L0227FHI2Y";s:7:"product";s:28:"Acer 3D Series HN274H bmiiid";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:699;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"777";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"833";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/HN274H_350x250.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/HN274H_350x250.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/HN274H_350x250.jpg";s:13:"relative_path";s:29:"detailed/0/HN274H_350x250.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2372082066";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:28:"Acer 3D Series HN274H bmiiid";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:699;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:699;s:13:"display_price";d:699;}s:9:"500958211";a:23:{s:10:"product_id";i:228;s:12:"product_code";s:10:"I0228OF40N";s:7:"product";s:12:"LG D2342P-PN";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:349.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"778";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"834";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/large01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1400";s:7:"image_y";s:4:"1400";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/large01.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/large01.jpg";s:13:"relative_path";s:22:"detailed/0/large01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"500958211";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:12:"LG D2342P-PN";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:349.990;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:349.990;s:13:"display_price";d:349.990;}}s:12:"package_info";a:7:{s:1:"C";d:1048.99;s:1:"W";s:4:"0.01";s:1:"I";i:2;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:2:{s:10:"2372082066";i:1;s:9:"500958211";i:1;}s:6:"amount";i:2;s:6:"weight";d:0.100;s:4:"cost";d:1048.99;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(195, 84, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:9:"319261745";a:23:{s:10:"product_id";i:220;s:12:"product_code";s:10:"P0220KHOS3";s:7:"product";s:31:"Series 7 Chronos 14” Notebook";s:6:"amount";i:3;s:15:"product_options";a:0:{}s:5:"price";d:1099.99;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"727";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"783";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:70:"http://localhost/git/work/images/detailed/0/700Z-side_back_open-01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"900";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:70:"http://localhost/git/work/images/detailed/0/700Z-side_back_open-01.jpg";s:13:"absolute_path";s:73:"/Users/alexions/www/git/work/images/detailed/0/700Z-side_back_open-01.jpg";s:13:"relative_path";s:37:"detailed/0/700Z-side_back_open-01.jpg";}}s:15:"original_amount";s:1:"3";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"319261745";s:6:"amount";s:1:"3";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:31:"Series 7 Chronos 14” Notebook";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1099.99;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:3;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:1099.99;s:13:"display_price";d:1099.99;}}s:12:"package_info";a:7:{s:1:"C";d:3299.970;s:1:"W";s:4:"0.01";s:1:"I";i:3;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:9:"319261745";i:3;}s:6:"amount";i:3;s:6:"weight";d:0.100;s:4:"cost";d:3299.970;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(196, 86, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:2:{s:10:"4072008611";a:23:{s:10:"product_id";i:190;s:12:"product_code";s:10:"O019015C2L";s:7:"product";s:36:"AF-S DX NIKKOR 10-24mm f/3.5-4.5G ED";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:899.950;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"667";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"723";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:54:"http://localhost/git/work/images/detailed/0/2181_1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:3:"816";s:15:"http_image_path";s:54:"http://localhost/git/work/images/detailed/0/2181_1.jpg";s:13:"absolute_path";s:57:"/Users/alexions/www/git/work/images/detailed/0/2181_1.jpg";s:13:"relative_path";s:21:"detailed/0/2181_1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4072008611";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"AF-S DX NIKKOR 10-24mm f/3.5-4.5G ED";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.950;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:899.950;s:13:"display_price";d:899.950;}s:10:"3961824982";a:23:{s:10:"product_id";i:163;s:12:"product_code";s:10:"W0163ME90H";s:7:"product";s:42:"NX200 20.3 Megapixel Compact System Camera";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:899.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"571";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"627";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:69:"http://localhost/git/work/images/detailed/0/NX200_F4_B_1024x768_6.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:3:"819";s:15:"http_image_path";s:69:"http://localhost/git/work/images/detailed/0/NX200_F4_B_1024x768_6.jpg";s:13:"absolute_path";s:72:"/Users/alexions/www/git/work/images/detailed/0/NX200_F4_B_1024x768_6.jpg";s:13:"relative_path";s:36:"detailed/0/NX200_F4_B_1024x768_6.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3961824982";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:42:"NX200 20.3 Megapixel Compact System Camera";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.990;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:899.990;s:13:"display_price";d:899.990;}}s:12:"package_info";a:7:{s:1:"C";d:1799.940;s:1:"W";s:4:"0.01";s:1:"I";i:2;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:2:{s:10:"4072008611";i:1;s:10:"3961824982";i:1;}s:6:"amount";i:2;s:6:"weight";d:0.100;s:4:"cost";d:1799.940;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(197, 87, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"1061624811";a:23:{s:10:"product_id";i:214;s:12:"product_code";s:10:"K02149B2ZX";s:7:"product";s:11:"ASUS CP6130";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:972;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"709";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"765";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:76:"http://localhost/git/work/images/detailed/0/P_50013287768924f3386bc5fe80.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:76:"http://localhost/git/work/images/detailed/0/P_50013287768924f3386bc5fe80.jpg";s:13:"absolute_path";s:79:"/Users/alexions/www/git/work/images/detailed/0/P_50013287768924f3386bc5fe80.jpg";s:13:"relative_path";s:43:"detailed/0/P_50013287768924f3386bc5fe80.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1061624811";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"ASUS CP6130";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:972;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:972;s:13:"display_price";d:972;}}s:12:"package_info";a:7:{s:1:"C";d:972;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"1061624811";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:972;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}');
INSERT INTO `[[dbprefix]]order_data` VALUES
(198, 89, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:6:{s:10:"3947455183";a:23:{s:10:"product_id";i:167;s:12:"product_code";s:10:"H0167T7K2E";s:7:"product";s:25:"D3100 + 18-55 VR Lens Kit";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:549.950;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"597";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"653";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/25472_1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/25472_1.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/25472_1.jpg";s:13:"relative_path";s:22:"detailed/0/25472_1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3947455183";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:25:"D3100 + 18-55 VR Lens Kit";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:549.950;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:549.950;s:13:"display_price";d:549.950;}s:10:"4033496702";a:23:{s:10:"product_id";i:74;s:12:"product_code";s:10:"S0074AE6U7";s:7:"product";s:7:"Droid 3";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:524.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"377";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"433";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:67:"http://localhost/git/work/images/detailed/0/21Y7tnPMVHL._SX220_.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:67:"http://localhost/git/work/images/detailed/0/21Y7tnPMVHL._SX220_.jpg";s:13:"absolute_path";s:70:"/Users/alexions/www/git/work/images/detailed/0/21Y7tnPMVHL._SX220_.jpg";s:13:"relative_path";s:34:"detailed/0/21Y7tnPMVHL._SX220_.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4033496702";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:7:"Droid 3";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:524.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:524.990;s:13:"display_price";d:524.990;}s:10:"2473281379";a:23:{s:10:"product_id";i:30;s:12:"product_code";s:10:"H00305TUE7";s:7:"product";s:14:"GO 2535 TM WTE";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:349.949;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"254";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"310";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:75:"http://localhost/git/work/images/detailed/0/mount_angle_500_tcm137-7794.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:75:"http://localhost/git/work/images/detailed/0/mount_angle_500_tcm137-7794.jpg";s:13:"absolute_path";s:78:"/Users/alexions/www/git/work/images/detailed/0/mount_angle_500_tcm137-7794.jpg";s:13:"relative_path";s:42:"detailed/0/mount_angle_500_tcm137-7794.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2473281379";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:14:"GO 2535 TM WTE";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:349.949;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:349.949;s:13:"display_price";d:349.949;}s:10:"1792750741";a:23:{s:10:"product_id";i:229;s:12:"product_code";s:10:"V0229W5J8F";s:7:"product";s:24:"HP 2711x 27" LED Monitor";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:299.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"782";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"838";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:59:"http://localhost/git/work/images/detailed/0/xp600aa_300.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:59:"http://localhost/git/work/images/detailed/0/xp600aa_300.jpg";s:13:"absolute_path";s:62:"/Users/alexions/www/git/work/images/detailed/0/xp600aa_300.jpg";s:13:"relative_path";s:26:"detailed/0/xp600aa_300.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1792750741";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:24:"HP 2711x 27" LED Monitor";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:299.990;s:13:"display_price";d:299.990;}s:10:"3864289797";a:23:{s:10:"product_id";i:132;s:12:"product_code";s:10:"S0132PANHE";s:7:"product";s:25:"Samsung Galaxy Player 5.0";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:269.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"507";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"563";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:69:"http://localhost/git/work/images/detailed/0/WiFi_Galaxy5_front3_4.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"800";s:7:"image_y";s:3:"800";s:15:"http_image_path";s:69:"http://localhost/git/work/images/detailed/0/WiFi_Galaxy5_front3_4.jpg";s:13:"absolute_path";s:72:"/Users/alexions/www/git/work/images/detailed/0/WiFi_Galaxy5_front3_4.jpg";s:13:"relative_path";s:36:"detailed/0/WiFi_Galaxy5_front3_4.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3864289797";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:25:"Samsung Galaxy Player 5.0";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:269.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:269.990;s:13:"display_price";d:269.990;}s:10:"2366072709";a:23:{s:10:"product_id";i:9;s:12:"product_code";s:10:"F0009ORD06";s:7:"product";s:45:"Toshiba 42TL515U 42" Class 1080P 3D LED HD TV";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:999.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"205";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"261";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:65:"http://localhost/git/work/images/detailed/0/led-tv-42TL515-01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"715";s:7:"image_y";s:3:"496";s:15:"http_image_path";s:65:"http://localhost/git/work/images/detailed/0/led-tv-42TL515-01.jpg";s:13:"absolute_path";s:68:"/Users/alexions/www/git/work/images/detailed/0/led-tv-42TL515-01.jpg";s:13:"relative_path";s:32:"detailed/0/led-tv-42TL515-01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2366072709";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"Toshiba 42TL515U 42" Class 1080P 3D LED HD TV";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:999.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:999.990;s:13:"display_price";d:999.990;}}s:12:"package_info";a:7:{s:1:"C";d:2994.860;s:1:"W";s:4:"0.01";s:1:"I";i:6;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:6:{s:10:"3947455183";i:1;s:10:"4033496702";i:1;s:10:"2473281379";i:1;s:10:"1792750741";i:1;s:10:"3864289797";i:1;s:10:"2366072709";i:1;}s:6:"amount";i:6;s:6:"weight";d:0.100;s:4:"cost";d:2994.860;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(199, 90, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"1364924988";a:23:{s:10:"product_id";i:205;s:12:"product_code";s:10:"Y0205HGGEI";s:7:"product";s:28:"DIR-657 HD Media Router 1000";s:6:"amount";i:5;s:15:"product_options";a:0:{}s:5:"price";d:149.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"683";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"739";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:61:"http://localhost/git/work/images/detailed/0/DIR-657_front.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1224";s:7:"image_y";s:4:"1224";s:15:"http_image_path";s:61:"http://localhost/git/work/images/detailed/0/DIR-657_front.jpg";s:13:"absolute_path";s:64:"/Users/alexions/www/git/work/images/detailed/0/DIR-657_front.jpg";s:13:"relative_path";s:28:"detailed/0/DIR-657_front.jpg";}}s:15:"original_amount";s:1:"5";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1364924988";s:6:"amount";s:1:"5";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:28:"DIR-657 HD Media Router 1000";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:149.990;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:5;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:149.990;s:13:"display_price";d:149.990;}}s:12:"package_info";a:7:{s:1:"C";d:749.950;s:1:"W";s:4:"0.01";s:1:"I";i:5;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"1364924988";i:5;}s:6:"amount";i:5;s:6:"weight";d:0.100;s:4:"cost";d:749.950;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(200, 92, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"4163016541";a:23:{s:10:"product_id";i:126;s:12:"product_code";s:10:"F01262AH0T";s:7:"product";s:19:"Casio PRIZM fx-CG10";s:6:"amount";i:5;s:15:"product_options";a:0:{}s:5:"price";d:129.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"486";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"542";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"529";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:13:"relative_path";s:29:"detailed/0/fx-cg10_xlarge.jpg";}}s:15:"original_amount";s:1:"5";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4163016541";s:6:"amount";s:1:"5";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:19:"Casio PRIZM fx-CG10";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:129.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:5;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:129.990;s:13:"display_price";d:129.990;}}s:12:"package_info";a:7:{s:1:"C";d:649.950;s:1:"W";s:4:"0.01";s:1:"I";i:5;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"4163016541";i:5;}s:6:"amount";i:5;s:6:"weight";d:0.100;s:4:"cost";d:649.950;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(201, 93, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"3636250333";a:23:{s:10:"product_id";i:15;s:12:"product_code";s:10:"H0015EXYM6";s:7:"product";s:39:"Nike Chambray Super Runner Men''s Jacket";s:6:"amount";i:1;s:15:"product_options";a:1:{i:7;s:2:"26";}s:5:"price";d:150;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"224";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"280";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/452499_010_A.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"900";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/452499_010_A.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/452499_010_A.jpg";s:13:"relative_path";s:27:"detailed/0/452499_010_A.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3636250333";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:1:{i:7;s:2:"26";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:39:"Nike Chambray Super Runner Men''s Jacket";s:10:"company_id";s:1:"2";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:150;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:1:{i:0;a:22:{s:9:"option_id";s:1:"7";s:10:"product_id";s:2:"15";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:2:"26";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:150;s:13:"display_price";d:150;}}s:12:"package_info";a:7:{s:1:"C";d:150;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"3636250333";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:150;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(202, 95, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:2:{s:10:"4072008611";a:23:{s:10:"product_id";i:190;s:12:"product_code";s:10:"O019015C2L";s:7:"product";s:36:"AF-S DX NIKKOR 10-24mm f/3.5-4.5G ED";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:899.950;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"667";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"723";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:54:"http://localhost/git/work/images/detailed/0/2181_1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:3:"816";s:15:"http_image_path";s:54:"http://localhost/git/work/images/detailed/0/2181_1.jpg";s:13:"absolute_path";s:57:"/Users/alexions/www/git/work/images/detailed/0/2181_1.jpg";s:13:"relative_path";s:21:"detailed/0/2181_1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4072008611";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"AF-S DX NIKKOR 10-24mm f/3.5-4.5G ED";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.950;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:899.950;s:13:"display_price";d:899.950;}s:10:"3961824982";a:23:{s:10:"product_id";i:163;s:12:"product_code";s:10:"W0163ME90H";s:7:"product";s:42:"NX200 20.3 Megapixel Compact System Camera";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:899.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"571";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"627";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:69:"http://localhost/git/work/images/detailed/0/NX200_F4_B_1024x768_6.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:3:"819";s:15:"http_image_path";s:69:"http://localhost/git/work/images/detailed/0/NX200_F4_B_1024x768_6.jpg";s:13:"absolute_path";s:72:"/Users/alexions/www/git/work/images/detailed/0/NX200_F4_B_1024x768_6.jpg";s:13:"relative_path";s:36:"detailed/0/NX200_F4_B_1024x768_6.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3961824982";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:42:"NX200 20.3 Megapixel Compact System Camera";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:899.990;s:13:"display_price";d:899.990;}}s:12:"package_info";a:7:{s:1:"C";d:1799.940;s:1:"W";s:4:"0.01";s:1:"I";i:2;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:2:{s:10:"4072008611";i:1;s:10:"3961824982";i:1;}s:6:"amount";i:2;s:6:"weight";d:0.100;s:4:"cost";d:1799.940;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(203, 19, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2316230027";a:23:{s:10:"product_id";i:223;s:12:"product_code";s:10:"O0223AQI3W";s:7:"product";s:56:"Samsung Galaxy Tab 8.9 (Wi-Fi Only) - 32GB Metallic Gray";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:499.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"753";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"809";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:73:"http://localhost/git/work/images/detailed/0/p7310_400x400_large1_cf_1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"728";s:7:"image_y";s:3:"546";s:15:"http_image_path";s:73:"http://localhost/git/work/images/detailed/0/p7310_400x400_large1_cf_1.jpg";s:13:"absolute_path";s:76:"/Users/alexions/www/git/work/images/detailed/0/p7310_400x400_large1_cf_1.jpg";s:13:"relative_path";s:40:"detailed/0/p7310_400x400_large1_cf_1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2316230027";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:56:"Samsung Galaxy Tab 8.9 (Wi-Fi Only) - 32GB Metallic Gray";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:499.990;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:499.990;s:13:"display_price";d:499.990;}}s:12:"package_info";a:7:{s:1:"C";d:499.990;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2316230027";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:499.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:4:"John";s:8:"lastname";s:5:"Smith";s:7:"address";s:15:"3351 Hiney Road";s:9:"address_2";N;s:4:"city";s:9:"Las Vegas";s:6:"county";N;s:5:"state";s:2:"NV";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"89102";s:5:"phone";s:12:"702-288-3585";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:6:"Nevada";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:11.300;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:1.03;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}');
INSERT INTO `[[dbprefix]]order_data` VALUES
(204, 21, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:5:{s:10:"1860791280";a:23:{s:10:"product_id";i:94;s:12:"product_code";s:10:"A0094VY6U3";s:7:"product";s:26:"Batman: Arkham City (X360)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:59.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"431";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"487";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/1000176186_f.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"625";s:7:"image_y";s:3:"849";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/1000176186_f.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/1000176186_f.jpg";s:13:"relative_path";s:27:"detailed/0/1000176186_f.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1860791280";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:26:"Batman: Arkham City (X360)";s:10:"company_id";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:59.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:59.990;s:13:"display_price";d:59.990;}s:10:"2162625244";a:23:{s:10:"product_id";i:96;s:12:"product_code";s:10:"C0096T88CH";s:7:"product";s:29:"Batman: Arkham City (X360) CE";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:99.989;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"433";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"489";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/1000235553_f.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1200";s:7:"image_y";s:4:"1200";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/1000235553_f.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/1000235553_f.jpg";s:13:"relative_path";s:27:"detailed/0/1000235553_f.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2162625244";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:29:"Batman: Arkham City (X360) CE";s:10:"company_id";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:99.989;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:99.989;s:13:"display_price";d:99.989;}s:9:"435051366";a:23:{s:10:"product_id";i:95;s:12:"product_code";s:10:"S0095VELIH";s:7:"product";s:28:"Game Party: In Motion (X360)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:19.989;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"432";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"488";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/2832686.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"512";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/2832686.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/2832686.jpg";s:13:"relative_path";s:22:"detailed/0/2832686.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"435051366";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:28:"Game Party: In Motion (X360)";s:10:"company_id";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:19.989;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:19.989;s:13:"display_price";d:19.989;}s:9:"289485416";a:23:{s:10:"product_id";i:120;s:12:"product_code";s:10:"B0120TBX2K";s:7:"product";s:42:"Samsung Galaxy S II, Epic 4G Touch (Black)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:199.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"475";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"531";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:70:"http://localhost/git/work/images/detailed/0/d710_600x600_xlarge_cf.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:70:"http://localhost/git/work/images/detailed/0/d710_600x600_xlarge_cf.jpg";s:13:"absolute_path";s:73:"/Users/alexions/www/git/work/images/detailed/0/d710_600x600_xlarge_cf.jpg";s:13:"relative_path";s:37:"detailed/0/d710_600x600_xlarge_cf.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"289485416";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:42:"Samsung Galaxy S II, Epic 4G Touch (Black)";s:10:"company_id";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:199.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:199.990;s:13:"display_price";d:199.990;}s:10:"4035837523";a:23:{s:10:"product_id";i:93;s:12:"product_code";s:10:"Y0093T69G8";s:7:"product";s:41:"Scene It? Bright Lights! Big Screen(X360)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:19.989;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"430";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"486";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/2423577.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/2423577.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/2423577.jpg";s:13:"relative_path";s:22:"detailed/0/2423577.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4035837523";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:41:"Scene It? Bright Lights! Big Screen(X360)";s:10:"company_id";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:19.989;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:19.989;s:13:"display_price";d:19.989;}}s:12:"package_info";a:7:{s:1:"C";d:399.950;s:1:"W";s:4:"0.01";s:1:"I";i:5;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:5:{s:10:"1860791280";i:1;s:10:"2162625244";i:1;s:9:"435051366";i:1;s:9:"289485416";i:1;s:10:"4035837523";i:1;}s:6:"amount";i:5;s:6:"weight";d:0.100;s:4:"cost";d:399.950;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:4:"Kate";s:8:"lastname";s:3:"Lee";s:7:"address";s:16:"59 Bowden Street";s:9:"address_2";N;s:4:"city";s:10:"LEICHHARDT";s:6:"county";N;s:5:"state";s:3:"NSW";s:7:"country";s:2:"AU";s:7:"zipcode";s:4:"2040";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:9:"Australia";s:11:"state_descr";s:15:"New South Wales";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(205, 97, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"4163016541";a:23:{s:10:"product_id";i:126;s:12:"product_code";s:10:"F01262AH0T";s:7:"product";s:19:"Casio PRIZM fx-CG10";s:6:"amount";i:5;s:15:"product_options";a:0:{}s:5:"price";d:129.99;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"486";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"542";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"529";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:13:"relative_path";s:29:"detailed/0/fx-cg10_xlarge.jpg";}}s:15:"original_amount";s:1:"5";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4163016541";s:6:"amount";s:1:"5";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:19:"Casio PRIZM fx-CG10";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:129.99;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:5;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:129.99;s:13:"display_price";d:129.99;}}s:12:"package_info";a:7:{s:1:"C";d:649.95;s:1:"W";s:4:"0.01";s:1:"I";i:5;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"4163016541";i:5;}s:6:"amount";i:5;s:6:"weight";d:0.1;s:4:"cost";d:649.95;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.55;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(206, 96, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"1061624811";a:23:{s:10:"product_id";i:214;s:12:"product_code";s:10:"K02149B2ZX";s:7:"product";s:11:"ASUS CP6130";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:972;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"709";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"765";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:76:"http://localhost/git/work/images/detailed/0/P_50013287768924f3386bc5fe80.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:76:"http://localhost/git/work/images/detailed/0/P_50013287768924f3386bc5fe80.jpg";s:13:"absolute_path";s:79:"/Users/alexions/www/git/work/images/detailed/0/P_50013287768924f3386bc5fe80.jpg";s:13:"relative_path";s:43:"detailed/0/P_50013287768924f3386bc5fe80.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1061624811";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"ASUS CP6130";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:972;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:972;s:13:"display_price";d:972;}}s:12:"package_info";a:7:{s:1:"C";d:972;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"1061624811";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:972;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(207, 94, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"3260818684";a:23:{s:10:"product_id";i:54;s:12:"product_code";s:10:"I0054QMMPO";s:7:"product";s:13:"TS-W3002D2|D4";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:269;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"307";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"363";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:66:"http://localhost/git/work/images/detailed/0/TS-W3002D2D4_large.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1024";s:7:"image_y";s:4:"1024";s:15:"http_image_path";s:66:"http://localhost/git/work/images/detailed/0/TS-W3002D2D4_large.jpg";s:13:"absolute_path";s:69:"/Users/alexions/www/git/work/images/detailed/0/TS-W3002D2D4_large.jpg";s:13:"relative_path";s:33:"detailed/0/TS-W3002D2D4_large.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3260818684";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:13:"TS-W3002D2|D4";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:269;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:269;s:13:"display_price";d:269;}}s:12:"package_info";a:7:{s:1:"C";d:269;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"3260818684";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:269;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(208, 91, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:2:{s:10:"2372082066";a:23:{s:10:"product_id";i:227;s:12:"product_code";s:10:"L0227FHI2Y";s:7:"product";s:28:"Acer 3D Series HN274H bmiiid";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:699;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"777";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"833";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/HN274H_350x250.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/HN274H_350x250.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/HN274H_350x250.jpg";s:13:"relative_path";s:29:"detailed/0/HN274H_350x250.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2372082066";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:28:"Acer 3D Series HN274H bmiiid";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:699;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:699;s:13:"display_price";d:699;}s:9:"500958211";a:23:{s:10:"product_id";i:228;s:12:"product_code";s:10:"I0228OF40N";s:7:"product";s:12:"LG D2342P-PN";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:349.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"778";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"834";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/large01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1400";s:7:"image_y";s:4:"1400";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/large01.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/large01.jpg";s:13:"relative_path";s:22:"detailed/0/large01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"500958211";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:12:"LG D2342P-PN";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:349.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:349.990;s:13:"display_price";d:349.990;}}s:12:"package_info";a:7:{s:1:"C";d:1048.99;s:1:"W";s:4:"0.01";s:1:"I";i:2;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:2:{s:10:"2372082066";i:1;s:9:"500958211";i:1;}s:6:"amount";i:2;s:6:"weight";d:0.100;s:4:"cost";d:1048.99;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(209, 85, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:4:{s:10:"2583444381";a:23:{s:10:"product_id";i:86;s:12:"product_code";s:10:"I0086KA0W2";s:7:"product";s:9:"Nokia 700";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:359;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"454";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"510";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:88:"http://localhost/git/work/images/detailed/0/700-red-front-png13286885734f322dbde9ae7.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:88:"http://localhost/git/work/images/detailed/0/700-red-front-png13286885734f322dbde9ae7.jpg";s:13:"absolute_path";s:91:"/Users/alexions/www/git/work/images/detailed/0/700-red-front-png13286885734f322dbde9ae7.jpg";s:13:"relative_path";s:55:"detailed/0/700-red-front-png13286885734f322dbde9ae7.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2583444381";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:9:"Nokia 700";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:359;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:359;s:13:"display_price";d:359;}s:10:"3390371295";a:23:{s:10:"product_id";i:106;s:12:"product_code";s:10:"C0106D3GWB";s:7:"product";s:11:"Nokia E5-00";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:179.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"448";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"504";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:95:"http://localhost/git/work/images/detailed/0/E5-black-front-black-png13286888164f322eb054f4c.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:95:"http://localhost/git/work/images/detailed/0/E5-black-front-black-png13286888164f322eb054f4c.jpg";s:13:"absolute_path";s:98:"/Users/alexions/www/git/work/images/detailed/0/E5-black-front-black-png13286888164f322eb054f4c.jpg";s:13:"relative_path";s:62:"detailed/0/E5-black-front-black-png13286888164f322eb054f4c.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3390371295";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"Nokia E5-00";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:179.990;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:179.990;s:13:"display_price";d:179.990;}s:10:"1394451557";a:23:{s:10:"product_id";i:105;s:12:"product_code";s:10:"M01052HXOG";s:7:"product";s:15:"Nokia Lumia 800";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:169.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"447";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"503";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:70:"http://localhost/git/work/images/detailed/0/Searay-white-Front-png.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:70:"http://localhost/git/work/images/detailed/0/Searay-white-Front-png.jpg";s:13:"absolute_path";s:73:"/Users/alexions/www/git/work/images/detailed/0/Searay-white-Front-png.jpg";s:13:"relative_path";s:37:"detailed/0/Searay-white-Front-png.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1394451557";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:15:"Nokia Lumia 800";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:169.990;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:169.990;s:13:"display_price";d:169.990;}s:10:"1416650876";a:23:{s:10:"product_id";i:101;s:12:"product_code";s:10:"E01010TOGW";s:7:"product";s:11:"Nokia X3-02";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:188.88;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"442";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"498";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:69:"http://localhost/git/work/images/detailed/0/X3-02-white-front-png.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:69:"http://localhost/git/work/images/detailed/0/X3-02-white-front-png.jpg";s:13:"absolute_path";s:72:"/Users/alexions/www/git/work/images/detailed/0/X3-02-white-front-png.jpg";s:13:"relative_path";s:36:"detailed/0/X3-02-white-front-png.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1416650876";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"Nokia X3-02";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:188.88;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:188.88;s:13:"display_price";d:188.88;}}s:12:"package_info";a:7:{s:1:"C";d:897.860;s:1:"W";s:4:"0.01";s:1:"I";i:4;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:4:{s:10:"2583444381";i:1;s:10:"3390371295";i:1;s:10:"1394451557";i:1;s:10:"1416650876";i:1;}s:6:"amount";i:4;s:6:"weight";d:0.100;s:4:"cost";d:897.860;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}');
INSERT INTO `[[dbprefix]]order_data` VALUES
(210, 77, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:4:{s:10:"2583444381";a:23:{s:10:"product_id";i:86;s:12:"product_code";s:10:"I0086KA0W2";s:7:"product";s:9:"Nokia 700";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:359;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"454";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"510";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:88:"http://localhost/git/work/images/detailed/0/700-red-front-png13286885734f322dbde9ae7.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:88:"http://localhost/git/work/images/detailed/0/700-red-front-png13286885734f322dbde9ae7.jpg";s:13:"absolute_path";s:91:"/Users/alexions/www/git/work/images/detailed/0/700-red-front-png13286885734f322dbde9ae7.jpg";s:13:"relative_path";s:55:"detailed/0/700-red-front-png13286885734f322dbde9ae7.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2583444381";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:9:"Nokia 700";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:359;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:359;s:13:"display_price";d:359;}s:10:"3390371295";a:23:{s:10:"product_id";i:106;s:12:"product_code";s:10:"C0106D3GWB";s:7:"product";s:11:"Nokia E5-00";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:179.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"448";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"504";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:95:"http://localhost/git/work/images/detailed/0/E5-black-front-black-png13286888164f322eb054f4c.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:95:"http://localhost/git/work/images/detailed/0/E5-black-front-black-png13286888164f322eb054f4c.jpg";s:13:"absolute_path";s:98:"/Users/alexions/www/git/work/images/detailed/0/E5-black-front-black-png13286888164f322eb054f4c.jpg";s:13:"relative_path";s:62:"detailed/0/E5-black-front-black-png13286888164f322eb054f4c.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3390371295";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"Nokia E5-00";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:179.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:179.990;s:13:"display_price";d:179.990;}s:10:"1394451557";a:23:{s:10:"product_id";i:105;s:12:"product_code";s:10:"M01052HXOG";s:7:"product";s:15:"Nokia Lumia 800";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:169.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"447";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"503";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:70:"http://localhost/git/work/images/detailed/0/Searay-white-Front-png.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:70:"http://localhost/git/work/images/detailed/0/Searay-white-Front-png.jpg";s:13:"absolute_path";s:73:"/Users/alexions/www/git/work/images/detailed/0/Searay-white-Front-png.jpg";s:13:"relative_path";s:37:"detailed/0/Searay-white-Front-png.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1394451557";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:15:"Nokia Lumia 800";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:169.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:169.990;s:13:"display_price";d:169.990;}s:10:"1416650876";a:23:{s:10:"product_id";i:101;s:12:"product_code";s:10:"E01010TOGW";s:7:"product";s:11:"Nokia X3-02";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:188.88;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"442";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"498";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:69:"http://localhost/git/work/images/detailed/0/X3-02-white-front-png.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:69:"http://localhost/git/work/images/detailed/0/X3-02-white-front-png.jpg";s:13:"absolute_path";s:72:"/Users/alexions/www/git/work/images/detailed/0/X3-02-white-front-png.jpg";s:13:"relative_path";s:36:"detailed/0/X3-02-white-front-png.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1416650876";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"Nokia X3-02";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:188.88;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:188.88;s:13:"display_price";d:188.88;}}s:12:"package_info";a:7:{s:1:"C";d:897.860;s:1:"W";s:4:"0.01";s:1:"I";i:4;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:4:{s:10:"2583444381";i:1;s:10:"3390371295";i:1;s:10:"1394451557";i:1;s:10:"1416650876";i:1;}s:6:"amount";i:4;s:6:"weight";d:0.100;s:4:"cost";d:897.860;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(211, 73, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"3636250333";a:23:{s:10:"product_id";i:15;s:12:"product_code";s:10:"H0015EXYM6";s:7:"product";s:39:"Nike Chambray Super Runner Men''s Jacket";s:6:"amount";i:1;s:15:"product_options";a:1:{i:2;s:1:"6";}s:5:"price";d:150;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"224";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"280";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/452499_010_A.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"900";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/452499_010_A.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/452499_010_A.jpg";s:13:"relative_path";s:27:"detailed/0/452499_010_A.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3636250333";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:1:{i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:39:"Nike Chambray Super Runner Men''s Jacket";s:10:"company_id";s:1:"2";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:150;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:1:{i:0;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:2:"15";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:150;s:13:"display_price";d:150;}}s:12:"package_info";a:7:{s:1:"C";d:150;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"3636250333";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:150;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(212, 69, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:3:{s:10:"1212055764";a:23:{s:10:"product_id";i:16;s:12:"product_code";s:10:"H00162EP2P";s:7:"product";s:36:"3D Blu-ray Disc™ Player (BD-D7500)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:349.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"226";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"282";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:66:"http://localhost/git/work/images/detailed/0/BD-D7500_01-copy_5.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:66:"http://localhost/git/work/images/detailed/0/BD-D7500_01-copy_5.jpg";s:13:"absolute_path";s:69:"/Users/alexions/www/git/work/images/detailed/0/BD-D7500_01-copy_5.jpg";s:13:"relative_path";s:33:"detailed/0/BD-D7500_01-copy_5.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1212055764";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"3D Blu-ray Disc™ Player (BD-D7500)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:349.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:349.990;s:13:"display_price";d:349.990;}s:10:"1685985038";a:23:{s:10:"product_id";i:22;s:12:"product_code";s:10:"F0022TLB3Q";s:7:"product";s:42:"7.1 Channel Blu-ray 3D Home Theater System";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:799.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"239";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"295";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:59:"http://localhost/git/work/images/detailed/0/HT_D6730W_5.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1086";s:7:"image_y";s:3:"768";s:15:"http_image_path";s:59:"http://localhost/git/work/images/detailed/0/HT_D6730W_5.jpg";s:13:"absolute_path";s:62:"/Users/alexions/www/git/work/images/detailed/0/HT_D6730W_5.jpg";s:13:"relative_path";s:26:"detailed/0/HT_D6730W_5.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1685985038";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:42:"7.1 Channel Blu-ray 3D Home Theater System";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:799.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:799.990;s:13:"display_price";d:799.990;}s:10:"2707236321";a:23:{s:10:"product_id";i:10;s:12:"product_code";s:10:"L00102FQ97";s:7:"product";s:45:"Toshiba 47TL515U 47" Class 1080P 3D LED HD TV";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:1199.99;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"209";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"265";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/47tl515.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"300";s:7:"image_y";s:3:"300";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/47tl515.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/47tl515.jpg";s:13:"relative_path";s:22:"detailed/0/47tl515.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2707236321";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"Toshiba 47TL515U 47" Class 1080P 3D LED HD TV";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1199.99;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:1199.99;s:13:"display_price";d:1199.99;}}s:12:"package_info";a:7:{s:1:"C";d:2349.970;s:1:"W";s:4:"0.01";s:1:"I";i:3;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:3:{s:10:"1212055764";i:1;s:10:"1685985038";i:1;s:10:"2707236321";i:1;}s:6:"amount";i:3;s:6:"weight";d:0.100;s:4:"cost";d:2349.970;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Oliver";s:8:"lastname";s:4:"Kahn";s:7:"address";s:15:"Bodestraße 1-3";s:9:"address_2";N;s:4:"city";s:6:"Berlin";s:6:"county";N;s:5:"state";s:3:"BER";s:7:"country";s:2:"DE";s:7:"zipcode";s:5:"10178";s:5:"phone";s:14:"+4930266424242";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:7:"Germany";s:11:"state_descr";s:6:"Berlin";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(213, 68, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"1941964244";a:23:{s:10:"product_id";i:239;s:12:"product_code";s:10:"L0239KVQ9F";s:7:"product";s:21:"Apple iPhone 4S White";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:509.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"800";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"856";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:63:"http://localhost/git/work/images/detailed/0/white-iphone-hi.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:63:"http://localhost/git/work/images/detailed/0/white-iphone-hi.jpg";s:13:"absolute_path";s:66:"/Users/alexions/www/git/work/images/detailed/0/white-iphone-hi.jpg";s:13:"relative_path";s:30:"detailed/0/white-iphone-hi.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1941964244";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Apple iPhone 4S White";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:509.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:509.990;s:13:"display_price";d:509.990;}}s:12:"package_info";a:7:{s:1:"C";d:509.990;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"1941964244";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:509.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Oliver";s:8:"lastname";s:4:"Kahn";s:7:"address";s:15:"Bodestraße 1-3";s:9:"address_2";N;s:4:"city";s:6:"Berlin";s:6:"county";N;s:5:"state";s:3:"BER";s:7:"country";s:2:"DE";s:7:"zipcode";s:5:"10178";s:5:"phone";s:14:"+4930266424242";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:7:"Germany";s:11:"state_descr";s:6:"Berlin";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(214, 67, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:9:"372045425";a:23:{s:10:"product_id";i:124;s:12:"product_code";s:10:"D01245K7FF";s:7:"product";s:38:"Truth SST.2 X9 Complete Bike 10SPD ''12";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:4595;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"479";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"535";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:56:"http://localhost/git/work/images/detailed/0/CB-truth.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"936";s:7:"image_y";s:3:"612";s:15:"http_image_path";s:56:"http://localhost/git/work/images/detailed/0/CB-truth.jpg";s:13:"absolute_path";s:59:"/Users/alexions/www/git/work/images/detailed/0/CB-truth.jpg";s:13:"relative_path";s:23:"detailed/0/CB-truth.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"372045425";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:38:"Truth SST.2 X9 Complete Bike 10SPD ''12";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:4595;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:4595;s:13:"display_price";d:4595;}}s:12:"package_info";a:7:{s:1:"C";d:4595;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:9:"372045425";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:4595;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Oliver";s:8:"lastname";s:4:"Kahn";s:7:"address";s:15:"Bodestraße 1-3";s:9:"address_2";N;s:4:"city";s:6:"Berlin";s:6:"county";N;s:5:"state";s:3:"BER";s:7:"country";s:2:"DE";s:7:"zipcode";s:5:"10178";s:5:"phone";s:14:"+4930266424242";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:7:"Germany";s:11:"state_descr";s:6:"Berlin";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(215, 66, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"4283388740";a:23:{s:10:"product_id";i:122;s:12:"product_code";s:10:"J01223DYAH";s:7:"product";s:40:"Evolution SST.2 XO Complete Bike 10SPD12";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:5695;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"477";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"533";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/CB-evolution.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"936";s:7:"image_y";s:3:"612";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/CB-evolution.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/CB-evolution.jpg";s:13:"relative_path";s:27:"detailed/0/CB-evolution.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4283388740";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:40:"Evolution SST.2 XO Complete Bike 10SPD12";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:5695;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:5695;s:13:"display_price";d:5695;}}s:12:"package_info";a:7:{s:1:"C";d:5695;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"4283388740";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:5695;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(216, 65, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"3210050320";a:23:{s:10:"product_id";i:207;s:12:"product_code";s:10:"W0207TLU5R";s:7:"product";s:12:"Asus USB-N53";s:6:"amount";i:15;s:15:"product_options";a:0:{}s:5:"price";d:42;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"694";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"750";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:53:"http://localhost/git/work/images/detailed/0/P_500.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:53:"http://localhost/git/work/images/detailed/0/P_500.jpg";s:13:"absolute_path";s:56:"/Users/alexions/www/git/work/images/detailed/0/P_500.jpg";s:13:"relative_path";s:20:"detailed/0/P_500.jpg";}}s:15:"original_amount";s:2:"15";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3210050320";s:6:"amount";s:2:"15";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:12:"Asus USB-N53";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:42;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:15;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:42;s:13:"display_price";d:42;}}s:12:"package_info";a:7:{s:1:"C";d:630;s:1:"W";s:4:"0.01";s:1:"I";i:15;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"3210050320";i:15;}s:6:"amount";i:15;s:6:"weight";d:0.100;s:4:"cost";i:630;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:20;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:1.820;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:20;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(217, 63, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:3:{s:10:"1860791280";a:23:{s:10:"product_id";i:94;s:12:"product_code";s:10:"A0094VY6U3";s:7:"product";s:26:"Batman: Arkham City (X360)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:59.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"431";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"487";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/1000176186_f.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"625";s:7:"image_y";s:3:"849";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/1000176186_f.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/1000176186_f.jpg";s:13:"relative_path";s:27:"detailed/0/1000176186_f.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1860791280";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:26:"Batman: Arkham City (X360)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:59.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:59.990;s:13:"display_price";d:59.990;}s:10:"1770303465";a:23:{s:10:"product_id";i:90;s:12:"product_code";s:10:"Y0090CLU50";s:7:"product";s:19:"F.E.A.R. 3 (PS3) MX";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:19.989;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"420";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"476";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/1000202232_f.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1200";s:7:"image_y";s:4:"1200";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/1000202232_f.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/1000202232_f.jpg";s:13:"relative_path";s:27:"detailed/0/1000202232_f.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1770303465";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:19:"F.E.A.R. 3 (PS3) MX";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:19.989;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:19.989;s:13:"display_price";d:19.989;}s:10:"2660368260";a:23:{s:10:"product_id";i:82;s:12:"product_code";s:10:"S0082Z8OYM";s:7:"product";s:49:"Legend of the Guardians: the Owls of Ga''hoole(VG)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:19.989;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"412";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"468";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/2817406.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"878";s:7:"image_y";s:4:"1200";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/2817406.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/2817406.jpg";s:13:"relative_path";s:22:"detailed/0/2817406.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2660368260";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:49:"Legend of the Guardians: the Owls of Ga''hoole(VG)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:19.989;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:19.989;s:13:"display_price";d:19.989;}}s:12:"package_info";a:7:{s:1:"C";d:99.969;s:1:"W";s:4:"0.01";s:1:"I";i:3;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:3:{s:10:"1860791280";i:1;s:10:"1770303465";i:1;s:10:"2660368260";i:1;}s:6:"amount";i:3;s:6:"weight";d:0.100;s:4:"cost";d:99.969;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}');
INSERT INTO `[[dbprefix]]order_data` VALUES
(218, 61, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:9:"342509608";a:23:{s:10:"product_id";i:224;s:12:"product_code";s:10:"Y0224Y3QQU";s:7:"product";s:32:"Samsung Galaxy Tab™ 8.9 (AT&T)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:479.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"760";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"816";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:70:"http://localhost/git/work/images/detailed/0/i957_600x600_xlarge_hf.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:70:"http://localhost/git/work/images/detailed/0/i957_600x600_xlarge_hf.jpg";s:13:"absolute_path";s:73:"/Users/alexions/www/git/work/images/detailed/0/i957_600x600_xlarge_hf.jpg";s:13:"relative_path";s:37:"detailed/0/i957_600x600_xlarge_hf.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"342509608";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:32:"Samsung Galaxy Tab™ 8.9 (AT&T)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:479.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:479.990;s:13:"display_price";d:479.990;}}s:12:"package_info";a:7:{s:1:"C";d:479.990;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:9:"342509608";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:479.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(219, 59, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:6:{s:10:"3421137111";a:23:{s:10:"product_id";i:58;s:12:"product_code";s:10:"I0058SG177";s:7:"product";s:11:"AVH-P8400BH";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:779;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"316";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"372";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:65:"http://localhost/git/work/images/detailed/0/AVH-P8400BH_large.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"800";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:65:"http://localhost/git/work/images/detailed/0/AVH-P8400BH_large.jpg";s:13:"absolute_path";s:68:"/Users/alexions/www/git/work/images/detailed/0/AVH-P8400BH_large.jpg";s:13:"relative_path";s:32:"detailed/0/AVH-P8400BH_large.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3421137111";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"AVH-P8400BH";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:779;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:779;s:13:"display_price";d:779;}s:10:"3994858278";a:23:{s:10:"product_id";i:60;s:12:"product_code";s:10:"O0060X7Y9Y";s:7:"product";s:11:"AVIC-Z130BT";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:1499;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"328";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"384";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:63:"http://localhost/git/work/images/detailed/0/AVIC-Z130BT_reg.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:63:"http://localhost/git/work/images/detailed/0/AVIC-Z130BT_reg.jpg";s:13:"absolute_path";s:66:"/Users/alexions/www/git/work/images/detailed/0/AVIC-Z130BT_reg.jpg";s:13:"relative_path";s:30:"detailed/0/AVIC-Z130BT_reg.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3994858278";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"AVIC-Z130BT";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1499;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:1499;s:13:"display_price";d:1499;}s:10:"1159954462";a:23:{s:10:"product_id";i:43;s:12:"product_code";s:10:"N0043XCGKY";s:7:"product";s:10:"FH-P8000BT";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:369;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"288";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"344";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:67:"http://localhost/git/work/images/detailed/0/FH-P8000BT_main_Lrg.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"800";s:7:"image_y";s:3:"800";s:15:"http_image_path";s:67:"http://localhost/git/work/images/detailed/0/FH-P8000BT_main_Lrg.jpg";s:13:"absolute_path";s:70:"/Users/alexions/www/git/work/images/detailed/0/FH-P8000BT_main_Lrg.jpg";s:13:"relative_path";s:34:"detailed/0/FH-P8000BT_main_Lrg.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1159954462";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:10:"FH-P8000BT";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:369;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:369;s:13:"display_price";d:369;}s:10:"3042645098";a:23:{s:10:"product_id";i:55;s:12:"product_code";s:10:"N005510VYI";s:7:"product";s:8:"PRS-D800";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:359;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"308";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"364";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/PRS-D800_large.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/PRS-D800_large.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/PRS-D800_large.jpg";s:13:"relative_path";s:29:"detailed/0/PRS-D800_large.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3042645098";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:8:"PRS-D800";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:359;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:359;s:13:"display_price";d:359;}s:10:"3308380389";a:23:{s:10:"product_id";i:50;s:12:"product_code";s:10:"V0050M1GB0";s:7:"product";s:9:"TS-D1720C";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:220;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"300";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"356";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:63:"http://localhost/git/work/images/detailed/0/TS-D1720C_large.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"833";s:7:"image_y";s:3:"625";s:15:"http_image_path";s:63:"http://localhost/git/work/images/detailed/0/TS-D1720C_large.jpg";s:13:"absolute_path";s:66:"/Users/alexions/www/git/work/images/detailed/0/TS-D1720C_large.jpg";s:13:"relative_path";s:30:"detailed/0/TS-D1720C_large.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3308380389";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:9:"TS-D1720C";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:220;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:220;s:13:"display_price";d:220;}s:10:"3260818684";a:23:{s:10:"product_id";i:54;s:12:"product_code";s:10:"I0054QMMPO";s:7:"product";s:13:"TS-W3002D2|D4";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:269;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"307";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"363";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:66:"http://localhost/git/work/images/detailed/0/TS-W3002D2D4_large.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1024";s:7:"image_y";s:4:"1024";s:15:"http_image_path";s:66:"http://localhost/git/work/images/detailed/0/TS-W3002D2D4_large.jpg";s:13:"absolute_path";s:69:"/Users/alexions/www/git/work/images/detailed/0/TS-W3002D2D4_large.jpg";s:13:"relative_path";s:33:"detailed/0/TS-W3002D2D4_large.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3260818684";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:13:"TS-W3002D2|D4";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:269;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:269;s:13:"display_price";d:269;}}s:12:"package_info";a:7:{s:1:"C";d:3495;s:1:"W";s:4:"0.01";s:1:"I";i:6;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:6:{s:10:"3421137111";i:1;s:10:"3994858278";i:1;s:10:"1159954462";i:1;s:10:"3042645098";i:1;s:10:"3308380389";i:1;s:10:"3260818684";i:1;}s:6:"amount";i:6;s:6:"weight";d:0.100;s:4:"cost";i:3495;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"George";s:8:"lastname";s:5:"Nills";s:7:"address";s:19:"60 Centre Street #5";s:9:"address_2";N;s:4:"city";s:8:"New York";s:6:"county";N;s:5:"state";s:2:"NY";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+16463863600";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:8:"New York";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(220, 49, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:2:{s:9:"803890817";a:23:{s:10:"product_id";i:208;s:12:"product_code";s:10:"F0208V084C";s:7:"product";s:45:"H.264 Megapixel Surveillance Camera TL-SC3430";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:82.939;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"698";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"754";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/TL-SC3430-01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"800";s:7:"image_y";s:3:"800";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/TL-SC3430-01.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/TL-SC3430-01.jpg";s:13:"relative_path";s:27:"detailed/0/TL-SC3430-01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"803890817";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"H.264 Megapixel Surveillance Camera TL-SC3430";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:82.939;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:82.939;s:13:"display_price";d:82.939;}s:10:"3360836486";a:23:{s:10:"product_id";i:206;s:12:"product_code";s:10:"Q0206MCK7B";s:7:"product";s:46:"RT-N66U Dual-Band Wireless-N900 Gigabit Router";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:179.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"687";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"743";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:68:"http://localhost/git/work/images/detailed/0/hyyfnOGfxDQXnGM0_500.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1680";s:7:"image_y";s:4:"1187";s:15:"http_image_path";s:68:"http://localhost/git/work/images/detailed/0/hyyfnOGfxDQXnGM0_500.jpg";s:13:"absolute_path";s:71:"/Users/alexions/www/git/work/images/detailed/0/hyyfnOGfxDQXnGM0_500.jpg";s:13:"relative_path";s:35:"detailed/0/hyyfnOGfxDQXnGM0_500.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3360836486";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:46:"RT-N66U Dual-Band Wireless-N900 Gigabit Router";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:179.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:179.990;s:13:"display_price";d:179.990;}}s:12:"package_info";a:7:{s:1:"C";d:262.930;s:1:"W";s:4:"0.01";s:1:"I";i:2;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:2:{s:9:"803890817";i:1;s:10:"3360836486";i:1;}s:6:"amount";i:2;s:6:"weight";d:0.100;s:4:"cost";d:262.930;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Sergey";s:8:"lastname";s:6:"Maxeev";s:7:"address";s:25:"Moskovskaya street, 65-12";s:9:"address_2";N;s:4:"city";s:6:"Moscow";s:6:"county";N;s:5:"state";s:3:"MOS";s:7:"country";s:2:"RU";s:7:"zipcode";s:6:"657849";s:5:"phone";s:12:"+79235456683";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:18:"Russian Federation";s:11:"state_descr";s:19:"Moskovskaja oblast''";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(221, 48, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:2:{s:10:"1106667350";a:23:{s:10:"product_id";i:219;s:12:"product_code";s:10:"M0219A3GX3";s:7:"product";s:21:"Series 3 15.6" Laptop";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:529.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"724";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"780";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:74:"http://localhost/git/work/images/detailed/0/300V5A_Raspberry-Pink_04_6.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:74:"http://localhost/git/work/images/detailed/0/300V5A_Raspberry-Pink_04_6.jpg";s:13:"absolute_path";s:77:"/Users/alexions/www/git/work/images/detailed/0/300V5A_Raspberry-Pink_04_6.jpg";s:13:"relative_path";s:41:"detailed/0/300V5A_Raspberry-Pink_04_6.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1106667350";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Series 3 15.6" Laptop";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:529.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:529.990;s:13:"display_price";d:529.990;}s:10:"4245286173";a:23:{s:10:"product_id";i:222;s:12:"product_code";s:10:"P0222KUH4T";s:7:"product";s:21:"Series 3 15.6" Laptop";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:529.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"750";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"806";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:73:"http://localhost/git/work/images/detailed/0/600x600_NP300E5A-A01_main.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:73:"http://localhost/git/work/images/detailed/0/600x600_NP300E5A-A01_main.jpg";s:13:"absolute_path";s:76:"/Users/alexions/www/git/work/images/detailed/0/600x600_NP300E5A-A01_main.jpg";s:13:"relative_path";s:40:"detailed/0/600x600_NP300E5A-A01_main.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4245286173";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Series 3 15.6" Laptop";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:529.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:529.990;s:13:"display_price";d:529.990;}}s:12:"package_info";a:7:{s:1:"C";d:1059.98;s:1:"W";s:4:"0.01";s:1:"I";i:2;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:2:{s:10:"1106667350";i:1;s:10:"4245286173";i:1;}s:6:"amount";i:2;s:6:"weight";d:0.100;s:4:"cost";d:1059.98;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Sergey";s:8:"lastname";s:6:"Maxeev";s:7:"address";s:25:"Moskovskaya street, 65-12";s:9:"address_2";N;s:4:"city";s:6:"Moscow";s:6:"county";N;s:5:"state";s:3:"MOS";s:7:"country";s:2:"RU";s:7:"zipcode";s:6:"657849";s:5:"phone";s:12:"+79235456683";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:18:"Russian Federation";s:11:"state_descr";s:19:"Moskovskaja oblast''";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(222, 47, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2490902739";a:23:{s:10:"product_id";i:237;s:12:"product_code";s:10:"B0237HI9M0";s:7:"product";s:21:"Elite Evanston 8 Tent";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:299.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"795";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"851";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/2000004674_500.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/2000004674_500.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/2000004674_500.jpg";s:13:"relative_path";s:29:"detailed/0/2000004674_500.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2490902739";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Elite Evanston 8 Tent";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:299.990;s:13:"display_price";d:299.990;}}s:12:"package_info";a:7:{s:1:"C";d:299.990;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2490902739";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:299.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Sergey";s:8:"lastname";s:6:"Maxeev";s:7:"address";s:25:"Moskovskaya street, 65-12";s:9:"address_2";N;s:4:"city";s:6:"Moscow";s:6:"county";N;s:5:"state";s:3:"MOS";s:7:"country";s:2:"RU";s:7:"zipcode";s:6:"657849";s:5:"phone";s:12:"+79235456683";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:18:"Russian Federation";s:11:"state_descr";s:19:"Moskovskaja oblast''";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(223, 46, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2707236321";a:23:{s:10:"product_id";i:10;s:12:"product_code";s:10:"L00102FQ97";s:7:"product";s:45:"Toshiba 47TL515U 47" Class 1080P 3D LED HD TV";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:1199.99;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"209";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"265";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/47tl515.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"300";s:7:"image_y";s:3:"300";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/47tl515.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/47tl515.jpg";s:13:"relative_path";s:22:"detailed/0/47tl515.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2707236321";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"Toshiba 47TL515U 47" Class 1080P 3D LED HD TV";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1199.99;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:1199.99;s:13:"display_price";d:1199.99;}}s:12:"package_info";a:7:{s:1:"C";d:1199.99;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2707236321";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:1199.99;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Sergey";s:8:"lastname";s:6:"Maxeev";s:7:"address";s:25:"Moskovskaya street, 65-12";s:9:"address_2";N;s:4:"city";s:6:"Moscow";s:6:"county";N;s:5:"state";s:3:"MOS";s:7:"country";s:2:"RU";s:7:"zipcode";s:6:"657849";s:5:"phone";s:12:"+79235456683";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:18:"Russian Federation";s:11:"state_descr";s:19:"Moskovskaja oblast''";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(224, 45, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:9:"217141192";a:23:{s:10:"product_id";i:169;s:12:"product_code";s:10:"A016998ZXV";s:7:"product";s:53:"D5100 + AF-S DX NIKKOR 18-55mm f/3.5-5.6G VR Lens Kit";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:749.950;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"605";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"661";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/25478_1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1200";s:7:"image_y";s:4:"1200";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/25478_1.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/25478_1.jpg";s:13:"relative_path";s:22:"detailed/0/25478_1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"217141192";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:53:"D5100 + AF-S DX NIKKOR 18-55mm f/3.5-5.6G VR Lens Kit";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:749.950;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:749.950;s:13:"display_price";d:749.950;}}s:12:"package_info";a:7:{s:1:"C";d:749.950;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:9:"217141192";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:749.950;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Sergey";s:8:"lastname";s:6:"Maxeev";s:7:"address";s:25:"Moskovskaya street, 65-12";s:9:"address_2";N;s:4:"city";s:6:"Moscow";s:6:"county";N;s:5:"state";s:3:"MOS";s:7:"country";s:2:"RU";s:7:"zipcode";s:6:"657849";s:5:"phone";s:12:"+79235456683";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:18:"Russian Federation";s:11:"state_descr";s:19:"Moskovskaja oblast''";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(225, 44, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"3308380389";a:23:{s:10:"product_id";i:50;s:12:"product_code";s:10:"V0050M1GB0";s:7:"product";s:9:"TS-D1720C";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:220;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"300";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"356";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:63:"http://localhost/git/work/images/detailed/0/TS-D1720C_large.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"833";s:7:"image_y";s:3:"625";s:15:"http_image_path";s:63:"http://localhost/git/work/images/detailed/0/TS-D1720C_large.jpg";s:13:"absolute_path";s:66:"/Users/alexions/www/git/work/images/detailed/0/TS-D1720C_large.jpg";s:13:"relative_path";s:30:"detailed/0/TS-D1720C_large.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3308380389";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:9:"TS-D1720C";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:220;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:220;s:13:"display_price";d:220;}}s:12:"package_info";a:7:{s:1:"C";d:220;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"3308380389";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:220;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Sergey";s:8:"lastname";s:6:"Maxeev";s:7:"address";s:25:"Moskovskaya street, 65-12";s:9:"address_2";N;s:4:"city";s:6:"Moscow";s:6:"county";N;s:5:"state";s:3:"MOS";s:7:"country";s:2:"RU";s:7:"zipcode";s:6:"657849";s:5:"phone";s:12:"+79235456683";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:18:"Russian Federation";s:11:"state_descr";s:19:"Moskovskaja oblast''";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(226, 43, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2316230027";a:23:{s:10:"product_id";i:223;s:12:"product_code";s:10:"O0223AQI3W";s:7:"product";s:56:"Samsung Galaxy Tab 8.9 (Wi-Fi Only) - 32GB Metallic Gray";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:499.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"753";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"809";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:73:"http://localhost/git/work/images/detailed/0/p7310_400x400_large1_cf_1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"728";s:7:"image_y";s:3:"546";s:15:"http_image_path";s:73:"http://localhost/git/work/images/detailed/0/p7310_400x400_large1_cf_1.jpg";s:13:"absolute_path";s:76:"/Users/alexions/www/git/work/images/detailed/0/p7310_400x400_large1_cf_1.jpg";s:13:"relative_path";s:40:"detailed/0/p7310_400x400_large1_cf_1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2316230027";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:56:"Samsung Galaxy Tab 8.9 (Wi-Fi Only) - 32GB Metallic Gray";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:499.990;s:12:"stored_price";s:1:"Y";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:499.990;s:13:"display_price";d:499.990;}}s:12:"package_info";a:7:{s:1:"C";d:499.990;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2316230027";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:499.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Sergey";s:8:"lastname";s:6:"Maxeev";s:7:"address";s:25:"Moskovskaya street, 65-12";s:9:"address_2";N;s:4:"city";s:6:"Moscow";s:6:"county";N;s:5:"state";s:3:"MOS";s:7:"country";s:2:"RU";s:7:"zipcode";s:6:"657849";s:5:"phone";s:12:"+79235456683";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:18:"Russian Federation";s:11:"state_descr";s:19:"Moskovskaja oblast''";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}');
INSERT INTO `[[dbprefix]]order_data` VALUES
(227, 42, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"1860791280";a:23:{s:10:"product_id";i:94;s:12:"product_code";s:10:"A0094VY6U3";s:7:"product";s:26:"Batman: Arkham City (X360)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:59.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"431";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"487";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/1000176186_f.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"625";s:7:"image_y";s:3:"849";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/1000176186_f.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/1000176186_f.jpg";s:13:"relative_path";s:27:"detailed/0/1000176186_f.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1860791280";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:26:"Batman: Arkham City (X360)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:59.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:59.990;s:13:"display_price";d:59.990;}}s:12:"package_info";a:7:{s:1:"C";d:59.990;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"1860791280";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:59.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Sergey";s:8:"lastname";s:6:"Maxeev";s:7:"address";s:25:"Moskovskaya street, 65-12";s:9:"address_2";N;s:4:"city";s:6:"Moscow";s:6:"county";N;s:5:"state";s:3:"MOS";s:7:"country";s:2:"RU";s:7:"zipcode";s:6:"657849";s:5:"phone";s:12:"+79235456683";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:18:"Russian Federation";s:11:"state_descr";s:19:"Moskovskaja oblast''";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:11:"taxed_price";i:0;s:5:"taxes";b:0;}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(228, 41, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"4191947349";a:23:{s:10:"product_id";i:78;s:12:"product_code";s:10:"L0078RO9Y9";s:7:"product";s:18:"adizero Rush Shoes";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:100;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"397";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"453";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/G48874_01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/G48874_01.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/G48874_01.jpg";s:13:"relative_path";s:24:"detailed/0/G48874_01.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4191947349";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:18:"adizero Rush Shoes";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:100;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:100;s:13:"display_price";d:100;}}s:12:"package_info";a:7:{s:1:"C";d:100;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"4191947349";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:100;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Sergey";s:8:"lastname";s:6:"Maxeev";s:7:"address";s:25:"Moskovskaya street, 65-12";s:9:"address_2";N;s:4:"city";s:6:"Moscow";s:6:"county";N;s:5:"state";s:3:"MOS";s:7:"country";s:2:"RU";s:7:"zipcode";s:6:"657849";s:5:"phone";s:12:"+79235456683";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:18:"Russian Federation";s:11:"state_descr";s:19:"Moskovskaja oblast''";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:11:"taxed_price";i:0;s:5:"taxes";b:0;}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(229, 40, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"1976192833";a:23:{s:10:"product_id";i:187;s:12:"product_code";s:10:"D0187LXFZO";s:7:"product";s:23:"2010 TOUR STAFF Bag 10"";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:299.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"662";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"718";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:80:"http://localhost/git/work/images/detailed/0/167734bda696f56942c278bee07e7236.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"800";s:7:"image_y";s:3:"800";s:15:"http_image_path";s:80:"http://localhost/git/work/images/detailed/0/167734bda696f56942c278bee07e7236.jpg";s:13:"absolute_path";s:83:"/Users/alexions/www/git/work/images/detailed/0/167734bda696f56942c278bee07e7236.jpg";s:13:"relative_path";s:47:"detailed/0/167734bda696f56942c278bee07e7236.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1976192833";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:23:"2010 TOUR STAFF Bag 10"";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:299.990;s:13:"display_price";d:299.990;}}s:12:"package_info";a:7:{s:1:"C";d:299.990;s:1:"W";s:5:"20.00";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"1976192833";i:1;}s:6:"amount";i:1;s:6:"weight";d:20;s:4:"cost";d:299.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Sergey";s:8:"lastname";s:6:"Maxeev";s:7:"address";s:25:"Moskovskaya street, 65-12";s:9:"address_2";N;s:4:"city";s:6:"Moscow";s:6:"county";N;s:5:"state";s:3:"MOS";s:7:"country";s:2:"RU";s:7:"zipcode";s:6:"657849";s:5:"phone";s:12:"+79235456683";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:18:"Russian Federation";s:11:"state_descr";s:19:"Moskovskaja oblast''";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(230, 39, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"3696523789";a:23:{s:10:"product_id";i:243;s:12:"product_code";s:10:"U02431526C";s:7:"product";s:24:"Apple iPod Classic White";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:249;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"802";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"858";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:63:"http://localhost/git/work/images/detailed/0/ipod-shuffle-hi.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"521";s:15:"http_image_path";s:63:"http://localhost/git/work/images/detailed/0/ipod-shuffle-hi.jpg";s:13:"absolute_path";s:66:"/Users/alexions/www/git/work/images/detailed/0/ipod-shuffle-hi.jpg";s:13:"relative_path";s:30:"detailed/0/ipod-shuffle-hi.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3696523789";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:24:"Apple iPod Classic White";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:249;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:249;s:13:"display_price";d:249;}}s:12:"package_info";a:7:{s:1:"C";d:249;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"3696523789";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:249;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:5:"David";s:8:"lastname";s:6:"Tenant";s:7:"address";s:27:"Glasgow, Lanarkshire G2 1DS";s:9:"address_2";N;s:4:"city";s:7:"Glasgow";s:6:"county";N;s:5:"state";s:4:"GLAS";s:7:"country";s:2:"GB";s:7:"zipcode";s:7:"141 332";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:30:"United Kingdom (Great Britain)";s:11:"state_descr";s:7:"Glasgow";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(231, 38, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"1965946732";a:23:{s:10:"product_id";i:160;s:12:"product_code";s:10:"L0160MZ4DS";s:7:"product";s:9:"Drifter 3";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:200;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"559";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"615";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:82:"http://localhost/git/work/images/detailed/0/DB2010Drifter3SatinRed_Profile_LRG.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"800";s:7:"image_y";s:3:"800";s:15:"http_image_path";s:82:"http://localhost/git/work/images/detailed/0/DB2010Drifter3SatinRed_Profile_LRG.jpg";s:13:"absolute_path";s:85:"/Users/alexions/www/git/work/images/detailed/0/DB2010Drifter3SatinRed_Profile_LRG.jpg";s:13:"relative_path";s:49:"detailed/0/DB2010Drifter3SatinRed_Profile_LRG.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1965946732";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:9:"Drifter 3";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:200;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:200;s:13:"display_price";d:200;}}s:12:"package_info";a:7:{s:1:"C";d:200;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"1965946732";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:200;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:5:"David";s:8:"lastname";s:6:"Tenant";s:7:"address";s:27:"Glasgow, Lanarkshire G2 1DS";s:9:"address_2";N;s:4:"city";s:7:"Glasgow";s:6:"county";N;s:5:"state";s:4:"GLAS";s:7:"country";s:2:"GB";s:7:"zipcode";s:7:"141 332";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:30:"United Kingdom (Great Britain)";s:11:"state_descr";s:7:"Glasgow";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(232, 37, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2118391450";a:23:{s:10:"product_id";i:88;s:12:"product_code";s:10:"E0088Z4YB8";s:7:"product";s:40:"Lord of the Rings: War in the North(PS3)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:39.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"418";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"474";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/3086390.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1040";s:7:"image_y";s:4:"1040";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/3086390.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/3086390.jpg";s:13:"relative_path";s:22:"detailed/0/3086390.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2118391450";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:40:"Lord of the Rings: War in the North(PS3)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:39.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:39.990;s:13:"display_price";d:39.990;}}s:12:"package_info";a:7:{s:1:"C";d:39.990;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2118391450";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:39.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:5:"David";s:8:"lastname";s:6:"Tenant";s:7:"address";s:27:"Glasgow, Lanarkshire G2 1DS";s:9:"address_2";N;s:4:"city";s:7:"Glasgow";s:6:"county";N;s:5:"state";s:4:"GLAS";s:7:"country";s:2:"GB";s:7:"zipcode";s:7:"141 332";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:30:"United Kingdom (Great Britain)";s:11:"state_descr";s:7:"Glasgow";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:11:"taxed_price";i:0;s:5:"taxes";b:0;}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(233, 36, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:9:"766302424";a:23:{s:10:"product_id";i:108;s:12:"product_code";s:10:"I0108TD8BL";s:7:"product";s:18:"Due Date (Blu-ray)";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:12.99;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"452";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"508";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:55:"http://localhost/git/work/images/detailed/0/2891878.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"636";s:15:"http_image_path";s:55:"http://localhost/git/work/images/detailed/0/2891878.jpg";s:13:"absolute_path";s:58:"/Users/alexions/www/git/work/images/detailed/0/2891878.jpg";s:13:"relative_path";s:22:"detailed/0/2891878.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"766302424";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:18:"Due Date (Blu-ray)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:12.99;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:12.99;s:13:"display_price";d:12.99;}}s:12:"package_info";a:7:{s:1:"C";d:12.99;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:9:"766302424";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:12.99;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:5:"David";s:8:"lastname";s:6:"Tenant";s:7:"address";s:27:"Glasgow, Lanarkshire G2 1DS";s:9:"address_2";N;s:4:"city";s:7:"Glasgow";s:6:"county";N;s:5:"state";s:4:"GLAS";s:7:"country";s:2:"GB";s:7:"zipcode";s:7:"141 332";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:30:"United Kingdom (Great Britain)";s:11:"state_descr";s:7:"Glasgow";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:11:"taxed_price";i:0;s:5:"taxes";b:0;}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(234, 35, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:9:"304156957";a:23:{s:10:"product_id";i:34;s:12:"product_code";s:10:"W00341JAWN";s:7:"product";s:35:"Nike "Untouchable" Women''s Tank Top";s:6:"amount";i:1;s:15:"product_options";a:1:{i:2;s:1:"6";}s:5:"price";d:25;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"264";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"320";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/451160_063_A.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"900";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/451160_063_A.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/451160_063_A.jpg";s:13:"relative_path";s:27:"detailed/0/451160_063_A.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"304156957";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:1:{i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:35:"Nike "Untouchable" Women''s Tank Top";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:25;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:1:{i:0;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:25;s:13:"display_price";d:25;}}s:12:"package_info";a:7:{s:1:"C";d:25;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:9:"304156957";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:25;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:5:"David";s:8:"lastname";s:6:"Tenant";s:7:"address";s:27:"Glasgow, Lanarkshire G2 1DS";s:9:"address_2";N;s:4:"city";s:7:"Glasgow";s:6:"county";N;s:5:"state";s:4:"GLAS";s:7:"country";s:2:"GB";s:7:"zipcode";s:7:"141 332";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:30:"United Kingdom (Great Britain)";s:11:"state_descr";s:7:"Glasgow";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:11:"taxed_price";i:0;s:5:"taxes";b:0;}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(235, 29, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"4245286173";a:23:{s:10:"product_id";i:222;s:12:"product_code";s:10:"P0222KUH4T";s:7:"product";s:21:"Series 3 15.6" Laptop";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:529.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"750";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"806";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:73:"http://localhost/git/work/images/detailed/0/600x600_NP300E5A-A01_main.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:73:"http://localhost/git/work/images/detailed/0/600x600_NP300E5A-A01_main.jpg";s:13:"absolute_path";s:76:"/Users/alexions/www/git/work/images/detailed/0/600x600_NP300E5A-A01_main.jpg";s:13:"relative_path";s:40:"detailed/0/600x600_NP300E5A-A01_main.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4245286173";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Series 3 15.6" Laptop";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:529.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:529.990;s:13:"display_price";d:529.990;}}s:12:"package_info";a:7:{s:1:"C";d:529.990;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"4245286173";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:529.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:5:"David";s:8:"lastname";s:6:"Tenant";s:7:"address";s:27:"Glasgow, Lanarkshire G2 1DS";s:9:"address_2";N;s:4:"city";s:7:"Glasgow";s:6:"county";N;s:5:"state";s:4:"GLAS";s:7:"country";s:2:"GB";s:7:"zipcode";s:7:"141 332";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:30:"United Kingdom (Great Britain)";s:11:"state_descr";s:7:"Glasgow";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(236, 28, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:3:{s:10:"1237327324";a:23:{s:10:"product_id";i:148;s:12:"product_code";s:10:"H0148VPS1T";s:7:"product";s:31:"16GB A Series Walkman Video MP3";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:219;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"537";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"593";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:58:"http://localhost/git/work/images/detailed/0/NWZA865BLK.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:4:"1000";s:7:"image_y";s:4:"1000";s:15:"http_image_path";s:58:"http://localhost/git/work/images/detailed/0/NWZA865BLK.jpg";s:13:"absolute_path";s:61:"/Users/alexions/www/git/work/images/detailed/0/NWZA865BLK.jpg";s:13:"relative_path";s:25:"detailed/0/NWZA865BLK.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"1237327324";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:31:"16GB A Series Walkman Video MP3";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:219;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:219;s:13:"display_price";d:219;}s:10:"3954105058";a:23:{s:10:"product_id";i:180;s:12:"product_code";s:10:"Q01802L8VS";s:7:"product";s:21:"18-55mm Portrait Lens";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:199.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"650";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"706";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/EX-S1855SB_600.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/EX-S1855SB_600.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/EX-S1855SB_600.jpg";s:13:"relative_path";s:29:"detailed/0/EX-S1855SB_600.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3954105058";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"18-55mm Portrait Lens";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:199.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:199.990;s:13:"display_price";d:199.990;}s:10:"3416647405";a:23:{s:10:"product_id";i:241;s:12:"product_code";s:10:"I0241GCXF9";s:7:"product";s:59:"Apple® - iPad® with Retina® display Wi-Fi - 32GB - White";s:6:"amount";i:1;s:15:"product_options";a:2:{i:13;s:2:"48";i:12;s:2:"44";}s:5:"price";d:499;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"851";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"907";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:60:"http://localhost/git/work/images/detailed/0/ipad-white-1.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"536";s:7:"image_y";s:3:"742";s:15:"http_image_path";s:60:"http://localhost/git/work/images/detailed/0/ipad-white-1.jpg";s:13:"absolute_path";s:63:"/Users/alexions/www/git/work/images/detailed/0/ipad-white-1.jpg";s:13:"relative_path";s:27:"detailed/0/ipad-white-1.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"3416647405";s:6:"amount";s:1:"1";}s:5:"extra";a:10:{s:15:"product_options";a:2:{i:13;s:2:"48";i:12;s:2:"44";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:59:"Apple® - iPad® with Retina® display Wi-Fi - 32GB - White";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:499;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:2:"13";s:10:"product_id";s:3:"241";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"C";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"48";s:11:"option_name";s:15:"3G Connectivity";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:2:"No";}i:1;a:22:{s:9:"option_id";s:2:"12";s:10:"product_id";s:3:"241";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"44";s:11:"option_name";s:15:"Memory capacity";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:4:"16GB";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:499;s:13:"display_price";d:499;}}s:12:"package_info";a:7:{s:1:"C";d:917.990;s:1:"W";s:4:"0.01";s:1:"I";i:3;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:3:{s:10:"1237327324";i:1;s:10:"3954105058";i:1;s:10:"3416647405";i:1;}s:6:"amount";i:3;s:6:"weight";d:0.100;s:4:"cost";d:917.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:5:"David";s:8:"lastname";s:6:"Tenant";s:7:"address";s:27:"Glasgow, Lanarkshire G2 1DS";s:9:"address_2";N;s:4:"city";s:7:"Glasgow";s:6:"county";N;s:5:"state";s:4:"GLAS";s:7:"country";s:2:"GB";s:7:"zipcode";s:7:"141 332";s:5:"phone";s:12:"+16175555555";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:30:"United Kingdom (Great Britain)";s:11:"state_descr";s:7:"Glasgow";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"F";s:10:"rate_value";s:2:"12";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:12;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:25.449;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(237, 26, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2889884971";a:23:{s:10:"product_id";i:45;s:12:"product_code";s:10:"Q0045PT1DZ";s:7:"product";s:37:"The Process of Research in Psychology";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:74;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"294";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"350";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:116:"http://localhost/git/work/images/detailed/0/29336_McBride_The_Process_of_Research_in_Psychology_72ppiRGB_150pixW.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:116:"http://localhost/git/work/images/detailed/0/29336_McBride_The_Process_of_Research_in_Psychology_72ppiRGB_150pixW.jpg";s:13:"absolute_path";s:119:"/Users/alexions/www/git/work/images/detailed/0/29336_McBride_The_Process_of_Research_in_Psychology_72ppiRGB_150pixW.jpg";s:13:"relative_path";s:83:"detailed/0/29336_McBride_The_Process_of_Research_in_Psychology_72ppiRGB_150pixW.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2889884971";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:37:"The Process of Research in Psychology";s:10:"company_id";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:74;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:74;s:13:"display_price";d:74;}}s:12:"package_info";a:7:{s:1:"C";d:74;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2889884971";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";i:74;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:4:"Kate";s:8:"lastname";s:5:"Smith";s:7:"address";s:12:"121 Street 7";s:9:"address_2";N;s:4:"city";s:8:"Poitiers";s:6:"county";N;s:5:"state";s:2:"16";s:7:"country";s:2:"FR";s:7:"zipcode";s:5:"01342";s:5:"phone";s:12:"+14032372345";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:6:"France";s:11:"state_descr";s:8:"Charente";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:11:"taxed_price";i:0;s:5:"taxes";b:0;}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:2:"45";s:10:"rate_value";a:1:{s:1:"C";a:2:{i:0;a:2:{s:5:"value";s:4:"0.00";s:4:"type";s:1:"F";}i:100;a:2:{s:5:"value";s:5:"25.45";s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:0;s:10:"group_name";s:7:"CS-Cart";}}}}');
INSERT INTO `[[dbprefix]]order_data` VALUES
(238, 25, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:3:{s:10:"4163016541";a:23:{s:10:"product_id";i:126;s:12:"product_code";s:10:"F01262AH0T";s:7:"product";s:19:"Casio PRIZM fx-CG10";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:129.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"486";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"542";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"529";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/fx-cg10_xlarge.jpg";s:13:"relative_path";s:29:"detailed/0/fx-cg10_xlarge.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"4163016541";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:19:"Casio PRIZM fx-CG10";s:10:"company_id";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:129.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:129.990;s:13:"display_price";d:129.990;}s:10:"2889884971";a:23:{s:10:"product_id";i:45;s:12:"product_code";s:10:"Q0045PT1DZ";s:7:"product";s:37:"The Process of Research in Psychology";s:6:"amount";i:2;s:15:"product_options";a:0:{}s:5:"price";d:74;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"294";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"350";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:116:"http://localhost/git/work/images/detailed/0/29336_McBride_The_Process_of_Research_in_Psychology_72ppiRGB_150pixW.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:116:"http://localhost/git/work/images/detailed/0/29336_McBride_The_Process_of_Research_in_Psychology_72ppiRGB_150pixW.jpg";s:13:"absolute_path";s:119:"/Users/alexions/www/git/work/images/detailed/0/29336_McBride_The_Process_of_Research_in_Psychology_72ppiRGB_150pixW.jpg";s:13:"relative_path";s:83:"detailed/0/29336_McBride_The_Process_of_Research_in_Psychology_72ppiRGB_150pixW.jpg";}}s:15:"original_amount";s:1:"2";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2889884971";s:6:"amount";s:1:"2";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:37:"The Process of Research in Psychology";s:10:"company_id";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:74;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:2;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:74;s:13:"display_price";d:74;}s:10:"2832975905";a:21:{s:12:"stored_price";s:1:"Y";s:5:"price";d:55;s:10:"product_id";s:2:"27";s:6:"amount";i:1;s:15:"product_options";a:1:{i:2;s:1:"6";}s:5:"extra";a:9:{s:15:"product_options";a:1:{i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:19:"Trefoil Logo Hoodie";s:10:"company_id";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:55;s:12:"stored_price";s:1:"N";}s:10:"company_id";s:1:"1";s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:9:"336913281";s:6:"amount";s:1:"1";}s:12:"prev_cart_id";s:9:"336913281";s:15:"stored_discount";s:1:"N";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"promotions";a:0:{}s:10:"base_price";d:55;s:13:"display_price";d:55;}}s:12:"package_info";a:7:{s:1:"C";d:332.990;s:1:"W";s:4:"0.01";s:1:"I";i:4;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:3:{s:10:"4163016541";i:1;s:10:"2889884971";i:2;s:10:"2832975905";i:1;}s:6:"amount";i:4;s:6:"weight";d:0.100;s:4:"cost";d:332.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(239, 22, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{i:36358138;a:23:{s:10:"product_id";i:161;s:12:"product_code";s:10:"N0161QCS4X";s:7:"product";s:53:"MV800 16.1 Megapixel MultiView Compact Digital Camera";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:279.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"560";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"616";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:62:"http://localhost/git/work/images/detailed/0/MV800_NEW_KV_6.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"600";s:7:"image_y";s:3:"600";s:15:"http_image_path";s:62:"http://localhost/git/work/images/detailed/0/MV800_NEW_KV_6.jpg";s:13:"absolute_path";s:65:"/Users/alexions/www/git/work/images/detailed/0/MV800_NEW_KV_6.jpg";s:13:"relative_path";s:29:"detailed/0/MV800_NEW_KV_6.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";i:36358138;s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:53:"MV800 16.1 Megapixel MultiView Compact Digital Camera";s:10:"company_id";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:279.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:279.990;s:13:"display_price";d:279.990;}}s:12:"package_info";a:7:{s:1:"C";d:279.990;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{i:36358138;i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:279.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:6:"Joseph";s:8:"lastname";s:7:"Cavazos";s:7:"address";s:20:"2324 Gladwell Street";s:9:"address_2";N;s:4:"city";s:6:"Dallas";s:6:"county";N;s:5:"state";s:2:"TX";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"75247";s:5:"phone";s:12:"+19032014518";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:5:"Texas";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:11.17;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:1.02;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(240, 20, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2790148689";a:23:{s:10:"product_id";i:217;s:12:"product_code";s:10:"H0217E3OE9";s:7:"product";s:11:"ASUS CP6230";s:6:"amount";i:1;s:15:"product_options";a:0:{}s:5:"price";d:610.990;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"716";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"772";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:76:"http://localhost/git/work/images/detailed/0/P_50013287772614f33882d85395.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:76:"http://localhost/git/work/images/detailed/0/P_50013287772614f33882d85395.jpg";s:13:"absolute_path";s:79:"/Users/alexions/www/git/work/images/detailed/0/P_50013287772614f33882d85395.jpg";s:13:"relative_path";s:43:"detailed/0/P_50013287772614f33882d85395.jpg";}}s:15:"original_amount";s:1:"1";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2790148689";s:6:"amount";s:1:"1";}s:5:"extra";a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"ASUS CP6230";s:10:"company_id";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:610.990;s:12:"stored_price";s:1:"N";}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:1;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:610.990;s:13:"display_price";d:610.990;}}s:12:"package_info";a:7:{s:1:"C";d:610.990;s:1:"W";s:4:"0.01";s:1:"I";i:1;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2790148689";i:1;}s:6:"amount";i:1;s:6:"weight";d:0.100;s:4:"cost";d:610.990;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:4:"Kate";s:8:"lastname";s:5:"Woods";s:7:"address";s:15:"4-34 Somestreet";s:9:"address_2";N;s:4:"city";s:10:"Alta Vista";s:6:"county";N;s:5:"state";s:2:"KS";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"12345";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:6:"Kansas";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:1:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}'),
(241, 16, 'G', 'a:1:{i:0;a:10:{s:4:"name";s:7:"CS-Cart";s:10:"company_id";i:1;s:8:"products";a:1:{s:10:"2302536527";a:23:{s:10:"product_id";i:41;s:12:"product_code";s:10:"I0041AGKCY";s:7:"product";s:28:"Gift Set (Onesie Plus Socks)";s:6:"amount";i:5;s:15:"product_options";a:1:{i:2;s:1:"6";}s:5:"price";d:35;s:12:"stored_price";s:1:"Y";s:9:"main_pair";a:5:{s:7:"pair_id";s:3:"283";s:8:"image_id";s:1:"0";s:11:"detailed_id";s:3:"339";s:8:"position";s:1:"0";s:8:"detailed";a:7:{s:10:"image_path";s:57:"http://localhost/git/work/images/detailed/0/X32679_01.jpg";s:3:"alt";s:0:"";s:7:"image_x";s:3:"500";s:7:"image_y";s:3:"500";s:15:"http_image_path";s:57:"http://localhost/git/work/images/detailed/0/X32679_01.jpg";s:13:"absolute_path";s:60:"/Users/alexions/www/git/work/images/detailed/0/X32679_01.jpg";s:13:"relative_path";s:24:"detailed/0/X32679_01.jpg";}}s:15:"original_amount";s:1:"5";s:21:"original_product_data";a:2:{s:7:"cart_id";s:10:"2302536527";s:6:"amount";s:1:"5";}s:5:"extra";a:10:{s:15:"product_options";a:1:{i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:28:"Gift Set (Onesie Plus Socks)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:35;s:12:"stored_price";s:1:"Y";s:21:"product_options_value";a:1:{i:0;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}s:15:"stored_discount";s:1:"N";s:8:"discount";i:0;s:10:"company_id";s:1:"1";s:12:"amount_total";i:5;s:12:"options_type";s:1:"P";s:15:"exceptions_type";s:1:"F";s:15:"modifiers_price";i:0;s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:10:"promotions";a:0:{}s:10:"base_price";d:35;s:13:"display_price";d:35;}}s:12:"package_info";a:7:{s:1:"C";d:175;s:1:"W";s:4:"0.01";s:1:"I";i:5;s:16:"shipping_freight";d:0;s:8:"packages";a:1:{i:0;a:4:{s:8:"products";a:1:{s:10:"2302536527";i:5;}s:6:"amount";i:5;s:6:"weight";d:0.100;s:4:"cost";i:175;}}s:11:"origination";a:8:{s:4:"name";s:7:"CS-Cart";s:7:"address";s:14:"44 Main street";s:4:"city";s:6:"Boston";s:7:"country";s:2:"US";s:5:"state";s:2:"MA";s:7:"zipcode";s:5:"02116";s:5:"phone";s:12:"+16175556985";s:3:"fax";s:0:"";}s:8:"location";a:13:{s:9:"firstname";s:8:"Customer";s:8:"lastname";s:8:"Customer";s:7:"address";s:14:"44 Main street";s:9:"address_2";N;s:4:"city";s:6:"Boston";s:6:"county";N;s:5:"state";s:2:"MA";s:7:"country";s:2:"US";s:7:"zipcode";s:5:"02134";s:5:"phone";s:12:"+16175556985";s:12:"address_type";s:11:"residential";s:13:"country_descr";s:13:"United States";s:11:"state_descr";s:13:"Massachusetts";}}s:21:"all_edp_free_shipping";b:0;s:17:"all_free_shipping";b:0;s:13:"free_shipping";b:0;s:20:"shipping_no_required";b:0;s:9:"shippings";a:2:{i:1;a:16:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:2.549;s:11:"description";s:3:"VAT";}}}i:3;a:16:{s:11:"shipping_id";s:1:"3";s:8:"shipping";s:19:"FedEx Home Delivery";s:13:"delivery_time";s:6:"2 days";s:16:"rate_calculation";s:1:"R";s:14:"service_params";a:11:{s:8:"user_key";s:16:"JAHR7R8oMgMFRH55";s:17:"user_key_password";s:25:"YxIJQaZt7Qx3Qt904ibYPhuDa";s:14:"account_number";s:9:"510087089";s:12:"meter_number";s:9:"118530569";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:2:"70";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:3:"216";s:6:"module";s:5:"fedex";s:12:"service_code";s:20:"GROUND_HOME_DELIVERY";s:9:"rate_info";a:0:{}s:9:"group_key";i:0;s:4:"rate";d:9.740;s:11:"taxed_price";i:0;s:5:"taxes";a:1:{i:6;a:7:{s:9:"rate_type";s:1:"P";s:10:"rate_value";s:2:"10";s:18:"price_includes_tax";s:1:"Y";s:9:"regnumber";s:7:"1234242";s:8:"priority";i:0;s:12:"tax_subtotal";d:0.890;s:11:"description";s:3:"VAT";}}}}s:16:"chosen_shippings";a:1:{i:0;a:15:{s:11:"shipping_id";s:1:"1";s:8:"shipping";s:22:"Custom shipping method";s:13:"delivery_time";s:8:"3-5 days";s:16:"rate_calculation";s:1:"M";s:14:"service_params";a:0:{}s:11:"destination";s:1:"I";s:10:"min_weight";s:4:"0.00";s:10:"max_weight";s:4:"0.00";s:10:"service_id";s:1:"0";s:6:"module";N;s:12:"service_code";N;s:9:"rate_info";a:2:{s:7:"rate_id";s:1:"1";s:10:"rate_value";a:2:{s:1:"C";a:3:{i:0;a:2:{s:5:"value";i:40;s:4:"type";s:1:"F";}i:30;a:2:{s:5:"value";i:10;s:4:"type";s:1:"F";}i:50;a:2:{s:5:"value";i:5;s:4:"type";s:1:"F";}}s:1:"I";a:2:{i:0;a:2:{s:5:"value";i:23;s:4:"type";s:1:"F";}i:10;a:2:{s:5:"value";i:15;s:4:"type";s:1:"F";}}}}s:9:"group_key";i:0;s:4:"rate";d:28;s:10:"group_name";s:7:"CS-Cart";}}}}');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_details`
--

CREATE TABLE `[[dbprefix]]order_details` (
  `item_id` int(11) unsigned NOT NULL DEFAULT '0',
  `order_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `product_code` varchar(64) NOT NULL DEFAULT '',
  `price` decimal(12,2) NOT NULL DEFAULT '0.00',
  `amount` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `extra` longblob NOT NULL,
  PRIMARY KEY (`item_id`,`order_id`),
  KEY `o_k` (`order_id`,`product_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]order_details`
--

INSERT INTO `[[dbprefix]]order_details` VALUES
(1237327324, 28, 148, 'H0148VPS1T', '219.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:31:"16GB A Series Walkman Video MP3";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:219;s:12:"stored_price";s:1:"N";}'),
(3954105058, 28, 180, 'Q01802L8VS', '199.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"18-55mm Portrait Lens";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:199.99000000000001;s:12:"stored_price";s:1:"N";}'),
(3416647405, 28, 241, 'I0241GCXF9', '499.00', 1, 'a:10:{s:15:"product_options";a:2:{i:13;s:2:"48";i:14;s:2:"49";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:59:"Apple® - iPad® with Retina® display Wi-Fi - 32GB - White";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:499;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:2:"13";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"C";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"48";s:11:"option_name";s:15:"3G Connectivity";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:2:"No";}i:1;a:22:{s:9:"option_id";s:2:"14";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"44";s:11:"option_name";s:15:"Memory capacity";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:4:"16GB";}}}'),
(4245286173, 29, 222, 'P0222KUH4T', '529.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Series 3 15.6" Laptop";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:529.99000000000001;s:12:"stored_price";s:1:"N";}'),
(304156957, 35, 34, 'W00341JAWN', '25.00', 1, 'a:10:{s:15:"product_options";a:1:{i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:35:"Nike "Untouchable" Women''s Tank Top";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:25;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:1:{i:0;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(766302424, 36, 108, 'I0108TD8BL', '12.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:18:"Due Date (Blu-ray)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:12.99;s:12:"stored_price";s:1:"N";}'),
(2118391450, 37, 88, 'E0088Z4YB8', '39.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:40:"Lord of the Rings: War in the North(PS3)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:39.990000000000002;s:12:"stored_price";s:1:"N";}'),
(1965946732, 38, 160, 'L0160MZ4DS', '200.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:9:"Drifter 3";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:200;s:12:"stored_price";s:1:"N";}'),
(3696523789, 39, 243, 'U02431526C', '249.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:24:"Apple iPod Classic White";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:249;s:12:"stored_price";s:1:"N";}'),
(1976192833, 40, 187, 'D0187LXFZO', '299.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:23:"2010 TOUR STAFF Bag 10"";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.99000000000001;s:12:"stored_price";s:1:"N";}'),
(4191947349, 41, 78, 'L0078RO9Y9', '100.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:18:"adizero Rush Shoes";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:100;s:12:"stored_price";s:1:"N";}'),
(1860791280, 42, 94, 'A0094VY6U3', '59.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:26:"Batman: Arkham City (X360)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:59.990000000000002;s:12:"stored_price";s:1:"N";}'),
(2316230027, 43, 223, 'O0223AQI3W', '499.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:56:"Samsung Galaxy Tab 8.9 (Wi-Fi Only) - 32GB Metallic Gray";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:499.99000000000001;s:12:"stored_price";s:1:"N";}'),
(3308380389, 44, 50, 'V0050M1GB0', '220.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:9:"TS-D1720C";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:220;s:12:"stored_price";s:1:"N";}'),
(217141192, 45, 169, 'A016998ZXV', '749.95', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:53:"D5100 + AF-S DX NIKKOR 18-55mm f/3.5-5.6G VR Lens Kit";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:749.95000000000005;s:12:"stored_price";s:1:"N";}'),
(2707236321, 46, 10, 'L00102FQ97', '1199.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"Toshiba 47TL515U 47" Class 1080P 3D LED HD TV";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1199.99;s:12:"stored_price";s:1:"N";}'),
(2490902739, 47, 237, 'B0237HI9M0', '299.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Elite Evanston 8 Tent";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.99000000000001;s:12:"stored_price";s:1:"N";}'),
(1106667350, 48, 219, 'M0219A3GX3', '529.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Series 3 15.6" Laptop";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:529.99000000000001;s:12:"stored_price";s:1:"N";}'),
(4245286173, 48, 222, 'P0222KUH4T', '529.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Series 3 15.6" Laptop";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:529.99000000000001;s:12:"stored_price";s:1:"N";}'),
(803890817, 49, 208, 'F0208V084C', '82.94', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"H.264 Megapixel Surveillance Camera TL-SC3430";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:82.939999999999998;s:12:"stored_price";s:1:"N";}'),
(3360836486, 49, 206, 'Q0206MCK7B', '179.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:46:"RT-N66U Dual-Band Wireless-N900 Gigabit Router";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:179.99000000000001;s:12:"stored_price";s:1:"N";}'),
(3994858278, 50, 60, 'O0060X7Y9Y', '1499.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"AVIC-Z130BT";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1499;s:12:"stored_price";s:1:"N";}'),
(3592732382, 51, 212, 'P0212CTOEA', '129.95', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:53:"Panasonic KX-MB2000 24PPM 3-in-1 Monochrome Laser MFP";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:129.94999999999999;s:12:"stored_price";s:1:"N";}'),
(4283906614, 52, 7, 'A0007DQ1TL', '55.00', 2, 'a:10:{s:15:"product_options";a:2:{i:10;s:2:"36";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:14:"Trefoil Hoodie";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:55;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:2:"10";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"36";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:23:"GreyHeather/Core Energy";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"7";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(822274303, 52, 12, 'U0012O5AF0', '30.00', 1, 'a:10:{s:15:"product_options";a:2:{i:9;s:2:"17";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:10:"100g Pants";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"9";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"17";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:17:"Black/White/White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:2:"12";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(677409494, 52, 11, 'Z0011CZSNI', '30.00', 1, 'a:10:{s:15:"product_options";a:2:{i:1;s:1:"1";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:17:"Collegiate 72 Tee";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"1";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"25";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:2:"20";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(2467687626, 53, 233, 'H023315I7E', '47.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:38:"Crystal Lake Warm Weather Sleeping Bag";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:47.990000000000002;s:12:"stored_price";s:1:"N";}'),
(2703461960, 54, 213, 'R0213E2U6B', '295.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:37:"Intel® Boxed Intel® Core™ i7-2600";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:295;s:12:"stored_price";s:1:"N";}'),
(3172189513, 55, 107, 'F01072HXUI', '465.00', 2, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:39:"Montblanc Classic Collection Money Clip";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:465;s:12:"stored_price";s:1:"N";}'),
(1521215566, 55, 109, 'C01099FRFC', '140.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:64:"Montblanc Contemporary Collection Key Ring with Montblanc emblem";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:140;s:12:"stored_price";s:1:"N";}'),
(3260818684, 56, 54, 'I0054QMMPO', '269.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:13:"TS-W3002D2|D4";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:269;s:12:"stored_price";s:1:"N";}'),
(2195660588, 57, 195, 'I0195ZFDB8', '29.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:38:"Crossroads Guitar Festival 2010 (2DVD)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:29.989999999999998;s:12:"stored_price";s:1:"N";}'),
(4283388740, 58, 122, 'J01223DYAH', '5695.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:40:"Evolution SST.2 XO Complete Bike 10SPD12";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:5695;s:12:"stored_price";s:1:"N";}'),
(1159954462, 59, 43, 'N0043XCGKY', '369.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:10:"FH-P8000BT";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:369;s:12:"stored_price";s:1:"N";}'),
(3308380389, 59, 50, 'V0050M1GB0', '220.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:9:"TS-D1720C";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:220;s:12:"stored_price";s:1:"N";}'),
(3260818684, 59, 54, 'I0054QMMPO', '269.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:13:"TS-W3002D2|D4";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:269;s:12:"stored_price";s:1:"N";}'),
(3042645098, 59, 55, 'N005510VYI', '359.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:8:"PRS-D800";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:359;s:12:"stored_price";s:1:"N";}'),
(3421137111, 59, 58, 'I0058SG177', '779.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"AVH-P8400BH";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:779;s:12:"stored_price";s:1:"N";}'),
(3994858278, 59, 60, 'O0060X7Y9Y', '1499.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"AVIC-Z130BT";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1499;s:12:"stored_price";s:1:"N";}'),
(4163016541, 60, 126, 'F01262AH0T', '129.99', 5, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:19:"Casio PRIZM fx-CG10";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:129.99000000000001;s:12:"stored_price";s:1:"N";}'),
(342509608, 61, 224, 'Y0224Y3QQU', '479.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:32:"Samsung Galaxy Tab™ 8.9 (AT&T)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:479.99000000000001;s:12:"stored_price";s:1:"N";}'),
(3816757317, 62, 236, 'A0236BQ31M', '299.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:46:"WeatherMaster Screened 6 Tent With Hinged Door";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.99000000000001;s:12:"stored_price";s:1:"N";}'),
(169655664, 62, 230, 'B0230S7Q0V', '125.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:13:"2011 Pit Boss";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:125;s:12:"stored_price";s:1:"N";}'),
(2054572543, 62, 235, 'N02351Q6BY', '79.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"Everglades Cold Weather Sleeping Bag";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:79.989999999999995;s:12:"stored_price";s:1:"N";}'),
(2660368260, 63, 82, 'S0082Z8OYM', '19.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:49:"Legend of the Guardians: the Owls of Ga''hoole(VG)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:19.989999999999998;s:12:"stored_price";s:1:"N";}'),
(1770303465, 63, 90, 'Y0090CLU50', '19.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:19:"F.E.A.R. 3 (PS3) MX";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:19.989999999999998;s:12:"stored_price";s:1:"N";}'),
(1860791280, 63, 94, 'A0094VY6U3', '59.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:26:"Batman: Arkham City (X360)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:59.990000000000002;s:12:"stored_price";s:1:"N";}'),
(2628381300, 64, 181, 'A0181ZSJSS', '899.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:26:"Women''s Bloom Complete Set";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.99000000000001;s:12:"stored_price";s:1:"N";}'),
(4065481614, 64, 177, 'J0177S9SI3', '400.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:15:"CG BLACK DRIVER";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:400;s:12:"stored_price";s:1:"N";}'),
(3849671376, 64, 188, 'M0188MVCYL', '10.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"NEW Wilson Staff Fifty Elite Yellow Golf Ball";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:10;s:12:"stored_price";s:1:"N";}'),
(47022039, 64, 186, 'N01868E9SB', '299.99', 4, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:18:"CG Black Staff Bag";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.99000000000001;s:12:"stored_price";s:1:"N";}'),
(3210050320, 65, 207, 'W0207TLU5R', '42.00', 15, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:12:"Asus USB-N53";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:42;s:12:"stored_price";s:1:"N";}'),
(4283388740, 66, 122, 'J01223DYAH', '5695.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:40:"Evolution SST.2 XO Complete Bike 10SPD12";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:5695;s:12:"stored_price";s:1:"N";}'),
(372045425, 67, 124, 'D01245K7FF', '4595.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:38:"Truth SST.2 X9 Complete Bike 10SPD ''12";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:4595;s:12:"stored_price";s:1:"N";}'),
(1941964244, 68, 239, 'L0239KVQ9F', '509.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Apple iPhone 4S White";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:509.99000000000001;s:12:"stored_price";s:1:"N";}'),
(2707236321, 69, 10, 'L00102FQ97', '1199.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"Toshiba 47TL515U 47" Class 1080P 3D LED HD TV";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1199.99;s:12:"stored_price";s:1:"N";}'),
(1212055764, 69, 16, 'H00162EP2P', '349.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"3D Blu-ray Disc™ Player (BD-D7500)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:349.99000000000001;s:12:"stored_price";s:1:"N";}'),
(1685985038, 69, 22, 'F0022TLB3Q', '799.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:42:"7.1 Channel Blu-ray 3D Home Theater System";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:799.99000000000001;s:12:"stored_price";s:1:"N";}'),
(2490902739, 70, 237, 'B0237HI9M0', '299.99', 2, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:21:"Elite Evanston 8 Tent";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.99000000000001;s:12:"stored_price";s:1:"N";}'),
(4283906614, 71, 7, 'A0007DQ1TL', '55.00', 1, 'a:10:{s:15:"product_options";a:2:{i:10;s:2:"36";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:14:"Trefoil Hoodie";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:55;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:2:"10";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"36";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:23:"GreyHeather/Core Energy";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"7";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(822274303, 71, 12, 'U0012O5AF0', '30.00', 1, 'a:10:{s:15:"product_options";a:2:{i:9;s:2:"17";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:10:"100g Pants";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"9";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"17";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:17:"Black/White/White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:2:"12";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(677409494, 71, 11, 'Z0011CZSNI', '30.00', 1, 'a:10:{s:15:"product_options";a:2:{i:1;s:1:"1";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:17:"Collegiate 72 Tee";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"1";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"25";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:2:"20";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(3636250333, 71, 15, 'H0015EXYM6', '150.00', 1, 'a:10:{s:15:"product_options";a:1:{i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:39:"Nike Chambray Super Runner Men''s Jacket";s:10:"company_id";s:1:"2";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:150;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:1:{i:0;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:2:"26";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(4283906614, 72, 7, 'A0007DQ1TL', '55.00', 1, 'a:10:{s:15:"product_options";a:2:{i:10;s:2:"36";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:14:"Trefoil Hoodie";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:55;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:2:"10";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"36";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:23:"GreyHeather/Core Energy";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"7";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:1:"6";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(822274303, 72, 12, 'U0012O5AF0', '30.00', 1, 'a:10:{s:15:"product_options";a:2:{i:9;s:2:"17";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:10:"100g Pants";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"9";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"17";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:17:"Black/White/White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:2:"12";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(677409494, 72, 11, 'Z0011CZSNI', '30.00', 1, 'a:10:{s:15:"product_options";a:2:{i:1;s:1:"1";i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:17:"Collegiate 72 Tee";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:30;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:1:"1";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"25";s:11:"option_name";s:5:"Color";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"White";}i:1;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:2:"20";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(3636250333, 73, 15, 'H0015EXYM6', '150.00', 1, 'a:10:{s:15:"product_options";a:1:{i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:39:"Nike Chambray Super Runner Men''s Jacket";s:10:"company_id";s:1:"2";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:150;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:1:{i:0;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:2:"26";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(467029654, 74, 196, 'I0196BBF6I', '17.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:40:"Feeding the Monkies At Ma Maison (Zappa)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:17;s:12:"stored_price";s:1:"N";}'),
(2195660588, 74, 195, 'I0195ZFDB8', '29.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:38:"Crossroads Guitar Festival 2010 (2DVD)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:29.989999999999998;s:12:"stored_price";s:1:"N";}'),
(643574442, 74, 204, 'B0204ZOC1I', '14.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:43:"The Police - The Stewart Copeland Anthology";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:14.99;s:12:"stored_price";s:1:"N";}'),
(4124585914, 74, 194, 'P01947A0SW', '10.60', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:23:"U218 Singles (U2TCD020)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:10.6;s:12:"stored_price";s:1:"N";}'),
(2338935559, 74, 199, 'Y0199F6AC6', '29.98', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:37:"B.B. King - Original Greatest Hits CD";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:29.98;s:12:"stored_price";s:1:"N";}'),
(4235092881, 74, 198, 'K01984N7PI', '17.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:124:"B.B. King One Kind Favor CD Grammy Award Winning CD Manufacturer: Geffen Records Sku: BBK-11ONEKINDFAVORCD  Reviewed 2 times";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:17.989999999999998;s:12:"stored_price";s:1:"N";}'),
(1825668608, 74, 197, 'A019737E4S', '14.98', 2, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:24:"Guitar Man Album Artwork";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:14.98;s:12:"stored_price";s:1:"N";}'),
(1446436389, 74, 201, 'V02011EWI8', '12.67', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"Beethoven Piano Concertos Nos. 1 & 2";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:12.67;s:12:"stored_price";s:1:"N";}'),
(556920499, 74, 200, 'X02002U30A', '26.92', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:38:"John Rutter - The Colours of Christmas";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:26.920000000000002;s:12:"stored_price";s:1:"N";}'),
(3477049247, 74, 202, 'T0202OTGXT', '34.68', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:76:"New Year''s Concert 2011 Diverse Klassik Welser-moest / Wiener Philharmoniker";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:34.68;s:12:"stored_price";s:1:"N";}'),
(3090726665, 74, 203, 'R02034W1ZL', '34.68', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:72:"New Year''s Concert 2012 Diverse Wr.Philharmoniker / Jansons,M. / Wr.Sän";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:34.68;s:12:"stored_price";s:1:"N";}'),
(2243091253, 74, 191, 'Q0191PBM44', '11.98', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:40:"Esperanza Spalding - Radio Music Society";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:11.98;s:12:"stored_price";s:1:"N";}'),
(482052751, 74, 192, 'E01923M6DA', '15.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:33:"Black and White America (CD Pack)";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:15;s:12:"stored_price";s:1:"N";}'),
(2836788418, 75, 142, 'H0142DQBME', '399.95', 4, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:16:"Yamaha TSX-130WH";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:399.94999999999999;s:12:"stored_price";s:1:"N";}'),
(319261745, 76, 220, 'P0220KHOS3', '1099.99', 3, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:31:"Series 7 Chronos 14” Notebook";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1099.99;s:12:"stored_price";s:1:"N";}'),
(2583444381, 77, 86, 'I0086KA0W2', '359.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:9:"Nokia 700";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:359;s:12:"stored_price";s:1:"N";}'),
(3390371295, 77, 106, 'C0106D3GWB', '179.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"Nokia E5-00";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:179.99000000000001;s:12:"stored_price";s:1:"N";}'),
(1394451557, 77, 105, 'M01052HXOG', '169.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:15:"Nokia Lumia 800";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:169.99000000000001;s:12:"stored_price";s:1:"N";}'),
(1416650876, 77, 101, 'E01010TOGW', '188.88', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"Nokia X3-02";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:188.88;s:12:"stored_price";s:1:"N";}'),
(4072008611, 78, 190, 'O019015C2L', '899.95', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"AF-S DX NIKKOR 10-24mm f/3.5-4.5G ED";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.95000000000005;s:12:"stored_price";s:1:"N";}'),
(3961824982, 78, 163, 'W0163ME90H', '899.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:42:"NX200 20.3 Megapixel Compact System Camera";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.99000000000001;s:12:"stored_price";s:1:"N";}'),
(1061624811, 79, 214, 'K02149B2ZX', '972.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"ASUS CP6130";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:972;s:12:"stored_price";s:1:"N";}'),
(3125424156, 80, 240, 'E0240Y27BE', '499.00', 2, 'a:10:{s:15:"product_options";a:2:{i:14;i:49;i:11;i:43;}s:18:"unlimited_download";s:1:"N";s:7:"product";s:59:"Apple® - iPad® with Retina® display Wi-Fi - 64GB - Black";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:499;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:2:{i:0;a:22:{s:9:"option_id";s:2:"14";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"C";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"43";s:11:"option_name";s:15:"3G Connectivity";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:2:"No";}i:1;a:22:{s:9:"option_id";s:2:"11";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"N";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:1:"0";s:5:"value";s:2:"39";s:11:"option_name";s:15:"Memory capacity";s:11:"option_text";s:0:"";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:4:"16GB";}}}'),
(1792750741, 81, 229, 'V0229W5J8F', '299.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:24:"HP 2711x 27" LED Monitor";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.99000000000001;s:12:"stored_price";s:1:"N";}'),
(2473281379, 81, 30, 'H00305TUE7', '349.95', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:14:"GO 2535 TM WTE";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:349.94999999999999;s:12:"stored_price";s:1:"N";}'),
(2366072709, 81, 9, 'F0009ORD06', '999.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"Toshiba 42TL515U 42" Class 1080P 3D LED HD TV";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:999.99000000000001;s:12:"stored_price";s:1:"N";}'),
(4033496702, 81, 74, 'S0074AE6U7', '524.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:7:"Droid 3";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:524.99000000000001;s:12:"stored_price";s:1:"N";}'),
(3864289797, 81, 132, 'S0132PANHE', '269.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:25:"Samsung Galaxy Player 5.0";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:269.99000000000001;s:12:"stored_price";s:1:"N";}'),
(3947455183, 81, 167, 'H0167T7K2E', '549.95', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:25:"D3100 + 18-55 VR Lens Kit";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:549.95000000000005;s:12:"stored_price";s:1:"N";}'),
(1364924988, 82, 205, 'Y0205HGGEI', '149.99', 5, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:28:"DIR-657 HD Media Router 1000";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:149.99000000000001;s:12:"stored_price";s:1:"N";}'),
(500958211, 83, 228, 'I0228OF40N', '349.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:12:"LG D2342P-PN";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:349.99000000000001;s:12:"stored_price";s:1:"N";}'),
(2372082066, 83, 227, 'L0227FHI2Y', '699.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:28:"Acer 3D Series HN274H bmiiid";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:699;s:12:"stored_price";s:1:"N";}'),
(319261745, 84, 220, 'P0220KHOS3', '1099.99', 3, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:31:"Series 7 Chronos 14” Notebook";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:1099.99;s:12:"stored_price";s:1:"N";}'),
(2583444381, 85, 86, 'I0086KA0W2', '359.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:9:"Nokia 700";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:359;s:12:"stored_price";s:1:"N";}'),
(3390371295, 85, 106, 'C0106D3GWB', '179.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"Nokia E5-00";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:179.99000000000001;s:12:"stored_price";s:1:"N";}'),
(1394451557, 85, 105, 'M01052HXOG', '169.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:15:"Nokia Lumia 800";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:169.99000000000001;s:12:"stored_price";s:1:"N";}'),
(1416650876, 85, 101, 'E01010TOGW', '188.88', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"Nokia X3-02";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:188.88;s:12:"stored_price";s:1:"N";}');
INSERT INTO `[[dbprefix]]order_details` VALUES
(4072008611, 86, 190, 'O019015C2L', '899.95', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"AF-S DX NIKKOR 10-24mm f/3.5-4.5G ED";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.95000000000005;s:12:"stored_price";s:1:"N";}'),
(3961824982, 86, 163, 'W0163ME90H', '899.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:42:"NX200 20.3 Megapixel Compact System Camera";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.99000000000001;s:12:"stored_price";s:1:"N";}'),
(1061624811, 87, 214, 'K02149B2ZX', '972.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"ASUS CP6130";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:972;s:12:"stored_price";s:1:"N";}'),
(1792750741, 89, 229, 'V0229W5J8F', '299.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:24:"HP 2711x 27" LED Monitor";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:299.99000000000001;s:12:"stored_price";s:1:"N";}'),
(2473281379, 89, 30, 'H00305TUE7', '349.95', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:14:"GO 2535 TM WTE";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:349.94999999999999;s:12:"stored_price";s:1:"N";}'),
(2366072709, 89, 9, 'F0009ORD06', '999.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:45:"Toshiba 42TL515U 42" Class 1080P 3D LED HD TV";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:999.99000000000001;s:12:"stored_price";s:1:"N";}'),
(4033496702, 89, 74, 'S0074AE6U7', '524.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:7:"Droid 3";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:524.99000000000001;s:12:"stored_price";s:1:"N";}'),
(3864289797, 89, 132, 'S0132PANHE', '269.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:25:"Samsung Galaxy Player 5.0";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:269.99000000000001;s:12:"stored_price";s:1:"N";}'),
(3947455183, 89, 167, 'H0167T7K2E', '549.95', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:25:"D3100 + 18-55 VR Lens Kit";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:549.95000000000005;s:12:"stored_price";s:1:"N";}'),
(1364924988, 90, 205, 'Y0205HGGEI', '149.99', 5, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:28:"DIR-657 HD Media Router 1000";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:149.99000000000001;s:12:"stored_price";s:1:"N";}'),
(500958211, 91, 228, 'I0228OF40N', '349.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:12:"LG D2342P-PN";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:349.99000000000001;s:12:"stored_price";s:1:"N";}'),
(2372082066, 91, 227, 'L0227FHI2Y', '699.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:28:"Acer 3D Series HN274H bmiiid";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:699;s:12:"stored_price";s:1:"N";}'),
(4163016541, 92, 126, 'F01262AH0T', '129.99', 5, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:19:"Casio PRIZM fx-CG10";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:129.99000000000001;s:12:"stored_price";s:1:"N";}'),
(3636250333, 93, 15, 'H0015EXYM6', '150.00', 1, 'a:10:{s:15:"product_options";a:1:{i:2;s:1:"6";}s:18:"unlimited_download";s:1:"N";s:7:"product";s:39:"Nike Chambray Super Runner Men''s Jacket";s:10:"company_id";s:1:"2";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:150;s:12:"stored_price";s:1:"N";s:21:"product_options_value";a:1:{i:0;a:22:{s:9:"option_id";s:1:"2";s:10:"product_id";s:1:"0";s:10:"company_id";s:1:"1";s:11:"option_type";s:1:"S";s:9:"inventory";s:1:"Y";s:6:"regexp";s:0:"";s:8:"required";s:1:"N";s:11:"multiupload";s:1:"N";s:18:"allowed_extensions";s:0:"";s:13:"max_file_size";s:1:"0";s:25:"missing_variants_handling";s:1:"M";s:6:"status";s:1:"A";s:8:"position";s:2:"10";s:5:"value";s:2:"26";s:11:"option_name";s:4:"Size";s:11:"option_text";s:4:"Size";s:11:"description";s:0:"";s:10:"inner_hint";s:0:"";s:17:"incorrect_message";s:0:"";s:8:"modifier";s:5:"0.000";s:13:"modifier_type";s:1:"A";s:12:"variant_name";s:5:"Small";}}}'),
(3260818684, 94, 54, 'I0054QMMPO', '269.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:13:"TS-W3002D2|D4";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:269;s:12:"stored_price";s:1:"N";}'),
(4072008611, 95, 190, 'O019015C2L', '899.95', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:36:"AF-S DX NIKKOR 10-24mm f/3.5-4.5G ED";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.95000000000005;s:12:"stored_price";s:1:"N";}'),
(3961824982, 95, 163, 'W0163ME90H', '899.99', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:42:"NX200 20.3 Megapixel Compact System Camera";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:899.99000000000001;s:12:"stored_price";s:1:"N";}'),
(1061624811, 96, 214, 'K02149B2ZX', '972.00', 1, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:11:"ASUS CP6130";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:972;s:12:"stored_price";s:1:"N";}'),
(4163016541, 97, 126, 'F01262AH0T', '129.99', 5, 'a:9:{s:15:"product_options";a:0:{}s:18:"unlimited_download";s:1:"N";s:7:"product";s:19:"Casio PRIZM fx-CG10";s:10:"company_id";s:1:"1";s:6:"is_edp";s:1:"N";s:12:"edp_shipping";s:1:"N";s:8:"discount";i:0;s:10:"base_price";d:129.99000000000001;s:12:"stored_price";s:1:"N";}');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_docs`
--

CREATE TABLE `[[dbprefix]]order_docs` (
  `doc_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `type` char(1) NOT NULL DEFAULT 'I',
  `order_id` mediumint(8) unsigned NOT NULL,
  PRIMARY KEY (`doc_id`,`type`),
  KEY `type` (`order_id`,`type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]order_transactions`
--

CREATE TABLE `[[dbprefix]]order_transactions` (
  `payment_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `transaction_id` varchar(255) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT '',
  `extra` longblob NOT NULL,
  PRIMARY KEY (`payment_id`,`transaction_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]original_values`
--

CREATE TABLE `[[dbprefix]]original_values` (
  `msgctxt` varchar(128) NOT NULL DEFAULT '',
  `msgid` text,
  PRIMARY KEY (`msgctxt`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]original_values`
--

INSERT INTO `[[dbprefix]]original_values` VALUES
('Languages::2co_enable_fraud_verification', 'Enable support of fraud notification'),
('Languages::2co_fraud_fail', 'Status for orders with failed fraud review'),
('Languages::2co_fraud_wait', 'Status for orders waiting for fraud review'),
('Languages::3d_secure', '3-D Secure'),
('Languages::404', 'The 404 Not Found error message'),
('Languages::absolute', 'Absolute'),
('Languages::installed_addons', 'Installed add-ons'),
('Languages::browse_all_available_addons', 'Browse all available add-ons'),
('Languages::accept', 'Accept'),
('Languages::access_denied', 'Access denied'),
('Languages::event.order.status_changed.name', 'Order status changed to [status]'),
('Languages::access_denied_text', 'You don''t have permission to access the page.'),
('Languages::account', 'Account'),
('Languages::account_name', 'Account name'),
('Languages::account_number', 'Account number'),
('Languages::account_type', 'Account type'),
('Languages::acquirerid', 'Acquirer ID'),
('Languages::action', 'Action'),
('Languages::actions', 'Actions'),
('Languages::activate_menu_tab_for', 'Activate menu item for dispatch'),
('Languages::activate_selected', 'Activate selected'),
('Languages::activate_skrill_merchant_tools', 'Activate Skrill Merchant Tools'),
('Languages::activation_link', 'Activation link'),
('Languages::activation_mode', 'Activation mode'),
('Languages::active', 'Active'),
('Languages::active_categories', 'Active categories'),
('Languages::active_style', 'Active style'),
('Languages::active_products', 'Active products'),
('Languages::active_promotions', 'Active promotions'),
('Languages::act_on_behalf', 'Act on behalf of'),
('Languages::log_in_as_user', 'Log in as user'),
('Languages::add', 'Add'),
('Languages::added', 'added'),
('Languages::adding_block_to_grid', 'Adding block to grid'),
('Languages::adding_grid', 'Adding grid'),
('Languages::additional_data', 'Additional data'),
('Languages::additional_images', 'Additional images'),
('Languages::additional_options', 'Additional options'),
('Languages::additional_parameter_not_correct', 'Additional parameter is incorrect'),
('Languages::additional_popup_larger_image', 'Popup larger images of additional thumbnails'),
('Languages::additional_thumbnail', 'Additional thumbnails'),
('Languages::additional__option_thumbnail', 'Additional option thumbnail'),
('Languages::addon', 'Add-on'),
('Languages::addons', 'Add-ons'),
('Languages::addon_sql_error', 'An error in an SQL query occurred during the add-on installation. The add-on will not be installed.'),
('Languages::address', 'Address'),
('Languages::addresses', 'Addresses'),
('Languages::address_2', 'Address (line 2)'),
('Languages::address_commercial', 'Commercial'),
('Languages::address_residential', 'Residential'),
('Languages::address_type', 'Address type'),
('Languages::add_administrator', 'Add administrator'),
('Languages::add_block', 'Add block'),
('Languages::add_image_from_server', 'Add image from server'),
('Languages::add_image_from_url', 'Add image from URL'),
('Languages::add_bonus', 'Add bonus'),
('Languages::add_cart_promotion', 'Add cart promotion'),
('Languages::add_catalog_promotion', 'Add catalog promotion'),
('Languages::add_categories', 'Add categories'),
('Languages::select_categories', 'Select categories'),
('Languages::add_categories_and_close', 'Add categories and close'),
('Languages::add_category', 'Add category'),
('Languages::add_chart', 'Add chart'),
('Languages::add_combination', 'Add combination'),
('Languages::add_companies', 'Add stores'),
('Languages::add_companies_and_close', 'Add stores and close'),
('Languages::add_condition', 'Add condition'),
('Languages::add_currency', 'Add currency'),
('Languages::add_customer', 'Add customer'),
('Languages::add_elements', 'Add elements'),
('Languages::add_empty_item', 'Add empty item'),
('Languages::add_feature', 'Add feature'),
('Languages::advanced_feature_creation', 'Advanced feature creation'),
('Languages::add_field', 'Add field'),
('Languages::add_file', 'Add file'),
('Languages::add_filter', 'Add filter'),
('Languages::add_filters', 'Add filters'),
('Languages::add_filters_and_close', 'Add filters and close'),
('Languages::add_folder', 'Add folder'),
('Languages::add_global_option', 'Add global option'),
('Languages::add_grid_block', 'Add grid or block'),
('Languages::add_group', 'Add group'),
('Languages::add_item', 'Add item'),
('Languages::add_items', 'Add [items]'),
('Languages::add_language', 'Add language'),
('Languages::add_language_variable', 'Add language variable'),
('Languages::add_layout', 'Add layout'),
('Languages::add_link', 'Add link'),
('Languages::add_localization', 'Add localization'),
('Languages::add_location', 'Add location'),
('Languages::add_rate_area', 'Add rate area'),
('Languages::add_menu', 'Add menu'),
('Languages::add_new', 'Add new'),
('Languages::add_new_field', 'Add new field'),
('Languages::add_new_order', 'Adding new order'),
('Languages::add_new_variant', 'Add new variant'),
('Languages::add_variant', 'Add variant'),
('Languages::add_option', 'Add option'),
('Languages::advanced_option_creation', 'Advanced option creation'),
('Languages::add_order', 'Add order'),
('Languages::add_orders', 'Add orders'),
('Languages::add_orders_and_close', 'Add orders and close'),
('Languages::add_page', 'Add page'),
('Languages::add_pages', 'Add pages'),
('Languages::add_pages_and_close', 'Add pages and close'),
('Languages::add_payment', 'Add payment method'),
('Languages::add_payout', 'Add payout'),
('Languages::add_product', 'Add product'),
('Languages::add_products', 'Add products'),
('Languages::add_products_and_close', 'Add products and close'),
('Languages::add_products_to_section', 'Add product(s) to this section'),
('Languages::add_product_filter', 'Add product filter'),
('Languages::add_promotions', 'Add promotions'),
('Languages::add_promotion', 'Add promotion'),
('Languages::add_report', 'Add report'),
('Languages::add_section', 'Add section'),
('Languages::add_selected_to_cart', 'Add selected to cart'),
('Languages::add_shipping_method', 'Add shipping method'),
('Languages::add_site_map_section', 'Add sitemap section'),
('Languages::add_state', 'Add state'),
('Languages::add_status', 'Add status'),
('Languages::add_subcategory', 'Add subcategory'),
('Languages::new_subscribers', 'New subscribers'),
('Languages::add_subscriber', 'Add subscriber'),
('Languages::add_subscribers_from_users', 'Add subscribers from the list of users'),
('Languages::add_tab', 'Add tab'),
('Languages::add_tax', 'Add tax'),
('Languages::add_to_cart', 'Add to cart'),
('Languages::add_to_comparison_list', 'Add to comparison list'),
('Languages::add_user', 'Add user'),
('Languages::add_users', 'Add users'),
('Languages::add_users_and_close', 'Add users and close'),
('Languages::add_vendor', 'Add store'),
('Languages::admin2', 'You can not perform an import to this store because you are using an expired trial version'),
('Languages::administration', 'Administration'),
('Languages::administration_panel', 'Administration panel'),
('Languages::administrator', 'Administrator'),
('Languages::administrators', 'Administrators'),
('Languages::main_administrator', 'Main administrator'),
('Languages::storefront_admin', 'Main admin for [storefront]'),
('Languages::administrators_notified', '[count] administrators notified.'),
('Languages::admin_panel', 'Administration panel'),
('Languages::admin_text_letter_footer', 'E-shop of [company_name].'),
('Languages::administration_view', 'Settings'),
('Languages::advanced', 'Advanced'),
('Languages::advanced_search', 'Advanced search'),
('Languages::advanced_search_options', 'Advanced search options'),
('Languages::search_add_filter', 'Add filter'),
('Languages::search_range_from', 'From'),
('Languages::search_range_to', 'To'),
('Languages::dynamic_navigation_more', 'More'),
('Languages::after_full_payment', 'After full payment'),
('Languages::after_sum', 'After sum'),
('Languages::agent_id', 'Agent ID'),
('Languages::agreement_required', 'Agreement required'),
('Languages::all', 'All'),
('Languages::allowed', 'Allowed'),
('Languages::allowed_combinations', 'Allowed combinations'),
('Languages::allowed_extensions', 'Allowed extensions'),
('Languages::allowed_extensions_hint', 'Leave this field empty to allow uploading of all file types, or input allowed extensions separated by comma (e.g. jpg,bmp,gif,pdf)'),
('Languages::allow_api_access', 'Yes, allow this user to use the API'),
('Languages::api_access_for_user', 'API access for this user'),
('Languages::generate_new_api_key', 'Generate new API key'),
('Languages::please_copy_api_key', 'Please copy the API key now and keep it somewhere. Once you save the changes, this key won''t appear here again. If the key is lost, the only way to regain API access will be to generate a new key on this page.'),
('Languages::allow_return_registration', 'Allow return registration'),
('Languages::all_categories', 'All categories'),
('Languages::all_downloads', 'All downloads'),
('Languages::all_features', 'All features'),
('Languages::all_filters', 'All product filters'),
('Languages::all_pages', 'All pages'),
('Languages::all_products_have_been_updated', 'All products have been updated successfully.'),
('Languages::all_vendors', 'All stores'),
('Languages::all_storefronts_short', 'All'),
('Languages::show_all_storefronts', 'Show all storefronts'),
('Languages::show_all_storefronts_with_count', 'Show all [count] storefronts'),
('Languages::all_words', 'All of these words'),
('Languages::also_bought', 'Also bought'),
('Languages::alt_text', 'Alternative text/title'),
('Languages::alternative_text', 'Alt text'),
('Languages::american_express', 'American Express'),
('Languages::american_express_info', 'CVV is on the front of the card above the credit card number (either on the right or on the left side of the credit card).'),
('Languages::amount', 'Amount'),
('Languages::amount_decreased', 'Quantity has been decreased by'),
('Languages::amount_increased', 'Quantity has been increased by'),
('Languages::anonymous', 'Anonymous'),
('Languages::answer', 'Answer'),
('Languages::any', 'Any'),
('Languages::any_date', 'Any date'),
('Languages::any_option_combinations', 'Any option combinations'),
('Languages::any_status', 'Any status'),
('Languages::any_words', 'Any of these words'),
('Languages::any_category', 'Any category'),
('Languages::any_product', 'Any product'),
('Languages::api', 'API'),
('Languages::api_access', 'API access'),
('Languages::api_key', 'API key'),
('Languages::need_company_id', 'Company ID is required (the company_id param)'),
('Languages::api_need_correct_company_id', 'Company by passed ID not found'),
('Languages::api_need_id', 'Object ID undefined'),
('Languages::api_need_params', 'Missing parameters'),
('Languages::api_need_store', 'Store is required (the company_id param or entity stores)'),
('Languages::api_not_need_id', 'ID must not be defined'),
('Languages::api_partner', 'API partner'),
('Languages::api_password', 'API password'),
('Languages::api_shipments_not_allow_update', 'Only the tracking_number and carrier params can be updated with the setting ''Allow multiple shipments for a single order'' set'),
('Languages::api_user', 'API user'),
('Languages::api_order_couldnt_be_created', 'Order couldn''t be created'),
('Languages::api_no_shipping_methods_available', 'No shipping methods are available'),
('Languages::appearance', 'Appearance'),
('Languages::appearance_settings', 'Appearance settings'),
('Languages::appearance_type', 'Appearance type'),
('Languages::application_id', 'Application ID'),
('Languages::application_login', 'Application login'),
('Languages::apply', 'Apply'),
('Languages::apply_as_link', 'Apply as link'),
('Languages::apply_tax_to_products', 'Apply selected taxes to all products'),
('Languages::apply_to_all_languages', 'Apply to all languages'),
('Languages::apply_to_products', 'Apply to products'),
('Languages::approve', 'Approve'),
('Languages::approved', 'Approved'),
('Languages::approve_selected', 'Approve selected'),
('Languages::enter_disapproval_reason', 'Enter the reason for disapproval'),
('Languages::arabic', 'Arabic'),
('Languages::arrows', 'Arrows'),
('Languages::asc', 'asc.'),
('Languages::attention', 'Attention!'),
('Languages::audience', 'Audience'),
('Languages::authentication_failed', 'Authentication failed'),
('Languages::authentication_key', 'Authentication key'),
('Languages::authentication_password', 'Authentication password'),
('Languages::author', 'Author'),
('Languages::authorization', 'Authorization'),
('Languages::authorize_capture', 'Authorize and capture'),
('Languages::authorize_only', 'Authorize only'),
('Languages::auth_code', 'Auth code'),
('Languages::auth_info', 'Authentication information'),
('Languages::auto', 'Auto'),
('Languages::auto_set_permissions_via_ftp', 'Auto-set permissions via FTP'),
('Languages::avail', 'Available'),
('Languages::availability', 'Availability'),
('Languages::available', 'Available'),
('Languages::available_fields', 'Available fields'),
('Languages::available_for_vendor', 'Available for store'),
('Languages::available_items', 'Available items'),
('Languages::available_languages', 'Available'),
('Languages::available_views', 'Available views'),
('Languages::available_since', 'Avail since'),
('Languages::installed_themes', 'Installed themes'),
('Languages::browse_all_available_themes', 'Browse all available themes'),
('Languages::currently_in_use', 'Currently in use'),
('Languages::avail_from', 'Available from'),
('Languages::avail_till', 'Available till'),
('Languages::average', 'Average'),
('Languages::avs', 'AVS'),
('Languages::awaiting', 'Awaiting'),
('Languages::awaiting_approval', 'Awaiting approval'),
('Languages::backtrace', 'Backtrace'),
('Languages::backup', 'Backup'),
('Languages::backupping_data', 'Backing up data for'),
('Languages::backupping_schema', 'Backing up schema for'),
('Languages::backup_data', 'Backup database data'),
('Languages::backup_filename', 'Backup file name'),
('Languages::backup_files', 'Backup files'),
('Languages::backup_options', 'Backup options'),
('Languages::backup_schema', 'Backup database schema'),
('Languages::back_in_stock_notification_footer', 'Welcome to purchase!'),
('Languages::back_in_stock_notification_header', 'We are writing to inform you that the following product is back in stock in our store:'),
('Languages::balance', 'Balance'),
('Languages::balance_account', 'Account balance'),
('Languages::bank', 'Bank'),
('Languages::ground_only', 'Ground only'),
('Languages::bank_cic', 'Groupe CIC'),
('Languages::bank_cm', 'Credit Mutuel'),
('Languages::bank_obc', 'OBC'),
('Languages::bank_routing_number', 'Bank routing number'),
('Languages::bar', 'Bar'),
('Languages::base_currency', 'Base'),
('Languages::base_currency_not_deleted', 'The currency has not been deleted because it is the base currency of the store.'),
('Languages::base_price', 'Base price'),
('Languages::bestsellers', 'Bestsellers'),
('Languages::biller_code', 'Biller code'),
('Languages::billing_address', 'Billing address'),
('Languages::billing_options', 'Billing Options'),
('Languages::billing_shipping_address', 'Billing and Shipping Address'),
('Languages::bill_to', 'Bill to'),
('Languages::block', 'Block'),
('Languages::blocks', 'Blocks'),
('Languages::block_already_exists_in_grid', 'This block already exists in this grid'),
('Languages::invalid_value_for_grid_with_content', 'This value can not be set, because the content does not fit into the grid width. Edit the grid content and try again.'),
('Languages::block_breadcrumbs', 'Breadcrumbs'),
('Languages::block_breadcrumbs_description', 'Navigation breadcrumbs'),
('Languages::block_categories_description', 'Category trees'),
('Languages::block_products_description', 'Product showcase'),
('Languages::block_cart_content', 'Cart content'),
('Languages::block_cart_content_description', 'Current cart content'),
('Languages::block_categories', 'Categories'),
('Languages::block_checkout', 'Checkout'),
('Languages::block_checkout_description', 'Current order information'),
('Languages::block_content', 'Block content'),
('Languages::block_currencies', 'Currencies'),
('Languages::block_currencies_description', 'Currency selector'),
('Languages::block_disabled', 'Block was disabled for this location'),
('Languages::block_enabled', 'Block was enabled for this location'),
('Languages::block_html_block', 'HTML block'),
('Languages::block_html_block_description', 'Any HTML content'),
('Languages::block_ip_after', 'Block IP after a number of unsuccessful attempts'),
('Languages::block_languages', 'Languages'),
('Languages::block_languages_description', 'Language selector'),
('Languages::block_localizations', 'Localizations'),
('Languages::block_localizations_description', 'Localization selector'),
('Languages::block_main', 'Main'),
('Languages::block_main_description', 'Main content (loaded by controller)'),
('Languages::block_manager', 'Block manager'),
('Languages::block_manager.fixed_layout', 'Fixed width'),
('Languages::block_manager.fluid_layout', 'Fluid'),
('Languages::block_manager.full_width_layout', 'Full width'),
('Languages::block_manager.grid_columns', 'Grid columns'),
('Languages::block_manager.layout_width', 'Layout width'),
('Languages::block_manager.max_width', 'Maximal width'),
('Languages::block_manager.min_width', 'Minimal width'),
('Languages::block_manager.forbid_changing_layout_in_css_mode', 'Changing layout when the theme is converted to CSS is not permitted. Please enable LESS mode in the <a target="_blank" class="cm-post" href="[url]">Theme editor</a>.'),
('Languages::block_manager.can_not_add_product', 'Sorry, we couldn''t take you to the checkout page. It requires at least one product in cart, and we couldn''t add any. Please create a product and make it available on the storefront first.'),
('Languages::block_manager.add_layout_page', 'Add layout page'),
('Languages::block_manager.editing_layout_page', 'Editing layout page'),
('Languages::block_manager.new_layout_page', 'New layout page'),
('Languages::block_manager.layout_pages', 'Layout pages'),
('Languages::block_manager.wrappers.lite_checkout', 'Lite checkout'),
('Languages::block_manager.description_available_values_for_grid_select', 'The available values depend on the size and offset of parent and nested elements.'),
('Languages::block_lite_checkout_location', 'Checkout: Location'),
('Languages::block_lite_checkout_location_description', 'Customer''s city, state, and country'),
('Languages::block_lite_checkout_customer_sign_in', 'Checkout: Sign-In'),
('Languages::block_lite_checkout_customer_sign_in_description', 'Sign-in button'),
('Languages::customer_sign_in', 'Customer Sign-In'),
('Languages::block_lite_checkout_customer_information', 'Checkout: Customer Information'),
('Languages::block_lite_checkout_customer_information_description', 'Profile fields for customer information'),
('Languages::block_lite_checkout_customer_address', 'Checkout: Address'),
('Languages::block_lite_checkout_customer_address_description', 'Profile fields for customer address'),
('Languages::customer_address', 'Customer address'),
('Languages::block_lite_checkout_shipping_methods', 'Checkout: Shipping methods'),
('Languages::block_lite_checkout_shipping_methods_description', 'Shipping method selection'),
('Languages::block_lite_checkout_payment_methods', 'Checkout: Payment methods'),
('Languages::block_lite_checkout_payment_methods_description', 'Payment method selection'),
('Languages::block_lite_checkout_customer_billing', 'Checkout: Billing address'),
('Languages::block_lite_checkout_customer_billing_description', 'Profile fields for billing address'),
('Languages::block_lite_checkout_customer_notes', 'Checkout: Notes'),
('Languages::block_lite_checkout_customer_notes_description', 'Customer''s notes about the order'),
('Languages::block_lite_checkout_terms_and_conditions', 'Checkout: Terms and conditions'),
('Languages::block_lite_checkout_terms_and_conditions_description', 'Checkbox for accepting terms and conditions'),
('Languages::terms_and_conditions', 'Terms and conditions'),
('Languages::block_menu', 'Menu'),
('Languages::block_my_account', 'My account'),
('Languages::block_my_account_description', 'Customer profile access'),
('Languages::block_name', 'Block name'),
('Languages::block_options', 'Block options'),
('Languages::block_order', 'Block order'),
('Languages::block_our_brands', 'Brands'),
('Languages::block_our_brands_description', 'Product brands presented in the store'),
('Languages::block_pages', 'Pages'),
('Languages::block_pages_description', 'Store pages'),
('Languages::block_payment_methods', 'Payment methods'),
('Languages::block_payment_methods_description', 'Available payment methods'),
('Languages::block_products', 'Products'),
('Languages::block_product_filters', 'Product filters'),
('Languages::block_product_filters_description', 'Product filtering options'),
('Languages::block_product_filters_home', 'Product filters for home page'),
('Languages::block_product_filters_home_description', 'Product filtering options, displayed on home page'),
('Languages::block_settings', 'Block settings'),
('Languages::block_shipping_methods', 'Shipping methods'),
('Languages::block_shipping_methods_description', 'Available shipping methods'),
('Languages::block_smarty_block', 'HTML block with Smarty support'),
('Languages::block_smarty_block_description', 'Any HTML/Smarty content'),
('Languages::block_template', 'Template'),
('Languages::block_template_description', 'Block with a particular template'),
('Languages::block_text', 'Block text'),
('Languages::block_time', 'Time for which IP should be blocked'),
('Languages::block_width', 'Block width'),
('Languages::block_wrapper_updated', 'Block wrapper was updated'),
('Languages::bm_confirm', 'Performing this action will [action] this block on all the [location_name] pages. Do you want to continue?'),
('Languages::body', 'Body'),
('Languages::bonus', 'Bonus'),
('Languages::bonuses', 'Bonuses'),
('Languages::both', 'Both'),
('Languages::bought', 'Already bought'),
('Languages::bought_amount', 'Bought quantity'),
('Languages::box_height', 'Box height'),
('Languages::box_length', 'Box length'),
('Languages::box_width', 'Box width'),
('Languages::brand', 'Brand'),
('Languages::brand_type', 'Brand/Manufacturer'),
('Languages::breadcrumbs', 'Breadcrumbs'),
('Languages::broken_addon_pack', 'Incorrect add-on structure. The uploaded pack cannot be installed.'),
('Languages::broken_po_pack', 'Incorrect PO-pack structure. The uploaded pack cannot be installed.'),
('Languages::incorrect_po_pack_structure_file_not_exist', 'The structure of package that contains ".po" translation files located at <b>"[pack_path]"</b> is incorrect. The file <b>"[po_file]"</b> does not exist.'),
('Languages::browse', 'Browse...'),
('Languages::browser_upgrade_notice', '<p>We have detected that the browser you are using is not fully supported by our Admin Panel. You can view this site using your current browser but it may not display properly, and you may not be able to fully use all features.</p><br><p>Admin Panel is best viewed using the following browsers:</p><br><ul><li>&ndash; <a href="http://windows.microsoft.com/en-US/internet-explorer/products/ie/home" target="_blank">Internet Explorer 9 and above</a></li><li>&ndash; <a href="http://www.mozilla.org/en-US/" target="_blank">Mozilla Firefox (latest version)</a></li><li>&ndash; <a href="https://www.google.com/intl/en/chrome/browser/" target="_blank">Google Chrome (latest version)</a></li></ul><br><p>Click on one of the links to download the browser of your choice. Once the download has completed, install the browser by running the setup program.</p><br><p>If you cannot upgrade your browser now, you can still access Admin Panel, but you may not be able to fully use all features.<br><br><a href="[url]">Continue</a></p>'),
('Languages::browser_upgrade_notice_title', 'Browser Upgrade Notice'),
('Languages::bucket', 'Bucket'),
('Languages::bulk_category_addition', 'Bulk category addition'),
('Languages::bulk_print_invoice', 'Invoice bulk print'),
('Languages::bulk_product_addition', 'Bulk product addition'),
('Languages::button_bgcolor', 'Button background color'),
('Languages::button_text_color', 'Button text color'),
('Languages::but_change', 'Change'),
('Languages::buyer_name', 'Buyer''s name'),
('Languages::buy_in_advance', 'Buy in advance'),
('Languages::buy_now', 'Buy now'),
('Languages::by', 'by'),
('Languages::bytes', 'bytes'),
('Languages::by_fixed', 'by fixed amount'),
('Languages::by_percentage', 'by percentage of the original price'),
('Languages::C128A', 'Code 128 is a high-density barcode symbology.<br/>Used extensively worldwide.<br/>Code 128 is designed to encode 128 full ASCII characters.<br/>Code 128-A - 0-9, A-Z, ASCII control codes, special characters.<br/>Code 128-B - 0-9, A-Z, a-z, special characters.<br/>Code 128-C - 00-99 (double density encoding of numeric only data).<br/>'),
('Languages::C128B', 'Code 128 is a high-density barcode symbology.<br/>Used extensively worldwide.<br/>Code 128 is designed to encode 128 full ASCII characters.<br/>Code 128-A - 0-9, A-Z, ASCII control codes, special characters.<br/>Code 128-B - 0-9, A-Z, a-z, special characters.<br/>Code 128-C - 00-99 (double density encoding of numeric only data).<br/>'),
('Languages::C128C', 'Code 128 is a high-density barcode symbology.<br/>Used extensively worldwide.<br/>Code 128 is designed to encode 128 full ASCII characters.<br/>Code 128-A - 0-9, A-Z, ASCII control codes, special characters.<br/>Code 128-B - 0-9, A-Z, a-z, special characters.<br/>Code 128-C - 00-99 (double density encoding of numeric only data).<br/>'),
('Languages::C39', 'Known also as USS Code 39, 3 of 9.<br/>Code 39 can encode alphanumeric characters.<br/>The symbology is used in non-retail environment.<br/>Code 39 is designed to encode 26 upper case letters, 10 digits and 7 special characters.'),
('Languages::cache_cleared', 'Cache has been cleared'),
('Languages::calculate', 'Calculate'),
('Languages::calculate_shipping_cost', 'Calculate shipping cost'),
('Languages::calendar', 'Calendar'),
('Languages::canada_post_activation_error', 'To activate the Canada post shipping processor, you must have the Canadian Dollar currency enabled.'),
('Languages::cancel', 'Cancel'),
('Languages::canceled_reversal', 'Canceled reversal'),
('Languages::cancelled', 'Canceled'),
('Languages::cancel_url_target', 'Cancel URL target'),
('Languages::cannot_buy', 'You cannot buy the product with these option variants'),
('Languages::cannot_proccess_checkout', 'Your cart is empty, so you cannot proceed to checkout.'),
('Languages::cannot_proccess_checkout_without_payment_methods', 'There are no payment methods available, so you cannot proceed to checkout.'),
('Languages::cannot_remove_active_theme', 'Cannot remove the active theme'),
('Languages::cannot_write_file', 'Cannot write to the file <b>[file]</b>. Please check the file and directory permissions.'),
('Languages::cant_save_percentage_price', 'You can not use percentage value for base price.'),
('Languages::cant_upload_file', 'Couldn''t upload the file. The problem isn''t necessarily on the [product] end. If it occurs regularly, please contact your server administrator or our technical support.'),
('Languages::capture', 'Capture'),
('Languages::card', 'Card'),
('Languages::cardholder_name', 'Cardholder''s name'),
('Languages::card_number', 'Card number'),
('Languages::carousel', 'Carousel'),
('Languages::carrier', 'Carrier'),
('Languages::carrier_aup', 'Australia Post'),
('Languages::carrier_can', 'Canada Post'),
('Languages::carrier_dhl', 'DHL'),
('Languages::carrier_fedex', 'FedEx'),
('Languages::carrier_swisspost', 'SwissPost'),
('Languages::carrier_ups', 'UPS'),
('Languages::tools_carrier_ups_msg', 'To get Client ID and Client Secret, <a target="_blank" href="[url]">register an app in your UPS account</a>.'),
('Languages::carrier_upsdeprecated', 'UPS [Deprecated]'),
('Languages::tools_carrier_upsdeprecated_msg', 'This shipping method will stop working in June 2024. To keep using UPS, please set up a shipping method that uses "UPS" rather than "UPS [Deprecated]" for rate calculation.'),
('Languages::carrier_usps', 'USPS'),
('Languages::cart', 'Cart'),
('Languages::cart_content', 'Cart content'),
('Languages::cart_contents', 'Cart contents'),
('Languages::cart_info', 'Site info'),
('Languages::cart_is_empty', 'Cart is empty'),
('Languages::cart_items', 'Cart items'),
('Languages::cart_subtotal', 'Cart subtotal'),
('Languages::cash_on_delivery', 'Cash on delivery'),
('Languages::catalog', 'Catalog'),
('Languages::catalog_pages', 'Catalog pages'),
('Languages::categories', 'Categories'),
('Languages::categories_have_been_added', 'Categories have been added'),
('Languages::category', 'Category'),
('Languages::category_delimiter', 'Category delimiter'),
('Languages::category_description', 'Category description'),
('Languages::category_location', 'Category location'),
('Languages::category_name', 'Category name'),
('Languages::cdn_settings', 'CDN settings'),
('Languages::central', 'Central'),
('Languages::central_content', 'Central content'),
('Languages::certificate', 'Certificate'),
('Languages::certificate_filename', 'Certificate filename'),
('Languages::change', 'Change'),
('Languages::changed', 'Changed'),
('Languages::changes', 'Changes'),
('Languages::change_access_permission_to_config', 'Also it is recommended to change the access permissions for the config.local.php file. It should have 644 (read/write for the owner and read for others) permissions.'),
('Languages::change_addons_initialization', 'Change add-ons initialization'),
('Languages::change_language', 'Change language'),
('Languages::change_password_notification', 'Please change your password'),
('Languages::change_password_notification_body', 'Your password to access the admin panel of the [store] store was last changed [days] days ago. For security reasons, please change your password. In order to do this, please follow the link:'),
('Languages::change_permissions', 'Change permissions'),
('Languages::check_permissions', 'Check permissions'),
('Languages::change_range', 'Change range'),
('Languages::charged_amount', 'Charged amount'),
('Languages::charset', 'Character set'),
('Languages::chart', 'Chart'),
('Languages::charts', 'Charts'),
('Languages::chart_type', 'Chart type'),
('Languages::check', 'Check'),
('Languages::checkbox', 'Check box'),
('Languages::checking_account_number', 'Checking account number'),
('Languages::checkout', 'Checkout'),
('Languages::checkout_as_guest', 'Checkout as guest'),
('Languages::checkout_edp_terms_n_conditions', 'I accept the terms in the'),
('Languages::checkout_terms_n_conditions', 'Select this check box to accept the [terms_href]'),
('Languages::checkout_terms_n_conditions_name', 'Terms and Conditions'),
('Languages::checkout_terms_n_conditions_alert', 'In order to proceed, you need to accept our Terms and Conditions.'),
('Languages::terms_and_conditions_content', '<p>Please read these Terms and Conditions ("Terms", "Terms and Conditions") carefully before using the <a href="http://www.mywebsite.com">http://www.mywebsite.com</a> website and the My Mobile App mobile application (the "Service") operated by My Company ("us", "we", or "our").</p><p><strong>By accessing or using the Service you agree to be bound by these Terms. If you disagree with any part of the Terms then you may not access the Service.</strong></p><p><strong>Purchases</strong></p><p>If you wish to purchase any product or service made available through the Service ("Purchase"), you may be asked to supply certain information relevant to your Purchase including, without limitation, your ...</p><p><strong>Content</strong></p><p>Our Service allows you to post, link, store, share and otherwise make available certain information, text, graphics, videos, or other material ("Content"). You are responsible for the ...</p><p><strong>Changes</strong></p><p>We reserve the right, at our sole discretion, to modify or replace these Terms at any time. If a revision is material we will try to provide at least 30 days'' notice prior to any new terms taking effect. What constitutes a material change will be determined at our sole discretion.</p><p><strong>Contact Us</strong></p><p>If you have any questions about these Terms, please contact us.</p>'),
('Languages::check_again', 'Recheck and correct'),
('Languages::check_all', 'All'),
('Languages::check_disabled', 'Disabled'),
('Languages::check_items_text', 'To include Order statuses, Payment methods and Locations in the conditions list, check the necessary item and click on the "Save" button.'),
('Languages::sales_reports_side_bar_notes', 'To include Order statuses, Payment methods and Rate areas in the conditions list, check the necessary item and click on the "Save" button.'),
('Languages::check_none', 'None'),
('Languages::check_active', 'Active'),
('Languages::check_hidden', 'Hidden'),
('Languages::check_pending', 'Pending'),
('Languages::check_number', 'Check Number'),
('Languages::check_ssl', 'Check SSL'),
('Languages::check_uncheck_all', 'Check / uncheck all'),
('Languages::chinese', 'Chinese'),
('Languages::choose', 'Choose'),
('Languages::choose_action', 'Choose action'),
('Languages::actions.more', 'More'),
('Languages::actions.bulk_product_addition', 'Add several products'),
('Languages::actions.cdn_settings', 'CDN settings'),
('Languages::actions.cities', 'Cities'),
('Languages::actions.clear_cache', 'Clear cache'),
('Languages::actions.clear_thumbnails', 'Clear thumbnails'),
('Languages::actions.countries', 'Countries'),
('Languages::actions.datakeeper_optimize', 'Optimize database'),
('Languages::actions.destinations', 'Rate areas'),
('Languages::actions.export_found', 'Export found'),
('Languages::actions.export', 'Export'),
('Languages::actions.feature_groups', 'Feature groups'),
('Languages::actions.file_changes_detector', 'Changed core files'),
('Languages::actions.files', 'File manager'),
('Languages::actions.global_update', 'Global update'),
('Languages::actions.import', 'Import'),
('Languages::actions.languages', 'Languages'),
('Languages::actions.layouts', 'Layouts'),
('Languages::actions.live_editor', 'Edit on site'),
('Languages::actions.logs', 'Logs'),
('Languages::actions.localizations', 'Localizations'),
('Languages::actions.preview', 'Preview'),
('Languages::actions.product_subscriptions', 'Expected products'),
('Languages::actions.product_tabs', 'Product tabs'),
('Languages::actions.seo_robots', 'Robots.txt'),
('Languages::actions.shipment_statuses', 'Shipment statuses'),
('Languages::actions.states', 'States'),
('Languages::actions.templates', 'Templates'),
('Languages::actions.upload_backup', 'Upload file'),
('Languages::actions.user_group_requests', 'User group requests'),
('Languages::choose_category', 'Choose category'),
('Languages::choose_user', 'Choose user'),
('Languages::choose_your_country', 'Choose your country'),
('Languages::choose_your_store_mode', 'Please choose your licensing mode'),
('Languages::cities', 'Cities'),
('Languages::city', 'City'),
('Languages::classes', 'classes'),
('Languages::clean', 'clean'),
('Languages::cleanup_history', 'Clean up history'),
('Languages::clean_logs', 'Clear logs'),
('Languages::clean_old_logs', 'Clear logs older than [n] day|Clear logs older than [n] days'),
('Languages::clean_up_all_locations_on_import', 'Clean up locations before import'),
('Languages::clear', 'Clear'),
('Languages::clear_cache', 'Clear cache'),
('Languages::generate_cache', 'Generate cache'),
('Languages::clear_cart', 'Clear cart'),
('Languages::clear_conditions', 'Clear conditions'),
('Languages::clear_fields', 'Clear fields'),
('Languages::clear_list', 'Clear list'),
('Languages::clear_thumbnails', 'Clean up generated thumbnails'),
('Languages::clicks', 'Clicks'),
('Languages::client_id', 'Client ID'),
('Languages::clone', 'Clone'),
('Languages::clone_from', 'Clone from'),
('Languages::clone_selected', 'Clone selected'),
('Languages::clone_table', 'Clone table'),
('Languages::clone_theme', 'Clone theme'),
('Languages::clone_this_item', 'Clone this item'),
('Languages::clone_this_page', 'Clone this page'),
('Languages::close', 'Close'),
('Languages::cmcic_societe', 'Societe'),
('Languages::cname', 'CNAME'),
('Languages::code', 'Code'),
('Languages::coefficient', 'Coefficient'),
('Languages::collapse_bg_color', 'Collapse background color'),
('Languages::collapse_sublist_of_items', 'Collapse the sublist of items'),
('Languages::collapse_text_color', 'Collapse text color'),
('Languages::color', 'Color'),
('Languages::combination', 'Combination'),
('Languages::comma', 'Comma'),
('Languages::comment', 'Comment'),
('Languages::comments', 'Comments'),
('Languages::comment_hint', 'Enter your comment to appear below the option'),
('Languages::commission', 'Commission'),
('Languages::commissions', 'Commissions'),
('Languages::commissions_of_last_periods', 'Commissions of latest periods'),
('Languages::commission_rates', 'Commission rates'),
('Languages::compact_list', 'Compact list'),
('Languages::company', 'Company'),
('Languages::company_address', 'Company address'),
('Languages::company_name', 'Company name'),
('Languages::company_not_found', 'Selected company not found.'),
('Languages::company_phone', 'Company phone'),
('Languages::company_settings', 'Company settings'),
('Languages::compare', 'Compare'),
('Languages::product_comparison_list', 'Comparison list'),
('Languages::comparison_list_note', 'Go to the products comparison list'),
('Languages::compare_product_features', 'Compare product features'),
('Languages::comparison_list', 'Comparison list'),
('Languages::compatible_class', 'Compatible class'),
('Languages::completed', 'Completed'),
('Languages::compressing_backup', 'Compressing backup file'),
('Languages::compress_dump', 'Compress backup file'),
('Languages::condition', 'Condition'),
('Languages::conditions', 'Conditions'),
('Languages::configure', 'Configure'),
('Languages::confirm', 'Confirm'),
('Languages::confirmation_dialog', 'Confirmation dialog'),
('Languages::confirm_password', 'Confirm password'),
('Languages::conflicts', 'Conflicts'),
('Languages::congratulations', 'Congratulations!'),
('Languages::connection_ticket', 'Connection ticket'),
('Languages::contact_information', 'Contact information'),
('Languages::contact_us_for_price', 'Contact us for a price'),
('Languages::container_options', 'Container options'),
('Languages::content', 'Content'),
('Languages::content_alignment', 'Content alignment'),
('Languages::content_changed_for', 'This block instances have different content for'),
('Languages::continue', 'Continue'),
('Languages::continue_shopping', 'Continue shopping'),
('Languages::controller', 'Replace with'),
('Languages::converting_data_in_table', 'Converting data in table [table]'),
('Languages::copyright_shopping_cart', '[product] - Shopping Cart Software'),
('Languages::core', 'Core'),
('Languages::cost', 'Cost'),
('Languages::cost_dependences', 'Cost dependencies'),
('Languages::could_not_open_file', 'File preview is not available'),
('Languages::countries', 'Countries'),
('Languages::country', 'Country'),
('Languages::coupon', 'Coupon'),
('Languages::coupons', 'Coupons'),
('Languages::coupon_already_used', 'This coupon is already in use'),
('Languages::coupon_code', 'Coupon code'),
('Languages::cpi_hash_key', 'CPI Hash Key'),
('Languages::create', 'Create'),
('Languages::created', 'Created'),
('Languages::create_account', 'Create account'),
('Languages::create_administrator_account', 'Create administrator account'),
('Languages::create_and_close', 'Create and close'),
('Languages::create_file', 'Create file'),
('Languages::create_folder', 'Create folder'),
('Languages::create_guest_account', 'Quick checkout with no account creating required'),
('Languages::create_new_account', 'Create a permanent account and use it for checkout'),
('Languages::create_new_block', 'Create New Block'),
('Languages::create_new_order', 'Create a new order'),
('Languages::create_process_payment', 'Create and process payment'),
('Languages::create_profile', 'Create a new profile'),
('Languages::create_profile_notification_header', 'Thank you for becoming a registered user at our store. Below you will find your account information.'),
('Languages::create_table', 'Create New Table'),
('Languages::creating', 'Creating'),
('Languages::creating_table', 'Creating table'),
('Languages::creation_date', 'Creation date'),
('Languages::credit_card', 'Credit card'),
('Languages::credit_card_info', 'This number is printed in the signature area on the back of the card. It is the 3 digits AFTER the credit card number.'),
('Languages::credit_memo', 'Credit memo'),
('Languages::credit_memo_id', 'Credit memo ID'),
('Languages::cresecureapitoken', 'CRE SecureAPIToken'),
('Languages::cresecureid', 'CRE SecureID'),
('Languages::cresecure_allowed_types', 'Allowed card types'),
('Languages::csv_delimiter', 'CSV delimiter'),
('Languages::csv_file', 'CSV file'),
('Languages::currencies', 'Currencies'),
('Languages::edit_currencies', 'Edit currencies'),
('Languages::currency', 'Currency'),
('Languages::currencycode', 'Currency code'),
('Languages::currency_code_aed', 'United Arab Emirates Dirham'),
('Languages::currency_code_ang', 'ANG'),
('Languages::currency_code_ars', 'ARS'),
('Languages::currency_code_aud', 'Australian Dollar'),
('Languages::currency_code_awg', 'AWG'),
('Languages::currency_code_bgn', 'BGN'),
('Languages::currency_code_brl', 'Brazilian Real'),
('Languages::currency_code_byr', 'BYN'),
('Languages::currency_code_cad', 'Canadian Dollar'),
('Languages::currency_code_chf', 'Swiss Franc'),
('Languages::currency_code_cny', 'CNY'),
('Languages::currency_code_cyr', 'Cyprus Pound'),
('Languages::currency_code_czk', 'Czech Koruna'),
('Languages::currency_code_dkk', 'Danish Kroner'),
('Languages::currency_code_eek', 'Estonian Kroon'),
('Languages::currency_code_egp', 'EGP'),
('Languages::currency_code_eur', 'Euro'),
('Languages::currency_code_fjd', 'Fiji Dollar'),
('Languages::currency_code_frf', 'French Franc'),
('Languages::currency_code_gbp', 'UK Pound'),
('Languages::currency_code_gel', 'GEL'),
('Languages::currency_code_hkd', 'Hong Kong Dollar'),
('Languages::currency_code_hrk', 'HRK'),
('Languages::currency_code_huf', 'Hungarian Forint'),
('Languages::currency_code_ils', 'Israel New Shequel'),
('Languages::currency_code_inr', 'Indian Rupee'),
('Languages::currency_code_isk', 'Iceland Krona'),
('Languages::currency_code_jpy', 'Japanese Yen'),
('Languages::currency_code_kpw', 'North Korean Won'),
('Languages::currency_code_krw', 'South Korean Won'),
('Languages::currency_code_kwd', 'Kuwaiti Dinar'),
('Languages::currency_code_kzt', 'Kazakhstani tenge'),
('Languages::currency_code_ltl', 'Lithuanian Litas'),
('Languages::currency_code_lvl', 'Latvian Lat'),
('Languages::currency_code_mad', 'MAD'),
('Languages::currency_code_mxn', 'Mexican Peso'),
('Languages::currency_code_myr', 'Malaysian Ringgit'),
('Languages::currency_code_nok', 'Norwegian Kroner'),
('Languages::currency_code_nzd', 'New Zealand Dollar'),
('Languages::currency_code_php', 'Philippine Peso'),
('Languages::currency_code_pln', 'Polish Zlotych'),
('Languages::currency_code_png', 'Papua New Guinea Kina'),
('Languages::currency_code_ron', 'RON'),
('Languages::currency_code_rub', 'RUB'),
('Languages::currency_code_rur', 'Russian Ruble'),
('Languages::currency_code_sar', 'Saudi Riyal'),
('Languages::currency_code_sbd', 'Solomon Islands Dollar'),
('Languages::currency_code_sek', 'Sweden Kroner'),
('Languages::currency_code_sgd', 'Singapore Dollar'),
('Languages::currency_code_sit', 'Slovenian Tolar'),
('Languages::currency_code_skk', 'Slovak Koruna'),
('Languages::currency_code_thb', 'Thai Baht'),
('Languages::currency_code_top', 'Tongan Pa''anga'),
('Languages::currency_code_try', 'Turkish Lira'),
('Languages::currency_code_twd', 'New Taiwan dollar'),
('Languages::currency_code_uah', 'UAH'),
('Languages::currency_code_usd', 'US Dollar'),
('Languages::currency_code_vuv', 'Vanuatu Vatu'),
('Languages::currency_code_wst', 'Samoan Tala'),
('Languages::currency_code_xaf', 'XAF'),
('Languages::currency_code_xof', 'XOF'),
('Languages::currency_code_xpf', 'XPF'),
('Languages::currency_code_zar', 'Rand'),
('Languages::currency_deleted', 'The currency has been deleted successfully.'),
('Languages::currency_rate', 'Rate'),
('Languages::currency_rate_greater_than_null', 'Currency exchange rate should be higher than 0.'),
('Languages::currency_sign', 'Sign'),
('Languages::current_database_size', 'Current database size'),
('Languages::current_path', 'Current path'),
('Languages::text_file_editor_notice', 'You can upload and download files via <a href="[href]">File Editor</a>'),
('Languages::text_file_editor_notice_with_image_size_info', 'You can upload and download files via <a href="[href]">File Editor</a>. The maximum size of image files is [file_size] MB.'),
('Languages::text_file_editor_notice_full_link', 'You can upload and download files via [link]'),
('Languages::current_previous_period', '''Current (''[date]'') and previous period'''),
('Languages::current_period', 'Current Period'),
('Languages::current_theme', 'Current theme'),
('Languages::custom', 'Custom'),
('Languages::customer', 'Customer'),
('Languages::customers', 'Customers'),
('Languages::customers_menu_title', 'Users'),
('Languages::my_customers', 'My customers'),
('Languages::my_administrators', 'My administrators'),
('Languages::customer_details', 'Customer details'),
('Languages::customer_email', 'Customer email'),
('Languages::customer_id', 'Customer ID'),
('Languages::customer_info', 'Customer information'),
('Languages::customer_information', 'Customer information'),
('Languages::customer_notes', 'Customer notes'),
('Languages::customer_signature', 'Customer''s signature'),
('Languages::customer_text_letter_footer', 'Thank you for using our shopping cart.'),
('Languages::customize', 'Customize'),
('Languages::theme_no_styles_text', 'This theme doesn''t have styles.'),
('Languages::custom_range', 'Custom Range'),
('Languages::cutted_product_codes', 'The following product codes are too long and were cut to 32 figures:'),
('Languages::cvv2', 'CVV/CVC'),
('Languages::czech', 'Czech'),
('Languages::danish', 'Danish'),
('Languages::dashboard', 'Dashboard'),
('Languages::database', 'Database'),
('Languages::database_data_changes', 'Database data changes'),
('Languages::backup_restore', 'Backup/Restore'),
('Languages::database_structure_changes', 'Database structure changes'),
('Languages::datatrans_caa', 'Authorization with immediate settlement'),
('Languages::datatrans_noa', 'Authorization only'),
('Languages::datatrans_sign', 'Digital signature'),
('Languages::date', 'Date'),
('Languages::date_added', 'Date added'),
('Languages::date_of_birth', 'Date of birth'),
('Languages::day', 'day'),
('Languages::days', 'days'),
('Languages::db_backup_restore', 'DB Backup/Restore'),
('Languages::create_backup', 'Create backup'),
('Languages::db_name', 'Database name'),
('Languages::dear', 'Dear'),
('Languages::debit', 'Debit'),
('Languages::decimals', 'Decimals'),
('Languages::decline', 'Decline'),
('Languages::default_decline_inventory_info', 'To avoid the situation when two customers buy the same product, this status always decreases inventory.'),
('Languages::declined', 'Declined'),
('Languages::decline_selected', 'Decline selected'),
('Languages::decorator', 'Decorator'),
('Languages::decrease', 'Decrease'),
('Languages::dec_sign', 'Dec sign'),
('Languages::select_selectbox_option', 'Select option'),
('Languages::default', 'Default'),
('Languages::select_default', 'Select default'),
('Languages::default_category_view', 'Default category view'),
('Languages::default_language', 'Default language'),
('Languages::default_layout', 'Default layout'),
('Languages::default_long_options_template', 'Default template (long product option names)'),
('Languages::default_product_details_view', 'Parent ([default])'),
('Languages::default_template', 'Default template'),
('Languages::bigpicture_template', 'The big picture'),
('Languages::default_value', 'Default value'),
('Languages::default_custom.disabled', 'Disabled'),
('Languages::default_custom.custom', 'Custom...'),
('Languages::default_custom.custom_value', 'Custom ([value])'),
('Languages::default_custom.parent', 'Parent ([name])'),
('Languages::default_custom.global', 'Global ([name])'),
('Languages::default_custom.edit_parent', 'Edit parent ([name])...'),
('Languages::default_custom.edit_global', 'Edit global ([name])...'),
('Languages::global_individual.global', 'Global'),
('Languages::global_individual.individual', 'Individual'),
('Languages::global_individual.global_value_all_items', 'Global value for all items'),
('Languages::global_individual.individual_values_each_item', 'Individual values for each item'),
('Languages::global_individual.individual_tooltip', 'This setting is currently global. Click here to allow changing its value for individual items.'),
('Languages::global_individual.global_tooltip', 'The value of this setting can be changed for individual items. Click here to make this setting global.'),
('Languages::global_individual.additional_settings', 'You can hide or show some extra product settings here. A hidden setting will be global and affect all products. Look out for icon [icon] <a href="[settings_url]">in the "Settings" menu</a>.'),
('Languages::deferred', 'Deferred'),
('Languages::defined', 'Defined'),
('Languages::defined_desired_products', 'List of desired products'),
('Languages::defined_items', 'defined items'),
('Languages::delay', 'Delay (in seconds)'),
('Languages::delete', 'Delete'),
('Languages::dismiss', 'Dismiss'),
('Languages::deleted', 'Deleted'),
('Languages::deleted_product', 'DELETED PRODUCT'),
('Languages::delete_block', 'Delete block'),
('Languages::delete_confirmation', 'Are you sure you want to delete the selected items?'),
('Languages::delete_grid', 'Delete grid'),
('Languages::delete_image', 'Delete image'),
('Languages::delete_image_pair', 'Delete image pair'),
('Languages::delete_install_folder', 'Please remove the install directory.<br /><br />Keeping the install directory on the server is insecure.'),
('Languages::delete_range', 'Delete range'),
('Languages::delete_selected', 'Delete selected'),
('Languages::delete_this_category', 'Delete this category'),
('Languages::delete_this_page', 'Delete this page'),
('Languages::delivery_time', 'Delivery time'),
('Languages::demo', 'Demo'),
('Languages::demo_mode', 'Demo mode is enabled'),
('Languages::demo_mode_content_text', '<p>The cart is working in the <b>DEMO</b> mode and this functionality is disabled.</p>'),
('Languages::demo_panel.demo_store_panel', 'Demo store panel'),
('Languages::demo_panel.go_admin_panel', 'Go to Administration panel'),
('Languages::demo_panel.go_storefront', 'Go to Storefront'),
('Languages::demo_panel.demo_will_be_reset_in', 'Demo will be reset in:'),
('Languages::denied', 'Denied'),
('Languages::dependence', 'Sort by'),
('Languages::deposit_amount', 'Deposit amount'),
('Languages::desc', 'desc.'),
('Languages::description', 'Description'),
('Languages::descr_avs', 'AVS verification response'),
('Languages::descr_cvv', 'CVV2 verification response'),
('Languages::design', 'Design'),
('Languages::design_mode', 'Design mode'),
('Languages::desired_amount', 'Desired quantity'),
('Languages::destination', 'Destination'),
('Languages::detailed_description', 'Detailed description'),
('Languages::detailed_images', 'Detailed images');
INSERT INTO `[[dbprefix]]original_values` VALUES
('Languages::details', 'details'),
('Languages::diff', 'File changes'),
('Languages::different_only', 'Different only'),
('Languages::directory', 'Directory'),
('Languages::direct_download', 'Direct download'),
('Languages::disable', 'Disable'),
('Languages::disabled', 'Disabled'),
('Languages::disabled_categories', 'Disabled categories'),
('Languages::disable_for', 'Disable for'),
('Languages::disable_selected', 'Disable selected'),
('Languages::disapprove', 'Disapprove'),
('Languages::disapproved', 'Disapproved'),
('Languages::disapprove_selected', 'Disapprove selected'),
('Languages::discount', 'Discount'),
('Languages::discounted_price', 'Discounted price'),
('Languages::discounts', 'Discounts'),
('Languages::discount_coupon', 'Discount coupon'),
('Languages::discount_coupon_code', 'Discount coupon code'),
('Languages::dispatch', 'Dispatch'),
('Languages::displayed_vendors', 'Displayed stores'),
('Languages::display_bottom_buttons', 'Display bottom buttons'),
('Languages::display_delete_icons', 'Display delete icons'),
('Languages::display_message', 'Display message'),
('Languages::display_on', 'Display on'),
('Languages::display_type', 'Display type'),
('Languages::display_variants_count', 'Number of displayed filter variants before scroll'),
('Languages::domains', 'Domains'),
('Languages::domestic_usps', 'Domestic U.S.P.S.'),
('Languages::done', 'Done'),
('Languages::dont_track', 'Do not track'),
('Languages::dont_use_cardinal', 'Don''t use Cardinal Centinel&reg; for 3-D Secure Payer Authentication'),
('Languages::dots', 'Dots'),
('Languages::down', 'Down'),
('Languages::download', 'Download'),
('Languages::downloadable', 'Downloadable'),
('Languages::downloadable_shipping', 'Enable shipping if downloadable'),
('Languages::downloads', 'Downloads'),
('Languages::downloads_max_left', 'Downloads (max./left)'),
('Languages::download_key_expiry', 'Download key expiry'),
('Languages::download_link_expired', 'The download link is expired or is not ready.'),
('Languages::do_not_change', 'Do not change'),
('Languages::do_not_pass_logo', 'Do not pass the shopping cart logo to the merchant'),
('Languages::do_not_use', 'Do not use'),
('Languages::drlicense_number', 'Driving License Number'),
('Languages::dropdown_horizontal', 'Dropdown horizontal'),
('Languages::dropdown_limit', 'Minimal number of items to be placed in a dropdown list.'),
('Languages::dropdown_second_level_elements', 'Second level elements'),
('Languages::dropdown_third_level_elements', 'Third level elements'),
('Languages::dropdown_vertical', 'Dropdown vertical'),
('Languages::drop_existing_data', 'Delete all existing product files before import'),
('Languages::delete_downloadable_product_files', 'Delete existing files of downloadable products'),
('Languages::delete_downloadable_product_files_tooltip', 'If you enable this setting, then importing downloadable products will delete their existing files. If the setting is disabled, the new files of downloadable products will simply be added to existing files.'),
('Languages::cant_create_backup_file', 'Cannot upload backup file. Please check permissions for the "var/backups" directory of your installation.'),
('Languages::dump_file_not_writable', 'Please set write permissions on the database backup file.'),
('Languages::duplicate', 'Duplicate transactions'),
('Languages::dutch', 'Dutch'),
('Languages::dynamic', 'Dynamic'),
('Languages::dynamic_content', 'This block content will be shown on <a href="[url]">this page</a> only.'),
('Languages::dynamic_tree_cat', 'Dynamic tree'),
('Languages::dynamic_tree_pages', 'Dynamic tree'),
('Languages::easing', 'Easing'),
('Languages::edit', 'Edit'),
('Languages::editing', 'Editing'),
('Languages::editing_block', 'Editing block'),
('Languages::editing_category', 'Editing category'),
('Languages::editing_chart', 'Editing chart'),
('Languages::editing_container', 'Editing container'),
('Languages::editing_currency', 'Editing currency'),
('Languages::editing_defined_products', 'Editing defined products'),
('Languages::editing_file', 'Editing file'),
('Languages::editing_filter', 'Editing filter'),
('Languages::editing_folder', 'Editing folder'),
('Languages::editing_grid', 'Editing grid'),
('Languages::editing_group', 'Editing group'),
('Languages::editing_item', 'Editing item'),
('Languages::editing_language', 'Editing language'),
('Languages::editing_layout', 'Editing layout'),
('Languages::editing_link', 'Editing link'),
('Languages::editing_localization', 'Editing localization'),
('Languages::editing_location', 'Editing location'),
('Languages::editing_rate_area', 'Editing rate area'),
('Languages::editing_menu', 'Editing menus'),
('Languages::editing_option', 'Editing option'),
('Languages::editing_order', 'Editing order'),
('Languages::editing_page', 'Editing page'),
('Languages::editing_payment', 'Editing payment'),
('Languages::editing_product', 'Editing product'),
('Languages::editing_product_feature', 'Editing product feature'),
('Languages::editing_profile', 'Editing profile'),
('Languages::editing_profile_field', 'Editing profile field'),
('Languages::editing_promotion', 'Editing promotion'),
('Languages::editing_quick_menu_link', 'Editing quick menu link'),
('Languages::editing_quick_menu_section', 'Editing quick menu section'),
('Languages::editing_report', 'Editing report'),
('Languages::editing_shipping_method', 'Editing shipping method'),
('Languages::editing_sitemap_section', 'Editing sitemap section'),
('Languages::editing_status', 'Editing status'),
('Languages::editing_tab', 'Editing tab'),
('Languages::editing_tax', 'Editing tax'),
('Languages::editing_vendor', 'Editing store'),
('Languages::edition_type', 'Edition type'),
('Languages::edit_content_on_site', 'Edit content on-site'),
('Languages::edit_files', 'Can edit'),
('Languages::edit_layout', 'Edit layout'),
('Languages::edit_order', 'Edit order'),
('Languages::edit_products', 'Edit products'),
('Languages::edit_profile', 'Edit profile'),
('Languages::edit_profile_note', 'Change email, password, shipping/billing info, and other profile settings'),
('Languages::edit_report', 'Edit report'),
('Languages::edit_selected', 'Edit selected'),
('Languages::edp_access_granted', 'Now you can download the purchased products.'),
('Languages::edp_access_subj', 'Access to electronically distributed products is granted'),
('Languages::edp_enable_shipping', 'Enable shipping for downloadable products'),
('Languages::email', 'E-mail'),
('Languages::emails', 'Emails'),
('Languages::email_address', 'E-mail address'),
('Languages::email_header', 'E-mail header'),
('Languages::email_subject', 'E-mail subject'),
('Languages::empty', 'Empty'),
('Languages::empty_key_value', 'Empty table key value'),
('Languages::enable', 'Enable'),
('Languages::enabled', 'Enabled'),
('Languages::enable_cdn', 'Enable CDN'),
('Languages::enable_for', 'Enable for'),
('Languages::enable_or_disable_block', 'Activate/Deactivate Block'),
('Languages::enable_or_disable_container', 'Activate/Deactivate Container'),
('Languages::enable_or_disable_grid', 'Activate/Deactivate Grid'),
('Languages::enable_quick_view', 'Enable quick view'),
('Languages::encryption', 'Encryption'),
('Languages::encryption_key', 'Encryption Key'),
('Languages::end_date', 'End date'),
('Languages::english', 'English'),
('Languages::enter_code', 'Enter code'),
('Languages::enter_data', 'Enter data'),
('Languages::enter_email', 'Enter e-mail address'),
('Languages::enter_new_lang_code', 'Enter a new language code'),
('Languages::enter_other', 'Enter other'),
('Languages::enter_your_price', 'Enter your price'),
('Languages::entity', 'Entity'),
('Languages::entry_page', 'Global entry page'),
('Languages::entry_point', 'Entry point'),
('Languages::envelope', 'Envelope'),
('Languages::epdq_3ds_main', 'Main window'),
('Languages::epdq_3ds_popup', 'Popup'),
('Languages::error', 'Error'),
('Languages::errorCode', 'Error Code'),
('Languages::errorName', 'Error Name'),
('Languages::error_account_disabled', 'Your account is disabled. Please contact the store administration.'),
('Languages::error_count_recover_password_ekeys', 'You''ve already requested password reset. If you haven''t received an email, please try again in a few minutes.'),
('Languages::error_admin_not_created_email_already_used', 'Administrator account was not created. The email address belongs to another user. You can add the administrator for this company manually.'),
('Languages::error_ajax', 'Oops, something went wrong ([error]). Please try again.'),
('Languages::error_area_access_denied', 'You are not allowed to login to this area.'),
('Languages::error_confirmation_code_invalid', 'Sorry, the anti-bot validation has failed. Please try again.'),
('Languages::error_curl_not_exists', '<b>Warning!</b><br />Your server <b>does not</b> support the PHP cURL extension. <b>[method]</b> will not be operational. Please contact your hosting provider.'),
('Languages::error_curl_ssl_not_exists', '<b>Warning!</b><br />The PHP cURL extension is compiled <b>without</b> SSL support on your server. <b>[method]</b> will not be operational. Please contact your hosting provider.'),
('Languages::error_currency_exists', 'Currency with code <b>[code]</b> already exists'),
('Languages::error_delete_theme_company', 'One of your storefronts uses this theme. Please set another theme before deleting it.'),
('Languages::error_delete_theme_layout', 'Layout that uses this theme is set as 	default. Please set another layout as default.'),
('Languages::error_demo_mode', 'The cart is working in the <b>DEMO</b> mode and this functionality is disabled.'),
('Languages::error_empty_company_name', 'Company name cannot be empty'),
('Languages::error_exim_get_images_for_products', 'Could not import images for some of the products. Either those images don''t exist (or can''t be accessed), or the paths to those images in the imported file are incorrect.'),
('Languages::error_exim_cant_open_file', 'Cannot open uploaded file'),
('Languages::error_exim_cant_read_file', 'Cannot read uploaded file'),
('Languages::error_exim_fields_not_selected', 'No fields selected for export'),
('Languages::error_exim_file_doesnt_exist', 'File doesn''t exist'),
('Languages::error_exim_incorrect_lines', 'Your CSV file has incorrect data formatting (incorrect delimiter, missed/missing fields, etc.) in the following lines: <b>[lines]</b>'),
('Languages::error_exim_incorrent_delimiter', 'The delimiter in CSV file differs from the one selected by you'),
('Languages::error_exim_invalid_count_langs', 'Multi-language line count mismatch: different number of lines for different languages provided.'),
('Languages::error_exim_layout_required_fields', 'The following fields are mandatory and cannot be removed from the layout:'),
('Languages::error_exim_no_data_exported_new', 'No data exported. The wrong export range is probably causing this issue. <a class="cm-post" href="[url]">Clear the export range</a>, then try again'),
('Languages::error_exim_no_file_uploaded', 'No file uploaded'),
('Languages::error_exim_pattern_definition_alt_keys', 'Invalid pattern definition: alternative key is missing'),
('Languages::error_exim_pattern_definition_references', 'Invalid pattern definition: missing table references'),
('Languages::error_exim_pattern_dont_match', 'Your import file does not match the selected pattern'),
('Languages::error_exim_pattern_not_found', 'Pattern not found'),
('Languages::error_exim_pattern_required_fields', 'Your import file MUST have the following fields: <b>[fields]</b>'),
('Languages::error_hash_generation', 'Error in hash generation. Please choose another payment method.'),
('Languages::error_images_need_located_root_dir', 'Please specify the images directory within the store root directory. Put the images to import in this directory.'),
('Languages::error_image_format_not_supported', 'The image format <b>[format]</b> is not supported by GD library installed on your server. The thumbnail was not created.'),
('Languages::error_incorrect_login', 'The username or password you have entered is invalid. Please try again.'),
('Languages::error_invalid_emails', 'The following email addresses are invalid: <b>[emails]</b>'),
('Languages::error_lang_code_exists', 'The provided language ([code]) code already exists'),
('Languages::error_login_not_exists', 'The username you have entered does not match any account in our store. Please make sure you have entered the correct username and try again.'),
('Languages::error_message_not_sent', 'Message could not be sent.<br />Mailer Error:'),
('Languages::error_not_logged', 'You must log in before you can access this resource!'),
('Languages::error_no_items_selected', 'No items selected! At least one check box must be selected to perform this action.'),
('Languages::error_occured', 'Error occurred.'),
('Languages::error_occurred', 'Error occurred'),
('Languages::error_passwords_dont_match', 'The passwords do not match.'),
('Languages::error_password_content', 'The password must contain both letters and numbers.'),
('Languages::error_password_expired', 'Your password has expired. You must change your password now.'),
('Languages::error_password_expired_change', 'Your password has expired. <p><a href="[link]" class="underlined"><b>Change password &#155;&#155;</b></a></p>'),
('Languages::error_password_min_symbols', 'The password must contain at least <b>[number]</b> characters.'),
('Languages::error_password_was_used', 'Your new password must not coincide with any of those four passwords used before. Please use another password.'),
('Languages::error_permissions_not_changed', 'Cannot change permissions'),
('Languages::error_status_not_changed', 'Error while updating the status. Status was not changed.'),
('Languages::error_theme_manifest_missed', 'Theme description file ("manifest") was not found. Installation canceled.'),
('Languages::error_user_exists', 'The username or email you have chosen already exists. Please try another one.'),
('Languages::error_validator_color', 'The color code in the <b>[field]</b> field is invalid.'),
('Languages::error_validator_email', 'The email address in the <b>[field]</b> field is invalid.'),
('Languages::error_validator_integer', 'The value of the <b>[field]</b> field is invalid. It should be integer.'),
('Languages::error_validator_message', 'The value of the <b>[field]</b> field is invalid.'),
('Languages::error_validator_multiple', 'The <b>[field]</b> field does not contain the selected options.'),
('Languages::error_validator_password', 'The passwords in the <b>[field2]</b> and <b>[field]</b> fields do not match.'),
('Languages::error_validator_phone', 'The phone number in the <b>[field]</b> field is invalid. The correct format is +16175555555.'),
('Languages::error_validator_phone_mask', 'The phone number in the <b>[field]</b> field is invalid.'),
('Languages::error_validator_phone_mask_with_phone', 'The phone number <b>[phone]</b> is invalid.'),
('Languages::error_validator_phone_phone_number_with_country_selection', 'The phone number is invalid'),
('Languages::error_validator_phone_number', 'It is required to use the following format for this payment method: +16175555555.'),
('Languages::error_validator_required', 'The <b>[field]</b> field is mandatory.'),
('Languages::error_validator_zipcode', 'The ZIP / Postal code in the <b>[field]</b> field is incorrect. The correct format is [extra].'),
('Languages::error_vendor_exists', 'The company with e-mail you have chosen already exists, please try another.'),
('Languages::error_validator_ccv', 'CVV/CVC is too short.'),
('Languages::error_validator_ccv_long', 'CVV/CVC is too long.'),
('Languages::error_change_admin_data_in_frontend', 'It''s forbidden to change the admin email or password in the customer area. Please sign in using a customer account.'),
('Languages::error_exchange_rate', 'Unable to get exchange rates. Please try reloading this page in a minute.'),
('Languages::exact_phrase', 'The exact phrase'),
('Languages::excellent', 'Excellent!'),
('Languages::exception', 'Exception'),
('Languages::exceptions', 'Exceptions'),
('Languages::exceptions_type', 'Exceptions type'),
('Languages::exception_disabled', 'No variant can be selected'),
('Languages::exception_disregard', 'Any variant'),
('Languages::exception_error', 'ERROR'),
('Languages::exception_error_code', 'Error code:'),
('Languages::exception_exist', 'This exception combination already exists'),
('Languages::exception_title', 'Oops!<br />We were unable to find what you were looking for.'),
('Languages::exchange_rate', 'Live exchange rates'),
('Languages::exec', 'Execute'),
('Languages::exim_remove_additional_images', 'Clean up'),
('Languages::exit_point', 'Exit point'),
('Languages::exp', 'Exp'),
('Languages::expanded', 'Expanded'),
('Languages::expand_collapse_list', 'Expand / collapse the list of items'),
('Languages::expand_sublist_of_items', 'Expand the sublist of items'),
('Languages::expired', 'Expired'),
('Languages::expirepreauth', 'Preauthorization'),
('Languages::expirepreauth_description', 'Preauthorization hold limit in days. The maximum value is 30 days. With the "Sale" request type, leave this field empty.'),
('Languages::expiry_date', 'Expiration date'),
('Languages::export', 'Export'),
('Languages::exported_fields', 'Exported fields'),
('Languages::exported_files', 'Exported files'),
('Languages::exporting_data', 'Exporting data'),
('Languages::export_data', 'Export data'),
('Languages::export_locations', 'Export locations'),
('Languages::export_options', 'Export options'),
('Languages::export_selected', 'Export selected'),
('Languages::export_products', 'Export products'),
('Languages::extended', 'Extended'),
('Languages::extra', 'Extra'),
('Languages::extra_services', 'Extra services'),
('Languages::extra_folders', 'Extra folders'),
('Languages::fail', 'Fail'),
('Languages::failed', 'Failed'),
('Languages::fair', 'Fair'),
('Languages::false', 'False'),
('Languages::faroese', 'Faroese'),
('Languages::fast', 'Fast'),
('Languages::fax', 'Fax'),
('Languages::feature', 'Feature'),
('Languages::features', 'Features'),
('Languages::features_delimiter', 'Feature variants delimiter'),
('Languages::feature_code', 'Feature code'),
('Languages::feature_comparison', 'Feature comparison'),
('Languages::feature_category', 'Feature category'),
('Languages::feature_display_on_catalog', 'Show in product list'),
('Languages::feature_display_on_header', 'Show in header on the product details page'),
('Languages::feature_display_on_product', 'Show on the Features tab'),
('Languages::feature_hide_on_catalog', 'Hide in product list'),
('Languages::feature_hide_on_header', 'Hide in header on the product details page'),
('Languages::feature_hide_on_product', 'Hide on the Features tab'),
('Languages::feedback_is_sent_successfully', 'The feedback has been sent successfully.'),
('Languages::feedback_values', 'Feedback values'),
('Languages::field', 'Field'),
('Languages::field_editor', 'Field Editor'),
('Languages::file', 'File'),
('Languages::filename', 'File name'),
('Languages::files', 'Files'),
('Languages::sell_files', 'Files to sell'),
('Languages::filesize', 'File size'),
('Languages::files_changes', 'File changes'),
('Languages::files_directory', 'Files directory'),
('Languages::downloadable_product_files_directory', 'Directory for the files of downloadable products'),
('Languages::file_avail_after_payment', 'This file will be available after the order is paid in full.'),
('Languages::file_browser', 'File browser'),
('Languages::file_doesnt_have_key', 'This file doesn''t have a download key.'),
('Languages::file_download_limit_exceeded', 'The file cannot be downloaded because the download limit equal to [limit] is exceeded.'),
('Languages::file_is_too_large', 'File is too large. Max uploading size is [size].'),
('Languages::files_are_too_large', 'Total size of the uploaded files exceeds the maximum limit of [size].'),
('Languages::file_tree', 'File tree'),
('Languages::filling', 'Filling'),
('Languages::filter', 'Filter'),
('Languages::filters', 'Filters'),
('Languages::filter_by', 'Filter by'),
('Languages::filter_description', 'Filter description'),
('Languages::filter_name', 'Filter name'),
('Languages::filters_in_use', 'All features are already in use'),
('Languages::finance_product_code', 'Finance product code'),
('Languages::financial_state', 'Financial state'),
('Languages::find_results_with', 'Find results with'),
('Languages::finish', 'Finish'),
('Languages::finished', 'Finished'),
('Languages::finnish', 'Finnish'),
('Languages::first_name', 'First name'),
('Languages::flemish', 'Flemish'),
('Languages::folder', 'Folder'),
('Languages::folder_is_empty', 'Folder is empty'),
('Languages::footer', 'Footer'),
('Languages::for', 'for'),
('Languages::forbidden', 'Forbidden'),
('Languages::forbidden_combinations', 'Forbidden combinations'),
('Languages::forgot_password_question', 'Forgot your password?'),
('Languages::form', 'Form'),
('Languages::format', 'Format'),
('Languages::forms', 'Forms'),
('Languages::form_id', 'Form ID'),
('Languages::for_all_found_orders', 'For orders on ALL pages'),
('Languages::for_this_page_orders', 'For orders on THIS page'),
('Languages::fragile', 'Fragile'),
('Languages::free', 'Free'),
('Languages::free_products', 'Free products'),
('Languages::free_shipping', 'Free shipping'),
('Languages::french', 'French'),
('Languages::from', 'from'),
('Languages::from_date', 'Date from'),
('Languages::fulfillment_state', 'Fulfillment state'),
('Languages::full', 'Full'),
('Languages::fullauth', 'Fullauth'),
('Languages::full_description', 'Full description'),
('Languages::full_list', 'Full list'),
('Languages::full_tree_cat', 'Full tree'),
('Languages::full_tree_pages', 'Full tree'),
('Languages::full_width', 'Full width'),
('Languages::function', 'Core'),
('Languages::function_deprecated', 'Function [old_function] is deprecated and will be removed in next version. Please use [new_function] instead of it.'),
('Languages::gateway', 'Gateway'),
('Languages::gateways', 'Gateways'),
('Languages::general', 'General'),
('Languages::general_info', 'General information'),
('Languages::general_statistics', 'General statistics'),
('Languages::generate', 'Generate'),
('Languages::generate_submenu', 'Generate submenu'),
('Languages::geography', 'Geography'),
('Languages::german', 'German'),
('Languages::get_rates', 'Get rates'),
('Languages::give_coupon_subj', 'you have new promotion'),
('Languages::global', 'Global'),
('Languages::global_options', 'Global options'),
('Languages::global_status', 'Global status'),
('Languages::global_update', 'Global update'),
('Languages::global_update_description', 'Positive or negative values can be entered in the fields below (e.g. -5).'),
('Languages::go', 'Go'),
('Languages::google', 'Google'),
('Languages::google_base', 'Google Base'),
('Languages::google_base_export_notice', '<b>Note:</b> You can setup Tax and Shipping rates on the <a href="http://www.google.com/merchants/taxshippingsettings">Tax and shipping summary</a> page in your Google merchant center.'),
('Languages::goto_theme_configuration', 'Browse themes'),
('Languages::remove_theme', 'Remove theme'),
('Languages::go_back', 'Go back'),
('Languages::go_to_the_admin_homepage', 'Go to the admin homepage'),
('Languages::admin.go_to_the_homepage', 'Go to the homepage'),
('Languages::go_to_the_homepage', 'Go to the homepage'),
('Languages::grams_in_the_unit_of_weight', 'Grams in the unit of weight defined by the weight symbol'),
('Languages::graphic', 'Graphic'),
('Languages::greek', 'Greek'),
('Languages::grid', 'Grid'),
('Languages::tmpl_grid', 'Grid'),
('Languages::tmpl_grid2', 'Grid2'),
('Languages::grid_options', 'Grid options'),
('Languages::gross_total', 'Gross total'),
('Languages::group', 'Group'),
('Languages::groups', 'Groups'),
('Languages::guest', 'Guest'),
('Languages::has_credit_memo', 'Has credit memo'),
('Languages::has_invoice', 'Has invoice'),
('Languages::header', 'Header'),
('Languages::sidebar', 'Sidebar'),
('Languages::header_image', 'Header image'),
('Languages::hebrew', 'Hebrew'),
('Languages::height', 'Height'),
('Languages::hello', 'Hello'),
('Languages::help', 'Help'),
('Languages::hidden', 'Hidden'),
('Languages::hide', 'Hide'),
('Languages::hide_add_to_cart_button', 'Hide add to cart button'),
('Languages::hide_options', 'Hide options'),
('Languages::show_options', 'Show options'),
('Languages::hide_option_completely', 'Hide option completely'),
('Languages::home', 'Home'),
('Languages::home_page', 'Home page'),
('Languages::horizontal', 'Horizontal'),
('Languages::host', 'Host name'),
('Languages::host_code', 'Host code'),
('Languages::hour', 'Hour'),
('Languages::how_to_send', 'How to send?'),
('Languages::html_block', 'HTML block'),
('Languages::hungarian', 'Hungarian'),
('Languages::I25', 'Interleaved 2 of 5 is based on Standard 2 of 5 symbology.<br/>Interleaved 2 of 5 is designed to encode only 10 digits.'),
('Languages::icon', 'Icon'),
('Languages::id', 'ID'),
('Languages::identifier', 'PayBox identifier'),
('Languages::iframe_mode', 'iFrame mode'),
('Languages::illegal_item_weight', 'Illegal item weight'),
('Languages::image', 'Image'),
('Languages::images', 'Images'),
('Languages::images_directory', 'Images directory'),
('Languages::image_pair', 'Image pair'),
('Languages::image_verification', 'Image verification'),
('Languages::image_verification_body', 'Type the characters you see in the picture above.'),
('Languages::image_verification_label', 'Anti-bot validation'),
('Languages::immediately', 'Immediately'),
('Languages::import', 'Import'),
('Languages::important', 'Important'),
('Languages::importing_data', 'Importing data'),
('Languages::import_data', 'Import data'),
('Languages::import_locations', 'Import locations'),
('Languages::import_options', 'Import options'),
('Languages::in', 'In'),
('Languages::included', 'included'),
('Languages::include_cvn', 'Include CVN'),
('Languages::including_discount', 'Including discount'),
('Languages::including_tax', 'Including tax'),
('Languages::incompleted', 'Incomplete'),
('Languages::incompleted_orders', 'Incomplete orders'),
('Languages::incorrect_filling_message', 'Incorrect filling message'),
('Languages::incorrect_price_warning', 'Product has not been added to the cart. Please enter the correct price.'),
('Languages::increase', 'Increase'),
('Languages::inc_tax', 'inc tax'),
('Languages::index', 'Home page'),
('Languages::information', 'Information'),
('Languages::tip', 'Tip'),
('Languages::inner_hint', 'Inner hint'),
('Languages::input_field', 'Input field'),
('Languages::insert_block', 'Add block'),
('Languages::insert_grid', 'Add grid'),
('Languages::install', 'Install'),
('Languages::installation_id', 'Installation ID'),
('Languages::installed', 'Installed'),
('Languages::installed_languages', 'Installed'),
('Languages::installed_upgrades', 'Installed upgrades'),
('Languages::welcome_screen.administrator_info', 'To access the administrator area, use the e-mail (<b>[email]</b>) and the password you have entered earlier.'),
('Languages::welcome_screen.go_admin_panel', 'Go to the administration panel'),
('Languages::welcome_screen.go_storefront', 'Go to the storefront'),
('Languages::welcome_screen.go_settings_wizard', 'Go to the Settings wizard for basic store setup'),
('Languages::welcome_screen.knowledge_base', 'Documentation'),
('Languages::welcome_screen.run_settings_wizard', 'Run Settings wizard'),
('Languages::welcome_screen.learn_more_configuration', 'Learn more about storefront configuration in our'),
('Languages::welcome_screen.thanks', 'Thank you for choosing [product]. Happy selling!'),
('Languages::installer_complete_title', 'Installation successfully finished'),
('Languages::international_settings', 'International settings'),
('Languages::international_usps', 'International U.S.P.S.'),
('Languages::inventory', 'Inventory'),
('Languages::track_inventory', 'Track inventory'),
('Languages::track_inventory_tooltip', 'When inventory is tracked, the number of products in stock will decrease after each purchase.'),
('Languages::invitees', 'Invitees'),
('Languages::invoice', 'Invoice'),
('Languages::invoices', 'Invoices'),
('Languages::invoice_credit_memo', 'Invoice/Credit memo'),
('Languages::invoice_id', 'Invoice ID'),
('Languages::invoice_title', 'INVOICE'),
('Languages::in_progress', 'In progress'),
('Languages::in_stock', 'In stock'),
('Languages::n_in_stock_products_short', '[quantity] in stock'),
('Languages::ip', 'IP'),
('Languages::ip_address', 'IP address'),
('Languages::manager', 'Manager'),
('Languages::is_back_in_stock', 'is back in stock!'),
('Languages::is_pbp', 'Allow payment by points'),
('Languages::italian', 'Italian'),
('Languages::items', 'item(s)'),
('Languages::items_dependences', 'Items dependencies'),
('Languages::items_in_box', 'Items in a box'),
('Languages::items_in_cart', 'You have [n] item in your cart|You have [n] items in your cart'),
('Languages::n_products', '[n] product|[n] products'),
('Languages::items_per_page', 'Items per page'),
('Languages::objects_per_page', '[n] per page'),
('Languages::items_title', 'Items'),
('Languages::item_number', 'Show item number'),
('Languages::item_quantity', 'Item quantity'),
('Languages::japanese', 'Japanese'),
('Languages::join', 'Join'),
('Languages::json_error_ctrl_char', 'Control character error, possibly incorrectly encoded'),
('Languages::json_error_depth', 'The maximum stack depth has been exceeded'),
('Languages::json_error_state_mismatch', 'Invalid or malformed JSON'),
('Languages::json_error_syntax', 'Syntax error, malformed JSON'),
('Languages::json_error_unknown', 'Unknown JSON error'),
('Languages::json_error_utf8', 'Malformed UTF-8 characters, possibly incorrectly encoded'),
('Languages::key', 'Key'),
('Languages::key1_for_md5', 'Auth key 1 for md5'),
('Languages::key2_for_md5', 'Auth key 2 for md5'),
('Languages::keywords', 'Keywords'),
('Languages::korean', 'Korean'),
('Languages::label_text_color', 'Label text color'),
('Languages::landing_header', 'Your order has been received'),
('Languages::language', 'Language'),
('Languages::language_content', 'The language of content'),
('Languages::languagecode', 'Language code'),
('Languages::languages', 'Languages'),
('Languages::texts_languages', 'Texts & languages'),
('Languages::language_code', 'Language code'),
('Languages::language_variable', 'Language variable'),
('Languages::language_variables', 'Language variables'),
('Languages::last4ssn', 'Last 4 digits of Social Security Number'),
('Languages::last_24hours', 'Last 24 hours'),
('Languages::last_days', 'Last days'),
('Languages::last_month', 'Last month'),
('Languages::last_name', 'Last name'),
('Languages::last_n_days', 'Last [N] days'),
('Languages::last_order', 'Last order'),
('Languages::first_order', 'First order'),
('Languages::registration_date', 'Registration date'),
('Languages::latitude', 'Latitude'),
('Languages::layout', 'Layout'),
('Languages::layouts', 'Layouts'),
('Languages::lbl_amazon_aws_access_public_key', 'AWS access public key'),
('Languages::lbl_amazon_aws_access_secret_key', 'AWS access secret key'),
('Languages::lbl_amazon_background_color', 'Background color'),
('Languages::lbl_amazon_button_color', 'Button color'),
('Languages::lbl_amazon_button_size', 'Button size'),
('Languages::lbl_amazon_button_style', 'Amazon button style'),
('Languages::lbl_amazon_color_dark', 'Dark'),
('Languages::lbl_amazon_color_light', 'Light'),
('Languages::lbl_amazon_color_orange', 'Orange'),
('Languages::lbl_amazon_color_tan', 'Tan'),
('Languages::lbl_amazon_color_white', 'White'),
('Languages::lbl_amazon_process_order_on_failure', 'Process order on callback failure'),
('Languages::lbl_amazon_size_large', 'Large'),
('Languages::lbl_amazon_size_medium', 'Medium'),
('Languages::lbl_amazon_size_xlarge', 'X-Large'),
('Languages::left', 'Left'),
('Languages::length', 'Length'),
('Languages::less', 'less'),
('Languages::letter', 'Letter'),
('Languages::level', 'Level'),
('Languages::licence_agreement', 'License Agreement'),
('Languages::license_agreement', 'License agreement'),
('Languages::license_number', 'License number'),
('Languages::license_number_cannot_be_empty', 'License number cannot be empty'),
('Languages::limit', 'Limit'),
('Languages::line', 'Line'),
('Languages::linear', 'Linear'),
('Languages::link', 'Link'),
('Languages::linked_categories', 'Linked categories'),
('Languages::linked_products', 'Linked products'),
('Languages::links', 'Links'),
('Languages::links_thumb', 'Links thumb'),
('Languages::link_text', 'Link text'),
('Languages::link_to', 'Link to'),
('Languages::list', 'List'),
('Languages::list_objects', 'List objects'),
('Languages::list_price', 'List price'),
('Languages::list_price_decreased', 'List price has been decreased by'),
('Languages::list_price_increased', 'List price has been increased by'),
('Languages::list_price_short', 'List price'),
('Languages::list_price_short_2', 'List price'),
('Languages::list_quantity_count', 'Number of available quantities'),
('Languages::tmpl_list_without_options', 'List without options'),
('Languages::live', 'Live'),
('Languages::live_preview', 'Live preview'),
('Languages::loading', 'Loading...'),
('Languages::local', 'Local'),
('Languages::localization', 'Localization'),
('Languages::localizations', 'Localizations'),
('Languages::location', 'Location'),
('Languages::rate_area', 'Rate area'),
('Languages::locations', 'Locations'),
('Languages::rate_areas', 'Rate areas'),
('Languages::statuses_management', 'Statuses'),
('Languages::loggedin_time', 'Logged in time'),
('Languages::logging', 'Logging'),
('Languages::login', 'Login'),
('Languages::login_url', 'Login URL'),
('Languages::logos', 'Logos'),
('Languages::logo_link', 'Location (URL) of logo'),
('Languages::logs', 'Logs'),
('Languages::log_action_backup', 'backup'),
('Languages::log_action_create', 'create'),
('Languages::log_action_delete', 'delete'),
('Languages::log_action_deprecated', 'deprecated'),
('Languages::log_action_error', 'error'),
('Languages::log_action_failed_login', 'failed login'),
('Languages::log_action_http', 'http/https request'),
('Languages::log_action_login', 'sign in'),
('Languages::log_action_low_stock', 'low stock'),
('Languages::log_action_optimize', 'optimize'),
('Languages::log_action_restore', 'restore'),
('Languages::log_action_runtime', 'runtime'),
('Languages::log_action_session', 'session'),
('Languages::log_action_status', 'status change'),
('Languages::log_action_update', 'update'),
('Languages::log_type_categories', 'Categories'),
('Languages::log_type_database', 'Database'),
('Languages::log_type_general', 'general'),
('Languages::log_type_orders', 'Orders'),
('Languages::log_type_products', 'Products'),
('Languages::log_type_requests', 'Requests'),
('Languages::log_type_users', 'Users'),
('Languages::longitude', 'Longitude'),
('Languages::low_stock_subj', 'Low inventory of "[product]"'),
('Languages::mac_key', 'Mac key'),
('Languages::mailing_lists', 'Mailing lists'),
('Languages::mail_message', 'Mail message'),
('Languages::mail_subject', 'Mail subject'),
('Languages::main', 'Main'),
('Languages::mainbox_general', 'Main block (H1 heading)'),
('Languages::mainbox_simple', 'Important block (H2 heading)'),
('Languages::footer_general', 'Footer general'),
('Languages::maintenance', 'Maintenance'),
('Languages::main_category', 'Main category'),
('Languages::make_default', 'Make default'),
('Languages::manage', 'Manage'),
('Languages::manage_addons', 'Manage add-ons'),
('Languages::manage_blocks', 'Manage blocks'),
('Languages::manage_categories', 'Manage categories'),
('Languages::manage_existing_block', 'Edit Existing Blocks'),
('Languages::manage_items', 'Manage items'),
('Languages::manage_languages', 'Manage languages'),
('Languages::manage_menus', 'Manage menus'),
('Languages::manage_pages', 'Can edit'),
('Languages::manage_products', 'Manage products'),
('Languages::manage_reports', 'Manage reports'),
('Languages::manage_shippings', 'Shipping methods'),
('Languages::manage_sitemap', 'Manage sitemap'),
('Languages::manage_stores', 'Manage stores'),
('Languages::mandatory', 'Required'),
('Languages::manually', 'Manually'),
('Languages::manually_set_tax_rates', 'Manually set tax rates'),
('Languages::mark', 'Mark as resolved'),
('Languages::marketing', 'Marketing'),
('Languages::maximum_items_in_box', 'Maximum items in box'),
('Languages::max_amount', 'Total cost'),
('Languages::max_box_weight', 'Max box weight'),
('Languages::max_downloads', 'Max downloads'),
('Languages::max_item', 'Number of items'),
('Languages::max_order_qty', 'Maximum quantity to buy per product'),
('Languages::max_uploading_file_size', 'Max uploading file size'),
('Languages::max_uploading_file_size_hint', 'Leave this field empty to allow uploading of files of any size, or limit the file size ("100" is equal to 100 Kb)'),
('Languages::mb_amounts_not_match', 'The amount value received in status request differs from the original order total'),
('Languages::mb_currencies_not_match', 'The currency value received in status request differs from the store currency'),
('Languages::mb_md5_hashes_not_match', 'The md5 hash value received in status request differs from the calculated one'),
('Languages::mb_transaction_id', 'MB Transaction ID'),
('Languages::md5_checksum_failed', 'MD5 checksum failed'),
('Languages::md5_hash_value', 'MD5 hash value'),
('Languages::menu', 'Menu'),
('Languages::menus', 'Menus'),
('Languages::menu_items', 'Items for menu'),
('Languages::merchantid', 'Merchant ID'),
('Languages::merchant_email', 'Merchant Notification Email'),
('Languages::merchant_firstname', 'Merchant first name'),
('Languages::merchant_id', 'Merchant ID'),
('Languages::merchant_key', 'Merchant key'),
('Languages::merchant_lastname', 'Merchant last name'),
('Languages::merchant_login', 'Merchant login'),
('Languages::merchant_name', 'Merchant name'),
('Languages::merchant_pin', 'Merchant PIN'),
('Languages::merchant_response_was_not_received', 'No response from the merchant received. Please check this transaction manually.'),
('Languages::merchant_site_id', 'Merchant site ID'),
('Languages::merchant_warrior_api_key', 'API Key.'),
('Languages::merchant_warrior_api_passphrase', 'API Passphrase.'),
('Languages::merge', 'Merge'),
('Languages::message', 'Message'),
('Languages::messages', 'Messages'),
('Languages::meta_description', 'Meta description'),
('Languages::meta_keywords', 'Meta keywords'),
('Languages::method', 'Method'),
('Languages::minimized', 'Minimized'),
('Languages::minimum_commission_payment', 'Minimum commission payment'),
('Languages::minimum_items_in_box', 'Minimum items in box'),
('Languages::minutes', 'minute(s)'),
('Languages::min_order_qty', 'Minimum quantity to buy per product'),
('Languages::missing_variants_handling', 'Missing variants handling'),
('Languages::modifier', 'Modifier'),
('Languages::modifiers', 'Modifiers'),
('Languages::modify_profile', 'Modify Profile'),
('Languages::modify_selected', 'Modify selected'),
('Languages::month', 'Month'),
('Languages::months', 'month(s)'),
('Languages::month_name_1', 'January'),
('Languages::month_name_10', 'October'),
('Languages::month_name_11', 'November'),
('Languages::month_name_12', 'December'),
('Languages::month_name_2', 'February'),
('Languages::month_name_3', 'March'),
('Languages::month_name_4', 'April'),
('Languages::month_name_5', 'May'),
('Languages::month_name_6', 'June'),
('Languages::month_name_7', 'July'),
('Languages::month_name_8', 'August'),
('Languages::month_name_9', 'September'),
('Languages::month_name_abr_1', 'Jan'),
('Languages::month_name_abr_10', 'Oct'),
('Languages::month_name_abr_11', 'Nov'),
('Languages::month_name_abr_12', 'Dec'),
('Languages::month_name_abr_2', 'Feb'),
('Languages::month_name_abr_3', 'Mar'),
('Languages::month_name_abr_4', 'Apr'),
('Languages::month_name_abr_5', 'May'),
('Languages::month_name_abr_6', 'Jun'),
('Languages::month_name_abr_7', 'Jul'),
('Languages::month_name_abr_8', 'Aug'),
('Languages::month_name_abr_9', 'Sep'),
('Languages::more', 'More'),
('Languages::content_more', 'more'),
('Languages::more_info', 'More info'),
('Languages::more_link', '[more]'),
('Languages::more_sign_in_options', 'Back to more sign in options'),
('Languages::more_than', 'More than'),
('Languages::more_w_ellipsis', 'More...'),
('Languages::most_popular', 'Most popular'),
('Languages::most_popular_addons', 'Most popular add-ons'),
('Languages::mr', 'Mr.'),
('Languages::ms', 'Ms.'),
('Languages::tmpl_multicolumns_small', 'Multicolumns small'),
('Languages::tmpl_multicolumn_list', 'Multi-column list'),
('Languages::multiple', 'Multiple'),
('Languages::multiple_selectbox_notice', '<p>To select several items, press and hold the CTRL key and click on the required items.</p>'),
('Languages::multiupload', 'Multiupload'),
('Languages::my_account', 'My account'),
('Languages::my_account_links', 'My account links'),
('Languages::my_points', 'My points'),
('Languages::na', 'N/A'),
('Languages::name', 'Name'),
('Languages::name_short', 'Name'),
('Languages::navigation', 'Navigation'),
('Languages::navi_pages', 'Pages'),
('Languages::neighbours', 'Neighbours'),
('Languages::new', 'New'),
('Languages::newest', 'Newest'),
('Languages::new_administrator_password', 'New administrator password'),
('Languages::new_category', 'New category'),
('Languages::new_chart', 'New chart'),
('Languages::new_combination', 'New combination'),
('Languages::new_currency', 'New currency'),
('Languages::new_customer', 'New customer'),
('Languages::new_feature', 'New feature'),
('Languages::new_file', 'New file'),
('Languages::new_filter', 'New filter'),
('Languages::new_folder', 'New folder'),
('Languages::new_group', 'New group'),
('Languages::new_items', 'New item'),
('Languages::new_language', 'New language'),
('Languages::new_language_variable', 'New language variable'),
('Languages::important_language_text', 'When you hide, disable, or delete a default language of one of the storefronts, make sure to update the value of the <b>Frontend default language</b> setting in <a href="[link]">Settings → Appearance</a>.'),
('Languages::important_currency_text', 'When you hide, disable, or delete a default currency of one of the storefronts, make sure to update the value of the <b>Frontend default currency</b> setting in <a href="[link]">Settings → Appearance</a>.'),
('Languages::new_layout', 'New layout'),
('Languages::new_link', 'New link'),
('Languages::new_localization', 'New localization'),
('Languages::new_location', 'New location'),
('Languages::new_rate_area', 'New rate area'),
('Languages::new_menu', 'New menu'),
('Languages::new_option', 'New option'),
('Languages::new_page', 'New page'),
('Languages::new_payments', 'New payment method'),
('Languages::new_payout', 'New payout'),
('Languages::new_post', 'New post'),
('Languages::new_product', 'New product'),
('Languages::new_profile', 'New profile'),
('Languages::new_profile_field', 'New profile field'),
('Languages::new_profile_notification', 'New profile notification'),
('Languages::new_promotion', 'New promotion'),
('Languages::new_report', 'New report'),
('Languages::new_saved_search', 'New saved search'),
('Languages::new_section', 'New section'),
('Languages::new_shipment', 'New shipment'),
('Languages::detailed_shipment', 'Detailed shipment'),
('Languages::create_detailed_shipment', 'Create detailed shipment'),
('Languages::new_shipment_was_created', 'New shipment was created'),
('Languages::new_shipping_method', 'New shipping method'),
('Languages::new_site_map_section', 'New sitemap section'),
('Languages::new_states', 'New state(s) for the selected country'),
('Languages::new_status', 'New status'),
('Languages::new_tab', 'New tab'),
('Languages::new_tax', 'New tax'),
('Languages::new_usergroups', 'New user group(s)'),
('Languages::new_user_profile', 'New user profile'),
('Languages::new_vendor', 'New store'),
('Languages::new_zealand', 'New Zealand'),
('Languages::next', 'Next'),
('Languages::next_step', 'Next step'),
('Languages::no', 'No'),
('Languages::nocombination', 'Unfortunately this combination is not accessible'),
('Languages::none', 'None'),
('Languages::normal', 'Normal'),
('Languages::norway', 'Norway'),
('Languages::norwegian', 'Norwegian'),
('Languages::note', 'Note'),
('Languages::notes', 'Notes'),
('Languages::notice', 'Notice'),
('Languages::notice_too_many_decimals', 'You have specified [DECIMALS] decimal places for [CURRENCY]. The maximum number of supported decimal places is 2. Further values will be displayed as zeros.'),
('Languages::notice_undeliverable_products_removed', 'Undeliverable products have been removed from your cart. You may proceed with the purchase.'),
('Languages::notice_update_customer_details', 'The customer updated the email address in the profile. Select the check box to update the order details:'),
('Languages::notify_customer', 'Notify customer'),
('Languages::notify_orders_department', 'Notify orders department'),
('Languages::notify_user', 'Notify user'),
('Languages::notify_vendor', 'Notify store owner'),
('Languages::notify_when_back_in_stock', 'Notify me when this product is back in stock'),
('Languages::not_active', 'Not active'),
('Languages::not_active_file_notice', 'This file will be available for downloading only after the administrator approves them'),
('Languages::not_a_member', 'Not a member'),
('Languages::not_installed', 'Not installed'),
('Languages::not_scroll_automatically', 'Do not scroll automatically'),
('Languages::enable_link', 'Enable link'),
('Languages::no_categories_available', 'No categories available'),
('Languages::no_data', 'No data found'),
('Languages::no_data_found', 'No data found that satisfies this chart conditions'),
('Languages::no_files', 'No files'),
('Languages::no_image', 'No image'),
('Languages::no_items', 'No items defined'),
('Languages::no_items_found', 'No items found matching the search criteria'),
('Languages::no_menus', 'No menus'),
('Languages::no_products_for_shipment', 'There are no products for shipment'),
('Languages::no_products_selected', 'No products selected'),
('Languages::no_rates_for_empty_cart', '<p class="error-text" align="center">Your cart is empty and the shipping cost cannot be estimated</p>'),
('Languages::no_rates_for_empty_cart_warning', 'Your cart is empty and the shipping cost cannot be estimated'),
('Languages::no_shipping_required', 'No shipping required'),
('Languages::no_such_coupon', 'The entered code cannot be applied, because it does not meet the requirements.'),
('Languages::no_themes_available', 'No themes available'),
('Languages::no_users_found', 'No users found'),
('Languages::number', 'Number'),
('Languages::number_of_columns', 'Number of columns in the objects list'),
('Languages::object', 'Object'),
('Languages::object_does_not_exist', 'The object doesn''t exist'),
('Languages::object_exists', 'Object of the same name already exists. Do you want to overwrite it?'),
('Languages::object_not_found', 'The [object] not found'),
('Languages::of', 'of'),
('Languages::off', 'Off'),
('Languages::offline', 'Offline'),
('Languages::offset', 'Offset'),
('Languages::ok', 'OK'),
('Languages::old_price', 'Old price'),
('Languages::on', 'on'),
('Languages::once_per_customer', 'Once per customer'),
('Languages::onclick_dropdown', 'Onclick-dropdown'),
('Languages::online_only', 'Online only'),
('Languages::on_off', 'On/Off'),
('Languages::on_site_template_editing', 'On-site template editing'),
('Languages::on_site_live_editing', 'On-site live editing'),
('Languages::open', 'Open'),
('Languages::open_action', 'Open'),
('Languages::open_file_or_create_new', 'Open a file or create a new one to get started.'),
('Languages::open_in_new_window', 'Open in new window'),
('Languages::open_store', 'Open storefront'),
('Languages::optimize_database', 'Optimize database'),
('Languages::optimizing_table', 'Optimizing table'),
('Languages::options', 'Options'),
('Languages::options_for', 'Options for'),
('Languages::options_have_been_applied_to_products', 'Options have been successfully applied to the selected products'),
('Languages::options_settings', 'Options settings'),
('Languages::options_type', 'Options type'),
('Languages::option_combinations', 'Option combinations'),
('Languages::option_name', 'Option name'),
('Languages::option_unlinked', 'Global option "[option_name]" has been deactivated for the product'),
('Languages::option_variants', 'Option variants'),
('Languages::opt_currency_name', 'Show currency titles'),
('Languages::opt_currency_symbol', 'Use currency symbols instead of titles'),
('Languages::opt_language_icon', 'Flags only'),
('Languages::opt_language_name', 'Flags and language names'),
('Languages::or', 'or'),
('Languages::order', 'Order'),
('Languages::ordered_products', 'Ordered products'),
('Languages::orders', 'Orders'),
('Languages::orders_not_allow_to_change_company', 'Company has not been changed. It is not allowed to change the company when editing an order.'),
('Languages::orders_no_items', 'Use the "Add products" button above to add products to order.'),
('Languages::order_by_status', 'Order by status'),
('Languages::order_date', 'Order date'),
('Languages::order_details', 'Order details'),
('Languages::order_discount', 'Order discount'),
('Languages::order_id', 'Order ID'),
('Languages::order_info', 'Order information'),
('Languages::order_items', 'Order items'),
('Languages::order_landing_page', 'Order landing page'),
('Languages::order_management', 'Order management'),
('Languages::order_placed', 'Order placed'),
('Languages::order_prefix', 'Order prefix'),
('Languages::order_search', 'Search order'),
('Languages::order_status', 'Order status'),
('Languages::order_statuses', 'Order statuses'),
('Languages::order_total', 'Order Total'),
('Languages::order_total_not_correct', 'The paid total amount does not match the order total'),
('Languages::order_was_not_placed', 'Order was not placed'),
('Languages::only_one_order_can_be_edited_at_a_time', 'Couldn''t save changes to the order. Only one order can be edited per browser at a time. Please close any other browser tabs where you''re editing orders, and reload the tab with the order that you want to edit.'),
('Languages::original', 'Original'),
('Languages::origination', 'Origination'),
('Languages::or_saved_search', 'or any item from the saved search'),
('Languages::or_use', 'Or use'),
('Languages::others', 'Others'),
('Languages::other_addons', 'Other add-ons'),
('Languages::output', 'Output'),
('Languages::out_of_stock_actions', 'Out of stock actions'),
('Languages::out_of_stock_products', 'Out of stock'),
('Languages::override_by_dispatch', 'Override locations by dispatch'),
('Languages::override_by_this', 'Use this content for all the block instances'),
('Languages::override_product_data', 'Apply values to all the selected products'),
('Languages::owner', 'Owner'),
('Languages::p21agree', 'Please type "AGREE" or "DISAGREE" in the box provided'),
('Languages::p21agree_tooltip', 'By typing AGREE in the below box I am providing my signature as authorization to Payment21&reg; to electronically debit my account for the amount I have entered. I also understand and expressly authorize the merchant, if my eCheck payment is dishonored or returned for any reason, to electronically debit my account for the amount of the eCheck payment plus an NSF fee not to exceed the state maximum legal limit. I will print or save this page for my records. I can call +18887700850 for 24/7 support with any questions regarding this payment transaction.'),
('Languages::package', 'Package'),
('Languages::packages', 'Packages'),
('Languages::show_package_contents', 'View upgrade contents');
INSERT INTO `[[dbprefix]]original_values` VALUES
('Languages::package_type', 'Package type'),
('Languages::packing_slip', 'Packing slip'),
('Languages::packing_slip_for_order', 'Packing slip for order'),
('Languages::page', 'Page'),
('Languages::pages', 'Pages'),
('Languages::page_cloned', 'The page <b>[page]</b> has been cloned successfully. Now you can edit the new page'),
('Languages::page_id', 'Page ID'),
('Languages::page_link', 'Page URL'),
('Languages::page_name', 'Page name'),
('Languages::page_not_found', 'Page Not Found'),
('Languages::page_not_found_text', 'The page you have requested cannot be found.'),
('Languages::page_title', 'Page title'),
('Languages::paid_amount', 'Paid amount'),
('Languages::param', 'Parameter'),
('Languages::parameter', 'Object to analyze'),
('Languages::parameter_name', 'Parameter name'),
('Languages::parent_category', 'Parent category'),
('Languages::parent_category_id', 'Parent category'),
('Languages::parent_item', 'Parent item'),
('Languages::parent_page', 'Parent page'),
('Languages::parent_page_id', 'Parent page'),
('Languages::partner', 'Partner'),
('Languages::passphrase', 'Pass-phrase'),
('Languages::passport_number', 'Passport number'),
('Languages::password', 'Password'),
('Languages::path_to_files', 'Full path to the "atos" files'),
('Languages::pause_delay', 'Pause delay (in seconds)'),
('Languages::payflowcolor', 'Payflow color'),
('Languages::payment', 'Payment'),
('Languages::payments', 'Payments'),
('Languages::payments.cresecure.location_notice', '<b>Please note:</b><br>1. This payment requires the https checkout option to be enabled!<br>2. By default, the Checkout location is shown to a user on payment placing. In order to show a different location, create a new location with the dispatch ''checkout.cresecure_template'' in the <a href="[url]" target="_blank">Layout manager</a>.'),
('Languages::payments.epdq.bgcolor', 'Background color'),
('Languages::payments.epdq.btn_bgcolor', 'Button background color'),
('Languages::payments.epdq.btn_textcolor', 'Button text color'),
('Languages::payments.epdq.font_type', 'Font type'),
('Languages::payments.epdq.hash_error', 'Sorry, the hash string does not match'),
('Languages::payments.epdq.instructions', '<ol><li><p>Enter the following URL in the "Technical information"→"Transaction feedback" section in the Barclaycard ePDQ admin area:</p><p>for the "accepted" and "cancelled" payments: [url]</p></li><li>Make sure that the "Timing of the request" is set to "Always online", and "Request method" is set to "POST"</li><li>Define the "SHA-OUT pass phrase" value in the ePDQ admin area as you like, then duplicate it in the "SHA-IN pass phrase" field in the "Data and origin verification" section, and also in the "Pass-phrase" field below</li><li>Make sure that the "Default operation code" option in the ePDQ admin area has the same value as the "Transaction type" option value below</li><li>Set the "Hash algorithm" parameter to "SHA-1" in the "Global security parameters" section in the Barclaycard ePDQ admin area</li></ol>'),
('Languages::payments.epdq.pspid', 'EPDQ pspid'),
('Languages::payments.epdq.tbl_bgcolor', 'Table background color'),
('Languages::payments.epdq.tbl_textcolor', 'Table text color'),
('Languages::payments.epdq.textcolor', 'Text color'),
('Languages::payments.epdq.title', 'Title'),
('Languages::payments.signin_to_checkout', '<a href=[url]>Sign in</a> to check out'),
('Languages::payments_tab1', 'Credit card'),
('Languages::payments_tab2', 'Internet Payments'),
('Languages::payments_tab3', 'Other Payment Options'),
('Languages::payment_amount', 'Payment amount'),
('Languages::payment_category', 'Payment category'),
('Languages::payment_category_note', 'Payment categories tabs will NOT be displayed if all the active payments belong to the same category'),
('Languages::payment_details', 'Payment details'),
('Languages::payment_form_url', 'Payment Form URL'),
('Languages::payment_info', 'Payment type'),
('Languages::payment_information', 'Payment information'),
('Languages::payment_instructions', 'Payment instructions'),
('Languages::payment_method', 'Payment method'),
('Languages::payment_methods', 'Payment methods'),
('Languages::payment_response_password', 'Payment Response password'),
('Languages::payment_surcharge', 'Payment surcharge'),
('Languages::payment_type', 'Payment type'),
('Languages::paypal_authentication_method', 'PayPal authentication method'),
('Languages::paypal_item_name', 'Name of the item (or a name for the Shopping Cart)'),
('Languages::paypal_security_error', 'Your order was not placed: the recipient PayPal account is wrong.'),
('Languages::pay_from_email', 'Customer email'),
('Languages::pay_order_again', 'Pay order again'),
('Languages::pay_to_email', 'Email address of the Merchant'),
('Languages::pending', 'Pending'),
('Languages::suspended', 'Suspended'),
('Languages::per', 'Per [object]'),
('Languages::percent', 'Percent'),
('Languages::period', 'Period'),
('Languages::per_item', 'Per Item'),
('Languages::per_page', 'Per Page'),
('Languages::pagination_range', '<span>[pagination.range_from]</span>–<span>[pagination.range_to]</span>&nbsp;of&nbsp;[pagination.total_items]'),
('Languages::phone', 'Phone'),
('Languages::phone1_label', 'Phone'),
('Languages::phone2_label', 'International'),
('Languages::phone2', 'International'),
('Languages::phone_mask_label', 'Phone'),
('Languages::phpinfo', 'PHP information'),
('Languages::pick_store', 'Pick a store'),
('Languages::pie', 'Pie'),
('Languages::pie_3d', 'Pie 3D'),
('Languages::pixels', 'pixels'),
('Languages::place_order', 'Place order'),
('Languages::placing_order', 'Placing the order'),
('Languages::plain', 'Plain'),
('Languages::platform', 'Platform'),
('Languages::please_be_patient', 'Please be patient'),
('Languages::please_enter_license_here', 'Enter your license number here'),
('Languages::please_select_one', 'Please, select one'),
('Languages::please_sign_in', 'Please sign in'),
('Languages::polish', 'Polish'),
('Languages::poor', 'Poor'),
('Languages::popularity', 'Popularity'),
('Languages::popup', 'Popup'),
('Languages::popup_larger_image', 'Popup larger image'),
('Languages::portugese', 'Portuguese'),
('Languages::posid', 'Pos ID'),
('Languages::position', 'Position'),
('Languages::positions_updated', 'Positions of items were updated'),
('Languages::position_short', 'Pos.'),
('Languages::postal_mail', 'Postal mail'),
('Languages::postauth', 'Postauth'),
('Languages::post_url', 'Post URL'),
('Languages::powered_by', 'Powered by'),
('Languages::po_number', 'PO number'),
('Languages::preauth', 'Preauth'),
('Languages::preauthorization', 'Preauthorization'),
('Languages::prefix', 'Prefix'),
('Languages::preshared_key', 'PreShared Key'),
('Languages::prev', 'Prev.'),
('Languages::preview', 'Preview'),
('Languages::preview_file', 'Preview file'),
('Languages::previous', 'Previous'),
('Languages::previous_month', 'Previous month'),
('Languages::previous_period', 'Previous period'),
('Languages::previous_week', 'Previous week'),
('Languages::previous_year', 'Previous year'),
('Languages::prev_page', 'Prev'),
('Languages::price', 'Price'),
('Languages::price_decreased', 'Price has been decreased by'),
('Languages::price_dec_sign_delimiter', 'Price decimal separator'),
('Languages::price_includes_tax', 'Price includes tax'),
('Languages::price_increased', 'Price has been increased by'),
('Languages::price_in_points', 'Price in points'),
('Languages::price_summary', 'Price summary'),
('Languages::pricing_inventory', 'Pricing / inventory'),
('Languages::primary', 'Primary'),
('Languages::primary_currency', 'Primary currency'),
('Languages::print_card', 'Print card'),
('Languages::print_credit_memo', 'Print credit memo'),
('Languages::print_invoice', 'Print invoice'),
('Languages::edit_invoice', 'Edit invoice'),
('Languages::remove_invoice', 'Remove invoice'),
('Languages::print_order_details', 'Print order details'),
('Languages::print_packing_slip', 'Print packing slip'),
('Languages::print_pdf_packing_slip', 'Print packing slip (pdf)'),
('Languages::print_pdf_credit_memo', 'Print credit memo (pdf)'),
('Languages::print_pdf_invoice', 'Print invoice (pdf)'),
('Languages::print_pdf_order_details', 'Print order details (pdf)'),
('Languages::print_slip', 'Print slip'),
('Languages::priority', 'Priority'),
('Languages::private', 'Private'),
('Languages::private_customer_settings', 'Private customer settings'),
('Languages::privilege', 'Privilege'),
('Languages::privileges', 'Privileges'),
('Languages::privileges.change_order_status', 'Can change statuses'),
('Languages::privileges.create_order', 'Can create orders (only if editing entire orders is allowed)'),
('Languages::privileges.backup_restore', 'Can manage'),
('Languages::privileges.delete_logs', 'Can delete'),
('Languages::privileges.delete_orders', 'Can delete'),
('Languages::privileges.edit_blocks', 'Can edit'),
('Languages::privileges.edit_order', 'Can edit entire order (select other products, payment and shipping methods, customers)'),
('Languages::privileges.edit_files', 'Edit files'),
('Languages::privileges.exim_access', 'Can manage'),
('Languages::privileges.manage_catalog', 'Can edit'),
('Languages::privileges.manage_currencies', 'Can edit'),
('Languages::privileges.manage_design', 'Can edit'),
('Languages::privileges.manage_languages', 'Can edit'),
('Languages::privileges.manage_locations', 'Can edit'),
('Languages::privileges.manage_order_statuses', 'Can edit'),
('Languages::privileges.manage_pages', 'Manage pages'),
('Languages::privileges.manage_payments', 'Can edit'),
('Languages::privileges.manage_promotions', 'Can edit'),
('Languages::privileges.manage_reports', 'Can edit'),
('Languages::privileges.manage_shipping', 'Can edit'),
('Languages::privileges.manage_sitemap', 'Can edit'),
('Languages::privileges.manage_static_data', 'Can edit'),
('Languages::privileges.manage_storage', 'Can manage'),
('Languages::privileges.manage_stores', 'Manage stores'),
('Languages::privileges.manage_taxes', 'Can edit'),
('Languages::privileges.manage_themes', 'Can edit'),
('Languages::privileges.manage_translation', 'Can edit'),
('Languages::privileges.manage_usergroups', 'Can manage customer user groups'),
('Languages::privileges.manage_users', 'Can edit'),
('Languages::privileges.manage_email_templates', 'Can edit'),
('Languages::privileges.manage_document_templates', 'Can edit'),
('Languages::privileges.update_settings', 'Can edit'),
('Languages::privileges.update_order_details', 'Can edit minor details (select manager; edit shipments, notes, and tracking number)'),
('Languages::privileges.upgrade_store', 'Can upgrade'),
('Languages::privileges.view_catalog', 'Can view'),
('Languages::privileges.view_currencies', 'Can view'),
('Languages::privileges.view_languages', 'Can view'),
('Languages::privileges.view_locations', 'Can view'),
('Languages::privileges.view_logs', 'Can view'),
('Languages::privileges.view_orders', 'Can view'),
('Languages::privileges.view_pages', 'Can view'),
('Languages::privileges.view_payments', 'Can view'),
('Languages::privileges.view_reports', 'Can view'),
('Languages::privileges.view_settings', 'Can view'),
('Languages::privileges.view_shipping', 'Can view'),
('Languages::privileges.view_static_data', 'Can view'),
('Languages::privileges.view_stores', 'View stores'),
('Languages::privileges.view_taxes', 'Can view'),
('Languages::privileges.view_usergroups', 'Can view'),
('Languages::privileges.view_users', 'Can view'),
('Languages::privilege_sections.addons', 'Add-on privileges'),
('Languages::privilege_sections.administration', 'Administration privileges'),
('Languages::privilege_sections.cart', 'Cart'),
('Languages::privilege_sections.products', 'Product privileges'),
('Languages::privilege_sections.settings', 'Settings privileges'),
('Languages::privilege_sections.catalog', 'Catalog'),
('Languages::privilege_sections.cms', 'CMS'),
('Languages::privilege_sections.design', 'Design privileges'),
('Languages::privilege_sections.orders', 'Order privileges'),
('Languages::privilege_sections.marketing', 'Marketing privileges'),
('Languages::privilege_sections.website', 'Website privileges'),
('Languages::privilege_sections.users', 'Customer privileges'),
('Languages::privilege_sections.vendors', 'Store privileges'),
('Languages::proceed', 'Proceed'),
('Languages::proceed_to_checkout', 'Proceed to checkout'),
('Languages::proceed_to_the_next_step', 'Proceed to the next step'),
('Languages::processed', 'Processed'),
('Languages::processing', 'Processing'),
('Languages::processing_order', 'Processing order'),
('Languages::processor', 'Processor'),
('Languages::processor_description_cardsave', 'Merchant Accounts provided by Worldpay Cardsave, <a href="http://www.cardsave.net">www.cardsave.net</a><br/><br/>Email: <a href=''mailto:ecomm@cardsave.net''>ecomm@cardsave.net</a>'),
('Languages::processor_description_p21', '<b>P21 Simple API</b> enables you to accept check payments. It offers the industry''s most comprehensive suite of check image creation and clearing solutions. With Check 21, you will receive your funds within the same day by check or direct deposit.<br/><br/>To activate the Check 21 option, please contact us via email at: <a href="mailto:support@payment21.com">support@payment21.com</a> or by phone at: +18887700850 (US Toll Free) or +41717401629 (International).<br/><br/><a href="http://www.payment21.com" target="_blank">www.payment21.com</a>'),
('Languages::processor_id', 'Processor ID'),
('Languages::process_selected', 'Process selected'),
('Languages::product', 'Product'),
('Languages::products', 'Products'),
('Languages::products_menu_title', 'Products'),
('Languages::products_deprecated', 'Products (Deprecated)'),
('Languages::products2', 'Products2'),
('Languages::products_added_to_cart', 'The products were added to your cart'),
('Languages::products_number_added_to_cart', '<b>[number]</b> products were added to your cart'),
('Languages::products_amount', 'Product quantity'),
('Languages::products_bar', 'Products bar'),
('Languages::products_cost', 'Products cost'),
('Languages::products_for_shipment_not_selected', 'Products for shipment were not selected'),
('Languages::products_found', 'Products found'),
('Languages::n_products_found', '[n] product found|[n] products found'),
('Languages::products_grid', 'Products grid'),
('Languages::products_information', 'Products information'),
('Languages::products_in_cart', 'Products in cart'),
('Languages::products_links_type', 'Products links type'),
('Languages::products_required', 'Please add product(s)'),
('Languages::products_stat', 'Product statistics'),
('Languages::products_weight', 'Products weight'),
('Languages::products_were_sent', 'The products have been sent out to you. The order information is given below'),
('Languages::product_added_to_cart', 'The product was added to your cart'),
('Languages::product_name_added_to_cart', '<b>[product]</b> was added to your cart'),
('Languages::product_added_to_cl', 'The product was added to your Comparison list'),
('Languages::product_cannot_be_added', 'The product cannot be added to cart. Check if all the uploading files meet the necessary conditions'),
('Languages::product_code', 'Product code'),
('Languages::product_columns', 'Product columns'),
('Languages::product_combinations', 'Product combinations'),
('Languages::product_coming_soon', 'This product can''t be added to cart now. It will be available on [avail_date]'),
('Languages::product_coming_soon_add', 'This product will be shipped on [avail_date]'),
('Languages::product_details', 'Product details page'),
('Languages::product_details_view', 'Product details view'),
('Languages::product_details_sidebar', 'Product details'),
('Languages::customer_info_sidebar', 'Customer info'),
('Languages::product_feature_cannot_assigned', 'The feature "[feature_name]" cannot be assigned to the product "[product_name]"'),
('Languages::product_fields', 'Product fields'),
('Languages::product_groups', 'Product groups'),
('Languages::product_id', 'Product ID'),
('Languages::product_images', 'Product images'),
('Languages::product_inventory', 'Product inventory'),
('Languages::product_in_cart', 'This product is already in the cart'),
('Languages::product_in_comparison_list', 'This product is already in the comparison list'),
('Languages::product_name', 'Product name'),
('Languages::product_notification_subscribed', 'You have been subscribed to the product in stock notifications'),
('Languages::product_notification_unsubscribed', 'You have been unsubscribed from the product in stock notifications'),
('Languages::product_notification_subscription_error', 'Cannot subscribe for the product in stock notification'),
('Languages::product_options', 'Product options'),
('Languages::product_options_forbidden_combination', 'The <strong>[product]</strong> product has options that are included in the forbidden combination. The product was deleted from the cart'),
('Languages::zero_price_product_was_deleted', 'The <strong>[product]</strong> product has zero price. The product was deleted from the cart'),
('Languages::product_disabled_options', 'The product <strong>[product]</strong> has options or option variants that are not available anymore, so it was removed from cart'),
('Languages::product_s', 'Product(s)'),
('Languages::product_subscriptions', 'Product subscriptions'),
('Languages::product_summary', 'Product summary'),
('Languages::product_tabs', 'Product tabs'),
('Languages::product_type', 'Product type'),
('Languages::profile', 'Profile'),
('Languages::profiles', 'Profiles'),
('Languages::profile_activated', 'Account activated'),
('Languages::profile_details', 'Profile details'),
('Languages::profile_fields', 'Profile fields'),
('Languages::profile_info', 'Profile information'),
('Languages::profile_name', 'Profile name'),
('Languages::project_id', 'Project ID'),
('Languages::project_password', 'Project password'),
('Languages::prolongate_download_key', 'Prolong download key to'),
('Languages::promotion', 'Promotion'),
('Languages::promotions', 'Promotions'),
('Languages::promotion_bonus_discount_on_categories', 'Discount on all products in categories'),
('Languages::promotion_bonus_discount_on_products', 'Discount on products'),
('Languages::promotion_bonus_free_products', 'Free products'),
('Languages::promotion_bonus_free_shipping', 'Free shipping'),
('Languages::promotion_bonus_give_coupon', 'Give coupon'),
('Languages::promotion_bonus_give_points', 'Give points'),
('Languages::promotion_bonus_give_usergroup', 'Give user group'),
('Languages::promotion_bonus_order_discount', 'Order discount'),
('Languages::promotion_bonus_product_discount', 'Product discount'),
('Languages::promotion_cond_auto_coupons', 'Automatically generated coupon codes'),
('Languages::promotion_cond_categories', 'Categories'),
('Languages::promotion_cond_country', 'Customer country (shipping)'),
('Languages::promotion_cond_coupon_code', 'Coupon code'),
('Languages::promotion_cond_feature', 'Product feature'),
('Languages::promotion_cond_number_of_usages', 'Number of usages'),
('Languages::promotion_cond_once_per_customer', 'Once per customer'),
('Languages::promotion_cond_payment', 'Payment method'),
('Languages::promotion_cond_price', 'Product price'),
('Languages::promotion_cond_products', 'Products'),
('Languages::promotion_cond_products_number', 'Total products in the cart'),
('Languages::promotion_cond_purchased_products', 'Purchased products'),
('Languages::promotion_cond_state', 'Customer state (shipping)'),
('Languages::promotion_cond_subtotal', 'Order subtotal'),
('Languages::promotion_cond_total', 'Order total'),
('Languages::promotion_cond_total_weight', 'Total products weight in the cart'),
('Languages::promotion_cond_usergroup', 'User group'),
('Languages::promotion_cond_users', 'Users'),
('Languages::promotion_cond_zip_postal_code', 'Customer zip/postal code (shipping)'),
('Languages::promotion_cond_shipping', 'Shipping methods'),
('Languages::promotion_op_amount', 'amount'),
('Languages::promotion_op_cont', 'contains'),
('Languages::promotion_op_eq', 'equal'),
('Languages::promotion_op_gt', 'greater'),
('Languages::promotion_op_gte', 'equal or greater'),
('Languages::promotion_op_in', 'in'),
('Languages::promotion_op_lt', 'less'),
('Languages::promotion_op_lte', 'equal or less'),
('Languages::promotion_op_ncont', 'doesn''t contain'),
('Languages::promotion_op_neq', 'not equal'),
('Languages::promotion_op_nin', 'not in'),
('Languages::promo_code', 'Promo code'),
('Languages::promo_text', 'Promo text'),
('Languages::properties', 'Properties'),
('Languages::provider', 'Provider'),
('Languages::pspid', 'PSPID'),
('Languages::public', 'Public'),
('Languages::purchased_in_orders', 'Purchased in orders'),
('Languages::purchased_qty', 'Purchased qty'),
('Languages::purchasers_name', 'From'),
('Languages::qty', 'Qty'),
('Languages::qty_discounts', 'Quantity discounts'),
('Languages::qty_discount_type_tooltip', 'Fixed amount/Percentage to be taken off the price'),
('Languages::quantity', 'Quantity'),
('Languages::quantity_long', 'Quantity'),
('Languages::quantity_step', 'Quantity step'),
('Languages::query', 'Query'),
('Languages::quick_checkout', 'Quick checkout'),
('Languages::quick_links', 'Quick links'),
('Languages::quick_menu', 'Quick start menu'),
('Languages::admin_menu.add_item', 'Add item'),
('Languages::admin_menu.add_item_for_menu_title', 'Add item for menu'),
('Languages::admin_menu.add_item_title', 'Add item'),
('Languages::admin_menu.edit_item_title', 'Edit item'),
('Languages::quick_product_viewer', 'Quick product viewer'),
('Languages::quick_view', 'Quick view'),
('Languages::radiogroup', 'Radio group'),
('Languages::random', 'Random'),
('Languages::rank_number', 'Rank (''machine'') number'),
('Languages::rates_depend_on', 'Rates depend on'),
('Languages::rate_calculation', 'Rate calculation'),
('Languages::rate_calculation_manual', 'Manual (by defined location)'),
('Languages::rate_calculation_manual_by_rate_area', 'Manual (by rate areas)'),
('Languages::rate_calculation_by_customer_address', 'By customer''s address'),
('Languages::rate_calculation_realtime', 'Realtime'),
('Languages::rate_calculation_realtime_automatic', 'Real-time (automatic)'),
('Languages::rate_value', 'Rate value'),
('Languages::read', 'Read'),
('Languages::readme', 'Readme'),
('Languages::read_more_3d_secure', 'Read more about 3-D Secure'),
('Languages::reason', 'Reason'),
('Languages::reasons', 'reasons'),
('Languages::reason_text', 'Payment processor response'),
('Languages::rebuild_cache_automatically', 'Rebuild cache automatically'),
('Languages::rebuild_cache_automatically_tooltip', 'Modified files are tracked in real time (including the files modified directly on server) and re-cached. Block cache will be disabled. Store performance may be slightly affected. Recommended to disable on production.'),
('Languages::rebuild_combinations', 'Rebuild combinations'),
('Languages::recalculate', 'Recalculate'),
('Languages::recalculate_rates', 'Recalculate rates'),
('Languages::recalculate_totals', 'Recalculate totals'),
('Languages::recent_activity', 'Recent activity'),
('Languages::recent_orders', 'Recent orders'),
('Languages::recent_products', 'Recently viewed'),
('Languages::recipient', 'Recipient'),
('Languages::recipients_name', 'To'),
('Languages::recipient_description', 'Description of the Merchant'),
('Languages::recommended', 'Recommended'),
('Languages::recover_password', 'Reset password'),
('Languages::recover_password_subj', 'Password recovery'),
('Languages::recursively', 'Recursively'),
('Languages::redirect_customer_from_storefront', 'Redirect visitors of this storefront to the one that has countries to which the visitors'' IP addresses belong defined'),
('Languages::referrers', 'Referrers'),
('Languages::referrer_domain', 'Referrer domain'),
('Languages::refresh', 'Refresh'),
('Languages::refresh_packages_list', 'Refresh available upgrades'),
('Languages::refund', 'Refund'),
('Languages::refunded', 'Refunded'),
('Languages::refunded_amount', 'Refunded amount'),
('Languages::regexp', 'RegExp'),
('Languages::regexp_hint', 'If you are using the regexp checking, it is necessary to set a prompting message informing of the incorrect filling of the field, otherwise, the checking will not be performed'),
('Languages::region', 'Region'),
('Languages::regions', 'Regions'),
('Languages::register', 'Register'),
('Languages::registered', 'Registered'),
('Languages::registered_customers', 'Registered customers'),
('Languages::register_new_account', 'Register for a new account'),
('Languages::register_profile', 'Register profile'),
('Languages::registration', 'Registration'),
('Languages::regnumber', 'Registration number'),
('Languages::related_order', 'Related order'),
('Languages::release_date', 'Release date'),
('Languages::remember_me', 'Remember me'),
('Languages::remove', 'Remove'),
('Languages::remove_backup_files', 'Remove backup files'),
('Languages::remove_cc_info', 'Remove CC info'),
('Languages::remove_this_item', 'Remove this item'),
('Languages::rename', 'Rename'),
('Languages::repay_order', 'Pay order'),
('Languages::report', 'Report'),
('Languages::reports', 'Reports'),
('Languages::reports_interval_1', 'Total'),
('Languages::reports_interval_3', 'Day'),
('Languages::reports_interval_5', 'Week'),
('Languages::reports_interval_7', 'Month'),
('Languages::reports_interval_9', 'Year'),
('Languages::reports_list', 'Reports list'),
('Languages::reports_parameter_1', 'Order totals'),
('Languages::reports_parameter_10', 'Shipping costs'),
('Languages::reports_parameter_11', 'Categories'),
('Languages::reports_parameter_12', 'Products'),
('Languages::reports_parameter_13', 'Product costs'),
('Languages::reports_parameter_14', 'The number of products'),
('Languages::reports_parameter_15', 'Managers'),
('Languages::reports_parameter_2', 'The number of orders'),
('Languages::reports_parameter_3', 'Orders'),
('Languages::reports_parameter_4', 'Statuses of orders'),
('Languages::reports_parameter_5', 'Payment methods'),
('Languages::reports_parameter_6', 'Rate areas'),
('Languages::reports_parameter_7', 'Users'),
('Languages::reports_parameter_8', 'Discounts and coupons'),
('Languages::reports_parameter_9', 'Taxes'),
('Languages::request', 'Request'),
('Languages::requests_count', 'Requests count'),
('Languages::requesttype', 'Request type'),
('Languages::request_account_name', 'Requested account name'),
('Languages::required', 'Required'),
('Languages::reset', 'Reset'),
('Languages::reset_filter', 'Reset filter'),
('Languages::reset_inventory', 'Reset inventory'),
('Languages::reset_quantity_to_zero', 'Set quantity of all products to zero'),
('Languages::reset_quantity_to_zero_tooltip', 'If you enable this setting, all the products in your store will have their quantity set to 0, except for the products that have the quantity specified in the imported file.'),
('Languages::reset_password', 'Reset password'),
('Languages::resolved', 'Resolved'),
('Languages::response', 'Response'),
('Languages::restore', 'Restore'),
('Languages::restore_default', 'Use default value'),
('Languages::restore_from_repository', 'Restore from the repository'),
('Languages::ResultCode', 'ResultCode'),
('Languages::ResultDescription', 'ResultDescription'),
('Languages::return', 'Return to normal view'),
('Languages::returning_customer', 'Returning customer'),
('Languages::return_url_target', 'Return URL target'),
('Languages::reuse', 'Reuse'),
('Languages::reversed', 'Reversed'),
('Languages::revert', 'Revert'),
('Languages::re_order', 'Reorder this order'),
('Languages::right', 'Right'),
('Languages::right_to_left_orientation', 'Right to left orientation'),
('Languages::risk_checking', 'Risk checking is in process. Please try reloading this page in a minute.'),
('Languages::risk_information', 'Risk information'),
('Languages::romanian', 'Romanian'),
('Languages::root_category', 'Root category'),
('Languages::root_level', 'Root level'),
('Languages::root_page', 'Root level page'),
('Languages::round_to', 'Round to'),
('Languages::routing_code', 'Routing Number'),
('Languages::runtime', 'Runtime'),
('Languages::russian', 'Russian'),
('Languages::sale', 'Sale'),
('Languages::sales', 'Sales'),
('Languages::sales_commission', 'Sales commission'),
('Languages::sales_reports', 'Sales reports'),
('Languages::same_as_source', 'same as source'),
('Languages::save', 'Save'),
('Languages::saved_search', 'Saved searches'),
('Languages::save_and_close', 'Save and close'),
('Languages::save_as', 'Save As...'),
('Languages::save_changes', 'Save changes'),
('Languages::save_discount', 'Save'),
('Languages::save_layout', 'Save layout'),
('Languages::save_layout_as', 'Save layout as'),
('Languages::save_process_payment', 'Save and process payment'),
('Languages::save_this_search_as', 'Save this search as'),
('Languages::scb_text_notice', 'Please send the following URL to the SCB support to be set as PostbackURL: <br /><b>[return_url]</b>'),
('Languages::screen', 'Screen'),
('Languages::screen_resolution', 'Screen resolution'),
('Languages::script', 'Script'),
('Languages::tmpl_scroller', 'Scroller'),
('Languages::scroller_direction', 'Auto-scroll direction'),
('Languages::search', 'Search'),
('Languages::admin_search_title', 'Search'),
('Languages::admin_search_button', 'Search'),
('Languages::admin_search_field', 'Search'),
('Languages::admin_search_general', 'Search'),
('Languages::storefront_search_button', 'Search'),
('Languages::storefront_search_field', 'Search'),
('Languages::storefront_search_label', 'Search'),
('Languages::storefront_search_general', 'Search'),
('Languages::search_again', 'Search again'),
('Languages::search_by_order', 'Search by order'),
('Languages::search_by_customer', 'Search by customer'),
('Languages::search_by_owner', 'Search by owner'),
('Languages::search_by_price', 'Search by price'),
('Languages::search_by_product_features', 'Search by product features'),
('Languages::search_by_product_filters', 'Search by product filters'),
('Languages::search_by_sku', 'Search by product code'),
('Languages::search_by_vendor', 'Search by store'),
('Languages::search_by_weight', 'Search by weight'),
('Languages::search_engine', 'Search engine'),
('Languages::search_for_pattern', 'Search for pattern'),
('Languages::search_in', 'Search in'),
('Languages::search_in_category', 'Search in category'),
('Languages::search_in_subcategories', 'Search in subcategories'),
('Languages::search_options', 'Search options'),
('Languages::search_product', 'Search product'),
('Languages::search_products', 'Search products'),
('Languages::searching_all_products', 'Searching all products'),
('Languages::search_results', 'Search results'),
('Languages::search_results_for', 'Search results for [search]'),
('Languages::search_string', 'Search string'),
('Languages::search_words', 'Search words'),
('Languages::secret_key', 'Secret key'),
('Languages::secret_string', 'Secret string'),
('Languages::secret_word', 'Secret word'),
('Languages::section', 'Section'),
('Languages::section_is_not_completed', 'Section is not completed.'),
('Languages::section_links', 'Section links'),
('Languages::section_name', 'Section name'),
('Languages::secure', 'Secure'),
('Languages::security', 'Security'),
('Languages::secure_checkout', 'Secure checkout'),
('Languages::secure_storefront_url', 'Secure storefront URL'),
('Languages::store_access_key', 'Access key to temporarily closed store'),
('Languages::secure_storefront_url_already_exists', 'The value of the <strong>Secure storefront URL</strong> parameter mentioned by you already belongs to another company.'),
('Languages::url_access_storefront', 'Use the following URL to access the storefront:<br><a href="[url]" target="_blank">[url]</a>'),
('Languages::security_settings', 'Security settings'),
('Languages::see_demo', 'See demo'),
('Languages::select', 'Select'),
('Languages::selectbox', 'Select box'),
('Languages::selected', 'Selected'),
('Languages::selected_fields', 'Selected fields'),
('Languages::selected_items', 'Selected items'),
('Languages::select_all', 'Select all'),
('Languages::select_all_product_options', 'You should select all product options'),
('Languages::select_block', 'Select block'),
('Languages::select_country', 'Select country'),
('Languages::select_customer', 'Select customer'),
('Languages::select_dates', 'Select dates'),
('Languages::period_selector_from', 'From'),
('Languages::period_selector_to', 'To'),
('Languages::select_descr_lang', 'Select the description language'),
('Languages::select_fields_to_edit', 'Select fields to edit'),
('Languages::select_file', 'Select file'),
('Languages::select_image', 'Select image'),
('Languages::select_options', 'Select options'),
('Languages::select_option_above', 'Select the previous option first'),
('Languages::select_product', 'Select product'),
('Languages::select_products', 'Select products'),
('Languages::select_profile', 'Select profile'),
('Languages::select_shipping_method', 'Select shipping method'),
('Languages::select_state', 'Select state'),
('Languages::select_tables', 'Select tables'),
('Languages::select_storefront', 'Select [store] storefront'),
('Languages::semicolon', 'Semicolon'),
('Languages::send', 'Send'),
('Languages::sender', 'Sender'),
('Languages::send_feedback', 'Help us improve [product]'),
('Languages::send_notification', 'Send notification to selected'),
('Languages::send_shipment_notification_to_customer', 'Send shipment notification to customer'),
('Languages::send_shipping_address', 'Send customer shipping address'),
('Languages::send_via', 'Send via'),
('Languages::send_via_email', 'Send via email'),
('Languages::send_via_postal_mail', 'Send via postal mail'),
('Languages::seo_meta_data', 'Meta data'),
('Languages::sequential', 'Sequential'),
('Languages::server', 'Server'),
('Languages::service_not_available', 'This service is not available.'),
('Languages::settings', 'Settings'),
('Languages::settings_wizard', 'Settings wizard'),
('Languages::settings_wizard_close_tooltip', 'Wizard will be possible to re-open in the menu ''Settings -> Settings wizard''.'),
('Languages::settings_wizard_title', 'Settings wizard: Step [current_step] of [total_steps]'),
('Languages::store_mode_menu_description', 'View and manage your licensing details.'),
('Languages::upgrade_center_menu_description', 'Get the latest versions of CS-Cart and its add-ons.'),
('Languages::import_data_menu_description', 'Import products, orders, users and more.'),
('Languages::export_data_menu_description', 'Export products, orders, users and more.'),
('Languages::languages_menu_description', 'Configure the available languages and edit any texts on your site.'),
('Languages::storage_menu_description', 'Back up your site data or restore a previous copy, manage files and CDN.'),
('Languages::settings_general', 'General'),
('Languages::settings_general_menu_description', 'Configure your company info and basic principles of how your site works.'),
('Languages::payment_methods_menu_description', 'Set up the payment options available to your customers.'),
('Languages::shipping_methods_menu_description', 'Set up shipping options, their rates and availability by location.'),
('Languages::taxes_menu_description', 'Configure what taxes you show, how you do it, and tax rates by location.'),
('Languages::storefronts_menu_description', 'Create regional or thematic branches, manage common storefront details.'),
('Languages::stores_menu_description', 'Create regional or thematic branches, manage common storefront details.'),
('Languages::profile_fields_menu_description', 'Manage information collected from customers and sellers.'),
('Languages::notifications_menu_description', 'Manage the notifications sent to customers, administrators and sellers.'),
('Languages::logs_menu_description', 'Store activity log.'),
('Languages::sync_data_manage', 'Sync data'),
('Languages::sync_data_manage_menu_description', 'Connect your store with external systems.'),
('Languages::currencies_menu_description', 'Set up the currencies in which you show the prices to customers.'),
('Languages::statuses_management_menu_description', 'Edit the possible statuses for orders, shipments, etc.'),
('Languages::share', 'Share'),
('Languages::share.congratulations_first_order', 'Congratulations on your first complete order.'),
('Languages::share.first_order_tweet', 'Wow! The first complete order in my [product]-powered store'),
('Languages::share.installation_tweet', 'I have just created an online store with [product_name]'),
('Languages::sharedsec', 'SharedSec'),
('Languages::shared_secret', 'Shared Secret'),
('Languages::sha_sign', 'SHA-1 Signature'),
('Languages::shipment', 'Shipment'),
('Languages::shipments', 'Shipments'),
('Languages::shipment_date', 'Shipment date'),
('Languages::shipment_details', 'Shipment details'),
('Languages::shipment_has_been_created', 'Shipment has been created'),
('Languages::shipment_id', 'Shipment ID'),
('Languages::shipment_info', 'Shipment information'),
('Languages::shipped', 'Shipped'),
('Languages::shipped_products', 'Shipped products'),
('Languages::shipper_number', 'Shipper number'),
('Languages::shipping', 'Shipping'),
('Languages::shippings', 'Shippings'),
('Languages::shippings.service_not_configured', 'Service is not configured'),
('Languages::shippings.service_not_found', 'Service was not found'),
('Languages::shippings.currency_not_found', 'Currency [currency] was not found'),
('Languages::shippings_taxes', 'Shipping & taxes'),
('Languages::shipping_address', 'Shipping address'),
('Languages::shipping_charges', 'Shipping charges'),
('Languages::shipping_time_and_charges', 'Shipping time and rates'),
('Languages::shipping_cost', 'Shipping cost'),
('Languages::shipping.pricing', 'Pricing'),
('Languages::shipping_estimation', 'Shipping estimation'),
('Languages::shipping_freight', 'Shipping freight'),
('Languages::shipping_information', 'Shipping information'),
('Languages::shipping_method', 'Shipping method'),
('Languages::shipping_methods', 'Shipping methods'),
('Languages::shipping_name', 'Shipping name'),
('Languages::shipping_options', 'Shipping Options'),
('Languages::shipping_properties', 'Shipping properties'),
('Languages::shipping_rates', 'Shipping rates'),
('Languages::shipping_same_as_billing', 'Shipping and billing address the same?'),
('Languages::shipping_service', 'Shipping service'),
('Languages::shipping_time', 'Shipping time'),
('Languages::shipping_rate', 'Rate'),
('Languages::shipping_condition', 'Condition'),
('Languages::shipping_price_condition', 'Price condition'),
('Languages::shipping_weight_condition', 'Weight condition'),
('Languages::shipping_items_condition', 'Items condition'),
('Languages::shipping_surcharge_discount', 'Surcharge / Discount'),
('Languages::shipping_per', 'per'),
('Languages::shipping_from_value', 'From'),
('Languages::shipping_to_value', 'To'),
('Languages::shipping_and_up', 'and up'),
('Languages::shipping_item', 'item'),
('Languages::shipping_add_conditions', 'Add conditions'),
('Languages::shipping_hide_conditions', 'Hide conditions'),
('Languages::shipping_add_price_condition', 'Add price conditions'),
('Languages::shipping_add_weight_condition', 'Add weight conditions'),
('Languages::shipping_add_items_condition', 'Add items conditions'),
('Languages::shipping_remove_price_condition', 'Remove price conditions'),
('Languages::shipping_remove_weight_condition', 'Remove weight conditions'),
('Languages::shipping_remove_items_condition', 'Remove items conditions'),
('Languages::shipping_edit_rate_area', 'Edit rate area'),
('Languages::shipping_remove_rate_area', 'Remove rate area from shipping'),
('Languages::shipping_rate_range_overlap_error_message', 'Condition must not fall within existing range.'),
('Languages::shipping_rate_range_limit_error_message', 'The beginning of the range can''t be higher than the end.'),
('Languages::shipping_rate_absolute', 'Absolute ([currency])'),
('Languages::shipping_rate_percent', 'Cart percent (%)'),
('Languages::ship_dhl_height', 'Package height'),
('Languages::ship_dhl_length', 'Package length'),
('Languages::ship_dhl_site_id', 'Site ID'),
('Languages::ship_dhl_width', 'Package width'),
('Languages::ship_fedex_ancillary_endorsement', 'Ancillary Endorsements'),
('Languages::ship_fedex_ancillary_endorsement_address_correction', 'Address Service Requested'),
('Languages::ship_fedex_ancillary_endorsement_carrier_leave_if_no_response', 'Carrier Leave If No Response'),
('Languages::ship_fedex_ancillary_endorsement_change_service', 'Change Service Requested'),
('Languages::ship_fedex_ancillary_endorsement_forwarding_service', 'Forwarding Service Requested'),
('Languages::ship_fedex_ancillary_endorsement_return_delivery', 'Return Service Requested'),
('Languages::ship_fedex_customer_manifest_id', 'Customer manifest ID'),
('Languages::ship_fedex_drop_off_type', 'Drop Off Type'),
('Languages::ship_fedex_drop_off_type_regular_pickup', 'Regular pickup'),
('Languages::ship_fedex_drop_off_type_request_courier', 'Request courier'),
('Languages::ship_fedex_drop_off_type_station', 'Drop at station'),
('Languages::ship_fedex_height', 'Height (inches)'),
('Languages::ship_fedex_hub_id', 'Hub ID'),
('Languages::ship_fedex_indicia', 'Indicia'),
('Languages::ship_fedex_indicia_media_mail', 'Media Mail (Packages from 1 to 70 lbs Books, DVDs, CDs, videotapes)'),
('Languages::ship_fedex_indicia_parcel_select', 'Parcel Select (Packages from 1 to 70 lbs)'),
('Languages::ship_fedex_indicia_presorted_bound_printed_matter', 'Bound Printed Matter packages (Packages from 1 to 15 lbs Catalogs, phone books or anything permanently bound)'),
('Languages::ship_fedex_indicia_presorted_standard', 'Standard Mail packages (Packages less than 1 lb)'),
('Languages::ship_fedex_length', 'Length (inches)'),
('Languages::ship_fedex_meter_number', 'Meter number'),
('Languages::ship_fedex_package_type_fedex_10kg_box', 'FedEx 10kg Box'),
('Languages::ship_fedex_package_type_fedex_25kg_box', 'FedEx 25kg Box'),
('Languages::ship_fedex_package_type_fedex_box', 'FedEx Box'),
('Languages::ship_fedex_package_type_fedex_envelope', 'FedEx Envelope'),
('Languages::ship_fedex_package_type_fedex_pak', 'FedEx Pak'),
('Languages::ship_fedex_package_type_fedex_tube', 'FedEx Tube'),
('Languages::ship_fedex_package_type_your_packaging', 'Your packaging'),
('Languages::ship_fedex_smart_post', 'Smart Post'),
('Languages::ship_fedex_special_services', 'Special service (delivery confirmation)'),
('Languages::ship_fedex_width', 'Width (inches)'),
('Languages::ship_height', 'Package height (cm)'),
('Languages::ship_length', 'Package length (cm)'),
('Languages::ship_sp_l_acknowledgement_of_delivery', 'Acknowledgement of delivery (for registered mail only)'),
('Languages::ship_sp_l_cash_on_delivery', 'Cash on delivery (for registered mail only)'),
('Languages::ship_sp_l_personal_delivery', 'Personal delivery (for registered mail only)'),
('Languages::ship_sp_l_registered_mail', 'Registered mail'),
('Languages::ship_sp_pc_assurance', 'Assurance'),
('Languages::ship_sp_pc_cash_on_delivery', 'Cash on delivery (COD)'),
('Languages::ship_sp_pc_fragile', 'Fragile'),
('Languages::ship_sp_pc_manual_handling', 'Manual handling'),
('Languages::ship_sp_pc_personal', 'Personal'),
('Languages::ship_sp_pc_signature', 'Signature'),
('Languages::ship_sp_pp_additional_insurance', 'Additional insurance (up to CHF 3000.-)'),
('Languages::ship_sp_pp_bulky_goods', 'Bulky goods'),
('Languages::ship_sp_pp_cash_on_delivery', 'Cash on delivery (ECONOMY only)'),
('Languages::ship_sp_pp_manual_processing', 'Manual processing'),
('Languages::ship_sp_ur_additional_insurance', 'Additional insurance for URGENT goods  (up to CHF 3000.-)'),
('Languages::ship_swisspost_error_intl_delivery', 'Cannot use this shipping method for the international delivery'),
('Languages::ship_swisspost_error_private_delivery', 'Cannot use this shipping method for the private delivery'),
('Languages::ship_swisspost_heavy_package', 'The package is too heavy'),
('Languages::ship_swisspost_unable_to_open_additional_services', 'Cannot open the additional_services.csv file'),
('Languages::ship_swisspost_unable_to_open_service', 'Cannot open the [code] file'),
('Languages::ship_to', 'Ship to'),
('Languages::ship_to_another', 'Ship to a different address'),
('Languages::ship_ups_access_key', 'UPS Rates Access Key'),
('Languages::ship_ups_package_type_01', 'UPS letter/ UPS Express Envelope'),
('Languages::ship_ups_package_type_03', 'UPS Tube'),
('Languages::ship_ups_package_type_04', 'UPS Pack'),
('Languages::ship_ups_package_type_21', 'UPS Express Box'),
('Languages::ship_ups_package_type_24', 'UPS 25Kg Box'),
('Languages::ship_ups_package_type_25', 'UPS 10Kg Box'),
('Languages::ship_ups_pickup_type', 'Pickup type'),
('Languages::ship_ups_pickup_type_01', 'Daily Pickup'),
('Languages::ship_ups_pickup_type_03', 'Customer Counter'),
('Languages::ship_ups_pickup_type_06', 'One Time Pickup'),
('Languages::ship_ups_pickup_type_07', 'On Call Air'),
('Languages::ship_ups_pickup_type_11', 'Suggested Retail Rates'),
('Languages::ship_ups_pickup_type_19', 'Letter Center'),
('Languages::ship_ups_pickup_type_20', 'Air Service Center'),
('Languages::ship_ups_delivery_confirmation', 'No Signature'),
('Languages::ship_ups_delivery_confirmation_signature', 'Signature Required'),
('Languages::ship_ups_delivery_confirmation_adult_signature', 'Adult Signature Required'),
('Languages::ship_ups_use_delivery_confirmation', 'Use Delivery confirmation'),
('Languages::ship_ups_dcist_type', 'Confirmation type'),
('Languages::ship_usps_container', 'Container'),
('Languages::ship_usps_container_express', 'Container (Express)'),
('Languages::ship_usps_container_express_flat_rate_envelope', 'Flat Rate Envelope'),
('Languages::ship_usps_container_priority', 'Container (Priority Mail)'),
('Languages::ship_usps_container_priority_flat_rate_box', 'Flat Rate Box'),
('Languages::ship_usps_container_priority_flat_rate_envelope', 'Flat Rate Letter'),
('Languages::ship_usps_container_priority_lg_flat_rate_box', 'Large Flat Rate Box'),
('Languages::ship_usps_container_priority_md_flat_rate_box', 'Medium Flat Rate Box'),
('Languages::ship_usps_container_priority_nonrectangular', 'NonRectangular'),
('Languages::ship_usps_container_priority_rectangular', 'Rectangular'),
('Languages::ship_usps_container_priority_regional_a_rate_box', 'Regional Rate Box A'),
('Languages::ship_usps_container_priority_regional_b_rate_box', 'Regional Rate Box B'),
('Languages::ship_usps_container_priority_regional_c_rate_box', 'Regional Rate Box C'),
('Languages::ship_usps_container_priority_sm_flat_rate_box', 'Small Flat Rate Box'),
('Languages::ship_usps_container_priority_padded_flat_rate_envelope', 'Padded Flat Rate Envelope'),
('Languages::ship_usps_container_priority_legal_flat_rate_envelope', 'Legal Flat Rate Envelope'),
('Languages::ship_usps_container_priority_sm_flat_rate_envelope', 'Sm Flat Rate Envelope'),
('Languages::ship_usps_container_priority_window_flat_rate_envelope', 'Window Flat Rate Envelope'),
('Languages::ship_usps_container_priority_gift_card_flat_rate_envelope', 'Gift Card Flat Rate Envelope'),
('Languages::ship_usps_first_class_mail_type', 'First Class Mail Type'),
('Languages::ship_usps_first_class_mail_type_flat', 'Flat'),
('Languages::ship_usps_first_class_mail_type_parcel', 'Parcel'),
('Languages::ship_usps_intl_package_girth', 'Package girth'),
('Languages::ship_usps_intl_package_height', 'Package height'),
('Languages::ship_usps_intl_package_length', 'Package length'),
('Languages::ship_usps_intl_package_size', 'Package size'),
('Languages::ship_usps_intl_package_width', 'Package width'),
('Languages::ship_usps_machinable', 'Machinable (First-Class Mail or Standard Post)'),
('Languages::ship_usps_machinable_false', 'False'),
('Languages::ship_usps_machinable_true', 'True'),
('Languages::ship_usps_mailtype', 'Type of Mail'),
('Languages::ship_usps_mailtype_matter_for_the_blind', 'Matter for the Blind'),
('Languages::ship_usps_mailtype_postcards_or_aerogrammes', 'Postcards or Aerogrammes'),
('Languages::ship_usps_package_size', 'Package Size (length + girth, inches)'),
('Languages::ship_usps_package_size_large', 'Large (84..108)'),
('Languages::ship_usps_package_size_oversize', 'Oversize (108..130)'),
('Languages::ship_usps_package_size_regular', 'Regular (0..84)'),
('Languages::ship_usps_priority_girth', 'Priority Mail (Size:Large, Container:NonRectangular) Girth (inches)'),
('Languages::ship_usps_priority_height', 'Priority Mail (Size:Large) Height (inches)'),
('Languages::ship_usps_priority_length', 'Priority Mail (Size:Large) Length (inches)'),
('Languages::ship_usps_priority_width', 'Priority Mail (Size:Large) Width (inches)'),
('Languages::ship_usps_username', 'User ID'),
('Languages::ship_width', 'Package width (cm)'),
('Languages::short_description', 'Short description'),
('Languages::short_hour', 'h.'),
('Languages::short_list', 'Short list'),
('Languages::show', 'Show'),
('Languages::show_all', 'Show all'),
('Languages::show_items_in_line', 'Show items inline'),
('Languages::show_orders', 'Show orders'),
('Languages::show_price', 'Show price'),
('Languages::show_rate_for_destination', 'Show rates for location'),
('Languages::show_rate_for_rate_area', 'Show rates for rate area'),
('Languages::show_tab_in_popup', 'Show this tab in a popup window'),
('Languages::tmpl_sidebox_1_item', 'Side box first item'),
('Languages::sidebox_general', 'Ordinary block (H3 heading) [deprecated]'),
('Languages::sidebox_important', 'Ordinary block (H3 heading)'),
('Languages::signature', 'Signature'),
('Languages::signed_in_as', 'Signed in as'),
('Languages::sign_in', 'Sign in'),
('Languages::sign_in_as_different', 'Sign in as a different user'),
('Languages::sign_in_to_buy', 'Please sign in to buy'),
('Languages::sign_in_to_view_price', '[Sign in to view price]'),
('Languages::sign_out', 'Sign out'),
('Languages::sign_up_for_notification', 'Sign up for notification'),
('Languages::similar_only', 'Similar only'),
('Languages::simple_ultimate_companies_selector', 'Please contact the technical support'),
('Languages::simultaneous', 'Simultaneous'),
('Languages::single', 'Single'),
('Languages::single_coupon_is_allowed', 'Single discount coupon is allowed only'),
('Languages::sitemap', 'Sitemap'),
('Languages::sitemap_settings', 'Sitemap settings'),
('Languages::site_number', 'Site number (EPT)'),
('Languages::size', 'Size'),
('Languages::skiplastpage', 'Skip the last page'),
('Languages::skip_payment', 'Skip payment'),
('Languages::skrill_customer_id', 'Skrill Customer ID'),
('Languages::sku', 'CODE'),
('Languages::slovak', 'Slovak'),
('Languages::slow', 'Slow'),
('Languages::small_items', 'Small items'),
('Languages::smarty_block', 'HTML block with Smarty support'),
('Languages::sms_customer_registered', 'Customer [name] has been registered.'),
('Languages::sms_for_the_sum', 'to the amount of'),
('Languages::sms_order_placed', 'has been placed'),
('Languages::snapshot_date', 'Snapshot date'),
('Languages::sort_by', 'Sort by'),
('Languages::sort_by_null_asc', 'No sorting'),
('Languages::sort_by_popularity_asc', 'Sort by Popularity: Low to High'),
('Languages::sort_by_popularity_desc', 'Sort by Popularity'),
('Languages::sort_by_position_asc', 'Sort by Position: Low to High'),
('Languages::sort_by_position_desc', 'Sort by Position: High to Low'),
('Languages::sort_by_price_asc', 'Sort by Price: Low to High'),
('Languages::sort_by_price_desc', 'Sort by Price: High to Low'),
('Languages::sort_by_product_asc', 'Sort Alphabetically: A to Z');
INSERT INTO `[[dbprefix]]original_values` VALUES
('Languages::sort_by_product_desc', 'Sort Alphabetically: Z to A'),
('Languages::sort_by_timestamp_asc', 'Oldest Items First'),
('Languages::sort_by_timestamp_desc', 'Newest Items First'),
('Languages::sort_images', 'Sort images'),
('Languages::spanish', 'Spanish'),
('Languages::specific_settings', 'Specific settings'),
('Languages::specify_url', 'Specify URL'),
('Languages::speed', 'Speed'),
('Languages::tooltip_carousel_speed', 'The time of the animation in milliseconds. The shorter the time, the faster the animation.'),
('Languages::type_to_search', 'Type to search...'),
('Languages::type_to_create', 'Type to create...'),
('Languages::type_to_search_or_click_button', 'Type to search, or click the button on the right for advanced search'),
('Languages::use_comma_enter_to_separate_variants', 'Use a comma or Enter to separate variants.'),
('Languages::enter_color_name_and_code', 'Enter color name and code. Example, "Red #ff0000"'),
('Languages::enter_category_name_and_path', 'Enter path and category name. Example, "Electronics/Computers/Laptops"'),
('Languages::object_picker.remove_all_items', 'Remove all items'),
('Languages::ssl_certificate', 'SSL certificate'),
('Languages::staff_only_notes', 'Staff only notes'),
('Languages::stage', 'Stage'),
('Languages::standard_sidebox', 'Standard side box'),
('Languages::start', 'Start'),
('Languages::start_communication', 'Start communication'),
('Languages::start_date', 'Start date'),
('Languages::start_price', 'Start price'),
('Languages::state', 'State/Province'),
('Languages::states', 'States'),
('Languages::static_block', 'Static block'),
('Languages::static_data', 'Static data'),
('Languages::static_data_use_item', 'Use the "Link text" and "URL" values from this item in the storefront'),
('Languages::statistics', 'Statistics'),
('Languages::status', 'Status'),
('Languages::status_changed', 'Status has been changed'),
('Languages::no_active_storefronts', 'No active storefronts'),
('Languages::status_changed_after_process_payment', 'Order status was set according to the payment processing result'),
('Languages::stay_connected', 'Stay Connected'),
('Languages::stay_connected_notice', 'Enter your email address to receive special offers and promotions.'),
('Languages::step_four', 'Step 4'),
('Languages::step_one', 'Step 1'),
('Languages::step_three', 'Step 3'),
('Languages::step_two', 'Step 2'),
('Languages::stop_other_rules', 'Stop other rules'),
('Languages::storage', 'Storage'),
('Languages::store', 'Store'),
('Languages::storefront', 'Storefront'),
('Languages::storefront_url', 'Storefront URL'),
('Languages::storefront_url_already_exists', 'The value of the <strong>Storefront URL</strong> parameter mentioned by you already belongs to another company.'),
('Languages::storefront_url_not_defined', 'Storefront URL not defined'),
('Languages::stores_status', 'Status'),
('Languages::storefront_status_access_key_hint', 'Even if the storefront is closed (the status set to OFF), you''ll be able to view it if you have an access key. Go to <a target="blank" href="[url]">Settings → General</a> and specify the <i>Access key to temporarily closed store</i> setting. Please note that a different key can be specified for each storefront, so make sure to select the correct storefront first. Use the key as described in the tooltip of that setting.'),
('Languages::stores', 'Stores'),
('Languages::store_mode', 'Licensing mode'),
('Languages::store_mode_changed', 'Licensing mode has been changed'),
('Languages::store_number', 'Store number'),
('Languages::store_object_denied', 'The [object_type] [object_name] is unavailable for this store.'),
('Languages::store_theme', 'Storefront theme'),
('Languages::subcategories', 'Subcategories'),
('Languages::submit', 'Submit'),
('Languages::submit_my_order', 'Submit my order'),
('Languages::subpages', 'Subpages'),
('Languages::subscribe', 'Subscribe'),
('Languages::subscriber', 'Subscriber'),
('Languages::subscribers', 'Subscribers'),
('Languages::subscriber_email', 'Subscriber email'),
('Languages::subscriptions', 'Subscriptions'),
('Languages::subtotal', 'Subtotal'),
('Languages::subtotal_sum', 'Subtotal sum'),
('Languages::suburb', 'Suburb'),
('Languages::successful', 'Successful'),
('Languages::successfully_registered', 'Successfully registered'),
('Languages::successful_login', 'You have been successfully logged in.'),
('Languages::success_registration_text', 'Congratulations! The registration was successful!<br/>Now, you have full access to all the store features. Click on "My account" to see them.'),
('Languages::suffix', 'Suffix'),
('Languages::summary', 'Summary'),
('Languages::supplier', 'Supplier'),
('Languages::suppliers', 'Suppliers'),
('Languages::supplier_id', 'Supplier'),
('Languages::surcharge', 'Surcharge'),
('Languages::surcharge_title', 'Surcharge title'),
('Languages::sweden', 'Sweden'),
('Languages::swedish', 'Swedish'),
('Languages::swing', 'Swing'),
('Languages::switch_layout', 'Switch layout'),
('Languages::layout_page', 'Layout Page'),
('Languages::layout_meta_data', 'Meta data & more'),
('Languages::symbol', 'Symbol'),
('Languages::system', 'System'),
('Languages::tab', 'Tab'),
('Languages::table', 'Table'),
('Languages::tables', 'Tables'),
('Languages::table_conditions', 'Table Conditions'),
('Languages::tabs', 'Tabs'),
('Languages::tax', 'Tax'),
('Languages::taxes', 'Taxes'),
('Languages::tax_exempt', 'Tax exempt'),
('Languages::tax_rates', 'Tax rates'),
('Languages::template', 'Template'),
('Languages::templates_tree', 'Templates tree'),
('Languages::file_editor', 'File editor'),
('Languages::file_editor_archive_contains_incorrect_paths', 'Archive contains files with incorrect paths.'),
('Languages::terminal', 'Terminal'),
('Languages::terminal_id', 'Terminal ID'),
('Languages::test', 'Test'),
('Languages::test_live_mode', 'Test/Live mode'),
('Languages::test_mode', 'Test mode'),
('Languages::text', 'Text'),
('Languages::textarea', 'Text area'),
('Languages::text_2checkout_notice', '<b>Note</b>: In order to track your 2Checkout orders with the shopping cart software you have to take these steps:<br /><br />-&nbsp;Log in to your 2Checkout account<br />-&nbsp;Click on <u>''Site management''</u> in the <u>''Account''</u> section.<br />-&nbsp;Select <b>''Given links back to my website''</b> option in the <u>''Direct Return''</u> subsection <br />-&nbsp;Set <u>''Approved URL''</u> and <u>''Pending URL''</u> to:<br /><b>[return_url]</b><br />-&nbsp;Set <u>''Secret Word''</u>. The Secret Word is known only to the seller and 2CheckOut.<br />'),
('Languages::text_2co_ins', 'Instant Notification Service (INS)'),
('Languages::text_additional_detailed_image', '(displayed in popup window)'),
('Languages::text_additional_thumbnail', '(displayed on product details page in "Additional images")'),
('Languages::addon_files_was_copied', 'The <b>"[addon]"</b> add-on files has been copied successfully'),
('Languages::text_addon_cannot_enable', 'Add-on "[addon_name]" is incompatible with the following add-ons: [addons]. It cannot be enabled'),
('Languages::text_addon_confclicts', 'Add-on "[addon_name]" is incompatible with the following add-ons: [addons]. These add-ons will be automatically disabled.'),
('Languages::text_addon_confclicts_on_install', 'Add-on "[addon_name]" is incompatible with the following add-ons: [addons]. It has not been be enabled. Enable it manually and all the incompatible add-ons will be disabled automatically.'),
('Languages::text_addon_installed', 'The <b>"[addon]"</b> add-on has been installed successfully'),
('Languages::text_addon_install_dependencies', 'The add-on cannot be installed because a dependence on the [addon] add-on is set for it. Please install the [addon] add-on first.'),
('Languages::text_addon_refreshed', 'The settings and language variables of the <b>"[addon]"</b> add-on have been updated successfully'),
('Languages::text_addon_uninstalled', 'The <b>"[addon]"</b> add-on has been uninstalled.'),
('Languages::text_addon_uninstall_dependencies', 'The add-on cannot be uninstalled because the following add-ons depend on it: [addons]'),
('Languages::text_addresses_wildcards', 'You are able to use wildcards in this field:<br /><b>''?''</b> - any single character;<b>''*''</b> - any number of characters.<br /><br /><u>Example:</u><br /><b>* street</b> &nbsp;&nbsp;(corresponds to 1st Street, 102nd Street, etc)'),
('Languages::text_admin_new_orders', 'This section shows the orders you have never viewed.'),
('Languages::text_allowed_to_upload_file_extension', 'The following file extensions are supported: <b>[ext]</b>.'),
('Languages::text_amazon_callback_url', 'Important! You must specify your store''s URL <b>[callback_url]</b> as the Merchant URL on the Amazon''s Seller Central Website (Settings > Checkout Pipeline Settings). Otherwise, you won''t be able to accept payments through Amazon Checkout in your store'),
('Languages::text_amazon_failed_order', 'No response from Amazon Checkout has been received yet, please hold on. Although the order might not be created in the store as long last, it is highly probable that it has been successfully created and processed by Amazon Checkout. Please contact the store staff and tell them the order ID as provided by Amazon'),
('Languages::text_amazon_incorrect_products_count', 'Number of products in your cart differs from the number of products in the Amazon request.'),
('Languages::text_amazon_link_message', 'For testing purposes, the Merchant URL may be the HTTP link to your store, but the live mode requires secure connection and you must use the HTTPS link. Also, remember to enable the production mode on Amazon''s Seller Central website when you are ready to go live.'),
('Languages::text_amazon_surcharge', '<b>Note:</b> According to the Amazon <a href=''https://payments.amazon.com/sdui/sdui/about?nodeId=6019'' target=''_blank''>policy</a> (B4.2), surcharges are not supported. Any surcharges you may have set will be ignored when Amazon Checkout is used.'),
('Languages::text_anonymous_checkout', 'You must be a registered user to proceed to checkout'),
('Languages::recalculate_shipping_cost', 'Recalculate shipping cost'),
('Languages::text_applied_promotions', 'Applied promotions'),
('Languages::text_are_you_sure_to_delete_file', 'Are you sure you want to delete the item?'),
('Languages::text_are_you_sure_to_proceed', 'Are you sure you want to proceed?'),
('Languages::text_atos_notice', '<b>Note:</b><br />1. Copy your certificate that you received on the disk to the [home_path] directory. Rename the certificate to certif.fr.[my_merchant_id], where [my_merchant_id] is your web site number.<br /> 2. Rename the store parameters file (parmcom.014213245611111 file) to parmcom.[my_merchant_id].<br />3. Edit the <b>pathfile</b> file in the  <b>[home_path]</b> directory<br />- Replace string ''<u>D_LOGO![some_dir]!</u>'' with ''<u>D_LOGO![http_path]/logo/!</u>''<br />- Replace string ''<u>F_DEFAULT![/some_dirs/parmcom.sogenactif]!</u>'' with ''<u>F_DEFAULT![home_path]/parmcom.sogenactif!</u>''<br />- Replace string ''<u>F_PARAM![/some_dirs/parmcom]!</u>'' with ''<u>F_PARAM![home_path]/parmcom!</u>''<br />- Replace string ''<u>F_CERTIFICATE![/some_dirs/certif]!</u>'' with ''<u>F_CERTIFICATE![home_path]/certif!</u>''<br />4. Edit the <b>parmcom.[some_number]</b> file in the <b>[home_path]</b> directory<br />- Replace string ''<u>AUTO_RESPONSE_URL![some_url]!</u>'' with ''<u>AUTO_RESPONSE_URL![auto_url]!</u>''<br />- Replace string ''<u>CANCEL_URL![some_url]!</u>'' with ''<u>CANCEL_URL![ok_url]!</u>''<br />- Replace string ''<u>RETURN_URL![some_url]!</u>'' with ''<u>RETURN_URL![ok_url]!</u>''<br />'),
('Languages::text_atos_warning', '<span style="color:#FF2222">Warning!!!</span> The path to atos files should consist of not more than 60 symbols, otherwise please copy the atos_files folder to some parent directory, e.g. to the cart core directory. Also please make sure the atos files directory has full permissions.'),
('Languages::text_authentication_failed_message', 'Your financial institution has indicated that it could not successfully authenticate this transaction. To protect against unauthorized use, this card cannot be used to complete your purchase. You may complete the purchase by selecting another form of payment.'),
('Languages::text_backup_filename_hint', 'To download this backup, click the gear icon and select Download'),
('Languages::text_backup_management_notice', 'This section allows you to manage your backup files.<br />- To restore the database, select the check box near the appropriate file name and click on Restore.<br />- To delete files, select the check boxes near the files that need to be deleted and click on Delete.<br />- To download a file to your local computer, click on the file name.'),
('Languages::text_billing_same_with_shipping', 'Billing and shipping addresses are the same'),
('Languages::text_billing_address_is_different_from_shipping', 'My billing address is different from shipping address'),
('Languages::text_block_trial_notice', 'Your 30-day evaluation period has expired. Please, buy a license ([href]) or remove the software from your server.'),
('Languages::text_cannot_create_directory', 'Cannot create the directory <b>[directory]</b>. Please check the permissions.'),
('Languages::text_cannot_create_file', 'Cannot create the file <b>[file]</b>. Please check the directory permissions.'),
('Languages::text_cannot_delete_directory', 'Cannot delete the directory <b>[directory]</b>. Please check the permissions.'),
('Languages::text_cannot_delete_file', 'Cannot delete the file <b>[file]</b>. Please check the permissions.'),
('Languages::text_cannot_rename_directory', 'Cannot rename the directory <b>[directory]</b>. Please check the permissions.'),
('Languages::text_cannot_rename_file', 'Cannot rename the file <b>[file]</b>. Please check the permissions.'),
('Languages::text_cannot_restore_directory', 'Cannot restore the directory <b>[directory]</b> from the repository. Please check if the repository exists.'),
('Languages::text_cannot_restore_file', 'Cannot restore file <b>[file]</b> from the repository. Please check if the repository exists.'),
('Languages::text_can_be_used_once', 'This coupon can be used only once. You have already applied it.'),
('Languages::text_cart_amount_changed', 'The quantity of the product <b>[product]</b> in your cart  has been changed to allowable.'),
('Languages::text_cart_amount_corrected', 'The number of products in the inventory is not enough for your order. The quantity of the product <b>[product]</b> in your cart has been reduced to <b>[count]</b>.'),
('Languages::text_cart_empty', 'Your cart is empty'),
('Languages::text_cart_max_qty', 'Maximum quantity for "[product]" is <b>[quantity]</b>'),
('Languages::text_cart_min_qty', 'Minimum quantity for "[product]" is <b>[quantity]</b>'),
('Languages::text_cart_not_enough_inventory', 'The number of products in the inventory is not enough for your order'),
('Languages::text_cart_zero_inventory', '<b>[product]</b> has zero inventory and cannot be added to the cart'),
('Languages::text_cart_zero_inventory_and_removed', '<b>[product]</b> has zero inventory and is removed from the cart'),
('Languages::text_categories_have_been_deleted', 'Categories have been deleted successfully.'),
('Languages::text_category_delimiter', 'Category path delimiter for product main category (e.g. "Computers///Desktops")'),
('Languages::text_category_detailed_image', '(optional displayed on category details page only)'),
('Languages::text_category_has_been_deleted', 'Category, subcategories and their products have been deleted successfully.'),
('Languages::text_category_icon', '(displayed on category list and details pages)'),
('Languages::text_cc_processor_connection', 'Connecting to <b>[processor]</b>...'),
('Languages::text_cdn_check', '<strong>Attention!</strong> Please test some static URL, e.g. <a href="[url]">[url]</a>, to ensure it''s working before enabling CDN (you can enable it after storage became active). It usually takes 10-15 minutes to activate storage (the "Status" field should display "Active", refresh page for updates).'),
('Languages::text_cdn_setup', 'CDN was set up successfully.'),
('Languages::text_changes_not_saved', 'Your changes have not been saved.'),
('Languages::text_changes_saved', 'Your changes have been saved.'),
('Languages::text_change_password', 'You are now logged in to your account. Please change the password and click the "Save" button.'),
('Languages::text_checkout_new_profile_notice', 'If you are a new customer, we need to know your personal details.'),
('Languages::text_cities_wildcards', 'You are able to use wildcards in this field:<br /><b>''?''</b> - any single character;<b>''*''</b> - any number of characters.<br /><br /><u>Example:</u><br /><b>New Y*</b> &nbsp;&nbsp;(corresponds to New York, New Yark, etc)<br /><b>L?s*</b>&nbsp;&nbsp; (corresponds to Las Vegas, Los Angeles, etc..)'),
('Languages::tmpl_text_ckeditor', 'CKEditor'),
('Languages::text_click_here', 'Click here for more details'),
('Languages::text_cmcic_notice', 'Please set the following URL as the <b>CGI2</b>: <b>[postback_url]</b>'),
('Languages::text_cmpi_frame_message', 'For your security, please fill out the form below to complete your order. Do not click the Refresh or Back button, or this transaction may be interrupted or canceled.'),
('Languages::text_cmpi_go_back', 'Go back'),
('Languages::text_combination_out_of_stock', 'No products with the selected options in stock'),
('Languages::text_companies_activated', 'Selected companies have been activated'),
('Languages::text_companies_disabled', 'Selected companies have been disabled'),
('Languages::text_company_status_active_subj', 'Your company was activated.'),
('Languages::text_company_status_changed', 'Status of your company [company] was changed to [status].'),
('Languages::text_company_status_disabled_subj', 'Your company was disabled.'),
('Languages::text_conditions_cleared', 'Table conditions were cleared'),
('Languages::text_confirm_passwd_recovery', 'Please follow this link to confirm your password recovery procedure'),
('Languages::password_recovery.text_confirm', 'Somebody — hopefully you — has asked us to reset the password for your account at [site]. If it weren''t you, then feel free to ignore this message.'),
('Languages::password_recovery.link_expire', 'But if you''d like to reset the password, follow the link below. It will expire in 15 minutes'),
('Languages::text_csrf_attack', 'Access denied: Possible CSRF attack'),
('Languages::text_customer_area_logo', 'Logo for the <b>customer</b> area'),
('Languages::text_datatrans_notice', '<b>Note</b>: In order to track your Datatrans orders with the shopping cart software you have to take the following steps:<br /> <br /> -&nbsp;Log in to your Datatrans account<br /> -&nbsp;Click on the <u>''Upp Data''</u> link in the <u>''Upp Administration''</u> section.<br /> -&nbsp;Set <u>''URL Post data format''</u> to <b>''Data in HTML FORM''</b>.<br /> -&nbsp;Set <u>''URL Post''</u> to:<br /> <b>[post_url]</b><br /> -&nbsp;Click on the <u>''Security''</u> link in the <u>''Upp Administration''</u> section.<br /> -&nbsp;Select the <b>''An additional merchant identification will be send with payment messages''</b> option.<br /> -&nbsp;Generate new digital signature using the <u>''Generate new sign''</u> button.<br /> -&nbsp;Set generated value to the <u>''Digital signature''</u> field on the Datatrans payment configuration page in your store<br />'),
('Languages::text_data_changed', 'Your changes have not been saved.Press OK to continue, or Cancel to stay on the current page.'),
('Languages::text_tab_changed', 'Your changes on the current tab have not been saved. Click "OK" to continue or "Cancel" to stay on the current tab.'),
('Languages::text_decrease_points_in_use', 'The points used in the order were subtracted from user account.'),
('Languages::text_deltapay_notice', '<b>Note:</b> Please send the following information to the DeltaPay support:<br />Payment page: ''<u>[payment_url]</u>''<br />Success page: ''<u>[result_url]</u>''<br />Failure page: ''<u>[result_url]</u>''<br />Cancel page: ''<u>[result_url]</u>''<br />'),
('Languages::text_directebanking_notice', 'Set ''Success link'' to: <b>[success_url]</b><br /> Set ''Abort link'' to: <b>[abort_url]</b><br /> Add new HTTP notifications and set ''Notification URL'' to: <b>[notification_url]</b><br /> Activate input check and set ''Hash Algoritm'' to the ''SHA1''<br />'),
('Languages::text_directory_created', 'The directory <b>[directory]</b> has been successfully created.'),
('Languages::text_directory_deleted', 'The directory <b>[directory]</b> has been successfully deleted'),
('Languages::text_directory_renamed', 'The directory <b>[directory]</b> has been successfully renamed to <b>[to_directory]</b>'),
('Languages::text_directory_restored', 'The directory <b>[directory]</b> has been restored from the repository'),
('Languages::text_downloads_empty', 'Your downloads list is empty'),
('Languages::text_editing', 'Text editing'),
('Languages::text_edp_product', 'This product is electronically distributed'),
('Languages::text_ekey_not_valid', 'The confirmation link is invalid or has expired.'),
('Languages::text_email_sent', 'E-mail has been sent successfully.'),
('Languages::text_emerchantpay_notice', 'Please add these URL fields in your eMerchantPay eCommerce Payment Form configuration:<br/><br/><b>BackReturn URL:</b><br/>[backreturn_url]<br/><br/><b>Custom Approval URL:</b><br/>[notify_url]<br/><br/><b>Custom Decline URL:</b><br/>[decline_url]<br/><br/><b>Activate Notification URL:</b><br/>[process_url]'),
('Languages::text_enets_notice', 'Please send the following URL to the eNPS manager as a response URL for all the three cases (success, failure, cancel): [r_url]'),
('Languages::text_enter_filename', 'Please enter a new file name'),
('Languages::text_exim_data_exported', 'Data is exported successfully'),
('Languages::text_exim_data_imported', 'Data is imported successfully.<br />New objects - <b>[new]</b>;<br />Updated objects - <b>[exist]</b>;<br />Skipped objects - <b>[skipped]</b>;<br />Total - <b>[total]</b>.'),
('Languages::text_exim_data_imported_clear', 'Data is imported successfully.'),
('Languages::text_exim_export_notice', 'Below is a list of the fields that can be exported. The <b>highlighted</b> fields are mandatory.'),
('Languages::text_exim_import_features_note', '<h4>Product features import format</h4><code>(%Group name%) %Feature name%: %Feature type%[%Feature value%]</code>where,<dl class="dl-horizontal"><dt>%Group name%</dt><dd>the name of feature group</dd><dt>%Feature name%</dt><dd>the name of feature</dd><dt>%Feature type%</dt><dd>the feature type (C - checkbox, M - multiple checkboxes, S - text select box, N - number select box, E - extended selectbox, T - simple text, O - number, D - date)</dd><dt>%Feature value%</dt><dd>the feature value (several values can be delimited by comma)</dd></dl><p>Several features must be delimited by semicolon.</p><h5>Example:</h5><code>ISBN: T[1233423423]; Release date: D[05/05/07]; Color: S[Red]</code>'),
('Languages::text_exim_import_files_note', '<h4>File import format</h4><code>%File location%</code> where, <dl class="dl-horizontal"> <dt>%File location%</dt> <dd>can be an absolute or relative path in a server file system or a URL</dd> </dl> <p>Several files must be delimited by comma.</p> <h5>Example 1:</h5><code>file1.jpg</code><h5>Example 2:</h5><code>backup/file1.zip, images/file2.jpg</code>'),
('Languages::text_exim_import_images_note', '<h4>Image import format</h4><code>%Image location%#%Alternative text%</code> where,<br><dl class="dl-horizontal"><dt>%Image location%</dt><dd>can be an absolute or relative path in a server file system or a URL,</dd><dt>%Alternative text%<dt><dd>image alternative text</dd></dl><h5>Example 1:</h5><code>images/product_images/apples.jpg#Apples</code><h5>Example 2:</h5><code>http://www.site.com/apples.jpg#Apples</code>'),
('Languages::text_exim_import_notice', 'Below is a list of the fields that your data file can contain. The fields highlighted in bold are mandatory. If you are importing data with special symbols (commas, semicolons, etc.), please make sure you have these fields quoted.'),
('Languages::text_exim_import_options_note', '<h4>Product options import format</h4><code>%Option name%: %Option type%[{$ldelim}%Variant 1 ID%{$rdelim}%Variant 1%,{$ldelim}%Variant 2 ID%{$rdelim}%Variant 2%,{$ldelim}%Variant N ID%{$rdelim}%Variant N%]</code> where,<dl class="dl-horizontal"><dt>%Option name%</dt><dd>the name of the option,</dd><dt>%Variant N ID%</dt><dd>the id of the variant,</dd><dt>%Variant N%</dt><dd>the name of the variant. Variants must be specified if the option type is a selectbox or radiogroup only.</dd><dt>%Option type%</dt><dd>the option type, can be the following:<br><ul><li><b>S</b> - selectbox,</li><li><b>R</b> - radiogroup,</li><li><b>C</b> - checkbox,</li><li><b>I</b> - simple input,</li><li><b>T</b> - textarea.</li></ul></dd></dl><p>Several options must be delimited by semicolon.</p><h5>Examples:</h5>Simple text options:<code>Your age: I; Date of birth: I; Notes: T</code><br>Options with variants:<code>Color: S[Red, Green, Blue]; Size: R[X, XL, XXL]</code>'),
('Languages::text_exim_utf8_file_format', 'Please make sure that the file you are importing has UTF-8 charset for correct import'),
('Languages::text_expired_license', 'Unfortunately, your subscription for [product] software is over. Please renew it as soon as possible to avoid the program suspending.'),
('Languages::text_features_delimiter', 'Delimiter between variant values of a product feature.'),
('Languages::text_feedback_notice', 'The parameters that will be sent to our server to analyze the functionality and the current configuration are listed below.<br />Please note that no personal or financial information will be sent. After you get acquainted with the list of the parameters, click on "Send".<br />'),
('Languages::text_files_directory', 'Directory where product files are located. This will be used if the "File" field data is specified without a path.'),
('Languages::text_file_created', 'The file <b>[file]</b> has been successfully created'),
('Languages::text_file_deleted', 'The file <b>[file]</b> has been successfully deleted'),
('Languages::text_file_renamed', 'The file <b>[file]</b> has been successfully renamed to <b>[to_file]</b>'),
('Languages::text_file_restored', 'The file <b>[file]</b> has been restored from the repository'),
('Languages::text_file_saved', 'The file <b>[file]</b> is successfully saved'),
('Languages::text_fill_the_mandatory_fields', 'You need to complete all the mandatory fields'),
('Languages::text_forbidden_file_extension', 'It is not allowed to create/upload/rename files with the <b>.[ext]</b> extension.'),
('Languages::text_forbidden_file_mime', 'It is not allowed to create/upload/rename files of the <b>[mime]</b> MIME type.'),
('Languages::text_forbidden_functionality', '<p>To use this feature, you need a [product] license.</p>'),
('Languages::upgrade_license', 'Upgrade my license'),
('Languages::need_upgrade', 'Need upgrade'),
('Languages::text_forbidden_uploaded_file_extension', 'It is not allowed to upload files with the <b>.[ext]</b> extension. Allowed extensions are: <b>[exts]</b>'),
('Languages::text_forbidden_uploaded_file_size', 'It is not allowed to upload files with size more than <b>[size]</b>'),
('Languages::text_license_required_full', 'Your current CS-Cart edition is Professional. We also offer another one, a more advanced edition—<b>Ultimate</b>. With CS-Cart Ultimate, you''ll be able to use unlimited number of storefronts and the mobile commerce app as well as the eBay Synchronization add-on and the Facebook app without additional fees. To unlock unlimited storefronts and mobile commerce, get the Ultimate license.'),
('Languages::text_license_required_storefronts', 'Add as many storefronts as you want and manage them via a single admin panel.'),
('Languages::text_license_required_facebook', 'Build your store into your Facebook page to get closer to your audience and draw more new customers.'),
('Languages::text_license_required_ebay', 'Boost your sales by selling products presented in your CS-Cart store on the world''s biggest marketplace—eBay.'),
('Languages::text_form_cresecure_notice', 'Please complete your payment below.<br />This is a secure payment page, served from a secure location.'),
('Languages::text_license_required_storefronts-title', 'Unlimited Storefronts'),
('Languages::text_license_required_facebook-title', 'Facebook App'),
('Languages::text_license_required_ebay-title', 'eBay Synchronization'),
('Languages::text_full_mode_required', '<strong>Full mode</strong> required.'),
('Languages::license_required', '[product] license required'),
('Languages::text_gate2shop_notice', '<p>Please set the following values in the Gate2Shop merchant settings:</p><p>Success, failed and canceled URL: <b>[result_url]</b></p><p>Back URL: <b>[back_url]</b></p>'),
('Languages::text_gd_not_avail', 'GD library is <b>not</b> installed on your server. Please contact your hosting provider. <br />Charts can be represented only as tables (chart type "Table").'),
('Languages::text_hsbc_notice', '<b>Client ID  -</b> Your Client ID - a decimal value between 0 and 999999999, or a valid Client alias of the form UK12345678CUR. <br /> Note, the alias is case sensitive. <br /> <b>Important note for UNIX users:</b><br /> Please make sure you have appropriate permissions for the following directory: [cart_dir] (shell command "chmod -R 755").'),
('Languages::text_ideal_basic_notice', '-&nbsp;Log in to your iDEAL account<br />-&nbsp;Click on <u>''Security''</u> in the <u>''Profile''</u> section.<br />-&nbsp;Set the option <u>''Notification''</u> to <b>''XML''</b><br />-&nbsp;Set <u>''Notification URL''</u> to:<br /><b>[return_url]</b><br />-&nbsp;Set <u>''Secret key''</u>. The Secret key is known only to the seller and iDEAL.'),
('Languages::text_images_directory', 'Directory where images are located. This will be used if an image file is specified without a path.'),
('Languages::text_invalid_url', 'You have entered an invalid URL'),
('Languages::text_items_added', 'The items were added successfully'),
('Languages::text_items_updated', 'The items were updated successfully'),
('Languages::text_payment_first_data_notice', 'Please log in to FirstData Connect 2.0 Admin, open the "Administration" tab, click on the "Connect 2.0 Setup" link.<br /> Set the following URL in the "Order Submission Form", "Confirmation Page", "Failure Page" sections: [return_url]<br />'),
('Languages::text_links', 'Text links'),
('Languages::text_login_form', '<h4>Not a registered member?</h4><p>Creating a new account is easy and takes less than a minute.</p>'),
('Languages::text_login_to_add_to_cart', 'This product cannot be added to the<br>cart because you are not logged in.'),
('Languages::text_mail_area_logo', 'Logo for <b>invoices</b>'),
('Languages::text_mandatory_fields', '<p class="mandatory-fields">The fields marked with <span class="required">*</span> are mandatory</p>'),
('Languages::text_max_limit_of_parameters', 'Maximum value of the "limit" field cannot exceed 25 unless the chart type is "Table". Limit of this chart has been corrected.'),
('Languages::text_mb_failed_order', 'No response from Skrill has been received yet, please hold on. Although the order might not be created in the store as long last, it is highly probable that it has been successfully created and processed by Skrill. Please contact the store staff and tell them the order ID as provided by Skrill'),
('Languages::text_min_order_amount_required', 'To continue checkout process your order total must exceed'),
('Languages::text_min_products_amount_required', 'To continue checkout process your order subtotal must exceed'),
('Languages::text_multiprofile_notice', 'One user can have multiple profiles. For example, one for personal orders and another for office needs.'),
('Languages::text_new_user_activation', 'The profile owned by "[user_login]" has been newly created, you should check the details of this user (if required) and activate it by using the following link:<br /><a href="[url]">[url_text]</a>'),
('Languages::text_nothing_found', 'Nothing found'),
('Languages::text_not_allowed_to_upload_file_extension', 'It is not allowed to upload files with the <b>.[ext]</b> extension here.'),
('Languages::text_not_allowed_to_upload_file_size', 'It is not allowed to upload files that exceed the maximum allowed size of [file_size] MB.'),
('Languages::text_not_valid_email', '<b>[email]</b> is not a valid e-mail address.'),
('Languages::text_no_active_promotions', 'No promotions available.'),
('Languages::text_no_conflicts', 'No conflicts found'),
('Languages::text_no_items_defined', 'No [items] defined'),
('Languages::text_no_matching_products_found', 'No products found matching the search criteria'),
('Languages::text_no_matching_results_found', 'No results match the search query'),
('Languages::text_no_orders', 'No orders found'),
('Languages::text_no_payments_needed', 'No payment information required'),
('Languages::text_no_payments_required', 'No payment required'),
('Languages::text_no_products', 'There are no products in this section'),
('Languages::text_no_products_defined', 'No products defined'),
('Languages::text_no_products_found', 'No products found'),
('Languages::selected_filters', 'Selected filters'),
('Languages::text_no_shipments_found', 'No shipments found'),
('Languages::text_no_shipping_methods', 'Sorry, it seems that we have no shipping options available for your location.<br/>Please check your shipping address and contact us if everything is okay. We''ll see what we can do about it.'),
('Languages::text_no_upgrades_available', 'No upgrades currently available'),
('Languages::text_objects_for_export', '<b>[total]</b> [name] will be exported.'),
('Languages::text_ogonedirect_notice', 'Enter SHA-1 Signature both: here and on the Ogone Configuration.<br /><br />For new Ogone accounts created since May 11th, 2010, the new SHA policy is automatically active. <br/>Please do not forget to select the "Use new SHA signature policy" checkbox.'),
('Languages::text_ogoneweb_notice', 'Please set the following URL in the Technical Information section on the Ogone Configuration as a <b>Response Url</b> for all cases ("accepted", "on hold", "uncertain", "canceled by the client", "too many rejections by the acquirer"): <b>[r_url]</b><br /> Also enter SHA-1 Signature both: here and on the Ogone Configuration. Then select Request Type: "Make this request in background and deferred".'),
('Languages::text_options_no_inventory', 'In order to create option combinations, you must have the "Inventory" check box selected for at least one product option.'),
('Languages::text_order_backordered', 'Your order has been backordered. We will contact you at the first opportunity.'),
('Languages::text_order_placed_error', 'Your order has been declined by the payment processor. Please review your information and contact store administration.'),
('Languages::text_order_placed_successfully', 'Congratulations! Your order has been successfully placed.'),
('Languages::text_order_repayed_successfully', 'Order has been repaid successfully.'),
('Languages::text_order_saved_successfully', 'Order has been saved successfully.'),
('Languages::text_order_status_notification', 'Please note that the notification of changing the status  will be sent depending on the settings of this status'),
('Languages::text_out_of_stock', 'Out of stock'),
('Languages::text_pages_cloned', 'The pages have been cloned successfully. Below the list of new pages.'),
('Languages::text_pages_have_been_deleted', 'Pages have been deleted successfully.'),
('Languages::text_page_changed', 'Are you sure you want to leave this page? Your changes have not been saved. Click on OK to continue, or on Cancel to stay on the current page.'),
('Languages::text_page_has_been_deleted', 'Page has been deleted successfully.'),
('Languages::text_page_loading', 'Loading... Your request is being processed, please wait.'),
('Languages::text_password_recovery_instructions_sent', 'Password recovery instructions have been sent to [email] address.'),
('Languages::text_pay4later_notice', '<b>Note</b>: In order to track your Deko orders with the shopping cart software, you have to take these steps:<br /><br />-&nbsp;Log in to Deko BackOffice<br />-&nbsp;Click on the <u>''Settings/Installations''</u> link in the <u>''Quick Links''</u> section.<br />-&nbsp;Set <u>''Return URL (Verified)''</u> setting to:<br /><b>[verified_url]</b><br />-&nbsp;Set <u>''Return URL (Decline)''</u> setting to:<br /><b>[decline_url]</b><br />-&nbsp;Set <u>''Return URL (Refer)''</u> setting to:<br /><b>[refer_url]</b><br />-&nbsp;Set <u>''Return URL (Cancel)''</u> setting to:<br /><b>[cancel_url]</b><br />-&nbsp;Set <u>''CSN URL''</u> setting to:<br /><b>[process_url]</b><br />-&nbsp;Click on the <u>''Save Changes''</u> button<br />'),
('Languages::text_paybox_notice', '<b>Note:</b> Please download the file modulev2.cgi from the PayBox server, copy it to the <b>[paybox_dir]</b> directory <u>in binary mode</u> and make it executable. <br />Run the following command:<br /><b><i>chmod 755 modulev2.cgi</b></i><br /><br />Also ask &#8220;Paybox&#8221; service to add the following URL to the database as &#8220;Callback URL&#8221;:<br /><b>[callback_url]</b>'),
('Languages::text_payment_have_been_deleted', 'Payment have been deleted successfully.'),
('Languages::text_payment_have_not_been_deleted', 'Payment cannot be deleted.'),
('Languages::text_paypal_processing_payment', 'Please wait while processing the payment details...'),
('Languages::text_paysitecash_debug', 'Debug Information'),
('Languages::text_paysitecash_mode', 'Mode'),
('Languages::text_paysitecash_mode_debug_off', 'OFF'),
('Languages::text_paysitecash_mode_debug_on', 'ON'),
('Languages::text_paysitecash_mode_live', 'Live'),
('Languages::text_paysitecash_mode_test', 'Test'),
('Languages::text_paysitecash_nocurrencies', 'Currency mode'),
('Languages::text_paysitecash_nocurrencies_no', 'Allow customer select any of supported currency'),
('Languages::text_paysitecash_nocurrencies_yes', 'Do not show currency selection at all'),
('Languages::text_paysitecash_notice', 'Please add these URL fields in your Paysite-cash configuration:<br/><br/><b>URL:</b><br/>[url]<br/><br/><b>Referer url:</b><br/>[ref_url]<br/><br/><b>after payment return url:</b><br/>[sucess_url]<br/><br/><b>canceled payment url:</b><br/>[cancel_url]<br/><br/><b>Backoffice confirmation url:</b><br/>[confirm_url]'),
('Languages::text_paysitecash_processor', 'Processor'),
('Languages::text_paysitecash_site_id', 'Site ID'),
('Languages::text_payway_notice', 'Please set up the following parameters in PayWay back end: <p> Browser Return URL Pre Payment: <b>[prepayment]</b><br /> Browser Return URL: <b>[return]</b><br /> Notification URL: <b>[notify]</b><br /> Notification Post Type: leave empty </p>'),
('Languages::text_permissions_changed', 'Permissions changed'),
('Languages::text_piraeus_notice', '<b>Note:</b> Please send the following information to the payment support:<br /> Website URL: ''<u>[website_url]</u>''<br /> Referrer URL: ''<u>[referrer_url]</u>''<br /> Success URL: ''<u>[success_url]</u>''<br /> Failure URL: ''<u>[failure_url]</u>''<br /> Backlink URL: ''<u>[backlink_url]</u>''<br /> IP Address: ''<u>[ip_address]</u>''<br /><br /> Response Method: ''<u>[response_method]</u>''<br /><br />'),
('Languages::text_position_updating', 'Loading... Positions are being updated, please wait.'),
('Languages::text_price_dec_sign_delimiter', 'Decimal separator for product prices.'),
('Languages::text_products_added', 'The products have been added successfully. See the list of the new products below.'),
('Languages::text_products_cloned', 'The products have been cloned successfully. Below the list of new products'),
('Languages::text_products_have_been_deleted', 'Products have been deleted successfully.'),
('Languages::text_products_updated', 'The following products have been updated:'),
('Languages::text_products_updated_successfully', 'The product(s) have been updated successfully'),
('Languages::text_product_cloned', 'The product has been cloned'),
('Languages::text_product_detailed_image', '(optional displayed in popup window)'),
('Languages::text_product_file_has_been_deleted', 'Product file has been deleted'),
('Languages::text_product_filters_were_disabled', 'The following <a href="[url]" target="_blank">product filters</a> were disabled: [filters_list].'),
('Languages::text_product_has_been_deleted', 'Product has been deleted successfully.'),
('Languages::text_product_thumbnail', '(displayed on products list and product details pages)'),
('Languages::text_profile_activated', 'Your account is now active. You may log in to your account using your credentials.'),
('Languages::text_profile_benefits', '<h4>Benefits of becoming a registered member</h4><ul><li>Log in at any time to check order statuses</li><li>Personalize your shopping</li><li>Speed up future purchases</li></ul>'),
('Languages::text_profile_details', '<h4>Profile details</h4><p>On this page you can modify your login credentials and personal data to be used during future purchases.</p><p>To keep your account secure we recommend to avoid creating passwords that use:</p><ul><li>Dictionary words in any language.</li><li>Words spelled backwards, common misspellings, and abbreviations.</li><li>Sequences or repeated characters. Examples: 12345678, 222222, abcdefg, or adjacent letters on your keyboard (qwerty).</li><li>Personal information. Your name, birthday, driver''s license, passport number, or similar information.</li></ul>'),
('Languages::text_profile_is_created', 'The account has been created successfully.'),
('Languages::text_profile_is_updated', 'The profile data has been updated successfully.'),
('Languages::text_profile_should_be_approved', 'Your account has been created successfully, but it must be activated by the store administrator before you are able to sign in.'),
('Languages::text_promotions_group_condition', 'if [set] of these conditions are [set_value]'),
('Languages::our_brands', 'Our Brands'),
('Languages::text_qty_discounts', 'Our quantity discounts'),
('Languages::text_recover_password', '<p>If you have forgotten your password, enter your email address in the field and click <i>Reset password</i>.</p><p>You will receive a new password and a link to sign in. You will be able to change the password later.</p>'),
('Languages::text_recover_password_notice', 'Enter your email address to receive a new login key and a link to sign in and change your password.'),
('Languages::text_recover_password_title', 'Reset password'),
('Languages::text_remove_additional_images', 'When importing additional images of an updated product, existing images of this product will be deleted before import'),
('Languages::text_remove_backup_files', 'Warning! If you remove the backup files, you will not be able to restore your previous installation. Ensure that the new version is working properly, and the backup database files are in a safe place.'),
('Languages::text_required_group_product', 'Please select a product for the required group [group_name]'),
('Languages::text_reset_inventory_description', 'Quantity of all products in the store will be reset.'),
('Languages::text_restore_question', 'Are you sure that you want to restore the template?'),
('Languages::text_sagepay_dir_notice', '<b>Note:</b> In order to track your Opayo orders by the shopping cart software, please enable the 3D Secure Fraud Checking Option for your Opayo VSP Direct account.'),
('Languages::text_sagepay_notice', 'Use <b>testvendor</b> as <b>Vendor Name</b> for the testing purposes<br /><p><b>PAYMENT</b> - transaction type is used to gain an authorisation from the bank, then settle that transaction early the following morning, committing the funds to be taken from your customer''s card.<br /></p><p><b>DEFERRED</b> - transactions are NOT sent to the bank for completion until you RELEASE them by logging into the Opayo VSP Admin interface, finding the transaction and clicking the Release button.</p>'),
('Languages::text_secret_key_notice', 'Please complete this field with any non-empty value. It will increase the security of transactions.'),
('Languages::text_select_fields2edit_note', 'You are able to modify several items at once. Select the check boxes corresponding to the fields you wish to edit, and click on Modify Selected.'),
('Languages::text_select_file', 'Select a file or enter a URL'),
('Languages::text_select_range', 'You can select a range to export (otherwise all [name] will be exported)'),
('Languages::text_share_product_features_tooltip', 'Attention! Some data will not be copied during this operation: the categories set in filters will be lost even if you copy all categories. Please, fix categories manually.'),
('Languages::text_share_product_filters_tooltip', 'Attention! Some data will not be copied during this operation: the categories set in features will be lost even if you copy all categories. Please, fix categories manually.'),
('Languages::text_share_promotions_tooltip', 'In order to share promotions make sure the respective products are also shared (check Share products below)'),
('Languages::text_shipping_packages_info', 'To ensure a more precise shipping rate estimation, the products have been separated into packages as defined by the product settings and the shipping method configuration. The following info is for referential use only'),
('Languages::text_shipping_rates_changed', 'Shipping rates were changed'),
('Languages::text_ship_to_billing', 'Order will be delivered to the billing address'),
('Languages::text_skrill_activate_quick_checkout_short_explanation', 'Skrill Merchant Tools enables you to take payments from credit cards, debit cards and over 60 other local payment options in over 200 countries. The highly competitive rates for this service are published on the Skrill website at www.skrill.com.'),
('Languages::text_skrill_activate_quick_checkout_short_explanation_1', 'You have sent a request for activation on the [date]. Please be aware that the verification process to use Skrill Merchant Tools could take up to 72 hours. You will be contacted by Skrill when the verification process has been completed.'),
('Languages::text_skrill_activate_quick_checkout_short_explanation_2', 'After activation Skrill will grant you access to a new section in your Skrill Account called Merchant Tools. There please choose a secret word (NOT the same as your password) and enter it in the section below to connect to Skrill. The secret word is the last step of your activation process and encrypts your payments securely. After successful submission you will be ready to use all the direct payment options of Skrill.'),
('Languages::text_skrill_currs_notice', 'If you selected a currency that is not the base one in your store, please make sure that it has the correct <a href="http://en.wikipedia.org/wiki/ISO_4217">ISO 4217 code</a> on the <a href="[link]">currencies</a> page.'),
('Languages::text_skrill_email_is_not_registered', 'Specified email address is not registered in Skrill.'),
('Languages::text_skrill_email_is_registered', 'Specified email address is registered in Skrill.'),
('Languages::text_skrill_empty_input_data', 'Some of the fields required for Quick Checkout activation are missing. Please check.'),
('Languages::text_skrill_logo_notice', 'If your HTTPS server is not set up, the logo will be passed by the HTTP protocol and users will see the "Connection Partially Encrypted" warning on the Skrill page.'),
('Languages::text_skrill_notice', 'To gain access to the international payment network of Skrill, please register <a href="[register_url]" target="_blank">here</a> for a free account if you do not have one yet.<p><strong>Attention</strong>: please save settings before validating email, secret word or activating merchant tools.</p>'),
('Languages::text_skrill_notice_register', 'To gain access to the international payment network of Skrill, please register <a href="[register_url]" target="_blank">here</a> for a free account if you do not have one yet.<p><strong>Attention</strong>: please save settings before activating merchant tools.</p>'),
('Languages::text_skrill_payment_is_not_saved', 'In order to use this feature, please save the payment method first.'),
('Languages::text_skrill_secred_word_notice', 'The secret word must be in lower case without special characters and at least 10 digits long.'),
('Languages::text_skrill_secret_word_is_correct', 'Specified secret word is correct.'),
('Languages::text_skrill_secret_word_is_incorrect', 'Your secret word is incorrect. Please choose your secret word in the Merchant Tools section of your Skrill Account and then enter it here.'),
('Languages::text_skrill_support', '<b>Support:</b> <br /><br /> Do you have questions?<br /> Contact Skrill on <a href="mailto:">ecommerce@skrill.com</a> or by phone +4408703830762.<br />'),
('Languages::text_status_is_float', 'You cannot use time interval for the "Status" parameter because this parameter is time dependent.'),
('Languages::text_storage_changed', 'Storage changed successfully'),
('Languages::text_store_mode_changed_to_full', '<strong>Full mode</strong> has been activated. In this mode, all the advanced eCommerce features are available.'),
('Languages::text_store_mode_closed', 'The store was <b>closed</b>'),
('Languages::text_store_mode_full', '<p>Full unrestricted access to all features. Enter a valid license number to activate.</p><p>This mode can be activated at any time.</p><br />'),
('Languages::text_store_mode_opened', 'The store was <b>opened</b>'),
('Languages::text_store_mode_open', 'The store was <b>opened</b>'),
('Languages::text_store_mode_trial', '<p>Full access to all features during the 30-day trial period, starting from the time of activation.</p><p>Once the 30-day trial period expires, you''ll have to <a href="[product_buy_url]" target="_blank">purchase a license</a> or enter a valid license number to be able to manage your store.</p>'),
('Languages::text_store_mode_trial_rb', 'All features are available during 30 days after download of the installation package. You don''t need to enter the license key.<br /><br />After the 30-day trial period is over, you need to buy the license or enter the license key if you already have one.<br /><br />');
INSERT INTO `[[dbprefix]]original_values` VALUES
('Languages::text_tax_applied', 'The tax <b>[tax]</b> has been applied to all products'),
('Languages::text_tax_unset', 'The tax <b>[tax]</b> has been removed from all products'),
('Languages::text_template_changed', 'Your changes have not been saved.Press OK to save changes or Cancel to discard them.'),
('Languages::text_thaiepay_notice', '<p>Please set the following values in the ThaiePay merchant settings:</p><p>Return Url: <b>[return_url]</b></p><p>Status: <b>Yes (it is important!)</b></p><p>Post Back Url: <b>[postback_url]</b></p><p>Main Parameter: <b>"total" must be checked</b> - it will increase the security of transactions</p><p>Additional Parameter: it is obligatory for successful processing of transactions. For example, you can set <b>name=completed</b> and <b>value=some_secret_word</b>. Copy these values to these form fields: "Additional parameter Name" and "Additional parameter Value".</p>'),
('Languages::text_thumbnail_manual_loading', 'Thumbnails will be generated from detailed images automatically, but you can also <a id="[id]" class="[class]">upload them manually.</a>'),
('Languages::text_tinymce', 'TinyMCE'),
('Languages::text_topmenu_more', 'More [item] <i class="text-arrow">&rarr;</i>'),
('Languages::text_topmenu_view_more', 'View more <i class="text-arrow">&rarr;</i>'),
('Languages::text_track_instructions_sent', 'Access instructions were sent to your e-mail address.'),
('Languages::text_track_request', 'You requested information on the orders you placed in our store.'),
('Languages::text_track_view_all_orders', 'To view all your orders, please follow this link:'),
('Languages::text_track_view_order', 'To view order #[order] please open this link:'),
('Languages::text_transaction_cancelled', 'Transaction was canceled by the customer'),
('Languages::text_transaction_declined', 'Transaction was declined by the payment processor or was canceled by the customer'),
('Languages::text_uc_another_update_process_running', 'Possibly another upgrade process is running.<br />Please wait until it is finished.<br />If the process has finished with an error, you can remove the file [filename] and try to restart the upgrade.<br /><a href="[url]">Remove the lock file and restart the upgrade</a>'),
('Languages::text_uc_backup_database', 'The following database tables have been backed up'),
('Languages::text_uc_backup_files', 'The following files have been backed up'),
('Languages::text_uc_broken_package', 'The upgrade package seems to be broken. Please refresh packages list and try to download it again'),
('Languages::text_uc_cannot_lock_upgrade_process', 'Failed to disable upgrade process launching'),
('Languages::text_uc_cant_download_package', 'Cannot download the upgrade package'),
('Languages::text_uc_changed_files_message', 'These files have local modifications and will be backed up. Once the upgrade is complete, compare the backup files with the new files and reapply the modifications to the new files, if necessary.'),
('Languages::text_uc_check_ok', 'Your [product] version has been checked successfully. It is ready for upgrade.'),
('Languages::text_uc_conflicts', 'The following files had local modifications'),
('Languages::text_uc_db_right_needed', 'Not enough permissions to update database. Please assign the following privileges to your database user [db_user]: [priviliges].'),
('Languages::text_uc_emergency_restore', 'Attention! Please copy and save the URL below - you can use it to restore your store if upgrade fails.<br /><b>[href]</b>'),
('Languages::text_uc_failed_to_backup_tables', 'The database tables have not been backed up'),
('Languages::text_uc_failed_to_create_directory', 'Failed to create a new directory'),
('Languages::text_uc_failed_to_ftp_copy', 'FTP transfer failed'),
('Languages::text_uc_ftp_cart_directory_not_found', 'We were unable to find CS-Cart installation in the specified directory. Please make sure that you have entered the correct FTP directory.'),
('Languages::text_uc_ftp_connection_failed', 'FTP connection failed'),
('Languages::text_uc_ftp_connect_failed', 'Cannot connect to FTP server. Please check if the host name is correct'),
('Languages::text_uc_ftp_login_failed', 'Cannot log in to FTP server. Please check if username and password are correct'),
('Languages::text_uc_ftp_needed', 'FTP credentials to access the files and set proper permissions automatically'),
('Languages::text_uc_has_conflicts', 'Some of your files had local modifications. You can check them by clicking the following link'),
('Languages::text_uc_incorrect_upgrade_path', 'Wrong path to upgrade files'),
('Languages::text_uc_license_number_required', 'Please enter your [product] license number'),
('Languages::text_uc_list_of_updates_missing', 'List of upgrades is missing'),
('Languages::text_uc_non_writable_files', 'These files require write permissions set (manually or automatically via FTP)'),
('Languages::text_uc_no_enough_space_to_backup_database', 'Insufficient disk space to back up the database'),
('Languages::text_uc_no_ftp_module', 'It seems that no FTP module is installed on your server. You cannot use FTP until this module is installed'),
('Languages::text_uc_unable_to_create_upgrade_folder', 'Failed to create an upgrade folder'),
('Languages::text_uc_unable_to_parse_uc_xml', 'Failed to parse the upgrade process descriptor uc.xml'),
('Languages::text_uc_unable_to_remove_file', 'Failed to remove the file'),
('Languages::text_uc_unable_to_remove_packages_xml', 'Failed to remove the upgrade descriptor packages.xml'),
('Languages::text_uc_unable_to_remove_upgrade_lock', 'Failed to remove the upgrade lock file. Please remove the [file] file.'),
('Languages::text_uc_unable_to_update_list_of_installed_upgrades', 'Failed to update the list of installed upgrades'),
('Languages::text_uc_upgrade_completed', 'Your store has been upgraded successfully'),
('Languages::text_uc_upgrade_completed_check_and_open', '<p>Your store was closed during the upgrading procedure. We recommend you to check the work of the store after the upgrade and only then open it.</p><p>You can open the store by unchecking the Close storefront setting under Settings → General.</p>'),
('Languages::text_uc_upgrade_log_file_not_writable', 'Upgrade log file is not writable'),
('Languages::text_uc_upgrade_needed', 'You need to upgrade to version <b>[to_version]</b> before applying this upgrade package (your version is <b>[your_version]</b>).'),
('Languages::text_uc_upgrade_not_selected', 'No upgrade package is selected'),
('Languages::text_uc_upgrade_reverted', 'The upgrade has been reverted successfully'),
('Languages::text_ult_product_store_field_tooltip', 'Product owner. Only product owner can edit all fields in shared products.'),
('Languages::text_unable_to_parse_xml', 'Failed to parse XML structure'),
('Languages::text_unsupported_currency', 'The currency which is not supported by the payment system is used on the website. Please contact the store administrator regarding this issue.'),
('Languages::text_upgrade_available', 'A new version of [product] is available. If you want to upgrade to the latest version now, click <a href="[link]">here</a>.'),
('Languages::text_usergroup_activated', 'The following user groups have been activated for your account: [usergroups].'),
('Languages::text_usergroup_disactivated', 'The following user groups have been removed from your account: [usergroups].'),
('Languages::text_usergroup_request', 'Customer requested user group.'),
('Languages::text_usergroup_requested_by', 'The <b>[usergroup]</b> group was requested by [name] ([email]).'),
('Languages::text_worldpay_notice', 'Configure your Worldpay account before using the payment.<br /><br />Go to the Worldpay administration page and switch to the Installation section.<br /><br />Fill the fields as follows:<br /><br />Payment Response URL: <b>[return_url]</b><br />Payment Response Password: <b>Make up a secret word.</b> The same word must be entered in the respective field below<br />MD5 secret for transactions: <b>Make up a secret word.</b> The same word must be entered in the respective field below<br />SignatureFields: <b>instId:amount:currency:cartId</b>'),
('Languages::text_zipcodes_wildcards', 'You are able to use wildcards in this field:<br /><b>''?''</b> - any single character;<b>''*''</b> - any number of characters.<br /><br /><u>Example:</u><br /><b>98?78</b> &nbsp;&nbsp;(corresponds to 98878, 98378, 98978, etc)<br /><b>12*</b>&nbsp;&nbsp; (corresponds to 12345, 12876, 12098, etc..)'),
('Languages::theme', 'Theme'),
('Languages::themes', 'Themes'),
('Languages::theme_directory', 'Theme directory'),
('Languages::theme_editor', 'Theme editor'),
('Languages::theme_editor.background', 'Background'),
('Languages::theme_editor.backgrounds', 'Backgrounds'),
('Languages::theme_editor.background_color', 'Background color'),
('Languages::theme_editor.base_color', 'Base'),
('Languages::theme_editor.body_font', 'Body'),
('Languages::theme_editor.browse', 'Browse'),
('Languages::theme_editor.buttons_font', 'Buttons'),
('Languages::theme_editor.close', 'Close theme editor'),
('Languages::theme_editor.color', 'Color'),
('Languages::theme_editor.colors', 'Colors'),
('Languages::theme_editor.background_image', 'Background image'),
('Languages::theme_editor.color_gen_algorithm', 'Colors combination'),
('Languages::theme_editor.color_gen_analogic', 'Analogic'),
('Languages::theme_editor.color_gen_base_color', 'Base color'),
('Languages::theme_editor.color_gen_contrast', 'Contrast'),
('Languages::theme_editor.color_gen_dark_pastel', 'Dark pastel'),
('Languages::theme_editor.color_gen_default', 'Default'),
('Languages::theme_editor.color_gen_light_pastel', 'Light pastel'),
('Languages::theme_editor.color_gen_monochromatic', 'Monochromatic'),
('Languages::theme_editor.color_gen_pale', 'Pale'),
('Languages::theme_editor.color_gen_pastel', 'Pastel'),
('Languages::theme_editor.color_gen_title', 'Generate colors'),
('Languages::theme_editor.color_gen_triad', 'Triad'),
('Languages::theme_editor.color_gen_variant', 'Variation'),
('Languages::theme_editor.color_gen_vcontrast', 'Contrast'),
('Languages::theme_editor.content_bg', 'Content'),
('Languages::theme_editor.css', 'Custom CSS'),
('Languages::theme_editor.customize', 'Customize'),
('Languages::theme_editor.decorative_color', 'Decorative'),
('Languages::theme_editor.discount_label', 'Discount label'),
('Languages::theme_editor.error_style_exists', 'The style with this name is already exist. Please choose another one.'),
('Languages::theme_editor.favicon', 'Favicon'),
('Languages::theme_editor.favicon_size', 'Favicon size must be 16x16 px'),
('Languages::theme_editor.fixed', 'Fixed'),
('Languages::theme_editor.font', 'Font'),
('Languages::theme_editor.fonts', 'Fonts'),
('Languages::theme_editor.font_color', 'Font'),
('Languages::theme_editor.footer', 'Footer'),
('Languages::theme_editor.footer_text', 'Footer text'),
('Languages::theme_editor.full_width', 'Full width'),
('Languages::theme_editor.general', 'General'),
('Languages::theme_editor.general_bg', 'General'),
('Languages::theme_editor.gradient', 'Gradient'),
('Languages::theme_editor.header', 'Header'),
('Languages::theme_editor.headings_font', 'Headings'),
('Languages::theme_editor.hide_show', 'Hide/show theme editor panel'),
('Languages::theme_editor.incorrect_style_name', 'Style name can not contain the following characters: "/ # % ? * : ; { } \\ + "'),
('Languages::theme_editor.in_stock', 'In stock'),
('Languages::theme_editor.links_font', 'Links'),
('Languages::theme_editor.link_color', 'Links'),
('Languages::theme_editor.logos', 'Logos'),
('Languages::theme_editor.mail', 'Mail'),
('Languages::theme_editor_logo.mail', 'E-mails'),
('Languages::theme_editor.main', 'Main content'),
('Languages::theme_editor.max_image_size', 'The image must not be bigger than 200 kB.'),
('Languages::theme_editor.menu_color', 'Menu'),
('Languages::theme_editor.menu_links_color', 'Menu links'),
('Languages::theme_editor.middle_bg', 'Middle'),
('Languages::theme_editor.no_repeat', 'No repeat'),
('Languages::theme_editor.off', 'Off'),
('Languages::theme_editor.on', 'On'),
('Languages::theme_editor.out_of_stock', 'Out of stock'),
('Languages::theme_editor.pattern', 'Pattern'),
('Languages::theme_editor.position', 'Position'),
('Languages::theme_editor.styles', 'Styles'),
('Languages::theme_editor.style', 'Style'),
('Languages::theme_editor.color_scheme', 'Color scheme'),
('Languages::theme_editor.style_data_cannot_be_saved', 'Style data cannot be saved. You should set write permissions for <b>[theme_dir]</b> directory to fix this issue.'),
('Languages::theme_editor.style_name', 'Style name'),
('Languages::theme_editor.price', 'Price'),
('Languages::theme_editor.price_font', 'Price tag'),
('Languages::theme_editor.primary_button', 'Primary button'),
('Languages::theme_editor.tertiary_button', 'Tertiary button'),
('Languages::theme_editor.repeat', 'Repeat'),
('Languages::theme_editor.repeat_x', 'Repeat x'),
('Languages::theme_editor.repeat_y', 'Repeat y'),
('Languages::theme_editor.reset_backgrounds', 'Reset backgrounds'),
('Languages::theme_editor.reset_colors', 'Reset colors'),
('Languages::theme_editor.reset_css', 'Reset CSS'),
('Languages::theme_editor.reset_fonts', 'Reset fonts'),
('Languages::theme_editor.reset_general', 'Reset general'),
('Languages::theme_editor.reset_logos', 'Reset logos'),
('Languages::theme_editor.rounded_corners', 'Rounded corners'),
('Languages::theme_editor.scroll', 'Scroll'),
('Languages::theme_editor.secondary_button', 'Secondary button'),
('Languages::theme_editor.sidebar', 'Sidebar'),
('Languages::theme_editor.text_align', 'Text alignment'),
('Languages::theme_editor.text_close_editor', 'Are you sure to exit the theme editor?'),
('Languages::theme_editor.text_close_editor_unsaved', 'You have unsaved changes. Are you sure to exit from theme editor?'),
('Languages::theme_editor.text_reset_changes', 'All changes after last save will be reset'),
('Languages::theme_editor.theme', 'Theme'),
('Languages::theme_editor_logo.theme', 'Theme'),
('Languages::theme_editor.top_panel', 'Top panel'),
('Languages::theme_editor.top_panel_links', 'Top panel links'),
('Languages::theme_editor.top_panel_text', 'Top panel text'),
('Languages::theme_editor.transparent', 'Transparent'),
('Languages::theme_editor.upload_image', 'Upload image'),
('Languages::theme_editor.enable', 'Enable Theme editor'),
('Languages::theme_editor.system_fonts', 'System fonts'),
('Languages::theme_editor.popular_fonts', 'Popular fonts'),
('Languages::theme_editor.other_fonts', 'Other fonts'),
('Languages::theme_editor_mode', 'Theme editor mode'),
('Languages::theme_editor.checkout_selected_control_border', 'Checkout: Selected payment / shipping method border'),
('Languages::theme_editor.checkout_active_selector_border', 'Checkout: Active selector border'),
('Languages::theme_editor.checkout_control_border', 'Checkout: Payment / shipping method border'),
('Languages::theme_editor.checkout_selector_border', 'Checkout: Selector border'),
('Languages::theme_editor.checkout_input_border', 'Checkout: Field border'),
('Languages::theme_editor.checkout_selected_input_border', 'Checkout: Selected field border'),
('Languages::theme_editor.checkout_step_title', 'Checkout: Step title'),
('Languages::theme_editor.checkout_input_text', 'Checkout: Text in fields'),
('Languages::theme_editor.checkout_input_label', 'Checkout: Field label'),
('Languages::theme_editor.checkout_control_background', 'Checkout: Payment / shipping method background'),
('Languages::theme_editor.checkout_selector_background', 'Checkout: Selector background'),
('Languages::theme_editor.checkout_selected_control_background', 'Checkout: Selected payment / shipping method background'),
('Languages::theme_editor.checkout_active_selector_background', 'Checkout: Active selector background'),
('Languages::theme_editor.checkout_control_title', 'Checkout: Payment / shipping method title'),
('Languages::theme_editor.checkout_selector_title', 'Checkout: Selector title'),
('Languages::theme_editor.checkout_control_description', 'Checkout: Payment / shipping method description'),
('Languages::theme_editor.checkout_selector_tooltip', 'Checkout: Selector tooltip'),
('Languages::theme_editor.checkout_control_label', 'Checkout: Credit card field names'),
('Languages::theme_editor.checkout_terms_background', 'Checkout: "Terms and conditions" section background'),
('Languages::theme_editor.checkout_link', 'Checkout: Link'),
('Languages::admin_panel.block_manager', 'Editing layout'),
('Languages::theme_editor.create_style_first', 'You cannot modify this parameter for default styles. Create a new one first'),
('Languages::backoffice_color_scheme.dark_mode', 'Dark theme'),
('Languages::backoffice_color_scheme.light_mode', 'Light theme'),
('Languages::backoffice_color_scheme.system_mode', 'System theme'),
('Languages::the_test_transaction', 'This is a TEST transaction'),
('Languages::this_day', 'This day'),
('Languages::this_month', 'This month'),
('Languages::this_week', 'This week'),
('Languages::this_year', 'This year'),
('Languages::ths_sign', 'Ths sign'),
('Languages::thumb', 'Thumbnail'),
('Languages::thumbnail', 'Thumbnail'),
('Languages::thumbnails', 'Thumbnails'),
('Languages::thumbnails_removed', 'Thumbnails have been removed'),
('Languages::thumbnail_width', 'Thumbnail width in scroller'),
('Languages::image_file_size_set_to_server_setting', 'Image file size set to [file_size] MB. This is the largest file size allowed by the server settings.'),
('Languages::tier_account', 'tier account'),
('Languages::time', 'Time'),
('Languages::timeout', 'Timeout'),
('Languages::Timestamp', 'Timestamp'),
('Languages::time_interval', 'Time interval'),
('Languages::time_unlimited_download', 'Time-unlimited download'),
('Languages::title', 'Title'),
('Languages::tmpl_copyright', 'Copyright information'),
('Languages::tmpl_logo', 'Store logo'),
('Languages::tmpl_payment_icons', 'Payment systems icons'),
('Languages::tmpl_quick_links', 'Quick links'),
('Languages::tmpl_search', 'Search field'),
('Languages::to', 'TO'),
('Languages::today', 'Today'),
('Languages::tools', 'Tools'),
('Languages::tools_addons_current_state', 'Current state'),
('Languages::tools_addons_no_addons', 'No add-ons'),
('Languages::tools_addons_no_third_party_addons', 'No third party add-ons'),
('Languages::tooltip', 'Tooltip'),
('Languages::container_not_used', 'This container is NOT used. "[container]" container from the default location will be used instead. Set this location as default to use this container as "[container]" for all locations.'),
('Languages::top_panel', 'Top panel'),
('Languages::total', 'Total'),
('Languages::totally_paid', 'Total paid'),
('Languages::totals', 'Totals'),
('Languages::total_amount', 'Total amount'),
('Languages::total_cost', 'Total cost'),
('Languages::total_items', 'Total items'),
('Languages::total_price', 'Total price'),
('Languages::total_product_cost', 'Total product cost'),
('Languages::total_results', 'Total results'),
('Languages::to_all_subcats', 'Apply to all subcategories'),
('Languages::to_date', 'Date through'),
('Languages::to_fixed', 'to fixed amount'),
('Languages::to_percentage', 'to percentage of the original price'),
('Languages::tpe', 'TPE'),
('Languages::track', 'Track'),
('Languages::tracking_num', 'Tracking number'),
('Languages::tracking_number', 'Tracking number'),
('Languages::tracks', 'Identifier'),
('Languages::track_my_order', 'Track my order(s)'),
('Languages::track_orders', 'Track orders'),
('Languages::track_request_subj', 'Order tracking'),
('Languages::track_without_options', 'Track without options'),
('Languages::track_with_options', 'Track with options'),
('Languages::TransactionDateTime', 'TransactionDateTime'),
('Languages::transaction_approved', 'Transaction approved'),
('Languages::transaction_cancelled', 'Transaction was canceled'),
('Languages::transaction_declined', 'Transaction declined'),
('Languages::transaction_id', 'Transaction ID'),
('Languages::transaction_datetime', 'Transaction date'),
('Languages::transaction_key', 'Transaction key'),
('Languages::transaction_password', 'Transaction password'),
('Languages::transaction_type', 'Transaction type'),
('Languages::transaction_url', 'Transaction URL'),
('Languages::translate', 'Translate'),
('Languages::translations', 'Translations'),
('Languages::edit_texts', 'Edit texts'),
('Languages::tree', 'Tree'),
('Languages::trial', 'Trial'),
('Languages::trial_mode_mve_disabled', 'Trial mode is not available anymore since you have a valid license activated for this installation'),
('Languages::trial_mode_ult_disabled', 'Trial mode cannot be activated'),
('Languages::trial_notice', 'Your store is in the Trial mode.<br /><br />When the 30-day trial period expires, you''ll have to enter a valid license number to be able to manage your store.<br /><br />To dismiss this message permanently, and to access to the Administration panel after the trial period is over, purchase a license and <a class="cm-dialog-opener cm-dialog-auto-size" data-ca-target-id="store_mode_dialog">activate the Full mode</a>.'),
('Languages::trial_expired', 'Your [product] trial period has expired'),
('Languages::text_input_license_code', 'Please enter your license number to be able to manage your store:'),
('Languages::text_buy_new_license', 'If you don''t have a license number yet, you can purchase it at our official website.'),
('Languages::buy_license', 'Purchase a license'),
('Languages::true', 'True'),
('Languages::tt_views_shippings_update_delivery_time', 'The delivery time appears next to the name of the shipping method. If you use realtime shipping rate calculation, your shipping service may provide its own delivery time. The time provided by the shipping service will be displayed instead of the time you specify here.'),
('Languages::ttc_page_title', 'Page title displayed on a browser panel.'),
('Languages::ttc_popularity', 'Product popularity rating based on how many times the storefront has been viewed, number of additions to cart and number of purchases.'),
('Languages::ttc_search_words', 'Enter a few words here, and the product will appear in the results of the built-in search for those words, even if the product name or description doesn''t have them. Separate different search words by commas.'),
('Languages::ttc_storefront_url', 'All the storefronts domain names must be associated with the same IP-address. Note: Switch to "All stores" to edit'),
('Languages::ttc_stores_status', 'ON—the storefront is open; everyone will see it. OFF—the storefront is closed; only those who have the access key will be able to see it.'),
('Languages::access_for_authorized_customers_only', 'Access for authorized customers only'),
('Languages::tts_activate_menu_tab_for', 'The menu item will be shown activated for the specified dispatch.'),
('Languages::tts_generate_submenu', 'The submenu will include child elements of the selected object.'),
('Languages::tts_link_text', 'Target URL. May be an external URL, an inner store URL or a dispatch.'),
('Languages::tts_menu_user_class', 'User-defined CSS class will be added to the menu item, so this will allow to define the menu item with its own CSS style.'),
('Languages::tt_views_block_manager_update_block_override_by_this', 'If you save the block with this option checked, the current block content value will override the content of this block everywhere it is used in the cart'),
('Languages::tt_views_block_manager_update_block_width', 'Block width works for blocks located in the group having horizontal direction, for other cases this parameter does not work.'),
('Languages::tt_views_block_manager_update_location_default', 'One location must be picked as default. Its Top and Bottom containers will be used in all locations.'),
('Languages::tt_views_cart_components_carts_search_form_online_only', 'If enabled, search results include only users who are online at the moment.'),
('Languages::tt_views_currencies_update_after_sum', 'If enabled, the symbol of the currency is shown after the sum.'),
('Languages::tt_views_currencies_update_decimals', 'Number of digits after the decimal sign.'),
('Languages::tt_views_currencies_update_dec_sign', 'Decimal separator.'),
('Languages::tt_views_currencies_update_ths_sign', 'Thousand separator.'),
('Languages::tt_views_database_manage_backup_data', 'If enabled, the database backup file includes the actual table data.'),
('Languages::tt_views_database_manage_backup_schema', 'If enabled, the database backup file keeps the table structure.'),
('Languages::tt_views_exim_export_output', 'Choose an action on the file: "Direct download" - to save the file on the local computer, "Screen" - to display the file''s contents, "Server" - to save the file on the server file system.'),
('Languages::tt_views_languages_manage_language_code', 'Two-letter code of the language.'),
('Languages::tt_views_languages_update_country', 'The flag of this country will be used as language icon.'),
('Languages::tt_views_orders_components_orders_search_form_customer_files', 'If enabled, the search results will contain the orders for which customers loaded their own files.'),
('Languages::tt_views_payments_update_surcharge_title', 'Leave empty to use the ''Payment surcharge'' as a title'),
('Languages::tt_views_payments_update_template', 'Template responsible for displaying supplementary fields for the payment method.'),
('Languages::tt_views_products_components_products_shipping_settings_items_in_box', 'Use this field to define the minimum and maximum number of product items to be shipped in a separate box. Enter a non-zero value and specify the box dimensions below.'),
('Languages::tt_views_products_components_products_shipping_settings_weight', 'Non-downloadable products with zero weight are handled as having minimal possible non-zero weight'),
('Languages::tt_views_products_update_categories', 'Categories to be displayed in the navigation breadcrumbs.'),
('Languages::tt_views_products_update_images', 'The maximum size of image files is [file_size] MB.'),
('Languages::tt_views_products_update_inventory', 'Track in stock product quantity. Enable the "Enable inventory tracking" option (Settings -> General) to modify.'),
('Languages::tt_views_products_update_list_price', 'Manufacturer suggested retail price.'),
('Languages::tt_views_products_update_out_of_stock_actions', '''Buy in advance'' lets customers buy out-of-stock products and products that will be available since a specific date. ''Sign up for notification'' works only when the product has zero or negative quantity.'),
('Languages::tt_views_product_features_update_feature_display_on_catalog', 'Show this feature on product list pages along with product description.'),
('Languages::tt_views_product_features_update_feature_display_on_product', 'If enabled, the product feature is displayed on the product details page in the storefront'),
('Languages::tt_views_product_features_update_prefix', 'An affix that precedes the product feature.'),
('Languages::tt_views_product_features_update_suffix', 'An affix that follows the product feature.'),
('Languages::tt_views_product_options_update_incorrect_filling_message', 'Message that is displayed if the entered data is incorrect.'),
('Languages::tt_views_product_options_update_inner_hint', 'A note that indicates the value to be entered.'),
('Languages::tt_views_product_options_update_inventory', 'If enabled, the option is taken into account when forming the product inventory.'),
('Languages::tt_views_product_options_update_regexp', 'Regular expression specifying a pattern to match.'),
('Languages::tt_views_promotions_update_stop_other_rules', 'If enabled, the other promotions are not applied.'),
('Languages::tt_views_sales_reports_table_time_interval', 'Periods to analyze (day, week, month, year).'),
('Languages::tt_views_sales_reports_update_table_dependence', 'Parameter to sort values by. It should relate to the Value to display param (e.g. Product costs—Total cost or Number of products—Number of items).'),
('Languages::tt_views_sales_reports_update_table_limit', 'Max number of chart components.'),
('Languages::tt_views_site_layout_logos_alt_text', 'Leave empty to use company name as alternative text.'),
('Languages::tt_views_storage_cdn_cname', 'Domain name that you want to use instead of the CloudFront domain name for the URLs for your files. You also need to create a CNAME record with your DNS service to route queries to CloudFront host (it will be displayed on this page after you enter account information).'),
('Languages::tt_views_storage_cdn_key', 'AWS Access Key ID. See <a href="https://docs.aws.amazon.com/powershell/latest/userguide/pstools-appendix-sign-up.html" target="_blank">https://docs.aws.amazon.com</a> to learn how to get key and secret key.'),
('Languages::tt_views_taxes_update_regnumber', 'Registration number of this tax in the store.'),
('Languages::turkish', 'Turkish'),
('Languages::type', 'Type'),
('Languages::type_comments_here', 'You can leave us a comment here'),
('Languages::uc_ok', 'OK'),
('Languages::uk_cookies_law', 'Cookies are used on this site to provide the best user experience. If you continue, we assume that you agree to receive cookies from this site. <span class="button button-wrap-left"><span class="button button-wrap-right"><a rel="nofollow" href="[url]">OK</a></span></span>'),
('Languages::ult_share_users_setting_disabled', 'The setting value can not be changed as identical email addresses are registered in your store.'),
('Languages::unable_delete_vendor_orders_exists', 'Unable to delete this store because there are orders containing the products of this company in the store database. To delete the account, please delete all such orders first.'),
('Languages::unable_to_assign_usergroup', 'Unable to assign the usergroup. Please contact the shop administrator.'),
('Languages::unable_to_check_license', 'Unable to check your license number'),
('Languages::unable_to_delete_setting_description', 'Unable to delete setting description: [reason]'),
('Languages::unable_to_delete_setting_variant', 'Unable to delete setting_variant: [reason]'),
('Languages::unable_to_read_resource', 'Unable to read resource: [file]'),
('Languages::unable_to_update_setting_description', 'Unable to set description: [reason]'),
('Languages::unable_to_update_setting_value', 'Unable to set value: [reason]'),
('Languages::unable_to_unpack_file', 'Unable to decompress file'),
('Languages::ungroupped_features', 'Ungrouped features'),
('Languages::uninstall', 'Uninstall'),
('Languages::unique_html_block', 'Unique HTML block'),
('Languages::unit', 'Unit'),
('Languages::united_kingdom', 'United Kingdom'),
('Languages::unit_price', 'Unit price'),
('Languages::unknown', 'Unknown'),
('Languages::unknown_server_response', 'Unknown server response'),
('Languages::unmark', 'Unmark'),
('Languages::unregistered_customer', 'Unregistered customer'),
('Languages::unregistered_customer_short', 'Unregistered'),
('Languages::unselect_all', 'Unselect all'),
('Languages::unset_tax_to_products', 'Remove selected taxes from all products'),
('Languages::unsubscribe', 'Unsubscribe'),
('Languages::up', 'Up'),
('Languages::update', 'Update'),
('Languages::update_categories', 'Update categories'),
('Languages::update_customer_info', 'Update customer information'),
('Languages::update_for_all_act', 'New value will be saved for ALL stores which share this item. Click to save it only for the owner-store.'),
('Languages::update_for_all_dis', 'New value will be saved ONLY for the owner-store. Click to save it for all stores which share this item.'),
('Languages::update_for_all_hid_act', 'Click to cancel field update.'),
('Languages::update_for_all_hid_dis', 'Click to enter a new field value to update in all stores when saving item.'),
('Languages::update_group', 'Update group'),
('Languages::update_period_expired', '<p class="text-error">Your upgrade subscription has expired, so this software upgrade cannot be installed. You can prolongate your subscription in the <a href="[url]">Customer Help Desk</a>.</p><p>Please note that it is not mandatory: you can continue using this software with no limitation even without an upgrade subscription.</p>'),
('Languages::update_products', 'Update products'),
('Languages::update_profile', 'Update profile'),
('Languages::update_profile_notification', 'Your profile has been updated.'),
('Languages::update_profile_notification_header', 'Your profile has been updated'),
('Languages::update_status', 'Update status'),
('Languages::update_text', 'Update text'),
('Languages::updating', 'Updating'),
('Languages::updating_links', 'Updating links'),
('Languages::upgrade', 'Upgrade'),
('Languages::upgrade_center', 'Upgrade center'),
('Languages::upgrade_center_permission_adjusted_properly', 'All file and folder permissions have been adjusted properly.'),
('Languages::upgrade_center.validation_issue', 'Validation issue'),
('Languages::upgrade_center.validator_fail_result', 'Validator "[validator_name]" returned fail status'),
('Languages::upgrade_center.filehash_check_failed', 'Upgrade is impossible due to file integrity check error. Please contact the technical support team.'),
('Languages::upgrade_center.upgrades_are_not_available_in_trial', 'Upgrades are available only in <strong>Full</strong> and <strong>Free</strong> licensing modes.<br /><br />The licensing mode can be changed under Settings → <a class="cm-dialog-opener cm-dialog-auto-size" data-ca-target-id="store_mode_dialog">Licensing mode</a>.'),
('Languages::upgrade_center.incompatible_third_party_addons', 'Some of your add-ons weren''t tested with this version yet. Before the upgrade, ask the developers of these add-ons if they''ll work.'),
('Languages::upgrade_center.check_addons', 'See add-ons that weren''t tested →'),
('Languages::upgrade_flash_player', 'You need to upgrade your Flash Player'),
('Languages::upgrade_is_not_avail', '<p class="text-error">This upgrade is not available for your [product] license. Please contact our <a href="[href]">support team</a> to update your license status.</p>'),
('Languages::upgrade_center.warning_msg_upgrade_is_complicated', 'The upgrade is a complicated process. It can be failed due to reasons that are beyond our control.<br> To make the upgrade of your store safer, we have prepared tips for you:'),
('Languages::upgrade_center.warning_msg_specialists', 'If you are not familiar with technical aspects of CS-Cart and the upgrade process, we strongly recommend that you <a href="[upgrade_center_specialist]" target="_blank">hire a specialist</a> or <a href="[upgrade_center_team]" target="_blank">ask our support team</a> to upgrade your store for you.'),
('Languages::upgrade_center.warning_msg_third_party_add_ons', 'The upgrade doesn''t update third-party add-ons. That''s why we recommend that you disable all the third-party add-ons before the upgrade.'),
('Languages::upgrade_center.warning_msg_test_local', 'Upgrade the test copy of your store first to make sure that the upgrade will go smoothly.'),
('Languages::upgrade_center.warning_msg_after_upgrade', 'After the upgrade, check the basic functionality of your store.'),
('Languages::upgrade_center.warning_msg_generally', 'Generally, the upgrade fails because the PHP script execution is terminated due to your server configuration. It''s essential to check the PHP script timeout settings on your server'),
('Languages::upgrade_center.warning_msg_timeout_fail', 'We DO NOT recommend to start the upgrade on your server.'),
('Languages::upgrade_center.warning_msg_timeout_check_failed', 'Your server has wrong PHP script timeout settings. This could be due to restrictions on the PHP <a href="http://php.net/manual/en/function.set-time-limit.php" target="_blank">set_time_limit</a> function or FastCGI "Timeout" options. We recommend you to contact your hosting provider in order to resolve this issue or contact our tech support team to perform the upgrade for you.'),
('Languages::upgrade_center.warning_msg_executed_php', '<p class="text-error">We have started a dummy PHP script. It will be working during 6 minutes. When the check is finished, we''ll tell you if the PHP script''s timeouts can be set correctly. If yes, then you are good to go with the upgrade. Please wait until the check is finished to be sure that your server has correct PHP timeout configuration.</p>'),
('Languages::upload', 'Upload'),
('Languages::upload_install', 'Upload & install'),
('Languages::upload_another_file', 'Upload another file'),
('Languages::upload_file', 'Upload file'),
('Languages::ups', 'United Parcel Service'),
('Languages::url', 'URL'),
('Languages::user', 'User'),
('Languages::usergroup', 'User group'),
('Languages::usergroups', 'User groups'),
('Languages::usergroup_activated', 'User group has been activated'),
('Languages::usergroup_disactivated', 'User group has been deactivated'),
('Languages::usergroup_privileges', 'User group privileges'),
('Languages::usergroup_request_by_customer', 'User group request by customer'),
('Languages::username', 'Username'),
('Languages::users', 'Users'),
('Languages::users_carts', 'Abandoned / Live carts'),
('Languages::users_carts_menu', 'Live carts'),
('Languages::user_type', 'User type'),
('Languages::user_account_info', 'User account information'),
('Languages::user_account_information', 'User account information'),
('Languages::user_cannot_be_deleted', 'Sorry, user with id [user_id] can not be deleted.'),
('Languages::user_class', 'User-defined CSS class'),
('Languages::wrapper_class', 'User-defined wrapper CSS class'),
('Languages::user_data_required', 'Please select a customer or enter data'),
('Languages::user_details_page', 'User details page'),
('Languages::user_group_requests', 'User group requests'),
('Languages::user_id', 'User ID'),
('Languages::user_info', 'User information'),
('Languages::user_pin', 'User PIN'),
('Languages::user_profile_info', 'User profile information'),
('Languages::user_settings', 'User settings'),
('Languages::use_avail_period', 'Use available period'),
('Languages::use_cardinal', 'Use Cardinal Centinel&reg; for 3-D Secure Payer Authentication'),
('Languages::use_coupons_commission', 'Coupon commission'),
('Languages::use_current_link', 'Use the current page link'),
('Languages::use_custom_view', 'Use custom view'),
('Languages::use_custom_weight_settings', 'Use custom weight settings'),
('Languages::use_existing_block', 'Use Existing Block'),
('Languages::use_existing_store', 'Copy existing storefront configuration'),
('Languages::use_negotiated_rates', 'Use negotiated rates'),
('Languages::use_new_sha_method', 'Use new SHA signature policy'),
('Languages::usps', 'U.S Postal Service'),
('Languages::usps_package_size_large', 'Large'),
('Languages::usps_package_size_regular', 'Regular'),
('Languages::usps_service_certificate_of_mailing', 'Certificate of mailing'),
('Languages::usps_service_certificate_of_mailing_for_firm_mailing_books', 'Certificate of mailing for firm mailing books'),
('Languages::usps_service_certificate_of_mailing_per_individual_article', 'Certificate of mailing per individual article'),
('Languages::usps_service_certified', 'Certified'),
('Languages::usps_service_collect_on_delivery', 'Collect on delivery'),
('Languages::usps_service_delivery_confirmation', 'USPS Tracking/Delivery confirmation'),
('Languages::usps_service_edelivery_confirmation', 'e-Delivery Confirmation'),
('Languages::usps_service_express_mail_insurance', 'Express mail insurance'),
('Languages::usps_service_insurance', 'Insurance'),
('Languages::usps_service_pick_up_on_demand', 'Pick up on demand'),
('Languages::usps_service_registered_mail', 'Registered mail'),
('Languages::usps_service_registered_without_insurance', 'Registered without insurance'),
('Languages::usps_service_registered_with_insurance', 'Registered with insurance'),
('Languages::usps_service_return_receipt', 'Return receipt'),
('Languages::usps_service_return_receipt_electronic', 'Return receipt electronic'),
('Languages::usps_service_return_receipt_for_merchandise', 'Return receipt for merchandise'),
('Languages::usps_service_signature_confirmation', 'Signature confirmation'),
('Languages::usps_size', 'Please specify the package width, height and length for Priority mail, if Package Size is Large only.'),
('Languages::valid', 'Period of validity'),
('Languages::validate_email', 'Validate E-mail'),
('Languages::validate_secret_word', 'Validate secret word'),
('Languages::valid_thru', 'Valid thru (mm/yy)'),
('Languages::value', 'Value'),
('Languages::value_to_display', 'Value to display'),
('Languages::variant', 'Variant'),
('Languages::variants', 'Variants'),
('Languages::variant_name', 'Variant name'),
('Languages::vendor', 'Store'),
('Languages::vendors', 'Stores'),
('Languages::vendor_id', 'Store ID'),
('Languages::vendor_name_field', 'Vendor name'),
('Languages::vendor_name', 'Store name'),
('Languages::vendor_pages', 'Store pages'),
('Languages::version', 'Version'),
('Languages::vertical', 'Vertical'),
('Languages::very_good', 'Very Good'),
('Languages::view', 'View'),
('Languages::viewing_feature', 'Viewing feature'),
('Languages::viewing_filter', 'Viewing filter'),
('Languages::view_all', 'view all'),
('Languages::view_all_orders', 'View all orders'),
('Languages::view_all_product_features', 'View all product features'),
('Languages::view_cart', 'View cart'),
('Languages::view_categories', 'View categories'),
('Languages::view_comparison_list', 'Comparison list'),
('Languages::view_details', 'View details'),
('Languages::view_orders', 'View orders'),
('Languages::view_page', 'View page'),
('Languages::view_product', 'View product'),
('Languages::view_products', 'View products'),
('Languages::view_product_features', 'View product features'),
('Languages::view_purchased_products', 'View purchased products'),
('Languages::view_report', 'View report'),
('Languages::view_results', 'View results'),
('Languages::view_storefront', 'View storefront'),
('Languages::view_vendor_categories', 'View store categories'),
('Languages::view_vendor_orders', 'View store orders'),
('Languages::view_vendor_products', 'View store products'),
('Languages::view_vendor_users', 'View store users'),
('Languages::visa_card_discover', 'Visa, MasterCard, Discover'),
('Languages::visited_page', 'Visited page'),
('Languages::voided', 'Voided'),
('Languages::warning', 'Warning'),
('Languages::warning_default_language_disabled', 'The default language defined in your settings has been disabled or deleted. Please update the Frontend default language value on the following page: <a href="[link]">Settings :: Appearance</a>'),
('Languages::default_language_status', 'Status of the Default language cannot be changed'),
('Languages::warning_cannot_disable_all_currencies', 'All currencies cannot be hidden or disabled. Primary currency activated.'),
('Languages::warning_default_currency_disabled', 'The default currency of one of the storefronts defined in your settings has been disabled or deleted, or its code has been changed. Please update the Frontend default currency value on the following page: <a href="[link]">Settings :: Appearance</a>'),
('Languages::default_currency_status', 'Status of the Primary currency cannot be changed'),
('Languages::warning_https_is_disabled', 'The secure connection check has failed. Please ensure that SSL certificate is installed on your server. Check out the <a href="[href]" target="_blank">Documentation article</a> for more details.'),
('Languages::warning_insecure_admin_script', 'It is strongly recommended that you rename the default <b>admin.php</b> script (check the <a href="[href]" target="_blank">Documentation</a>) for security reasons.'),
('Languages::warning_insecure_password_email', 'The password must be different from the E-mail! <p><a href="[link]" class="underlined"><b>Change password &#155;&#155;</b></a></p>'),
('Languages::warning_lanvar_incorrect_name', 'Language variable name contains unsupported characters!'),
('Languages::warning_not_deleted_default_language', 'The [lang_name] language cannot be deleted because it is the default store language'),
('Languages::warning_promotions_incorrect_condition', 'The "[condition]" condition can be used in groups with "[set_value]" conditions only.'),
('Languages::warning_store_optimization_dev', 'Auto cache update enabled.<br /><br />Modified files are tracked in real time (including the files modified directly on server) and re-cached.<br /><br />Store performance may be slightly affected. Recommended to disable on production in the <a href="[link]">Themes</a>.'),
('Languages::warning_store_optimization_dev_disabled', 'Auto cache update disabled.<br /><br />Clear compiled templates manually after modifying the theme files by following <a href="[link]">this link</a> to apply the changes.'),
('Languages::warning_subscr_email_exists', '<b>[email]</b> is already in the subscribers list'),
('Languages::warning_theme_clone_dir_exists', 'Can not clone theme, because directory you entered is already exist. Please enter another one.'),
('Languages::warning_track_orders_not_allowed', 'You are not allowed to view the details of this order.'),
('Languages::warning_track_orders_not_found', 'The E-mail/Order ID you entered doesn''t exist'),
('Languages::warning_variants_removal', 'Clicking on Save will remove product feature values.'),
('Languages::website', 'Website'),
('Languages::web_pages', 'Web pages'),
('Languages::web_site', 'Website'),
('Languages::week', 'Week'),
('Languages::weekday_0', 'Sunday'),
('Languages::weekday_1', 'Monday'),
('Languages::weekday_2', 'Tuesday'),
('Languages::weekday_3', 'Wednesday'),
('Languages::weekday_4', 'Thursday'),
('Languages::weekday_5', 'Friday'),
('Languages::weekday_6', 'Saturday'),
('Languages::weekday_abr_0', 'Sun'),
('Languages::weekday_abr_1', 'Mon'),
('Languages::weekday_abr_2', 'Tue'),
('Languages::weekday_abr_3', 'Wed'),
('Languages::weekday_abr_4', 'Thu'),
('Languages::weekday_abr_5', 'Fri'),
('Languages::weekday_abr_6', 'Sat'),
('Languages::weeks', 'week(s)'),
('Languages::weight', 'Weight'),
('Languages::weight_dependences', 'Weight dependencies'),
('Languages::weight_limit', 'Weight limit'),
('Languages::weight_modifier', 'Weight modifier'),
('Languages::weight_symbol', 'Weight symbol'),
('Languages::well_done', 'Well done!'),
('Languages::what_is_cvv2', 'What is CVV/CVC'),
('Languages::widget_code', 'Widget code'),
('Languages::widget_what_is_it', '<a href="[href]" target="_blank">What is it?</a>'),
('Languages::width', 'Width'),
('Languages::without_image', 'Without image'),
('Languages::with_contact_information', 'With contact information only'),
('Languages::world', 'World'),
('Languages::worldnettps_hash_error', 'An error occurred. Error details: Request and Response hash do not match.'),
('Languages::worldpay_secret', 'MD5 secret for transactions'),
('Languages::wrapper', 'Wrapper'),
('Languages::write', 'Write'),
('Languages::year', 'Year'),
('Languages::yes', 'Yes'),
('Languages::yesterday', 'Yesterday'),
('Languages::your_message', 'Your message'),
('Languages::your_name', 'Your name'),
('Languages::your_range', 'Your range'),
('Languages::you_have_no_permissions', 'You have no permissions'),
('Languages::you_save', 'You save'),
('Languages::zero_price_action', 'Zero price action'),
('Languages::zipcodes', 'Zip/Postal codes'),
('Languages::zip_postal_code', 'Zip/postal code'),
('Languages::zone', 'Zone'),
('Languages::zpa_ask_price', 'Ask customer to enter the price'),
('Languages::zpa_permit', 'Allow customers to add the product to cart'),
('Languages::zpa_refuse', 'Do not allow customers to add the product to cart'),
('Languages::po_file', 'Choose a file in the PO or ZIP format'),
('Languages::hidden_categories', 'Hidden categories'),
('Languages::clone_categories', 'Copy categories'),
('Languages::clone_layouts', 'Copy layouts'),
('Languages::clone_pages', 'Share pages'),
('Languages::clone_payments', 'Share payment methods'),
('Languages::clone_products', 'Share products'),
('Languages::clone_product_features', 'Share product features'),
('Languages::clone_product_filters', 'Share product filters'),
('Languages::clone_profile_fields', 'Share profile fields'),
('Languages::clone_promotions', 'Share promotions'),
('Languages::clone_settings', 'Copy settings'),
('Languages::clone_shippings', 'Share shipping methods'),
('Languages::clone_sitemap', 'Copy sitemap'),
('Languages::clone_static_data_clone', 'Copy menus'),
('Languages::text_uc_failed_to_decompress_files', 'Failed to extract files from the archive'),
('Languages::development', 'Development'),
('Languages::po_file_is_incorrect', 'PO-file <b>"[file]"</b> contains syntax errors or incorrect structure.'),
('Languages::product_option_delimiter', 'Option delimiter'),
('Languages::text_product_option_delimiter', 'Delimiter for product options within an option combination (e.g. "Color: Red, Size: Small")'),
('Languages::upload_addon', 'Upload & install add-on'),
('Languages::upload_theme', 'Upload theme'),
('Languages::install_theme_text', 'Uploading and installing a new theme is a great way to personalize your storefront. You can upload a theme by picking a [exts] format archive and clicking <strong>Upload</strong>.'),
('Languages::install_upgrade_package_text', 'You can upload an upgrade package manually from the local machine, your server, or from a remote location. Specify the location of a [exts] format archive and click <strong>Upload</strong>.'),
('Languages::non_writable_directories', 'The following directories do not have writable permissions'),
('Languages::text_set_write_permissions_for_dirs', 'You can set the write permissions for the Web server to the directories listed above or provide an FTP-access with the write permissions to these directories.'),
('Languages::ftp_server_options', 'FTP server options'),
('Languages::ftp_directory', 'FTP directory'),
('Languages::recheck', 'Re-check'),
('Languages::use_this_style', 'Use this style'),
('Languages::upload_via_ftp', 'Upload via FTP'),
('Languages::invalid_ftp_access', 'Invalid FTP access'),
('Languages::install_addon_text', 'Add-ons extend the functionality of your store. <br /> You can install an add-on by picking a [exts] format archive and clicking Upload & install.'),
('Languages::xml_error', 'XML parse error'),
('Languages::column', 'Column'),
('Languages::checking_core_version_is_not_suitable', 'Version of your cart ([version]) is not supported. Minimal: [min]. Maximal: [max].'),
('Languages::checking_core_edition_is_not_suitable', 'Edition of your cart ([current_edition]) is not supported. Required: [required_edition].'),
('Languages::checking_php_version_is_not_suitable', 'PHP version ([version]) is not supported. Minimal: [min]. Maximal: [max].'),
('Languages::checking_extension_should_be_installed', 'The [extension] extension should be installed on your server for correct add-on operation.'),
('Languages::checking_extension_should_be_removed', 'The [extension] extension should be removed from your server for correct add-on operation.');
INSERT INTO `[[dbprefix]]original_values` VALUES
('Languages::checking_extension_version_is_not_suitable', 'The [extension] version ([version]) is not supported by the add-on. Minimal: [min]. Maximal: [max].'),
('Languages::scroll_per_page', 'Scroll per page'),
('Languages::payments.paypal_adv_layout', 'Layout'),
('Languages::payments.layout_a', 'Layout A'),
('Languages::payments.layout_b', 'Layout B'),
('Languages::payments.layout_c', 'Layout C'),
('Languages::payments.eway_rapidapi_rsp.header_text', 'Header text'),
('Languages::filter_by_categories', 'Filter by categories'),
('Languages::default_filter_by_location', 'No filter specified. Filter by location set as default.'),
('Languages::theme_information', 'Theme information'),
('Languages::developer', 'Developer'),
('Languages::theme_styles_and_layouts', 'Theme styles and layouts'),
('Languages::activate', 'Activate'),
('Languages::export_layout', 'Export layout'),
('Languages::import_layout', 'Import layout'),
('Languages::create_new_layout', 'Create new layout'),
('Languages::update_current_layout', 'Update current layout'),
('Languages::get_social', 'Get social'),
('Languages::uc_searchanise_disabled', 'The Searchanise add-on was automatically disabled during upgrade to avoid false search results. Activate it at any time on the <a href="[url]">Add-ons</a> page.'),
('Languages::text_store_closed', 'Sorry, the store is temporarily closed for maintenance.'),
('Languages::theme_editor.presets', 'Presets'),
('Languages::theme_editor.preset_data_cannot_be_saved', 'Preset data cannot be saved. You should set write permissions for <b>[theme_dir]</b> directory to fix this issue.'),
('Languages::theme_editor.preset_name', 'Preset name'),
('Languages::active_preset', 'Active preset'),
('Languages::theme_editor.error_preset_exists', 'The preset with this name is already exist. Please choose another one.'),
('Languages::theme_editor.incorrect_preset_name', 'Preset name can not contain the following characters: "/ # % ? * : ; { } \\ "'),
('Languages::theme_editor.convert_to_css', 'Convert to CSS'),
('Languages::theme_editor.text_convert_to_css', '<p>Generate CSS files from LESS (for manual editing).</p><p>IMPORTANT: You won''t be able to use the Theme editor to customize the storefront!</p><p><i>The original LESS files will be backed up and you will be able to restore them later</i></p>'),
('Languages::theme_editor.enable_less', 'Enable LESS'),
('Languages::theme_editor.warning_css_changes_will_be_reverted', '<p>You should switch back to LESS to be able to use the Theme editor, because it deals with LESS files instead of plain CSS.</p><p><strong>Important:</strong> All CSS files will be overwritten during the restore! Custom CSS modifications will be saved in the backup directory.</p>'),
('Languages::theme_editor.confirm_enable_less', 'Your CSS modifications will be backed up and overwritten. Are you sure to continue with the LESS restore?'),
('Languages::theme_editor.error_theme_converted_to_css', 'Compiled CSS files do not support styling. Restore LESS in the <a target="_blank" href="[url]">Theme editor</a> to be able to change styles.'),
('Languages::need_product_name', 'You have to specify product name'),
('Languages::api_required_field', 'The [field] field is required'),
('Languages::update_translation', 'Update translations'),
('Languages::po_meta_error_validating_lang_code', 'Language code in the PO file does not match that of the updated language'),
('Languages::error_class_phar_data_not_found', 'The PharData class not found. Read more: <a href="https://php.net/manual/en/class.phardata.php">https://php.net/manual/en/class.phardata.php</a>'),
('Languages::error_class_zip_archive_not_found', 'The ZipArchive class not found. Read more: <a href="https://php.net/manual/en/class.ziparchive.php">https://php.net/manual/en/class.ziparchive.php</a>'),
('Languages::error_zip_php_extension_not_installed', '"Zip" PHP extension is not installed. Please install the "Zip" PHP extension to create and extract ZIP-archives.'),
('Languages::make_archive', 'Make archive'),
('Languages::marketplace', 'Marketplace'),
('Languages::cscart_marketplace', 'CS-Cart Marketplace'),
('Languages::marketplace_find_more', 'Find more add-ons and themes in <a href="[href]" target="_blank">Marketplace</a>'),
('Languages::cscart_marketplace.search', 'Search'),
('Languages::cscart_marketplace.search_description', 'Search the Add-on Market for your business needs'),
('Languages::cscart_marketplace.buy', 'Buy'),
('Languages::cscart_marketplace.price', 'Price'),
('Languages::cscart_marketplace.list_price', 'List price'),
('Languages::cscart_marketplace.price_free', 'Free'),
('Languages::more_languages', 'More languages'),
('Languages::languages_find_more', 'If you haven''t found the language you need, check out <a href="[href]" target="_blank">our site with free language packs</a>.'),
('Languages::extract_archive', 'Extract archive'),
('Languages::seo', 'SEO'),
('Languages::text_owl', 'OwlCarousel'),
('Languages::carousel_swiper', 'Swiper'),
('Languages::bulk_print_packing_slip', 'Packing slip bulk print'),
('Languages::bulk_print_pdf', 'Invoice bulk print (PDF)'),
('Languages::text_all_categories_included', 'All categories included'),
('Languages::text_all_products_included', 'All products included'),
('Languages::usergroup_registered', 'Registered users'),
('Languages::person_name', 'Name'),
('Languages::promotions.cond_any', 'any'),
('Languages::promotions.cond_all', 'all'),
('Languages::promotions.cond_true', 'true'),
('Languages::promotions.cond_false', 'false'),
('Languages::text_select_vendor', 'Please select a store first'),
('Languages::views', 'Views'),
('Languages::first_name_and_last_name', 'First name and last name'),
('Languages::s_first_name_and_last_name', 'First name and last name (for shipping)'),
('Languages::b_first_name_and_last_name', 'First name and last name (for billing)'),
('Languages::last_name_and_first_name', 'Last name and first name'),
('Languages::s_last_name_and_first_name', 'Last name and first name (for shipping)'),
('Languages::b_last_name_and_first_name', 'Last name and first name (for billing)'),
('Languages::fullname', 'Full name'),
('Languages::s_fullname', 'Full name (for shipping)'),
('Languages::b_fullname', 'Full name (for billing)'),
('Languages::vendor_terms', 'Vendor terms and conditions'),
('Languages::vendor_terms_field_alert', 'Vendor terms and conditions alert'),
('Languages::vendor_terms_field_terms_text', 'Vendor terms and conditions text'),
('Languages::product_must_have_owner_category', 'Product must belong to some category created by the owner company.'),
('Languages::last_year', 'Last year'),
('Languages::store_closed', 'Store closed'),
('Languages::store_closed_banner', 'Store<br/>closed'),
('Languages::copy_to_other_locations', 'Copy to other locations'),
('Languages::head_custom_html', 'Custom HTML code'),
('Languages::tt_views_block_manager_update_location_head_custom_html', 'This code will be put between the &lt;head&gt;&lt;/head&gt; tags. Use it to specify meta tags or to reference external scripts or styles.'),
('Languages::category_deletion_side_effects', 'This will delete all selected category''s products, as well as its subcategories and their products.'),
('Languages::bulk_category_deletion_side_effects', 'This will delete all selected categories'' products, as well as their subcategories and their products.'),
('Languages::restore_original', 'Restore original'),
('Languages::set_custom_configuration', 'Set custom configuration'),
('Languages::use_default_block_configuration', 'Use default block configuration'),
('Languages::private_files', 'Private files'),
('Languages::public_files', 'Public files'),
('Languages::templates', 'Templates'),
('Languages::payments.realex.referring_url', 'Please supply this URL to your Realex Payments account manager'),
('Languages::payments.globalpayments.referring_url', 'Please supply this URL to your Global Payments account manager'),
('Languages::payments.realex.referring_ip', 'Please supply the IP address of your server to your Realex Payments account manager'),
('Languages::payments.globalpayments.referring_ip', 'Please supply the IP address of your server to your Global Payments account manager'),
('Languages::payments.realex.settlement', 'Settlement'),
('Languages::payments.realex.delayed_settlement', 'Delayed settlement'),
('Languages::payments.realex.auto_settled', 'Auto-settled'),
('Languages::payments.realex.text_status_map', 'Realex to CS-Cart order status conversion map'),
('Languages::payments.globalpayments.text_status_map', 'Global Payments to [product] order status conversion map'),
('Languages::payments.realex.subaccount', 'Subaccount'),
('Languages::payments.realex.liability_shift', 'Liability Shift'),
('Languages::payments.realex.liability_shift_required', 'Liability Shift required'),
('Languages::payments.realex.3d_secure_message', '3-D Secure message'),
('Languages::payments.realex.connector_error', 'Your Realex account has been suspended. Contact Realex support for further information.'),
('Languages::payments.globalpayments.connector_error', 'Your Global Payments account has been suspended. Contact Global Payments support for further information.'),
('Languages::payments.realex.incorrect_request', 'Incorrect XML message formation or content'),
('Languages::payments.realex.realex_error', 'Error with Realex systems'),
('Languages::payments.globalpayments.globalpayments_error', 'Error with Global Payments systems'),
('Languages::payments.realex.bank_error', 'Error with bank systems'),
('Languages::payments.realex.card_lost_or_stolen', 'Card reported lost or stolen'),
('Languages::payments.realex.refferal', 'Referral by bank'),
('Languages::payments.realex.avs_postcode', 'AVS Postcode'),
('Languages::payments.realex.avs_address', 'AVS Address'),
('Languages::payments.realex.tss_result', 'TSS'),
('Languages::payments.realex.eci', 'ECI'),
('Languages::payments.realex.cavv', 'CAVV'),
('Languages::payments.realex.xid', 'XID'),
('Languages::payments.realex.result_message', 'Result message'),
('Languages::payments.realex.result_code', 'Result code'),
('Languages::payments.realex.transaction_pasref', 'Transaction PASREF'),
('Languages::payments.realex.transaction_order_id', 'Transaction Order ID'),
('Languages::payments.realex.avs.matched', 'Matched'),
('Languages::payments.realex.avs.not_matched', 'Not matched'),
('Languages::payments.realex.avs.problem_with_check', 'Problem with check'),
('Languages::payments.realex.avs.unable_to_check', 'Unable to check'),
('Languages::payments.realex.avs.partial_match', 'Partial match'),
('Languages::payments.realex.wrong_card_type', 'This payment is unavailable for this type of credit cards.'),
('Languages::payments.realex.incorrect_valid_trhu', 'Incorrect values of ''Valid thru'' fields.'),
('Languages::use_for_login', 'Login form'),
('Languages::use_for_recover', 'Recover password form'),
('Languages::use_for_register', 'Create and edit profile form'),
('Languages::use_for_checkout', 'Checkout (user information) form'),
('Languages::use_for_track_orders', 'Track my order form'),
('Languages::use_for_track_product_in_stock', 'In-stock notification subscription form'),
('Languages::seo_robots', 'robots.txt'),
('Languages::robots_title', 'Editing: robots.txt'),
('Languages::edit_robots', 'Edit robots.txt'),
('Languages::restore_robots', 'Restore the default robots.txt'),
('Languages::option_exceptions', 'Option exceptions'),
('Languages::horizontal_filters', 'Horizontal filters'),
('Languages::vendor_filters_description', ''),
('Languages::uc_broken_upgrade_connector', 'Upgrade connector [connector_id] returned incorrect data'),
('Languages::uc_downloaded_and_ready', 'Upgrade package has been downloaded and ready to install'),
('Languages::uc_connector_not_found', 'Upgrade connector not found'),
('Languages::uc_unable_to_read_schema', 'Unable to read package schema (schema.json)'),
('Languages::uc_package_schema_not_found', 'Package content schema not found'),
('Languages::uc_package_schema_is_not_json', 'Package schema is not a valid JSON'),
('Languages::uc_addon_package_forbidden_path', 'Forbidden: Add-on tries to upgrade core files ([path])'),
('Languages::uc_addon_package_migrations_forbidden', 'Package contains migrations that were not described in schema or schema has links to missing migration files'),
('Languages::uc_addon_package_languages_forbidden', 'Package contains languages that were not described in schema or schema has links to missing languages files'),
('Languages::uc_addon_package_files_do_not_match_schema', 'Package contains files that were not described in schema or schema has links to missing files'),
('Languages::uc_addon_package_pre_post_scripts_mismatch', 'Package contains pre/post scripts that were not described in schema or schema has links to missing files'),
('Languages::new_version', 'New version'),
('Languages::migrations', 'Migrations'),
('Languages::permissions_issue', 'Permissions issue'),
('Languages::text_uc_local_modification', 'Local modifications'),
('Languages::text_uc_agreed_collisions', 'I understand that my local modifications will be permanently lost during the upgrade'),
('Languages::text_uc_will_be_changed', 'Will be changed'),
('Languages::text_uc_will_be_deleted', 'Will be deleted'),
('Languages::uc_title_validators', 'Upgrade package validators'),
('Languages::uc_execute_validator', 'Execute "[validator]" validator'),
('Languages::uc_copy_files', 'Copy files'),
('Languages::uc_run_migrations', 'Run migrations'),
('Languages::uc_install_languages', 'Install languages'),
('Languages::uc_upgrade_progress', 'Upgrade progress'),
('Languages::upload_upgrade_package', 'Upload upgrade package'),
('Languages::upload_upgrade_text', 'Uploading upgrade package allows you to apply HotFixes or Add-on upgrades. You can upload an upgrade pack by picking a tgz,gz,zip format archive and clicking Upload.'),
('Languages::outside_navigation', 'Outside navigation'),
('Languages::exim_error_incorrect_feature_type', 'Incorrect feature type. Some product features were not updated.'),
('Languages::exim_error_empty_feature_name', 'Feature name is missing. Some product features were not updated.'),
('Languages::unable_to_delete_last_storefront', 'At least one storefront must remain'),
('Languages::datakeeper.run_backup_via_cron_message', 'You can run the backup automatically at certain time intervals. To do it, add the following command to <a href="https://en.wikipedia.org/wiki/Cron" target="_blank">Cron</a>:'),
('Languages::datakeeper.error_unsupported_file_type', 'File cannot be restored. Only .sql, .zip and .tgz files are allowed.'),
('Languages::datakeeper.file_cannot_be_overrided', 'Cannot write to the file <b>[file]</b>. Set the writable permissions manually or check the FTP access to your server in the <a href="[url]">"Upgrade center"</a> section'),
('Languages::uc_restore_email_body', '<p>Your store''s database and files has been backed up before the upgrade. The backup archive includes the whole database and all files except for images. The backup archive has been stored on your server: [backup_file].</p><p>Before the upgrade, your store was closed. Check if it''s running fine after the upgrade and <a href="[settings_section]">open it</a>.</p><p>If something goes wrong during the upgrade, go to your admin panel, <strong>Administration → Backup/Restore</strong>, to restore the backup.</p><p>If you can''t access your admin panel, use the following link to restore the last backup. <b>Important:</b> following this link will immediately launch the restore process. Use it only if you can''t access your admin panel! Restore the last backup:</p>'),
('Languages::uc_backup_info_subj', 'Upgrade Center: Store has been backed up and closed.'),
('Languages::uc_info_subj', 'Upgrade Center: Store has been closed.'),
('Languages::error_features_too_many_variants', 'Search by features is not available due to the excessive number of variants.'),
('Languages::upgraded_on', 'Upgraded on'),
('Languages::error_unable_to_create_thumbnail', 'Unable to create thumbnail for file "[file]": [error]'),
('Languages::cookie_is_disabled', 'For a complete shopping experience, please <a href="https://www.wikihow.com/Enable-Cookies-in-Your-Internet-Web-Browser" target="_blank">set your browser to accept cookies</a>'),
('Languages::uc_restore_email_subject', 'Upgrade center: Store has been backed up and closed.'),
('Languages::warning_zero_price_restricted_product', 'Product <b>"[product]"</b> has not been added to the cart, because it doesn''t have a price.'),
('Languages::exim_vendor_cant_create_feature', 'Vendors cannot create product features and their variants. Some product features cannot be modified.'),
('Languages::uc_migration_failed', 'An error has occured during upgrading database structure (applying migration [migration]).'),
('Languages::text_entered_html_was_sanitized', 'Some <strong>HTML tags</strong> that you have used <strong>were cut off</strong> because of the restrictions on inserting HTML tags such as &lt;object&gt;, &lt;iframe&gt;, &lt;embed&gt; and JavaScript code. That''s why the content that you''ve inserted via these tags will not be displayed.'),
('Languages::text_uc_package_installed_with_errors', 'Errors occurred during the upgrade process. Please contact technical support to investigate the problem.'),
('Languages::error_unable_to_create_backups', 'Unable to create backups.'),
('Languages::seconds_left', '[n] second left|[n] seconds left'),
('Languages::text_uc_timeout_check_success', 'Looks like your server allows to change the "max_execution_time" option from the script. You are good to go with the upgrade process.'),
('Languages::check_php_timeout', 'Check PHP script timeout'),
('Languages::i_agree_continue', 'I agree and continue'),
('Languages::upgrade_center.error_unable_to_prepare_restore', 'Unable to prepare restore script.'),
('Languages::text_cc_javascript_disabled', 'Note! Your browser has the <b>JavaScript</b> disabled. To pay for your order click'),
('Languages::cc_button_submit', 'Proceed to checkout'),
('Languages::payments.rocketgate.avs_mode', 'AVS Mode'),
('Languages::payments.rocketgate.scrub_mode', 'SCRUB Mode'),
('Languages::payments.rocketgate.ignore', 'Ignore'),
('Languages::use_for_free_shipping', 'Use for free shipping'),
('Languages::tt_views_products_components_products_shipping_settings_free_shipping', 'Products with the Free shipping option enabled will be excluded from shipping calculation if shipping method has the Use for free shipping option enabled'),
('Languages::tt_views_shippings_update_use_for_free_shipping', 'Exclude products with the enabled Free shipping option from the shipping price calculation'),
('Languages::tt_views_shippings_update_is_address_required', 'If address isn''t required, CS-Cart will treat this shipping method as "Pick-up".'),
('Languages::trash_category', 'Trash category'),
('Languages::trash_category_description', 'When a product is deleted from the last category in the store, it will be moved to this category.'),
('Languages::products_without_category', 'Products without category'),
('Languages::products_without_category_description', 'When a product is created without a category during import, it will be placed into this category.'),
('Languages::products_without_category_notification_text', 'Some of your products currently don''t have a category. It may be harder for customers to find those products.<br /> <a href="[url]" target="_blank">Please check these products and assign them a category.</a>'),
('Languages::deleting_required_category_notification_text', 'Category "[category]" is required and can''t be deleted.'),
('Languages::upgrade_notification_title', 'Upgrade changes in [product] [version]'),
('Languages::eway_configuration_note', '<a href=''https://go.eway.io/s/article/How-do-I-setup-my-Live-eWAY-API-Key-and-Password'' target=''_blank''>How do I set up my Live eWAY API Key and Password?</a>'),
('Languages::eway_failed_to_pay', 'Failed to pay for the order. Please contact the store administration about this payment method.'),
('Languages::show_more', 'Show more'),
('Languages::show_less', 'Show less'),
('Languages::products_moved_to_trash', '[count] products were moved to <a href=''[url]'' target=''_blank''>Trash category</a>'),
('Languages::products_adopted', '[n] product had a new main category assigned to it.|[n] products had a new main category assigned to them.'),
('Languages::text_uc_addon_upgrade_completed', 'Add-on "[name]" has been upgraded successfully'),
('Languages::change_addons_initialization_description', 'To determine if a certain problem is caused by an add-on, you can disable third-party add-ons or all add-ons. Re-enable them later with one click.'),
('Languages::tools_addons_disable_all', 'Disable all add-ons'),
('Languages::tools_addons_disable_third_party', 'Disable third-party add-ons'),
('Languages::tools_re_enable_add_ons', 'Re-enable add-ons'),
('Languages::tools_addons_installed_count', 'Installed add-ons:'),
('Languages::tools_addons_activated_count', 'Active add-ons:'),
('Languages::tools_addons_core_addons_count', 'Built-in add-ons:'),
('Languages::tools_addons_other_addons_count', 'Third-party add-ons:'),
('Languages::tools_addons_disabled_msg', 'An administrator disabled all add-ons or third-party add-ons.<br> Press the Re-enable add-ons button to initialize the add-ons that were previously active.'),
('Languages::tools_addons_additional_shipping_methods_msg', 'There may be more ways to calculate shipping rates. They''ll show up if you activate the corresponding <a href="[url]">shipping add-ons</a>.'),
('Languages::tools_addons_additional_payment_methods', 'There may be more payment processors. They''ll show up if you activate the corresponding <a href="[url]">payment add-ons</a>.'),
('Languages::tools_addons_additional_themes', 'There may be more themes. They''ll show up if you activate the corresponding <a href="[url]">theme add-ons</a>.'),
('Languages::addons_source', 'Source'),
('Languages::addon_built_in', 'Built-in'),
('Languages::addon_third_party', 'Third-party'),
('Languages::requires_upgrade', 'Requires [product] upgrade'),
('Languages::new_add_on_is_not_compatible_with_your_product', 'The new add-on is not compatible with your current version of [product]. To upgrade the add-on to the latest version, please upgrade [product] to version [version].'),
('Languages::upgrade_and_update_addon', 'Upgrade [product] and upgrade the add-on'),
('Languages::addons.upgrade_to_version', 'Upgrade to [version]'),
('Languages::addons.search_description', 'Search by add-on name, description, developer, and add-on ID.'),
('Languages::addons.show_review', 'Show review'),
('Languages::addons.show_all_reviews', 'Show all reviews'),
('Languages::addons.hide_all_reviews', 'Hide all reviews'),
('Languages::addons.show_n_reviews', 'Show [n] review|Show [n] reviews'),
('Languages::addons.n_reviews', 'review|reviews'),
('Languages::addons.out_of_five', 'out of 5'),
('Languages::addons.tap_star_to_rate_on_marketplace', 'Tap a star to rate it on the CS-Cart Marketplace.'),
('Languages::addons.write_review', 'Write a review'),
('Languages::addons.no_reviews', 'No reviews'),
('Languages::addons.stars', 'stars'),
('Languages::addons.and_half_stars', 'and a half stars'),
('Languages::n_stars', '[n] star|[n] stars'),
('Languages::addons.message', 'Message'),
('Languages::addons.name', 'Add-on name'),
('Languages::addons.support', 'Support'),
('Languages::addons.website', 'Website'),
('Languages::addons.documentation', 'Documentation'),
('Languages::addons.forum', 'Forum'),
('Languages::addons.forum_en', 'Forum (EN)'),
('Languages::addons.forum_ru', 'Forum (RU)'),
('Languages::addons.get_support', 'Get support'),
('Languages::addons.no_changelog', 'No changelog'),
('Languages::addons.no_information', 'No information'),
('Languages::subcategories_tree_cat', 'Subcategories tree'),
('Languages::settings_overwrite_title', 'The theme overwrites store settings'),
('Languages::settings_overwrite_text', '<b>[theme_name]</b> will set following settings on activation'),
('Languages::overwrite', 'Overwrite'),
('Languages::upgrade_center.skip_backup', 'Skip files and database backup'),
('Languages::uc_open_store_email_body', '<p>Before the upgrade, your store was closed. Check if it''s running fine after the upgrade and <a href="[settings_section]">open it</a>.</p>'),
('Languages::upgrade_notification_message', '<p class=''upgrade-center_notice-msg''>Copy of this message was sent to administrator''s email.</p><hr>'),
('Languages::http_transport_error_prefix_curl', 'Curl Error'),
('Languages::http_transport_error_prefix_socket', 'Socket Error'),
('Languages::curl_error_code_reference_link', 'To learn what caused the Curl error, look for your error number in <a target="_blank" href="[href]">this article</a>.'),
('Languages::n_days', '[n] day|[n] days'),
('Languages::track_on_carrier_site', 'Track on website'),
('Languages::unable_to_create_status', 'Couldn''t create a new status'),
('Languages::maximum_number_of_statuses_reached', 'You have reached the maximum number of statuses'),
('Languages::curl_error_description_curle_ssl_invalidcertstatus', 'Status returned failure when asked with CURLOPT_SSL_VERIFYSTATUS.'),
('Languages::error_unknown_archive_format', 'Unknown archive format: [ext]'),
('Languages::error_file_not_found', 'File "[file]" not found.'),
('Languages::error_file_already_exists', 'File "[file]" already exists.'),
('Languages::local_modifications', 'Local modifications'),
('Languages::local_modifications_message', 'These files had local modifications. During the upgrade a backup archive was created in the <strong>[dir]</strong> directory. You may want to check these files in the archive and reapply the modifications to your store.'),
('Languages::not_checked', 'Not checked'),
('Languages::checked', 'Checked'),
('Languages::error_filter_by_feature_exists', 'Filter by feature "[name]" already exists.'),
('Languages::error_filter_by_product_field_exists', 'Filter by product field "[name]" already exists.'),
('Languages::shipping_address_changed', 'Shipping address has been changed'),
('Languages::theme_editor_not_supported', 'This theme doesn''t support theme editor'),
('Languages::shipment_statuses', 'Shipment statuses'),
('Languages::email_templates', 'Email templates'),
('Languages::editing_email_template', 'Editing email template'),
('Languages::customer_notifications', 'Customer notifications'),
('Languages::admin_notifications', 'Administrator notifications'),
('Languages::subject', 'Subject'),
('Languages::variables', 'Variables'),
('Languages::snippets', 'Snippets'),
('Languages::code_snippets', 'Code snippets'),
('Languages::editing_email_snippet', 'Editing snippet'),
('Languages::editing_snippet', 'Editing snippet'),
('Languages::snippet_exists', 'The snippet with the chosen code already exists, please try another.'),
('Languages::document_exists', 'The document with the chosen code already exists, please try another.'),
('Languages::email_template_exists', 'The email template with the chosen code already exists, please try another.'),
('Languages::need_snippet_name', 'You have to specify valid snippet name'),
('Languages::snippets_have_been_deleted', 'Snippets have been deleted successfully.'),
('Languages::add_email_snippet', 'Add snippet'),
('Languages::add_snippet', 'Add snippet'),
('Languages::editing_document', 'Editing [name]'),
('Languages::product_info', 'Product info'),
('Languages::add_table_column', 'Add column'),
('Languages::editing_table_column', 'Editing column'),
('Languages::table_column_has_been_deleted', 'Product column has been deleted successfully.'),
('Languages::restore_default_value', 'Restore default value'),
('Languages::send_test_email', 'Send test email'),
('Languages::text_test_email_sent', 'Test email was sent to <b>[email]</b> address.'),
('Languages::editing_global_vars', 'Editing global variables'),
('Languages::global_vars', 'Global variables'),
('Languages::change_order_status_p_subj', 'Order #[order] has been processed'),
('Languages::change_order_status_p_text', 'Your order has been processed successfully.'),
('Languages::change_order_status_c_subj', 'Order #[order] has been completed'),
('Languages::change_order_status_c_text', 'Your order has been completed. Thank you for choosing us.'),
('Languages::change_order_status_o_subj', 'Order #[order] has been placed successfully'),
('Languages::change_order_status_o_text', 'Thank you for the order. You are welcome to come back!'),
('Languages::change_order_status_f_subj', 'Order #[order] failed'),
('Languages::change_order_status_f_text', 'Your order has been unsuccessful. Please contact shop administration.'),
('Languages::change_order_status_d_subj', 'Order #[order] has been declined'),
('Languages::change_order_status_d_text', 'Your order has been declined. Please contact shop administration.'),
('Languages::change_order_status_b_subj', 'Order #[order] has been backordered'),
('Languages::change_order_status_b_text', 'Your order has been backordered.'),
('Languages::change_order_status_i_subj', 'Order #[order] has been canceled'),
('Languages::change_order_status_i_text', 'Your order has been canceled. Please contact shop administration.'),
('Languages::change_order_status_default_subj', 'The status of order #[order] has been changed to [status]'),
('Languages::change_order_status_default_text', 'The status of your order has been changed to [status].'),
('Languages::email_template.activate_profile', 'User profile requires activation'),
('Languages::email_template.back_in_stock_notification', 'Back in stock notification'),
('Languages::email_template.create_profile', 'User profile creation'),
('Languages::email_template.edp_access', 'Orders: access to downloadable products'),
('Languages::email_template.give_coupon', 'Promotions: coupon'),
('Languages::email_template.low_stock', 'Product low stock notification'),
('Languages::email_template.order_notification', 'Order notification: [name]'),
('Languages::email_template.order_notification_default', 'Order notification: Default template for a new order status'),
('Languages::email_template.profile_activated', 'User account activation'),
('Languages::email_template.recover_password', 'Password recovery'),
('Languages::email_template.reminder', 'Admin password expiration'),
('Languages::email_template.shipment_products', 'Orders: products shipped'),
('Languages::email_template.track', 'Orders: tracking'),
('Languages::email_template.update_profile', 'User profile update'),
('Languages::email_template.usergroup_activation', 'User group activation'),
('Languages::email_template.usergroup_disactivation', 'User group disactivation'),
('Languages::email_template.usergroup_request', 'User group request'),
('Languages::email_template.upgrade_backup_info', 'Upgrade: restore link'),
('Languages::email_template.params.attach_order_document', 'Attach a PDF document'),
('Languages::edit_customer_notification', 'Edit the email sent to customers'),
('Languages::edit_admin_notification', 'Edit the email sent to administrators'),
('Languages::copy', 'Copy'),
('Languages::copied', 'Copied'),
('Languages::addon_uninstall_sql_error', 'An error in an SQL query occurred during the add-on uninstallation.'),
('Languages::payments.qbms.quickbooks_connection', 'QuickBooks Connection'),
('Languages::payments.qbms.configuration_required', '<p>Fill in the fields below and save the changes:<br>- App Token<br>- OAuth Consumer Key<br> - OAuth Consumer Secret</p><p>Click "Connect to QuickBooks" button that will appear instead of this message to finish payment configuration.</p>'),
('Languages::payments.qbms.app_token', 'App Token'),
('Languages::payments.qbms.oauth_consumer_key', 'OAuth Consumer Key'),
('Languages::payments.qbms.oauth_consumer_secret', 'OAuth Consumer Secret'),
('Languages::payments.qbms.oauth_client_id', 'OAuth Client Id'),
('Languages::payments.qbms.oauth_client_secret', 'OAuth Client Secret'),
('Languages::payments.qbms.token_expires', 'The token expires on <b>[date]</b> at <b>[time]</b>.'),
('Languages::payments.qbms.token_expired', 'The token has expired.'),
('Languages::payments.qbms.renew_token', 'Press "Connect to QuickBooks" to renew the token.'),
('Languages::payments.qbms.tip_fill_redirect', '<p>- In the QuickBooks application, copy the following value into the Redirect URI field:</p><p>[url]</p><p>- Click the "Connect to QuickBooks" button.</p>'),
('Languages::payments.qbms.configure_payment_method', '<p>How to configure the payment method:</p><p>1. <a target="_blank" href="https://developer.intuit.com/app/developer/qbo/docs/develop/authentication-and-authorization/oauth-2.0#obtain-oauth2-credentials-for-your-app">Obtain OAuth 2.0</a> credentials from <b>QuickBooks Online</b> application (QuickBooks Desktop won''t work).</p><p>2. Copy them to the payment method settings in [product].</p><p>3. Click "Create", then open the settings of this payment method again to finish its configuration.</p>'),
('Languages::text_money_back_guarantee', 'We offer 30-day money-back guarantee. If you don''t like our product, we''ll return you the money, no needless questions asked.'),
('Languages::admin_panel_will_be_blocked', 'Installation integrity check failed. The access to the Administration panel will be blocked within 2 days. Please contact our <a href="[href]">support team</a>'),
('Languages::text_license_is_disabled', 'The license is disabled. Please check your license status.'),
('Languages::text_license_is_invalid', 'Invalid license number. Please enter a valid license number.'),
('Languages::text_license_is_disabled_full', 'The license is disabled. Please check your license status or select a different store mode.'),
('Languages::text_license_is_invalid_full', 'Invalid license number. Please enter a valid license number or select a different store mode.'),
('Languages::shipping_tips', ''),
('Languages::error_directory_not_writable', 'Directory "[dir]" is not writable. Please check permissions for this directory of your installation.'),
('Languages::error_cannot_delete_files', 'Cannot delete files: <b>[files]</b>. Please check the permissions.'),
('Languages::feature_groups', 'Feature groups'),
('Languages::shippings.can.business_account_information', 'Business account information'),
('Languages::shippings.can.customer_number', 'Customer number'),
('Languages::ttc_shippings.can.customer_number', 'Customer number is required for commercial customers and Solutions for Small Business members to get discounted rates if parcel is mailed on behalf of customer'),
('Languages::shippings.can.contract_id', 'Contract ID'),
('Languages::ttc_shippings.can.contract_id', 'Contract ID is required to obtain discounted rates for commercial customers when the Customer number is specified. Contract ID must be omitted for Solutions for Small Business members or general business users'),
('Languages::shippings.can.api_keys', 'API keys'),
('Languages::shippings.can.username', 'Username'),
('Languages::shippings.can.password', 'Password'),
('Languages::shippings.can.options', 'Delivery options'),
('Languages::shippings.can.option_so', 'Signature'),
('Languages::shippings.can.option_cov', 'Coverage'),
('Languages::ttc_shippings.can.option_cov', 'Requires amount'),
('Languages::shippings.can.option_cov_amount', 'Coverage amount'),
('Languages::shippings.can.option_cod', 'Collect on Delivery'),
('Languages::shippings.can.option_pa18', 'Proof of Age Required - 18'),
('Languages::shippings.can.option_pa19', 'Proof of Age Required - 19'),
('Languages::shippings.can.option_hfp', 'Card for pickup'),
('Languages::shippings.can.option_dns', 'Do not safe drop'),
('Languages::shippings.can.option_lad', 'Leave at door - do not card'),
('Languages::shippings.aup.pac_api_key', 'PAC API key'),
('Languages::shippings.aup.currency_not_configured', 'To activate the Australia Post shipping processor, you must have the Australian Dollar currency enabled.'),
('Languages::licensing_and_upgrades', 'Licensing and upgrades'),
('Languages::addon_license_key_tooltip', 'Enter license key you''ve received by e-mail in order to receive the add-on upgrades.'),
('Languages::api_shipments_update_not_allowed', 'Only tracking_number, status, comments and timestamp can be updated'),
('Languages::api_shipments_status_not_correct', 'Value of status field is not correct. Allowed values: ''A'', ''P'', ''S'''),
('Languages::cannot_remove_theme_has_dependent_themes', 'The theme can''t be removed as the following themes depend on it: [dependent_themes]'),
('Languages::text_installing_theme_dependencies', 'Installing the theme dependencies: [dependencies]'),
('Languages::text_unable_to_install_theme_dependencies', 'Unable to install the theme dependencies: [dependencies]'),
('Languages::exim_cannot_create_variant_for_shareable_feature', 'You cannot create a variant for a shareable feature.'),
('Languages::warning_default_language_sharing_removed', 'The default language defined in settings has been removed for the <b>[company]</b> storefront. Please update the Frontend default language value on the following page: <a href="[link]">Settings :: Appearance</a>'),
('Languages::warning_default_currency_absent', 'Could not assign default currency for the <b>[storefront]</b> storefront. Please update the default currency value on the following page: <a href="[link]">Administration :: Currencies</a>'),
('Languages::page_url', 'Page URL'),
('Languages::tt_views_pages_components_pages_link_page_url', 'The page inner URL'),
('Languages::page_target_url', 'Target URL'),
('Languages::tt_views_pages_components_pages_link_page_target_url', 'The URL to redirect customers to'),
('Languages::shippings.fedex.freight_account_number', 'Freight account number'),
('Languages::ship_fedex_package_type_fedex_extra_large_box', 'FedEx Extra Large Box'),
('Languages::ship_fedex_package_type_fedex_large_box', 'FedEx Large Box'),
('Languages::ship_fedex_package_type_fedex_medium_box', 'FedEx Medium Box'),
('Languages::ship_fedex_package_type_fedex_small_box', 'FedEx Small Box'),
('Languages::ship_fedex_drop_off_type_business_service_center', 'Business service center'),
('Languages::ship_fedex_drop_off_type_drop_box', 'Drop box'),
('Languages::shippings.fedex.options', 'Delivery options'),
('Languages::shippings.fedex.option_broker_select_option', 'Broker select option'),
('Languages::shippings.fedex.option_call_before_delivery', 'Call before delivery'),
('Languages::shippings.fedex.option_cod', 'COD'),
('Languages::shippings.fedex.option_cod_amount', 'COD amount'),
('Languages::shippings.fedex.option_cod_collection_type', 'COD collection type'),
('Languages::shippings.fedex.option_cod_collection_type_any', 'Any'),
('Languages::shippings.fedex.option_cod_collection_type_cash', 'Cash'),
('Languages::shippings.fedex.option_cod_collection_type_guaranteed_funds', 'Guaranteed funds'),
('Languages::shippings.fedex.option_custom_delivery_window', 'Custom delivery window'),
('Languages::shippings.fedex.option_dangerous_goods', 'Dangerous goods'),
('Languages::shippings.fedex.option_dangerous_goods_options', 'Hazardous content options'),
('Languages::shippings.fedex.option_dangerous_goods_options_battery', 'Battery'),
('Languages::shippings.fedex.option_dangerous_goods_options_hazardous_materials', 'Hazardous materials'),
('Languages::shippings.fedex.option_dangerous_goods_options_orm_d', 'ORM-D'),
('Languages::shippings.fedex.option_dangerous_goods_options_limited_quantities_commodities', 'Limited quantities commodities'),
('Languages::shippings.fedex.option_dangerous_goods_options_reportable_quantities', 'Reportable quantities'),
('Languages::shippings.fedex.option_dangerous_goods_options_small_quantity_exception', 'Small quantity exception'),
('Languages::shippings.fedex.option_dangerous_goods_accessibility', 'Dangerous goods accessibility'),
('Languages::shippings.fedex.option_dangerous_goods_accessibility_accessible', 'Accessible'),
('Languages::shippings.fedex.option_dangerous_goods_accessibility_inaccessible', 'Inaccessible'),
('Languages::shippings.fedex.option_do_not_break_down_pallets', 'Do not break down pallets'),
('Languages::shippings.fedex.option_do_not_stack_pallets', 'Do not stack pallets'),
('Languages::shippings.fedex.option_dry_ice', 'Dry ice'),
('Languages::shippings.fedex.option_east_coast_special', 'East Coast special'),
('Languages::shippings.fedex.option_electronic_trade_documents', 'Electronic trade documents'),
('Languages::shippings.fedex.option_extreme_length', 'Extreme length'),
('Languages::shippings.fedex.option_food', 'Food'),
('Languages::shippings.fedex.option_fedex_one_rate', 'FedEx One Rate'),
('Languages::shippings.fedex.option_freight_guarantee', 'Freight guarantee'),
('Languages::shippings.fedex.option_freight_to_collect', 'Freight to collect'),
('Languages::shippings.fedex.option_future_day_shipment', 'Future day shipment'),
('Languages::shippings.fedex.option_hold_at_location', 'Hold at location'),
('Languages::shippings.fedex.option_home_delivery_premium', 'Home delivery Premium'),
('Languages::shippings.fedex.option_inside_delivery', 'Inside delivery'),
('Languages::shippings.fedex.option_inside_pickup', 'Inside pickup'),
('Languages::shippings.fedex.option_international_controlled_export_service', 'International controlled export service'),
('Languages::shippings.fedex.option_international_traffic_in_arms_regulations', 'International traffic in arms regulations'),
('Languages::shippings.fedex.option_liftgate_delivery', 'Liftgate delivery'),
('Languages::shippings.fedex.option_liftgate_pickup', 'Liftgate pickup'),
('Languages::shippings.fedex.option_limited_access_delivery', 'Limited access delivery'),
('Languages::shippings.fedex.option_limited_access_pickup', 'Limited access pickup'),
('Languages::shippings.fedex.option_pharmacy_delivery', 'Pharmacy delivery'),
('Languages::shippings.fedex.option_poison', 'Poison'),
('Languages::shippings.fedex.option_protection_from_freezing', 'Protection from freezing'),
('Languages::shippings.fedex.option_returns_clearance', 'Returns clearance'),
('Languages::shippings.fedex.option_saturday_delivery', 'Saturday delivery'),
('Languages::shippings.fedex.option_saturday_pickup', 'Saturday pickup'),
('Languages::shippings.fedex.option_top_load', 'Top load'),
('Languages::template_document_order_invoice', 'Invoice'),
('Languages::template_document_order_summary', 'Order summary'),
('Languages::template_document_packing_slip_default', 'Packing slip'),
('Languages::documents', 'Documents'),
('Languages::document_preview_order_not_found', 'Couldn''t find an order. Preview only works with existing data. Please create an order and use Preview again.'),
('Languages::editing_order_invoice', 'Editing invoice for order #[order_id]'),
('Languages::email_order_invoice_subject', '[company_name]: Invoice for order #[order_id]'),
('Languages::edit_and_send_invoice', 'Tweak and send invoice'),
('Languages::error_profile_field_name_exists', 'A profile field with this name already exists. Please choose another name.'),
('Languages::profile_field_name', 'Field name'),
('Languages::profile_field_name_tooltip', 'A character sequence that serves as an identifier. You can use figures from 0 to 9, symbols of the English alphabet and "_" sign.'),
('Languages::text_character_identifier_tooltip', 'A character sequence that serves as an identifier. You can use figures from 0 to 9, symbols of the English alphabet and the following signs: "-", "_", ".".'),
('Languages::core_files_have_been_modified', 'Some of your <a href="[changes_url]">core files</a>  were changed manually. That can lead to various problems, especially when upgrading to a new version of [product]. To learn more about why we advise against changing the core files, please read this <a href="[docs_url]" target="_blank" >article</a>.<br><br>[product] automatically checks for changes in core files every time you log in. To disable this check, go to <a href="[settings_url]">Settings → General</a>  and untick the Monitor changes in core files checkbox.'),
('Languages::scan_for_modified_core_files', 'Scan for changed core files'),
('Languages::last_scan_time', 'Last scan time'),
('Languages::no_modified_core_files_found', 'No changed core files found'),
('Languages::modified_core_files_found', 'Some of your core files have been changed. This may become a problem when upgrading [product] as changes in these files may be lost.'),
('Languages::file_changes_detector', 'File changes detector'),
('Languages::privileges.view_file_changes', 'Can view'),
('Languages::error_shipment_not_created', 'Couldn''t create a shipment. Please choose a carrier or enter a tracking number.'),
('Languages::my_cart', 'My cart'),
('Languages::exclusive_promotions', 'Exclusive discounts'),
('Languages::exclusive_promotions_content', 'Subscribe to our news and get a 10% discount coupon!'),
('Languages::tmpl_subscription_advanced', 'Subscription advanced form'),
('Languages::tmpl_newsletters_subscription_advanced', 'Newsletters: subscription advanced form'),
('Languages::tmpl_payment_icons_rus', 'Payment systems russian icons'),
('Languages::my_account_links_advanced', 'My account advanced'),
('Languages::api_access_has_been_enabled', 'You are free to use the API now'),
('Languages::api_access_has_been_disabled', 'From now on, you cannot use the API'),
('Languages::report_a_bug', 'Report a bug'),
('Languages::import_results', 'Import results'),
('Languages::import_errors', 'Import errors'),
('Languages::email_template_import_success_msg', 'All the email templates have been imported without errors.'),
('Languages::document_import_success_msg', 'All the documents have been imported without errors.'),
('Languages::count_document_successfully_imported', 'Documents successfully imported:'),
('Languages::count_email_template_successfully_imported', 'Email templates successfully imported:'),
('Languages::count_snippet_successfully_imported', 'Snippets successfully imported:'),
('Languages::count_document_fail_imported', 'Documents import failed:'),
('Languages::count_email_template_fail_imported', 'Email templates import failed:'),
('Languages::count_snippet_fail_imported', 'Snippets import failed:'),
('Languages::storefronts_limit_exceeded', 'The number of storefronts in your CS-Cart License has exceeded the number of purchased storefront licenses.'),
('Languages::licensed_product', 'Licensed product'),
('Languages::store_mode.free', 'Free'),
('Languages::store_mode.ultimate', 'Ultimate'),
('Languages::store_mode.enterprise', 'Enterprise'),
('Languages::product_state_description.ult.new', '<p>You can use one of these licenses: <a href="[standard_license_url]" target="_blank">[product]</a> or <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>. Both licenses allow you to use [product] without time restrictions.</p><br>'),
('Languages::product_state_description.ult', '<p>You can use the software without time restrictions now. Please note that some advanced features are available only in <a href="[ultimate_license_url]" target="_blank">[product] Ultimate.</a></p><br>'),
('Languages::product_state_description.ult.ultimate', '<p>You can use the software without time restrictions now.</p><br>'),
('Languages::product_state_description.ult.enterprise', '<p>You can use the software without time restrictions now.</p><br>'),
('Languages::product_state_description.ult.ru.new', '<p>You can use one of these licenses: <a href="[standard_license_url]" target="_blank">[product]</a> or <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>. Both licenses allow you to use [product] without time restrictions.</p><br>'),
('Languages::product_state_description.ult.ru', '<p>You can use the software without time restrictions now. Please note that some advanced features are available only in <a href="[ultimate_license_url]" target="_blank">[product] Ultimate.</a></p><br>'),
('Languages::product_state_description.ult.ru.ultimate', '<p>You can use the software without time restrictions now.</p><br>'),
('Languages::product_state_description.ult.ru.enterprise', '<p>You can use the software without time restrictions now.</p><br>'),
('Languages::product_state_description.ult.b2b.new', '<p>You can use one of these licenses: <a href="[standard_license_url]" target="_blank">[product]</a> or <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>. Both licenses allow you to use [product] without time restrictions.</p><br>'),
('Languages::product_state_description.ult.b2b', '<p>You can use the software without time restrictions now. Please note that some advanced features are available only in <a href="[ultimate_license_url]" target="_blank">[product] Ultimate.</a></p><br>'),
('Languages::product_state_description.ult.b2b.ultimate', '<p>You can use the software without time restrictions now.</p><br>'),
('Languages::product_state_description.ult.b2b.enterprise', '<p>You can use the software without time restrictions now.</p><br>'),
('Languages::text_store_mode_changed_to_ult.free', 'Your store now uses an active license of [product].'),
('Languages::text_store_mode_changed_to_ult.free_ru', 'Your store now uses an active license of [product].'),
('Languages::text_store_mode_changed_to_ult', 'Your store now uses an active license of [product].'),
('Languages::text_store_mode_changed_to_ult.ultimate', 'Your store now uses an active license of [product].'),
('Languages::text_store_mode_changed_to_ult.enterprise', 'Your store now uses an active license of [product].'),
('Languages::text_store_mode_changed_to_ult.ru', 'Your store now uses an active license of [product].'),
('Languages::text_store_mode_changed_to_ult.ru.ultimate', 'Your store now uses an active license of [product].'),
('Languages::text_store_mode_changed_to_ult.ru.enterprise', 'Your store now uses an active license of [product].'),
('Languages::text_store_mode_changed_to_ult.b2b', 'Your store now uses an active license of [product].'),
('Languages::text_store_mode_changed_to_ult.b2b.ultimate', 'Your store now uses an active license of [product].'),
('Languages::text_store_mode_changed_to_ult.b2b.enterprise', 'Your store now uses an active license of [product].'),
('Languages::ultimate_license', '[product] Ultimate'),
('Languages::ultimate_license_required', '[product] Ultimate is required for this'),
('Languages::ultimate_or_storefront_license_required', 'This action requires [product] Ultimate'),
('Languages::ultimate_or_storefront_license_required.ult.new', 'This action requires [product] Ultimate'),
('Languages::ultimate_or_storefront_license_required.ult', 'This action requires [product] Ultimate'),
('Languages::ultimate_or_storefront_license_required.ult.ultimate', 'This action requires [product] Ultimate'),
('Languages::ultimate_or_storefront_license_required.ult.b2b.new', 'This action requires [product] Ultimate');
INSERT INTO `[[dbprefix]]original_values` VALUES
('Languages::ultimate_or_storefront_license_required.ult.b2b', 'This action requires [product] Ultimate'),
('Languages::ultimate_or_storefront_license_required.ult.b2b.ultimate', 'This action requires [product] Ultimate'),
('Languages::ultimate_or_storefront_license_required.ult.ru.new', 'This action requires [product] Ultimate'),
('Languages::ultimate_or_storefront_license_required.ult.ru', 'This action requires [product] Ultimate'),
('Languages::ultimate_or_storefront_license_required.ult.ru.ultimate', 'This action requires [product] Ultimate'),
('Languages::max_storefronts_reached', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::max_storefronts_reached.ult.new', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::max_storefronts_reached.ult', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::max_storefronts_reached.ult.ultimate', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::max_storefronts_reached.ult.b2b.new', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::max_storefronts_reached.ult.b2b', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::max_storefronts_reached.ult.b2b.ultimate', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::max_storefronts_reached.ult.ru.new', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::max_storefronts_reached.ult.ru', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::max_storefronts_reached.ult.ru.ultimate', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::new_text_ultimate_license_required', 'A special edition of [product] that offers an unlimited number of storefronts. If you switch to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>, you''ll never see the message about the storefront limit again.'),
('Languages::text_only_ultimate_license_required', 'A special edition called [product] Ultimate is required to perform this action. If you switch to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>, you''ll never see this message again, and you''ll also be able to create an unlimited number of storefronts.'),
('Languages::text_storefront_license_required', 'An additional storefront for your standard [product] license. Good for those who don''t intend to add a few more storefronts in the future.'),
('Languages::available_upgrades', 'Available upgrades'),
('Languages::additional_storefront_license_required', 'Additional [product] Storefront License Required'),
('Languages::text_additional_storefront_license_required', '<p>You can''t add a new storefront. The maximum number of storefronts allowed by your current license <code>[license_number]</code> is [allowed_storefronts], and you currently have [existing_storefronts].</p><p>To be able to add another storefront, please buy additional [product] Storefront License. If you want to add multiple new storefronts, buy the corresponding number of licenses.</p>'),
('Languages::storefront_license', 'Storefront License'),
('Languages::buy_new_storefront_license', 'Buy [product] Storefront License'),
('Languages::import_new_vendor', '[n] new vendor was created during the import. This vendor only has a name so far. Please edit the new vendor to add other information.|[n] new vendors were created during the import. These vendors only have names so far. Please edit the new vendors to add other information.'),
('Languages::file_changes_detector.snapshot_not_found', 'Snapshot of the clear installation was not found. Please restore <b>[dist_filename]</b>.'),
('Languages::file_changes_detector.added', 'Added'),
('Languages::file_changes_detector.changed', 'Changed'),
('Languages::file_changes_detector.deleted', 'Deleted'),
('Languages::licensing.license_error_license_is_disabled', 'The license is disabled. Please check your license status.'),
('Languages::licensing.license_error_license_is_disabled.title', 'Your [product] license has been disabled'),
('Languages::licensing.license_error_license_is_disabled.text', 'Please contact us <a href="[helpdesk_url]" target="_blank">via Customer Help Desk</a> to find out why it happened and what can be done about it. To access the admin panel right now, you can enter another valid license number, as long as it isn''t used in another store:'),
('Languages::licensing.license_error_license_is_invalid', 'Invalid license number. Please enter a valid license number.'),
('Languages::licensing.license_error_wrong_edition', 'The license does not match your store edition. Please enter a valid license number.'),
('Languages::licensing.license_error_wrong_licensing_mode', 'The license does not match your store licensing mode. Please enter a valid license number.'),
('Languages::upgrade_center.upgrade_process_failed', 'Upgrade process of your store has failed'),
('Languages::upgrade_center.apply_migration_failed', '<p>Please restore the pre-upgrade backup manually or via a link sent to your email address, then contact our technical support.</p><br><p>Tech details: Couldn''t complete migration [migration]. Reason: [error].</p><p>Completed migrations: [processed_count] out of [total_count].</p>'),
('Languages::profile_deactivated', 'Account deactivated'),
('Languages::text_profile_deactivated', 'Your account has been deactivated. Please contact us for more details.'),
('Languages::email_template.profile_deactivated', 'User account deactivation'),
('Languages::text_addon_disable_dependencies', 'The add-on cannot be disabled because the following add-ons depend on it: [addons]'),
('Languages::text_addon_enable_dependencies', 'The add-on cannot be enabled because it depends on the following add-ons: [addons]'),
('Languages::current_setting_value', 'Current value'),
('Languages::new_setting_value', 'New value'),
('Languages::overwrite_selected_settings', 'Overwrite selected settings'),
('Languages::payment_method_not_found', 'Payment method not found. It could''ve been disabled, or a technical problem occurred. Please choose a payment method and try again.'),
('Languages::shippings.ups.package_type.00', 'UNKNOWN'),
('Languages::shippings.ups.package_type.01', 'UPS Letter'),
('Languages::shippings.ups.package_type.02', 'Package'),
('Languages::shippings.ups.package_type.03', 'Tube'),
('Languages::shippings.ups.package_type.04', 'Pak'),
('Languages::shippings.ups.package_type.21', 'Express Box'),
('Languages::shippings.ups.package_type.24', '25KG Box'),
('Languages::shippings.ups.package_type.25', '10KG Box'),
('Languages::shippings.ups.package_type.30', 'Pallet'),
('Languages::shippings.ups.package_type.2a', 'Small Express Box'),
('Languages::shippings.ups.package_type.2b', 'Medium Express Box'),
('Languages::shippings.ups.package_type.2c', 'Large Express Box'),
('Languages::wrong_number_initial_order_id', 'The value you entered for the "Initial order ID value" setting is not supported. Only integers from 1 to [max_initial_order_id] are supported'),
('Languages::tt_views_shippings_components_services_ups_ship_ups_pickup_type', '<p>Select "Daily Pickup" to calculate the delivery cost according to Daily Rates.</p><p>Select "One Time Pickup", "Letter Center", or "Air Service Center" to calculate the delivery cost according to Retail Rates.</p>'),
('Languages::php_extension_missing', 'The [extension] PHP extension is not installed on your server'),
('Languages::customization', 'Customization'),
('Languages::assign_to_me', 'Assign to me'),
('Languages::customer_phone', 'Customer phone'),
('Languages::could_not_connect_to_database', 'Could not connect to database'),
('Languages::information_file_roobots', 'A robots.txt file was detected. The changes you make here won''t take effect until you delete the existing <b>robots.txt</b> file from the root directory of your store.'),
('Languages::advanced_products_search', 'Advanced products search'),
('Languages::advanced_companies_search', 'Advanced companies search'),
('Languages::advanced_storefronts_search', 'Advanced storefronts search'),
('Languages::api_wrong_user_company_relation', 'The user doesn''t exist for this store, and sharing users among stores is disabled.'),
('Languages::product_details_tabs', 'Tabs'),
('Languages::shippings.fedex.currency_is_missing', 'The rates calculated by FedEx are in [currency], and that currency doesn''t exist in your store. Please create that currency; otherwise customers won''t be able to select this shipping method.'),
('Languages::text_redactor2', 'Redactor II'),
('Languages::image_url', 'Image URL'),
('Languages::insert_image', 'Insert image'),
('Languages::view_avail_files_for_order', 'View the list of available files from order #[order_id].'),
('Languages::advanced_customer_search', 'Advanced customer search'),
('Languages::change_customer', 'Change customer'),
('Languages::on_backorder', 'On backorder'),
('Languages::invoice_heading', 'Invoice'),
('Languages::min_quantity', 'Minimum order quantity'),
('Languages::ship_downloadable', 'Enable shipping for downloadable products'),
('Languages::inventory_tracking', 'Inventory'),
('Languages::detailed_image', 'Detailed image'),
('Languages::secondary_categories', 'Secondary category'),
('Languages::override_points', 'Override points'),
('Languages::override_exchange_rate', 'Override exchange rate'),
('Languages::max_quantity', 'Maximum order quantity'),
('Languages::list_qty_count', 'List quantity count'),
('Languages::product_url', 'Product URL'),
('Languages::detailed_image_url', 'Detailed image URL'),
('Languages::box_size', 'Box size'),
('Languages::usergroup_ids', 'Usergroup ids'),
('Languages::combination_code', 'Combination code'),
('Languages::pair_type', 'Pair type'),
('Languages::lower_limit', 'Lower limit'),
('Languages::user_group', 'User group'),
('Languages::percentage_discount', 'Percentage discount'),
('Languages::feature_name', 'Feature name'),
('Languages::feature_id', 'Feature ID'),
('Languages::show_on_the_features_tab', 'Show on the features tab'),
('Languages::show_in_product_list', 'Show in product list'),
('Languages::show_in_product_header', 'Show in product header'),
('Languages::comparsion', 'Comparison'),
('Languages::variant_id', 'Variant ID'),
('Languages::feature_group', 'Feature group'),
('Languages::payment_id', 'Payment ID'),
('Languages::billing_first_name', 'Billing: first name'),
('Languages::billing_last_name', 'Billing: last name'),
('Languages::billing_address_line_2', 'Billing: address (line 2)'),
('Languages::billing_city', 'Billing: city'),
('Languages::billing_state', 'Billing: state'),
('Languages::billing_country', 'Billing: country'),
('Languages::billing_zipcode', 'Billing: zipcode'),
('Languages::shipping_first_name', 'Shipping: first name'),
('Languages::shipping_last_name', 'Shipping: last name'),
('Languages::shipping_address_line_2', 'Shipping: address (line 2)'),
('Languages::shipping_city', 'Shipping: city'),
('Languages::shipping_state', 'Shipping: state'),
('Languages::shipping_country', 'Shipping: country'),
('Languages::shipping_zipcode', 'Shipping: zipcode'),
('Languages::item_id', 'Item ID'),
('Languages::issuer_id', 'Issuer ID'),
('Languages::billing_phone', 'Billing: phone'),
('Languages::shipping_phone', 'Shipping: phone'),
('Languages::extra_fields', 'Extra fields'),
('Languages::country_code', 'Country code'),
('Languages::salt', 'Salt'),
('Languages::user_group_ids', 'User group IDs'),
('Languages::skip_creating_new_products', 'Skip creating new products'),
('Languages::text_skip_creating_new_products', 'If you enable this setting, then only the products that already exist in your database will be updated.'),
('Languages::update_existing_products_only', 'Update existing products only'),
('Languages::update_existing_products_only_tooltip', 'If you enable this setting, products that don''t exist in the database of your store will be skipped during import.'),
('Languages::updated_last', 'Updated in the last'),
('Languages::hour_or_hours', 'hour(s)'),
('Languages::api_required_fields', 'The following fields are required: [fields]'),
('Languages::api_one_of_fields_required', 'One of the following fields is required: [fields]'),
('Languages::api_invalid_value', 'Invalid value `[value]` specified for [field]'),
('Languages::api_invalid_value_w_valid_list', 'Invalid value `[value]` specified for [field]. Valid values are: [valid_list]'),
('Languages::api_empty_value', 'Empty value specified for the required [field] field.'),
('Languages::recover', 'Recover'),
('Languages::image_has_been_deleted', 'This image has been deleted'),
('Languages::delete_all_images', 'Delete all images'),
('Languages::cannot_upload_file', 'Cannot upload file'),
('Languages::ogone.sha_in', 'SHA-IN pass phrase'),
('Languages::ttc_ogone.sha_in', 'The SHA-IN pass phrase is set on the Ingenico administration panel on the <b>Data and origin verification</b> tab.'),
('Languages::ogone_web.sha_out', 'SHA-OUT pass phrase'),
('Languages::ttc_ogone_web.sha_out', 'The SHA-OUT pass phrase is set on the Ingenico administration panel on the <b>Transaction feedback</b> tab.'),
('Languages::ogone_direct.config_info', 'Enter SHA-IN pass phrase both here and on the Ingenico administation panel.<br><br>For new Ingenico accounts created since May 11th, 2010, the new SHA policy is automatically active.<br/>Please do not forget to select the "Use new SHA signature policy" checkbox.'),
('Languages::ogone_web.config_info', 'Please set the following URL in the Technical Information section on the Ingenico administation panel as the <b>URL of the merchant''s post-payment page</b> for all cases ("accepted", "on hold", "uncertain", "canceled by the client", "too many rejections by the acquirer"): <code>[r_url]</code><br>Select "Always deferred (not immediately after the payment)" for the <b>Timing of the request</b>.<br>Enter SHA-IN and SHA-OUT pass phrases both here and on the Ingenico administation panel.'),
('Languages::sort_by_null_desc', 'No sorting'),
('Languages::storefront_name', 'Storefront name'),
('Languages::storefront_name_short', 'Storefront name'),
('Languages::internal_option_name', 'Internal name'),
('Languages::internal_option_name_tooltip', 'This name is shown only in the Administration panel to help you distinguish between multiple options that have the same displayed name.'),
('Languages::internal_feature_name_tooltip', 'This name is shown only in the Administration panel to help you distinguish between multiple features that have the same displayed name.'),
('Languages::internal_feature_group_name_tooltip', 'This name is shown only in the Administration panel to help you distinguish between multiple feature groups that have the same displayed name.'),
('Languages::edit_corresponding_profile_field', 'To change the field type or variants, <a href="[URL]">edit the corresponding field in the Shipping Address section</a>.'),
('Languages::error_product_codes_length', 'The following product codes are too long and were cut off at [product_code_length] symbols:'),
('Languages::log_action_shipping', 'Shipping request'),
('Languages::email_template.shipping_error', 'Shipping: request error'),
('Languages::request_error_information_title', 'Shipping error'),
('Languages::request_error_information', 'Customers have experienced issues with receiving rates from <b>the [shipping]</b> shipping method. Please make sure that is configured properly and that the shipping rate calculation is correct'),
('Languages::press_continue_to_recover_password', 'Click <b>Continue</b> to proceed with password change.'),
('Languages::file_uploader.default_message', 'Drop files here to upload'),
('Languages::file_uploader.fallback_message', 'Your browser does not support drag''n''drop file uploads.'),
('Languages::file_uploader.fallback_text', 'Please use the fallback form below to upload your files like in the olden days.'),
('Languages::file_uploader.file_too_big', 'File is too big ({{filesize}}MB). Max filesize: {{maxFilesize}}MB.'),
('Languages::file_uploader.invalid_file_type', 'You can''t upload files of this type.'),
('Languages::file_uploader.response_error', 'Server responded with {{statusCode}} code.'),
('Languages::file_uploader.cancel_upload', 'Cancel upload'),
('Languages::file_uploader.upload_canceled', 'Upload canceled.'),
('Languages::file_uploader.cancel_upload_confirmation', 'Are you sure you want to cancel this upload?'),
('Languages::file_uploader.remove_file', 'Remove file'),
('Languages::file_uploader.remove_file_confirmation', 'Do you want to remove this image?'),
('Languages::file_uploader.max_files_exceeded', 'You can not upload any more files.'),
('Languages::file_uploader.file_size_units_tb', 'TB'),
('Languages::file_uploader.file_size_units_gb', 'GB'),
('Languages::file_uploader.file_size_units_mb', 'MB'),
('Languages::file_uploader.file_size_units_kb', 'KB'),
('Languages::file_uploader.file_size_units_b', 'b'),
('Languages::drop_images_to_upload', 'Drop images here'),
('Languages::drop_images_select_short', 'Select'),
('Languages::drop_images_select', 'Select images'),
('Languages::currency_code_afn', 'Afghan Afghani'),
('Languages::currency_code_dzd', 'Algerian Dinar'),
('Languages::currency_code_aoa', 'Angolan Kwanza'),
('Languages::currency_code_aon', 'Angolan New Kwanza'),
('Languages::currency_code_ats', 'Antillian Guilder'),
('Languages::currency_code_azn', 'Azerbaijanian Manat'),
('Languages::currency_code_bsd', 'Bahamian Dollar'),
('Languages::currency_code_bhd', 'Bahraini Dinar'),
('Languages::currency_code_bdt', 'Bangladesh Taka'),
('Languages::currency_code_bbd', 'Barbados Dollar'),
('Languages::currency_code_byn', 'Belarussian Ruble'),
('Languages::currency_code_bef', 'Belgian Franc'),
('Languages::currency_code_bzd', 'Belize Dollar'),
('Languages::currency_code_bmd', 'Bermudian Dollar'),
('Languages::currency_code_btn', 'Bhutan Ngultrum'),
('Languages::currency_code_bob', 'Bolivian Boliviano'),
('Languages::currency_code_bam', 'Bosnia and Herzegovina Convertible Marks'),
('Languages::currency_code_bwp', 'Botswana Pula'),
('Languages::currency_code_bnd', 'Brunei Dollar'),
('Languages::currency_code_bgl', 'Bulgaria Lev'),
('Languages::currency_code_bif', 'Burundi Franc'),
('Languages::currency_code_khr', 'Cambodian Riel'),
('Languages::currency_code_cve', 'Cape Verde Escudo'),
('Languages::currency_code_kyd', 'Cayman Islands Dollar'),
('Languages::currency_code_clp', 'Chilean Peso'),
('Languages::currency_code_cop', 'Colombian Peso'),
('Languages::currency_code_kmf', 'Congolese Franc'),
('Languages::currency_code_crc', 'Costa Rican Colon'),
('Languages::currency_code_cyp', 'Cyprus Pound'),
('Languages::currency_code_dem', 'Deutsche Mark'),
('Languages::currency_code_djf', 'Djibouti Franc'),
('Languages::currency_code_std', 'Dobra'),
('Languages::currency_code_dop', 'Dominican Peso'),
('Languages::currency_code_nlg', 'Dutch Guilder'),
('Languages::currency_code_xcd', 'East Caribbean Dollar'),
('Languages::currency_code_ecs', 'Ecuador Sucre'),
('Languages::currency_code_cdf', 'Congolese Franc'),
('Languages::currency_code_svc', 'El Salvador Colon'),
('Languages::currency_code_ern', 'Eritrean Nafka'),
('Languages::currency_code_etb', 'Ethiopian Birr'),
('Languages::currency_code_fkp', 'Falkland Islands Pound'),
('Languages::currency_code_fim', 'Finnish Markka'),
('Languages::currency_code_gmd', 'Gambian Dalasi'),
('Languages::currency_code_ghs', 'Ghana Cedi'),
('Languages::currency_code_gip', 'Gibraltar Pound'),
('Languages::currency_code_grd', 'Greek Drachma'),
('Languages::currency_code_gtq', 'Guatemalan Quetzal'),
('Languages::currency_code_gnf', 'Guinea Franc'),
('Languages::currency_code_gyd', 'Guyana Dollar'),
('Languages::currency_code_htg', 'Haiti Gourde'),
('Languages::currency_code_hnl', 'Honduran Lempira'),
('Languages::currency_code_idr', 'Indonesian Rupiah'),
('Languages::currency_code_irr', 'Iranian Rial'),
('Languages::currency_code_iqd', 'Iraqi Dinar'),
('Languages::currency_code_iep', 'Irish Pound'),
('Languages::currency_code_itl', 'Italian Lira'),
('Languages::currency_code_jmd', 'Jamaican Dollar'),
('Languages::currency_code_jod', 'Jordanian Dinar'),
('Languages::currency_code_kes', 'Kenyan Shilling'),
('Languages::currency_code_lak', 'Laos Kip'),
('Languages::currency_code_lbp', 'Lebanese Pound'),
('Languages::currency_code_lsl', 'Lesotho Loti (Maloti)'),
('Languages::currency_code_lrd', 'Liberian Dollar'),
('Languages::currency_code_lyd', 'Libyan Dinar'),
('Languages::currency_code_luf', 'Luxembourg Franc'),
('Languages::currency_code_mop', 'Macau Pataca'),
('Languages::currency_code_mkd', 'Macedonian (FYR) Denar'),
('Languages::currency_code_mga', 'Malagasy Ariary'),
('Languages::currency_code_mgf', 'Malagasy Franc'),
('Languages::currency_code_mwk', 'Malawi Kwacha'),
('Languages::currency_code_mvr', 'Maldives Rufiyaa'),
('Languages::currency_code_mtl', 'Maltese Lira'),
('Languages::currency_code_mro', 'Mauritania Ouguiya'),
('Languages::currency_code_mur', 'Mauritius Rupee'),
('Languages::currency_code_mdl', 'Moldovan Leu'),
('Languages::currency_code_mnt', 'Mongolian Tugrik'),
('Languages::currency_code_mzn', 'Mozambique Metical'),
('Languages::currency_code_mmk', 'Myanmar Kyat'),
('Languages::currency_code_nad', 'Namibian Dollar'),
('Languages::currency_code_npr', 'Nepalese Rupee'),
('Languages::currency_code_rsd', 'New Serbian Dinar'),
('Languages::currency_code_nio', 'Nicaraguan Cordoba Oro'),
('Languages::currency_code_ngn', 'Nigerian Naira'),
('Languages::currency_code_pkr', 'Pakistan Rupee'),
('Languages::currency_code_pab', 'Panamanian Balboa'),
('Languages::currency_code_pgk', 'Papua New Guinea Kina'),
('Languages::currency_code_pyg', 'Paraguayan Guarani'),
('Languages::currency_code_pen', 'Peruvian Nuevo Sol'),
('Languages::currency_code_uyu', 'Peso Uruguayo'),
('Languages::currency_code_pte', 'Portugese Escudo'),
('Languages::currency_code_qar', 'Qatari Rial'),
('Languages::currency_code_omr', 'Rial Omani'),
('Languages::currency_code_rol', 'Romanian Lei'),
('Languages::currency_code_rwf', 'Rwanda Franc'),
('Languages::currency_code_csd', 'Serbian Dinar'),
('Languages::currency_code_scr', 'Seychelles Rupee'),
('Languages::currency_code_sll', 'Sierra Leone Leone'),
('Languages::currency_code_sos', 'Somalia Shilling'),
('Languages::currency_code_esp', 'Spanish Peseta'),
('Languages::currency_code_lkr', 'Sri Lanka Rupee'),
('Languages::currency_code_shp', 'St Helena Pound'),
('Languages::currency_code_sdp', 'Sudanese Pound'),
('Languages::currency_code_srd', 'Suriname Dollar'),
('Languages::currency_code_srg', 'Suriname Guilder'),
('Languages::currency_code_szl', 'Swaziland Lilangeni'),
('Languages::currency_code_syp', 'Syrian Pound'),
('Languages::currency_code_tjs', 'Tajikistan Somoni'),
('Languages::currency_code_tzs', 'Tanzanian Shilling'),
('Languages::currency_code_ttd', 'Trinidad and Tobago Dollar'),
('Languages::currency_code_tnd', 'Tunisian Dinar'),
('Languages::currency_code_trl', 'Turkish Lira'),
('Languages::currency_code_tmt', 'Turkmenistan Manat'),
('Languages::currency_code_ugx', 'Uganda Shilling'),
('Languages::currency_code_uzs', 'Uzbekistan Sum'),
('Languages::currency_code_veb', 'Venezuela Bolivar'),
('Languages::currency_code_vef', 'Venezuela Bolivar Fuerte'),
('Languages::currency_code_vnd', 'Vietnamese New Dong'),
('Languages::currency_code_yer', 'Yemeni Rial'),
('Languages::currency_code_yum', 'Yugoslavian New Dinar'),
('Languages::currency_code_zmw', 'Zambian Kwacha'),
('Languages::currency_code_zwd', 'Zimbabwe Dollar'),
('Languages::editing_order_invoice_responsive', 'Editing invoice for order'),
('Languages::responsive_admin.email_order_invoice_subject', '[company_name]: Invoice for order'),
('Languages::file_uploading_in_progress_please_wait', 'File uploading in progress. Please wait.'),
('Languages::profile_types_section_user', 'Customers and admins'),
('Languages::profile_types_section_seller', 'Vendor information'),
('Languages::profile_type', 'Profile type'),
('Languages::bulk_edit.example_of_modified_value', 'Example of the modified value'),
('Languages::bulk_edit.decrease_hint', 'To decrease the value use the "-". Example: -5'),
('Languages::bulk_edit.make_active', 'Make products active'),
('Languages::bulk_edit.make_disabled', 'Make products disabled'),
('Languages::bulk_edit.make_hidden', 'Make products hidden'),
('Languages::bulk_edit.price_and_stock', 'Price & Stock'),
('Languages::bulk_edit.what_do_these_checkboxes_mean', 'What do these checkboxes mean?'),
('Languages::bulk_edit.what_do_these_checkboxes_mean_checked', 'all the selected products belong to this category or will be assigned to it.'),
('Languages::bulk_edit.what_do_these_checkboxes_mean_unchecked', 'none of the selected products belong to this category, or they will be removed from it.'),
('Languages::bulk_edit.what_do_these_checkboxes_mean_indeterminate', 'some of the selected products belong to this category; no changes will be made.'),
('Languages::bulk_edit.unable_to_delete_all_categories', 'At least one category must be selected'),
('Languages::bulk_edit.some_products_were_omitted', 'Some products were skipped because the last remaining category can''t be removed or added for a product.'),
('Languages::bulk_edit.some_products_were_omitted_other_storefront', 'Couldn''t edit selected products. Some of the selected products belong to other storefronts; please deselect those products to be able to edit remaining ones.'),
('Languages::custom_search', 'Custom search'),
('Languages::system_environment', 'System environment'),
('Languages::product_feature.purpose', 'Purpose'),
('Languages::ttc_product_feature.purpose', 'Determines how you and your customers will be able to use this feature.'),
('Languages::product_feature.purpose.organize_catalog', 'Brand, author, etc.'),
('Languages::product_feature.purpose.organize_catalog.description', 'For features like "Brand" or "Manufacturer" (for most products), "Performer" or "Label" (for music), "Author" or "Publisher" (for books), and so on. Every variant of this feature gets its own page with an image, description, and the list of products.'),
('Languages::product_feature.purpose.find_products', 'Product search via filters'),
('Languages::product_feature.purpose.find_products.description', 'For a feature that just allows you to specify an additional property of a product (for example, "Fabric" for T-shirts). If you create a filter by that feature, customers will see that such a property exists, and will be able to search products by it.'),
('Languages::product_feature.purpose.describe_product', 'Additional information'),
('Languages::product_feature.purpose.describe_product.description', 'For cases when you just need to show some information on a product page. There are no filters for this kind of features.'),
('Languages::product_feature.feature_style', 'Feature style'),
('Languages::ttc_product_feature.feature_style', 'Determines the look of this feature on the product page.'),
('Languages::product_feature.feature_style.checkbox', 'Checkbox'),
('Languages::product_feature.feature_style.color', 'Color'),
('Languages::product_feature.filter_style.color', 'Color'),
('Languages::product_feature.feature_style.multiple_checkbox', 'Multiple checkboxes'),
('Languages::product_feature.feature_style.text', 'Text or number'),
('Languages::product_feature.feature_style.number', 'Number'),
('Languages::product_feature.feature_style.brand', 'Brand'),
('Languages::product_feature.filter_style', 'Filter type'),
('Languages::ttc_product_feature.filter_style', 'Determines the look of a filter by this feature on the product list. Filters make it easier for customers to find a product with the desired feature value. You''ll be able to create a filter after you create a feature.'),
('Languages::product_feature.filter_style.checkbox', 'Checkbox'),
('Languages::product_feature.filter_style.slider', 'Number slider'),
('Languages::product_feature.filter_style.date', 'Date selector'),
('Languages::privilege_groups.blog_and_pages', 'Blog & Pages'),
('Languages::privilege_groups.orders', 'Orders'),
('Languages::privilege_groups.order_statuses', 'Order statuses'),
('Languages::privilege_groups.other', 'Other'),
('Languages::privilege_groups.backup_restore', 'Backup/Restore'),
('Languages::privilege_groups.blocks', 'Blocks'),
('Languages::privilege_groups.currencies', 'Currencies'),
('Languages::privilege_groups.design', 'Design'),
('Languages::privilege_groups.documents', 'Documents'),
('Languages::privilege_groups.file_changes', 'File changes detector'),
('Languages::privilege_groups.files', 'Files'),
('Languages::privilege_groups.edit_on_site', 'Edit content on-site'),
('Languages::privilege_groups.email_templates', 'Email templates'),
('Languages::privilege_groups.exim', 'Import and export data'),
('Languages::privilege_groups.languages', 'Languages'),
('Languages::privilege_groups.locations', 'Rate areas'),
('Languages::privilege_groups.logs', 'Logs'),
('Languages::privilege_groups.sales_reports', 'Sales reports'),
('Languages::privilege_groups.sitemap', 'Sitemap'),
('Languages::privilege_groups.shipping', 'Shipping methods'),
('Languages::privilege_groups.payments', 'Payment methods'),
('Languages::privilege_groups.products', 'Categories, Products, Features, Filters, Options'),
('Languages::privilege_groups.promotions', 'Promotions'),
('Languages::privilege_groups.static_data', 'Static data'),
('Languages::privilege_groups.stores', 'Storefronts'),
('Languages::privilege_groups.storage', 'Storage'),
('Languages::privilege_groups.settings', 'Settings'),
('Languages::privilege_groups.taxes', 'Taxes'),
('Languages::privilege_groups.themes', 'Themes'),
('Languages::privilege_groups.users', 'Users'),
('Languages::privilege_groups.user_groups', 'User groups'),
('Languages::privilege_groups.upgrade_center', 'Upgrade center'),
('Languages::privilege.full_access', 'Full access'),
('Languages::privilege.view_access', 'Can view only'),
('Languages::privilege.no_access', 'No access'),
('Languages::privilege.custom_access', 'Custom access'),
('Languages::privilege.apply_to_all', 'Apply value to all'),
('Languages::open_hours', 'Open hours'),
('Languages::affected_email_templates', 'Email templates using this document'),
('Languages::pickup_point_not_selected', 'Sorry, we couldn''t determine your pickup point. Please choose a pickup point, so that we know where to deliver your order.'),
('Languages::no_manager_assigned', 'No manager assigned'),
('Languages::block_manager.view_layout.reset_filter', 'Edit layouts'),
('Languages::block_manager.view_layout.phone', 'Phone preview'),
('Languages::block_manager.view_layout.tablet', 'Tablet preview'),
('Languages::block_manager.view_layout.desktop', 'Desktop preview'),
('Languages::block_manager.availability.show_on', 'Show on'),
('Languages::block_manager.availability.phone', 'Phone'),
('Languages::block_manager.availability.tablet', 'Tablet'),
('Languages::block_manager.availability.desktop', 'Desktop'),
('Languages::add_as_order', 'Add as order'),
('Languages::is_address_required', 'Customer must specify his/her address'),
('Languages::go_to_admin_panel', 'Admin panel'),
('Languages::checkout.min_cart_subtotal_required', 'To continue checkout process your order subtotal must exceed [amount]'),
('Languages::lite_checkout.customer_information', 'Customer'),
('Languages::lite_checkout.personal_name', 'Full name'),
('Languages::lite_checkout.city_and_state', 'City, state'),
('Languages::lite_checkout.place_an_order_for', 'Place order ([amount])'),
('Languages::lite_checkout.delivery_note', 'Customer''s notes'),
('Languages::lite_checkout.shippings.show_all_on_map', 'Show all on map'),
('Languages::lite_checkout.nearest_station', 'Nearest station'),
('Languages::lite_checkout.select_pickup_item', 'Select a pickup point'),
('Languages::lite_checkout.choose_from_list', 'Choose from list'),
('Languages::lite_checkout.use_two_fingers_for_move_map', 'Use two fingers to move the map'),
('Languages::lite_checkout.select_your_city', 'Specify your city'),
('Languages::lite_checkout.deliver_to', 'Deliver to:'),
('Languages::lite_checkout.click_here_to_update_shipping', 'Enter city and state and click here to update shipping rates'),
('Languages::lite_checkout.shipping_method_for', 'Shipping method for [group_name]'),
('Languages::deprecated', 'Deprecated'),
('Languages::collapse_section', 'Collapse section'),
('Languages::expand_section', 'Expand section'),
('Languages::companies', 'Stores'),
('Languages::storefronts', 'Storefronts'),
('Languages::editing_storefront', 'Editing storefront'),
('Languages::creating_storefront', 'Creating storefront'),
('Languages::all_languages', 'All languages'),
('Languages::all_currencies', 'All currencies'),
('Languages::all_companies', 'All stores'),
('Languages::storefront_status', 'Status'),
('Languages::storefront_status.tooltip', 'Even if the storefront is closed (the status set to OFF), you''ll be able to view it if you have an access key. Specify the <i>Access key to temporarily closed storefront</i> below.<br/>Use http://www.example.com/index.php?store_access_key=key_value to access a closed storefront.'),
('Languages::storefront_access_key', 'Access key to temporarily closed storefront'),
('Languages::storefront_access_key.setting_notice', 'You can set the access key on the storefront editing page'),
('Languages::close_storefront', 'Close storefront'),
('Languages::close_storefront.setting_notice', 'You can open or close a storefront on the storefront editing page'),
('Languages::open_selected_storefronts', 'Open selected'),
('Languages::close_selected_storefronts', 'Close selected'),
('Languages::add_storefront', 'Add storefront'),
('Languages::storefront_status_changed.Y', 'The storefront was <b>closed</b>|The storefronts were <b>closed</b>'),
('Languages::storefront_status_changed.N', 'The storefront was <b>opened</b>|The storefronts were <b>opened</b>'),
('Languages::default_storefront', 'Default'),
('Languages::add_profile_fields', 'Add profile fields'),
('Languages::add_profile_fields_and_close', 'Add profile fields and close'),
('Languages::checkout_block_with_heading', 'Checkout block (H2 heading)'),
('Languages::notifications_center.no_notifications', 'No notifications'),
('Languages::notifications_center.notifications', 'Notifications'),
('Languages::notifications_center.section.all', 'All'),
('Languages::notifications_center.section.administration', 'Administration'),
('Languages::notifications_center.section.products', 'Products'),
('Languages::notifications_center.section.other', 'Other'),
('Languages::notifications_center.tag.administration.update', 'Update'),
('Languages::notifications_center.tag.administration.license', 'Licence'),
('Languages::notifications_center.tag.other', 'Other'),
('Languages::notifications_center.mark_all_as_read', 'Mark all as read'),
('Languages::notification.upgrade_available.title', 'New CS-Cart version is available'),
('Languages::notification.upgrade_available.message', 'To see what the new version brings, <a href="[link]">visit the Upgrade Center</a>.'),
('Languages::notification.addons_upgrade_available.title', 'New versions are available for your add-ons'),
('Languages::notification.addons_upgrade_available.message', 'To install these updates, <a href="[link]">visit the Upgrade Center</a>.'),
('Languages::authorize_before_order', 'Only registered customers can place an order. Please sign in to your account or register a new one.'),
('Languages::storefront_with_same_url_exists', 'A storefront with the specified URL already exists'),
('Languages::edit_layout_on_site', 'Edit layout on-site'),
('Languages::on_site_layout_editing', 'Editing layout page: [page]'),
('Languages::bottom_panel.go_to_home_page', 'Go to home page'),
('Languages::bottom_panel.go_to_dashboard', 'Go to Dashboard'),
('Languages::bottom_panel.show_bottom_admin_panel', 'Show admin toolbar'),
('Languages::bottom_panel.hide_bottom_admin_panel', 'Hide admin toolbar'),
('Languages::bottom_panel.storefront', 'Storefront'),
('Languages::bottom_panel.admin_panel', 'Admin panel'),
('Languages::bottom_panel.vendor_panel', 'Vendor panel'),
('Languages::bottom_panel.preview_mode', 'Preview'),
('Languages::bottom_panel.build_mode', 'Edit structure'),
('Languages::bottom_panel.build_mode.not_available', 'Available at the following page types: homepage, product, category, checkout.'),
('Languages::bottom_panel.theme_mode.not_available', 'Available only in your microstore or on the pages of your products and blog articles.'),
('Languages::bottom_panel.text_mode', 'Edit texts'),
('Languages::bottom_panel.theme_mode', 'Edit style'),
('Languages::bottom_panel.settings', 'Settings'),
('Languages::bottom_panel.change_theme', 'Change theme'),
('Languages::bottom_panel.edit_layout', 'Edit layout'),
('Languages::bottom_panel.edit_template', 'Edit template'),
('Languages::bottom_panel.edit_translations', 'Edit translations'),
('Languages::bottom_panel.edit_menus', 'Edit menus'),
('Languages::bottom_panel.edit_product_tabs', 'Edit product tabs'),
('Languages::bottom_panel.restore_demo', 'Restore demo'),
('Languages::bottom_panel.documentation', 'Documentation'),
('Languages::bottom_panel.help', 'Help'),
('Languages::bottom_panel.community_forums', 'Community forums'),
('Languages::bottom_panel.video_tutorials', 'Video tutorials'),
('Languages::bottom_panel.faq', 'FAQ'),
('Languages::bottom_panel.customer_help_desk', 'Contact support'),
('Languages::bottom_panel.hire_a_developers', 'Hire a developer'),
('Languages::bottom_panel.download', 'Download'),
('Languages::bottom_panel.buy_license', 'Buy license'),
('Languages::bottom_panel.trial_left', 'Remaining trial period'),
('Languages::demo_panel.theme_editor.enable', 'Edit style<br/><br/>Change the style of your store (logos, colors, fonts, and so on) and see the changes as you make them.<br/><br/>To use this functionality in your [product] store, go to Design → Themes and click "Theme editor"'),
('Languages::demo_panel.block_manager.enable', 'Edit structure<br/><br/>Change various blocks with information: show them, hide them, or move them as you see fit.<br/>This currently works at the following page types: homepage, product, category, checkout.<br/><br/>To use this functionality in your [product] store, go to Design → Themes and click "Edit layout on-site"'),
('Languages::individual', 'Individual'),
('Languages::link_an_existing_option', 'Link an existing option'),
('Languages::create_or_link_an_existing_option', 'Create or link an existing option'),
('Languages::tip.quick_select_and_close_category_selector', 'Tip: Hold ''Ctrl'' (or "⌘" on Mac) while clicking on a category name. This will add one category and close the window.'),
('Languages::checkout_select_profile_before_order', 'Please select a profile before you place the order.'),
('Languages::editing_profile_name', 'Editing profile: [name]'),
('Languages::bm.customer_information_block.warning.email_or_phome_must_be_required', 'Contact information must always have either email, or phone as a required field.'),
('Languages::bm.customer_information_block.warning.field_automaticly_added', '"[field_name]" has been added as a required field automatically.'),
('Languages::bm.customer_information_block.warning.field_marked_as_required', 'The "[field_name]" field has been marked as required.'),
('Languages::required_profile_field_description', 'The "[field_name]" profile field is required as it is used to calculate shipping rates.'),
('Languages::upgrade_notification_welcome_title', 'Welcome to [product] [version]!'),
('Languages::upgrade_notification_welcome_text', '<p class="lead">To help you get started, we’ve compiled the list of what you should check after the upgrade. The full list of changes is in the changelog.</p><p class="lead">If you ever need to check this message later, we’ve also sent a copy to [email].</p>'),
('Languages::view_changelog', 'View changelog'),
('Languages::upgrade_notification_what_check_first', 'What to check first?'),
('Languages::upgrade_notification_what_else_to_check', 'What else is there to check?'),
('Languages::cant_remove_addon_files', 'Add-on files couldn''t be removed'),
('Languages::addon_reinstall.intro', 'Looks like you are trying to install an add-on that is already installed. We can do it for you in two ways; we recommend the safe way.'),
('Languages::addon_reinstall.safe_way', '<strong>The safe way:</strong> we''ll uninstall the old add-on first, and then install the new one. The drawback is that any data and settings related to the add-on will be lost.'),
('Languages::addon_reinstall.dangerous_way', '<strong>The dangerous way:</strong> we''ll replace all the files of the add-on with new ones, but keep all the add-on''s data in the database intact. This can break the add-on, or might even break your store. Please don''t use the dangerous way, unless you absolutely know what you''re doing.'),
('Languages::addon_reinstall.dangerous_way.confirm', 'I know the risks and want to use the dangerous way.'),
('Languages::addon_reinstall.dangerous_way.action', 'Use the dangerous way'),
('Languages::addon_reinstall.safe_way.action', 'Use the safe way'),
('Languages::all_storefronts', 'All storefronts'),
('Languages::add_storefronts', 'Add storefronts'),
('Languages::add_storefronts_and_close', 'Add storefronts and close'),
('Languages::event.receiver.c', 'Customer'),
('Languages::event.receiver.a', 'Administrator'),
('Languages::event.receiver.v', 'Vendor'),
('Languages::event.transport.mail', 'E-mail'),
('Languages::event.transport.internal', 'Notifications center'),
('Languages::event.order.edp.name', 'Access to downloadable products granted'),
('Languages::event.notification_type', 'Notification type'),
('Languages::notifications', 'Notifications'),
('Languages::event.order.updated.name', 'Order was updated'),
('Languages::event.order.shipment_updated.name', 'Products were shipped'),
('Languages::purpose', 'Purpose'),
('Languages::feature_style', 'Feature style'),
('Languages::filter_style', 'Filter type'),
('Languages::all_block_types', 'All block types'),
('Languages::all_layouts', 'All layouts'),
('Languages::all_locations', 'All locations'),
('Languages::n_categories', '[n] category|[n] categories'),
('Languages::n_pages', '[n] page|[n] pages'),
('Languages::n_filters', '[n] filter|[n] filters'),
('Languages::n_profile_fields', '[n] profile field|[n] profile fields'),
('Languages::event.profile.activated.name', 'Profile was activated'),
('Languages::event.profile.deactivated.name', 'Profile was deactivated'),
('Languages::event.profile.password_reminder.name', 'Reminder about necessary password change'),
('Languages::event.profile.usergroup_request.name', 'Membership in user group was requested'),
('Languages::event.profile.updated.name', 'Profile was updated'),
('Languages::event.profile.added.name', 'Profile requires activation'),
('Languages::event.profile.created.name', 'Profile was created'),
('Languages::event.profile.usergroup_activation.name', 'User group activation'),
('Languages::event.profile.usergroup_disactivation.name', 'User group disactivation'),
('Languages::event.profile.usergroup_updated.name', 'Membership in user group was changed'),
('Languages::event.profile.password_recovery.name', 'Password recovery'),
('Languages::export_found_products', 'Export found products'),
('Languages::hello_name', 'Hello [name],'),
('Languages::checkout.email_exists.popup.title', 'You may have bought from us before'),
('Languages::checkout.email_exists.popup.message', 'An account with your email already exists. We can sign you in (password won''t be needed), or you can use another email if you''d like.'),
('Languages::checkout.email_exists.popup.cancel_btn', 'Use another email'),
('Languages::checkout.email_exists.popup.sign_in_btn', 'Sign me in'),
('Languages::auth.one_time_password.popup.title', 'Password-free sign-in'),
('Languages::auth.one_time_password.popup.message', 'We''ve sent a one-time code to <strong>[email]</strong>. Please enter it below, and we''ll sign you in without a password.'),
('Languages::auth.one_time_password.popup.input_placeholder', 'Enter the code here'),
('Languages::auth.one_time_password.popup.resend_btn', 'Resend the code'),
('Languages::auth.one_time_password.popup.sign_in_btn', 'Sign me in'),
('Languages::auth.one_time_password.notification.info_password_sent', 'We''ve sent a one-time code to [email].'),
('Languages::auth.one_time_password.notification.error_password_invalid', 'Sorry, it seems that the code you''ve entered is incorrect. It may have expired or been used already. Please check the code you''re entering or request a new code.'),
('Languages::auth.one_time_password.notification.error_password_required', 'Please enter the code to sign in.'),
('Languages::email.one_time_password.title', 'Sign in without password'),
('Languages::email.one_time_password.message', '<p>You''ve requested a one-time code to sign in to <a href="[storefront_url]">[storefront_url]</a>. Here it is:</p><p><strong><code>[password]</code></strong></p><p>Please don''t tell this code to anyone else. If you haven''t requested the code, then you can safely ignore this message. Nobody will be able to sign in to your account, unless they know your password or can view your inbox.</p>'),
('Languages::email_template.one_time_password_request', 'One-time code for password-free sign-in'),
('Languages::other_notification', 'Other'),
('Languages::see_full_templates_list', 'Can''t find a notification you''re looking for?<br/><a href="[email_template_manage]"></a><br/><a href="[internal_template_manage]">See the full list of on-site notification templates</a>'),
('Languages::other_notifications.title', 'Can''t find a notification you''re looking for?'),
('Languages::other_notifications.email_templates', 'See the full list of email templates'),
('Languages::other_notifications.internal_templates', 'See the full list of on-site notification templates'),
('Languages::internal_templates', 'On-site notification templates'),
('Languages::editing_internal_template', 'Editing on-site notification template'),
('Languages::send_test_notification', 'Send test notification'),
('Languages::count_internal_template_successfully_imported', 'On-site notification templates successfully imported:'),
('Languages::count_internal_template_fail_imported', 'On-site notification templates import failed:'),
('Languages::internal_template_import_success_msg', 'All the on-site notification templates have been imported without errors.'),
('Languages::internal_template_exists', 'The on-site notification template with the chosen code already exists, please try another.'),
('Languages::notification_template.tab.email', 'Email'),
('Languages::notification_template.tab.internal', 'On-site'),
('Languages::lite_checkout.chosen_shipping_not_avaliable', 'Sorry, we can''t get the rates for your selected shipping method. Please check your address and make sure that it is correct. If this doesn''t help, please select another shipping method or contact us.'),
('Languages::lite_checkout.not_available', 'Not available'),
('Languages::last_login', 'Last login'),
('Languages::total_orders', 'Created orders'),
('Languages::total_paid_orders', 'Paid orders'),
('Languages::total_spent_money', 'Total spend'),
('Languages::notifications_center.section.communication', 'Communication'),
('Languages::notifications_center.tag.messages', 'Messages'),
('Languages::settled_order_status', 'Consider order paid'),
('Languages::edit_on_site', 'Edit on site'),
('Languages::order_manager', 'Order manager'),
('Languages::privilege_groups.internal_templates', 'On-site notification templates'),
('Languages::privilege_groups.notification_settings', 'Notifications'),
('Languages::logo_section.theme', 'Site logo'),
('Languages::logo_section.favicon', 'Favicon'),
('Languages::logo_section.mail', 'E-mail logo'),
('Languages::show_extra_logos', 'Show extra logos'),
('Languages::hide_extra_logos', 'Hide extra logos'),
('Languages::test_rate_calculation', 'Test rate calculation'),
('Languages::calculated_rate', 'Calculated rate'),
('Languages::calculated_automatically', 'Calculated automatically'),
('Languages::additional_settings', 'Additional settings'),
('Languages::rates_calculated_info', 'Rates are calculated for [n] product that costs [price].|Rates are calculated for [n] products that cost [price].'),
('Languages::base_rate', 'Base rate'),
('Languages::price_rate_not_set', 'Price rate was not set.'),
('Languages::receivers', 'Receivers'),
('Languages::notification', 'Notification'),
('Languages::owner_company', 'Storefront'),
('Languages::block_manager.brands_per_screen', 'Brands per screen'),
('Languages::block_manager.total_displayed_brands', 'Total amount of brands displayed'),
('Languages::add_all_destinations', 'Add all'),
('Languages::block_manager.manage_layout_in_tab_not_exist_location', '<p>This [entity] currently doesn''t have an associated layout page. That''s why it uses blocks from the default layout page.<br> If you''d like to edit blocks specifically for this [entity], then:</p><p><ol><li>Go to <b><a href="[link]">Design → Layouts</a></b></li><li>Add a layout page with <b>Dispatch:</b> <code>[dispatch_value]</code>.</li><li>Switch to the <b>[entity_tab]</b> tab and make sure that the layout page is enabled for this [entity].</li><li>Save your changes and return here.</li></ol></p>');
INSERT INTO `[[dbprefix]]original_values` VALUES
('Languages::block_manager.manage_layout_in_tab_unavailable_by_object_id', '<p>This [entity] currently doesn''t have an associated layout page. That''s why it uses blocks from the default layout page.<br> If you''d like to edit blocks specifically for this [entity], then:</p><p><ol><li>Edit the <b><a href="[link]">[location_name]</a></b> layout page.</li><li>Switch to the [entity_tab] tab and make sure that the layout page is enabled for this [entity].</li><li>Save your changes and return here.</li></ol></p>'),
('Languages::block_manager.manage_layout_in_tab_unavailable', 'Sorry, you can''t edit blocks for this [entity]. If you''d like to do this, please contact the main administrator. Ask him or her to check the <b>Layouts</b> tab of this [entity] in their admin panel. That will give the main admin all the necessary information.'),
('Languages::block_manager.dynamic_entity_products', 'product'),
('Languages::block_manager.dynamic_entity_categories', 'category'),
('Languages::block_manager.dynamic_entity_pages', 'page'),
('Languages::payment_processors.category.checkout', 'Checkout'),
('Languages::payment_processors.category.gateway', 'Gateways'),
('Languages::payment_processors.category.russian', 'Russian payment methods'),
('Languages::add_in_all_realtime_shippings', 'Add in all realtime shipping methods'),
('Languages::event.system.realtime_shipping_error.name', 'Realtime shipping errors'),
('Languages::profile_field_contains_information', 'Сouldn''t change the field type: someone has already submitted data in this field.'),
('Languages::text_cannot_create_file_check_file', 'Сouldn''t create the file. Please try again or choose another file.'),
('Languages::error_profile_field_code_exists', 'A profile field with this code already exists. Please choose another code.'),
('Languages::can_not_add_file_type_profile_field', 'Sorry, this page doesn''t support fields with the "File" type, and they weren''t added.'),
('Languages::day_or_days', 'day(s)'),
('Languages::feature_already_in_use', 'Couldn''t delete the feature. It is already used by your or someone else''s products.'),
('Languages::feature_variants_already_in_use', 'Couldn''t delete some feature variants. They are already used by your or someone else''s products.'),
('Languages::stop_following_rules', 'Stop following rules'),
('Languages::exim_features', 'Features (Deprecated)'),
('Languages::exim_storefront_feature_name', 'Storefront feature name'),
('Languages::exim_reset_inventory_tooltip', 'This won''t affect the products that have the quantity specified in the imported file.'),
('Languages::thank_you', 'Thank you!'),
('Languages::text_review_and_reach_out_request', 'We''ll review your application and reach out to you via email soon.'),
('Languages::system_of_measurement', 'System of measurement'),
('Languages::imperial_units', 'Imperial (in, lb)'),
('Languages::metric_units', 'Metric (cm, kg)'),
('Languages::ship_dhl_account_country', 'Account country'),
('Languages::print_documents', 'Print documents'),
('Languages::change_to_status', 'Change to [status]'),
('Languages::invoice_pdf', 'Invoice (PDF)'),
('Languages::exim_import_detailed_image', 'Detailed image (Deprecated)'),
('Languages::settings.smtp_error', 'SMTP Error'),
('Languages::sync_data', 'Sync data'),
('Languages::never', 'Never'),
('Languages::nothing_sign', '&mdash;'),
('Languages::last_sync', 'Last sync'),
('Languages::log_file', 'Log file'),
('Languages::select_developer', 'Select developer'),
('Languages::popular_developer', 'Popular developer'),
('Languages::developers', 'Developers'),
('Languages::storefronts.manage_language_availability', 'Configure the languages available on this storefront'),
('Languages::storefronts.manage_currency_availability', 'Configure the currencies available on this storefront'),
('Languages::variant_with_name_already_exist', 'Couldn''t rename feature variant "[variant]". Reason: a variant with the new name already exists.'),
('Languages::delete_default_destination_notice', 'Couldn''t delete the default rate area. It must always exist.'),
('Languages::display', 'Display'),
('Languages::create_filters', 'Create filters'),
('Languages::text_n_filters_created', 'Filters created: [n].'),
('Languages::error_n_filters_already_exists', 'Some filters ([n]) already exist.'),
('Languages::bulk_product_features_warning', 'This change won''t affect some of the selected features, because they belong to a feature group. You can assign categories to an entire feature group.'),
('Languages::view_feature_groups', 'View feature groups'),
('Languages::show_on_storefront', 'Show on Storefront'),
('Languages::parent', 'Parent'),
('Languages::attempt_to_set_itself_or_a_own_child_as_its_parent_warning', 'The parent page wasn''t changed. Reason: can''t assign child page as a parent for its own parent.'),
('Languages::bulk_attempt_to_set_itself_or_a_own_child_as_its_parent_warning', 'The parent page of some of the selected pages wasn''t changed. Reason: can''t assign child page as a parent for its own parent.'),
('Languages::visit_marketplace', 'Visit the Add-on Market'),
('Languages::view_more_addons', 'View more add-ons'),
('Languages::manual_installation', 'Manual installation'),
('Languages::downloaded_addons', 'Downloaded add-ons ([n])'),
('Languages::upgrades', 'Upgrades ([n])'),
('Languages::addon_subscriptions', 'Subscriptions ([n])'),
('Languages::addon_type', 'Add-on type'),
('Languages::third_party_addons', 'Third-party add-ons'),
('Languages::unidentified', 'Unidentified'),
('Languages::without_rating', 'Without rating'),
('Languages::has_additional_pages', 'Has additional pages'),
('Languages::favorites', 'Favorites'),
('Languages::add_addon_to_favorites', 'Add add-on to favorites'),
('Languages::remove_addon_from_favorites', 'Remove add-on from favorites'),
('Languages::new_addon', 'New add-on'),
('Languages::install_date', 'Install date'),
('Languages::compatibility', 'Compatibility'),
('Languages::installed_date', 'Installed date'),
('Languages::what_is_new', 'What''s new'),
('Languages::where_access_addon', 'Where to access this add-on'),
('Languages::addon_is_compatible', 'This add-on version is compatible with your current [product] version.'),
('Languages::addon_required_version', 'The add-on requires [version] version.'),
('Languages::version_information', 'Version information'),
('Languages::show_all_developer_addons', 'Show all developer add-ons'),
('Languages::developer_page', 'Developer page'),
('Languages::show_all_category_addons', 'Show all [category] add-ons'),
('Languages::addons.other_category', 'Other'),
('Languages::updates', 'Updates'),
('Languages::actual_version', 'Actual version'),
('Languages::installed_version', 'Installed version'),
('Languages::subscription', 'Subscription'),
('Languages::license', 'License'),
('Languages::addon_reviews', 'Reviews'),
('Languages::addon_has_admin_review', 'You have left a review of the add-on'),
('Languages::addon_status', 'Add-on status'),
('Languages::verified', 'Verified'),
('Languages::verified_developer', 'Verified developer'),
('Languages::unverified', 'Unverified'),
('Languages::addons.is_enjoying_addon', 'Enjoying add-on?'),
('Languages::addons.is_enjoying_addon_name', 'Enjoying [addon]?'),
('Languages::rating', 'Rating'),
('Languages::view_in_marketplace', 'View in CS-Cart Marketplace'),
('Languages::addon_id', 'Add-on ID'),
('Languages::latest_available_version', 'Latest available version'),
('Languages::license_expires', 'License expires'),
('Languages::unsupported_browser_notice', '<p>We have detected that the browser you are using is not fully supported by our Admin Panel. You can view this site using your current browser but it may not display properly, and you may not be able to fully use all features.</p><br><p>Admin Panel is best viewed using the following browsers:</p><br><ul><li>&ndash; <a href="http://www.mozilla.org/en-US/" target="_blank">Mozilla Firefox (latest version)</a></li><li>&ndash; <a href="https://www.google.com/intl/en/chrome/browser/" target="_blank">Google Chrome (latest version)</a></li><li>&ndash; <a href="https://www.microsoft.com/en-us/edge" target="_blank">Microsoft Edge (latest version)</a></li><li>&ndash; <a href="https://www.apple.com/safari/" target="_blank">Safari (latest version)</a></li></ul><br><p>Click on one of the links to download the browser of your choice. Once the download has completed, install the browser by running the setup program.</p><br><p>If you cannot upgrade your browser now, you can still access Admin Panel, but you may not be able to fully use all features.<br><br><a href="[url]">Continue</a></p>'),
('Languages::usergroup_must_have_privileges', 'Usergroup must have at least one privilege.'),
('Languages::saved_search.set_as_default', 'Set as default'),
('Languages::saved_search.set_as_non_default', 'Set as non-default'),
('Languages::saved_search.more_short', 'More'),
('Languages::saved_search.set_as_default_confirm', 'Saved search "[name]" will open by default instead of the full list of objects. Is that what you''d like?'),
('Languages::saved_search.set_as_non_default_confirm', 'The full list of objects will open by default instead of saved search "[name]". Is that what you''d like?'),
('Languages::exim_subtotal_discount', 'Subtotal discount'),
('Languages::storefront_languages_assigned', 'The "<a href="[url]">[name]</a>" storefront had no available languages configured. All languages has been made available for it.'),
('Languages::storefront_currencies_assigned', 'The "<a href="[url]">[name]</a>" storefront had no available currencies configured. Default currency has been made available for it.'),
('Languages::storefront_all_currencies_assigned', 'The "<a href="[url]">[name]</a>" storefront had no available currencies configured. All currencies has been made available for it.'),
('Languages::storefronts_for_language_absent', 'The <b>[name]</b> language had no storefronts selected. All storefronts has been made available for it.'),
('Languages::storefronts_for_currency_absent', 'The <b>[name]</b> currency had no storefronts selected. All storefronts has been made available for it.'),
('Languages::event.product.back_in_stock.name', 'Product is back in stock'),
('Languages::core_addon', 'CS-Cart'),
('Languages::text_menus_have_been_deleted', 'Menus have been deleted successfully.'),
('Languages::addon_added_to_favorites', 'Add-on added to your favorites'),
('Languages::addon_removed_from_favorites', 'Add-on removed from your favorites'),
('Languages::contact_the_developer', 'Contact the developer'),
('Languages::message_successfully_sent_to_developer', 'Message was successfully sent to [developer]'),
('Languages::delete_subscribers', 'Delete subscribers'),
('Languages::addons.error_while_sending_review', 'Your add-on review was not posted to marketplace. Please make sure that you acquire this add-on from CS-Cart Marketplace and try again later.'),
('Languages::addons.upgrade_to_product_version', 'Upgrade to [product] [version]'),
('Languages::addons.latest_version', 'Latest released version'),
('Languages::addons.latest_available_for_installation_version', 'Latest version available for installation'),
('Languages::product_availability', 'Product availability'),
('Languages::addons.text_thank_you_for_post', 'Thank you for your post'),
('Languages::addons.text_post_pended', 'Your post will be checked before it gets published.'),
('Languages::addons.your_account_doesnt_have_this_addon', 'You can not create a add-on review because you do not have this add-on purchased in your Marketplace account.'),
('Languages::addons.you_already_posted_review', 'You can not create a add-on review because you already have a review that requires premoderation'),
('Languages::addons.something_went_wrong', 'Something went wrong with your request. Please try again later.'),
('Languages::addons.your_message', 'Your message'),
('Languages::addons.not_installed', 'Not installed'),
('Languages::addons.install', 'Install'),
('Languages::addons.disabled', 'Disabled'),
('Languages::addons.activate', 'Activate'),
('Languages::addons.mve_ult_or_plus_required', '[product] Plus or Ultimate required'),
('Languages::addons.ult_required', '[product] Ultimate required'),
('Languages::addons.upgrade_available', 'Upgrade available'),
('Languages::addons.upgrades', 'Upgrades'),
('Languages::addons.error_at_sending_addon_review', 'Something went wrong at sending add-on review. Please try again later.'),
('Languages::unable_delete_storefront_orders_exists', 'Unable to delete this storefront because there are orders containing the products of this storefront in the store database. To delete the storefront, please delete all such orders first.'),
('Languages::state_field_required_only_for_countries_with_regions', 'The "State" field is required for all countries with states or provinces. If you don''t have states for the customer''s country, then the field will be required at checkout only if it is required in the customer''s profile.'),
('Languages::need_storefront_id', 'Storefront ID is required (the storefront_id param)'),
('Languages::addons.multiple_dependencies_required', 'The add-on cannot be installed because it depends on the following add-ons:<ul>[addon_list]</ul> Please install these add-ons first.'),
('Languages::products_are_not_selectable_for_context_menu', 'You can not select products that belong to another storefront.'),
('Languages::product_filters_are_not_selectable_for_context_menu', 'You can not select product filters that belong to another storefront.'),
('Languages::product_options_are_not_selectable_for_context_menu', 'You can not select product options that belong to another storefront'),
('Languages::product_features_are_not_selectable_for_context_menu', 'You can not select product features that belong to another storefront.'),
('Languages::product_feature_groups_are_not_selectable_for_context_menu', 'You can not select product feature groups that belong to another storefront.'),
('Languages::removing_default_language_from_storefront', 'Sorry, we couldn''t remove the [language_name] language from storefront [storefront_name]. To remove it, please go to <b>Settings → Appearance</b> and change the <b>Frontend default language</b> for storefront [storefront_name] first.|Sorry, we couldn''t remove the [language_name] language from storefronts: [storefront_name]. To remove it, please go to <b>Settings → Appearance</b> and change the <b>Frontend default language</b> for storefronts: [storefront_name] first.'),
('Languages::sw.vendor_panel', 'Vendor panel'),
('Languages::sw.easy_admin_panel_for_vendors', 'Easy admin panel for vendors'),
('Languages::sw.product_tabs_and_properties', 'Product tabs and properties'),
('Languages::sw.branding_and_colors', 'Branding and colors'),
('Languages::create_new_product', 'Create new product'),
('Languages::import_products', 'Import products'),
('Languages::thank_you_for_registration', 'Thank you for registration!'),
('Languages::helpdesk_account.helpdesk_account', 'Help Desk account'),
('Languages::helpdesk_account.sign_in', 'Sign in'),
('Languages::helpdesk_account.sign_out', 'Sign out'),
('Languages::helpdesk_account.sign_up', 'Sign up'),
('Languages::helpdesk_account.signed_in_message', 'Signed in'),
('Languages::helpdesk_account.signed_out_message', 'Sign in with your Help Desk account to access all CS-Cart services using single account.'),
('Languages::helpdesk_account.signed_out_message.marketplace', 'Sign in with your Help Desk account to get information about newest add-on versions from Marketplace, rate and review add-ons you''ve bought, and prolong your license subscriptions.'),
('Languages::helpdesk_account.signed_out_message.marketplace_single_addon', 'Sign in with your Help Desk account to get information about newest add-on versions from Marketplace, rate and review this add-on, and prolong your license subscription.'),
('Languages::helpdesk_account.request_permissions_from_store_owner_to_manage_addons', 'You need to have the according permission from the store owner to manage add-ons.'),
('Languages::helpdesk_account.request_permissions', 'Request permissions'),
('Languages::helpdesk_account.sign_in_to_manage_addons', 'Sign in with your Help Desk account to manage add-ons.'),
('Languages::link_from_layout', 'Link blocks from layout'),
('Languages::use_for_all_new_vendors', 'Use for all new vendors'),
('Languages::show_vendor_info_if_shipping_no_required', 'Show information about vendors whose products do not require shipping'),
('Languages::sw.money_split_automaticaly_descr.ru', 'This is achieved via YooMoney for marketplaces, so each vendor must have a YooMoney account. We''ll create a payment method for you. You''ll just need to configure it, and vendors will need to provide their account information.'),
('Languages::delete_my_account', 'Delete my account'),
('Languages::delete_my_account_description', '<p>We’ll deactivate your account and remove all your personal data from it. After that you won’t be able to sign in. However, you’ll be able to register a new account with the same email address in the future. Please note that we’ll need some time to process this request, so your account won’t be deactivated immediately. If you have any comments regarding your request, please leave them in the field below.</p>'),
('Languages::email_body_anonymization_request', '<p><a href="[user_profile_url]" target="_blank">[user]</a> with the email address [customer_email] has requested the removal of personal data with the following comment:</p> <p>[comment]</p> <p>Make sure that all business with the customer (orders, return requests, etc.) is concluded. Then <a href="[user_profile_url]" target="_blank">go to the customer page in the admin panel</a> and choose the "Anonymize" action. This will remove the customer''s personal data (including email, name, etc.) everywhere in the system, while retaining the data relevant to your business (ordered products, etc). The customer will be able to register a new account with the same email.</p>'),
('Languages::email_subject_anonymization_request', 'Personal Data Removal Request: [customer_email]'),
('Languages::user_action_request_fail', 'An error has occurred during the attempt to send your request. Please try again or send a message to the following email address: <a href="mailto:[email]">[email]</a>'),
('Languages::user_action_request_success', 'Your request has been sent successfully.'),
('Languages::anonymize', 'Anonymize'),
('Languages::text_anonymize_question', 'Once you anonymize someone, all their personal information will be replaced with randomly-generated data. This action can not be undone, unless you restore the database from a backup. Are you sure you want to proceed?'),
('Languages::check_other_sources_for_personal_data', '<p>Please note that anonymization doesn''t affect any backups and logs that you might have. If necessary, please do the following:</p><ol><li>Clear the logs under <b>Administration → Logs</b>.</li><li>Secure and delete the backups you might have under <b>Administration → Backup/Restore</b>.</li></ol>'),
('Languages::user_anonymized', 'User has been anonymized.'),
('Languages::license_error_wrong_edition_build', 'The license number your site is using doesn''t match the installed software. This may get the license suspended. Please <a href="[helpdesk_url]" target="_blank">contact us via Help Desk</a>, and we''ll be able to look into it.'),
('Languages::license_error_wrong_edition_build_entered', 'The license number you''ve entered is incorrect or doesn''t suit the product. If you''re sure that the license number is correct, please <a href="[helpdesk_url]" target="_blank">contact us via Help Desk</a>, and we''ll look into it.'),
('Languages::privileges.manage_admin_usergroups', 'Can manage admin user groups (only if managing customer user groups is allowed)'),
('Languages::privilege_groups.disable_sanitize_html', 'Use advanced HTML code in content'),
('Languages::event.system.helpdesk_process_message.name', 'Notifications from CS-Cart team'),
('Languages::category_template', 'Category template'),
('Languages::exim_error_incorrect_concrete_feature_type', 'Incorrect feature type ''[feature_type]'' of the ''[feature_name]'' product feature. The product feature was skipped.'),
('Languages::product_state_description.ult.free.free', '<p>You''re using CS-Cart Free. It has all the functionality to launch your own independent online store, free of charge. If you ever need the extended functionality of CS-Cart Standard or Ultimate — such as user groups, advanced product settings, multiple storefronts, and more — please contact us.</p>'),
('Languages::product_state_description.ult.free_ru.free', '<p>You''re using CS-Cart Free. It has all the functionality to launch your own independent online store, free of charge. If you ever need the extended functionality of CS-Cart Standard or Ultimate — such as user groups, advanced product settings, multiple storefronts, and more — please contact us.</p>'),
('Languages::contact_us', 'Contact us'),
('Languages::ultimate_or_storefront_license_required.ult.free', 'This action requires [product] Ultimate'),
('Languages::ultimate_or_storefront_license_required.ult.free_ru', 'This action requires [product] Ultimate'),
('Languages::max_storefronts_reached.ult.free', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::max_storefronts_reached.ult.free_ru', '<p>You have reached the limit of storefronts available for your license. To add another storefront, please upgrade to <a href="[ultimate_license_url]" target="_blank">[product] Ultimate</a>.</p>'),
('Languages::helpdesk_account.activate_free_license_message', 'Create an account in our Help Desk system. It will allow you to upgrade your store, contact our Customer Care team, and get add-ons (both paid and free) from the CS-Cart Marketplace for add-ons and themes.'),
('Languages::helpdesk_account.activate_free_license_short_message', 'Create an account in our Help Desk to upgrade your store, receive support, and get free or paid add-ons from our Add-on Market.'),
('Languages::helpdesk_account.activate_free_license_message_send', 'An activation link for your free CS-Cart license was sent to the email: [email]'),
('Languages::no_items_for_marketplace_administrator', 'No items to show for marketplace administrator. Try to check the section as a vendor.'),
('Languages::sync_data_update_template_not_found', 'No template found for this sync provider. Please make sure the "update_template" field is filled in the "sync_data" schema.'),
('Languages::disabling_primary_currency_disallowed', 'Currency cannot be disabled as it is primary. Make a different currency primary first.'),
('Languages::product_env.released_n_years_ago', 'released <u title="[month] [year]">[n] year ago</u>|released <u title="[month] [year]">[n] years ago</u>'),
('Languages::product_env.released_n_months_ago', 'released <u title="[month] [year]">[n] month ago</u>|released <u title="[month] [year]">[n] months ago</u>'),
('Languages::product_env.released_this_month', 'released this month'),
('Languages::product_env.current_version', 'Current version'),
('Languages::product_env.available_upgrade', 'Available upgrade'),
('Languages::product_env.latest_version', 'Latest version'),
('Languages::product_env.now_running', 'You are using [release_info]'),
('Languages::product_env.can_upgrade_store', 'You can upgrade your store to [release_info]'),
('Languages::product_env.latest_product_version', 'The latest version is [release_info]'),
('Languages::product_env.dont_miss_features', 'Don''t miss all the new features!'),
('Languages::product_env.upgrade_to_latest_version', 'Upgrade to the latest version'),
('Languages::product_env.up_to_date', 'You are up to date'),
('Languages::notification_settings.profile.receivers', 'Users whose profile was changed'),
('Languages::dashboard.analytics_section_title', 'Analytics'),
('Languages::dashboard.view_reports', 'View reports'),
('Languages::dashboard.view_report', 'View report'),
('Languages::dashboard.view_all', 'View all'),
('Languages::dashboard.view', 'View'),
('Languages::dashboard.analytics_card.sales', 'Sales'),
('Languages::dashboard.analytics_card.unlimited', 'Unlimited'),
('Languages::dashboard.analytics_card.top_products', 'Top products'),
('Languages::dashboard.analytics_card.active_products', 'Active products'),
('Languages::dashboard.analytics_card.view_products', 'View products'),
('Languages::dashboard.analytics_card.products_details', 'Products details'),
('Languages::dashboard.analytics_card.out_of_stock', 'Out of stock'),
('Languages::dashboard.analytics_card.recent_orders', 'Recent orders'),
('Languages::dashboard.analytics_card.view_orders', 'View orders'),
('Languages::dashboard.analytics_card.average_order_value', 'Average order value'),
('Languages::dashboard.analytics_card.orders', 'Orders'),
('Languages::dashboard.analytics_card.activity', 'Activity'),
('Languages::dashboard.analytics_card.vendors_with_sales', 'Vendors with sales'),
('Languages::dashboard.analytics_card.view_stores', 'View storefronts'),
('Languages::dashboard.analytics_card.vendor_activity', 'Vendor activity'),
('Languages::dashboard.analytics_card.new_vendors', 'New vendors'),
('Languages::dashboard.analytics_card.vendors_with_new_products', 'Vendors with new products'),
('Languages::dashboard.analytics_card.vendors_not_logged', 'Vendors who haven''t signed in'),
('Languages::dashboard.analytics_card.new_products', 'New products'),
('Languages::dashboard.analytics_card.stores', 'Storefronts'),
('Languages::dashboard.analytics_card.registered_customers', 'Registered customers'),
('Languages::dashboard.analytics_card.view_customers', 'View customers'),
('Languages::custom_blocks.sections.onboarding_title', 'Onboarding Guide'),
('Languages::custom_blocks.create_block', 'Create block'),
('Languages::custom_blocks.edit_block', 'Edit block'),
('Languages::custom_blocks.name', 'Name'),
('Languages::custom_blocks.url', 'URL'),
('Languages::custom_blocks.url.hint', 'A link can lead to an external site (like https://example.com) or somewhere in the vendor admin panel (use the part after "?dispatch=" from the address bar of your browser).'),
('Languages::custom_blocks.first_menu_level_url.hint', 'If you enter a link, then the menu item will lead to the specified page, and won''t open the menu section. A link can lead to an external site (like https://example.com) or somewhere in the vendor admin panel (use the part after "?dispatch=" from the address bar of your browser).'),
('Languages::custom_blocks.content', 'Content'),
('Languages::custom_blocks.use_this_space', 'Use this space for announcements that all your vendors will see. You can write a plain text or use HTML and CSS for customization.'),
('Languages::custom_blocks.dismissed_by_vendor', 'This block was dismissed by this vendor. Other vendors may still see it.'),
('Languages::custom_menu.section_has_one_visible_item', 'This section has only one visible menu item. That item will appear instead of the section.'),
('Languages::custom_menu.item_hidden_due_to_privileges', 'This vendor can''t see this menu item due to privileges. Other vendors may still see it.'),
('Languages::dashboard.todo.has_products_without_category', '<strong>[n] product</strong> doesn''t have a category. Please assign it a category, or customers might not see it.|<strong>[n] products</strong> don''t have a category. Please assign them a category, or customers might not see them.'),
('Languages::dashboard.todo.upgrade_center_core_upgrade_available', 'A new version of CS-Cart is available.'),
('Languages::dashboard.todo.upgrade_center_addons_upgrade_available', 'New versions are available for some of your add-ons.'),
('Languages::addon_market', 'Add-on Market'),
('Languages::addon_market_n', 'Add-on Market ([n])'),
('Languages::downloaded_add_ons', 'Downloaded add-ons'),
('Languages::addons_developers', 'Developers'),
('Languages::safe_smarty_block', 'HTML block with Smarty support'),
('Languages::block_safe_smarty_block', 'HTML block with Smarty support'),
('Languages::block_safe_smarty_block_description', 'Any HTML/Smarty content'),
('Languages::block_smarty_block_deprecated_notice', 'This block type is deprecated for security reasons. The block still works, but its content can''t be edited. To edit the content, create a new "HTML block with Smarty support" and copy the content from this block to the new one. After that, check if the new block works properly on the storefront—the code that is potentially dangerous might not work.'),
('Languages::themes.google_fonts_was_replaced', 'The google fonts of your styles has been replaced successfully'),
('Languages::themes.google_fonts_replace_error', 'Couldn''t replace google fonts of your styles'),
('Languages::disabled_product_not_added_to_cart', 'This product is disabled and cannot be added to the cart'),
('Languages::ship_ups_access_token', 'UPS App access token'),
('Languages::ship_ups_access_token_expiration', 'UPS App access token expiration'),
('Languages::ship_ups_client_id', 'UPS App client ID'),
('Languages::ship_ups_client_secret', 'UPS App client secret'),
('Languages::authorize', 'Authorize'),
('SettingsSections::Appearance', 'Appearance'),
('SettingsSections::Company', 'Company'),
('SettingsSections::Emails', 'E-mails'),
('SettingsSections::General', 'General'),
('SettingsSections::Image_verification', 'Image verification'),
('SettingsSections::Logging', 'Logging'),
('SettingsSections::Reports', 'Reports'),
('SettingsSections::Security', 'Security settings'),
('SettingsSections::Checkout', 'Checkout'),
('SettingsSections::Sitemap', 'Sitemap'),
('SettingsSections::Stores', 'Stores'),
('SettingsSections::Thumbnails', 'Thumbnails'),
('SettingsSections::Upgrade_center', 'Upgrade center'),
('SettingsOptions::company_name', 'Company name'),
('SettingsOptions::secure_admin', 'Enable secure connection in the administration panel'),
('SettingsOptions::secure_storefront', 'Enable secure connection for the storefront'),
('SettingsOptions::license_number', 'License number'),
('SettingsOptions::alternative_currency', 'Alternative currency display format'),
('SettingsOptions::company_address', 'Company address'),
('SettingsOptions::show_cats', 'Show the ''Categories'' section'),
('SettingsOptions::mailer_send_method', 'Method of sending e-mails'),
('SettingsOptions::width', 'Image width'),
('SettingsOptions::log_lifetime', 'Days before a log entry is removed'),
('SettingsOptions::log_type_orders', 'Orders'),
('SettingsOptions::log_type_users', 'Users'),
('SettingsOptions::log_type_products', 'Products'),
('SettingsOptions::log_type_categories', 'Categories'),
('SettingsOptions::log_type_database', 'Database'),
('SettingsOptions::log_type_requests', 'Requests'),
('SettingsOptions::min_account_password_length', 'Minimum password length'),
('SettingsOptions::header_1', 'Administrator  settings'),
('SettingsOptions::header_7010', 'Format of time intervals'),
('SettingsOptions::share_users', 'Share users among stores'),
('SettingsOptions::log_type_general', 'General'),
('SettingsOptions::backend_default_language', 'Backend default language'),
('SettingsOptions::company_city', 'Company city'),
('SettingsOptions::day', 'Day'),
('SettingsOptions::show_rootcats_only', 'Show only root level categories links in the ''Categories'' section'),
('SettingsOptions::height', 'Image height'),
('SettingsOptions::account_passwords_must_contain_mix', 'Password must contain both letters and numbers'),
('SettingsOptions::header_10003', 'SMTP server settings'),
('SettingsOptions::header_8158', 'FTP server options'),
('SettingsOptions::default_state_update_for_all', 'Default state of the "Update for all stores" icon'),
('SettingsOptions::ftp_hostname', 'Hostname'),
('SettingsOptions::weight_symbol', 'Weight symbol'),
('SettingsOptions::company_country', 'Company country'),
('SettingsOptions::week', 'Week'),
('SettingsOptions::mailer_smtp_host', 'SMTP host'),
('SettingsOptions::string_length', 'String length'),
('SettingsOptions::change_admin_password_on_first_login', 'Force administrators to change password on the first login'),
('SettingsOptions::show_site_info', 'Show the ''Site info'' section'),
('SettingsOptions::lines_number', 'Number of grid lines'),
('SettingsOptions::grid_color', 'Grid color (hexadecimal code)'),
('SettingsOptions::ftp_username', 'Username'),
('SettingsOptions::company_state', 'Company state'),
('SettingsOptions::weight_symbol_grams', 'Grams in the unit of weight defined by the weight symbol'),
('SettingsOptions::month', 'Month'),
('SettingsOptions::mailer_smtp_username', 'SMTP username'),
('SettingsOptions::min_font_size', 'Minimum font size'),
('SettingsOptions::account_password_expiration_period', 'Password validity period in days (0 - unlimited)'),
('SettingsOptions::ftp_password', 'Password'),
('SettingsOptions::company_zipcode', 'Company zip code'),
('SettingsOptions::year', 'Year'),
('SettingsOptions::mailer_smtp_password', 'SMTP password'),
('SettingsOptions::max_font_size', 'Maximum font size'),
('SettingsOptions::store_mode', 'Close storefront'),
('SettingsOptions::cron_password', 'Access key to cron script which sends e-mail notifications of password change.'),
('SettingsOptions::order_start_id', 'Initial order ID value'),
('SettingsOptions::tax_calculation', 'Tax calculation method based on'),
('SettingsOptions::feedback_type', 'Help us improve software'),
('SettingsOptions::auto_check_updates', 'Check for updates automatically'),
('SettingsOptions::ftp_directory', 'Directory'),
('SettingsOptions::admin_elements_per_page', 'Elements per page'),
('SettingsOptions::company_phone', 'Company phone'),
('SettingsOptions::default_wysiwyg_editor', 'Default wysiwyg editor'),
('SettingsOptions::mailer_smtp_auth', 'Use SMTP authentication'),
('SettingsOptions::string_type', 'String type'),
('SettingsOptions::header_7003', 'Default customer location'),
('SettingsOptions::char_shadow', 'Character shadows'),
('SettingsOptions::default_address', 'Default address'),
('SettingsOptions::company_phone_2', 'Company phone 2'),
('SettingsOptions::image_file_size', 'Image file size'),
('SettingsOptions::thumbnail_background_color', 'Thumbnail background color'),
('SettingsOptions::colour', 'Color'),
('SettingsOptions::header_2', 'Customer settings'),
('SettingsOptions::header_10004', 'Sendmail settings'),
('SettingsOptions::default_zipcode', 'Default zipcode'),
('SettingsOptions::frontend_default_language', 'Frontend default language'),
('SettingsOptions::frontend_default_currency', 'Frontend default currency'),
('SettingsOptions::convert_to', 'Thumbnail format'),
('SettingsOptions::mailer_sendmail_path', 'Path to sendmail program'),
('SettingsOptions::background_image', 'Background image'),
('SettingsOptions::hide_if_logged', 'Do not use verification if user is logged in'),
('SettingsOptions::hide_after_validation', 'Do not use verification after first valid answer'),
('SettingsOptions::default_city', 'Default city'),
('SettingsOptions::company_website', 'Company website'),
('SettingsOptions::orders_per_page', 'Orders per page'),
('SettingsOptions::jpeg_quality', 'JPEG format quality (0-100)'),
('SettingsOptions::company_start_year', 'Year when the store started its operation'),
('SettingsOptions::default_country', 'Default country'),
('SettingsOptions::products_per_page', 'Products per page'),
('SettingsOptions::company_users_department', 'User department e-mail address'),
('SettingsOptions::use_for', 'Use for'),
('SettingsOptions::product_lists_thumbnail_width', 'Products list (category, search, etc) thumbnail width'),
('SettingsOptions::default_state', 'Default state'),
('SettingsOptions::company_site_administrator', 'Site administrator e-mail address'),
('SettingsOptions::product_lists_thumbnail_height', 'Products list (category, search, etc) thumbnail height'),
('SettingsOptions::company_orders_department', 'Order department e-mail address'),
('SettingsOptions::default_phone', 'Default phone'),
('SettingsOptions::product_details_thumbnail_width', 'Product details page thumbnail width'),
('SettingsOptions::header_7004', 'Catalog'),
('SettingsOptions::company_support_department', 'Help/Support department e-mail address'),
('SettingsOptions::elements_per_page', 'Elements per page'),
('SettingsOptions::inventory_tracking', 'Enable inventory tracking'),
('SettingsOptions::product_details_thumbnail_height', 'Product details page thumbnail height'),
('SettingsOptions::allow_negative_amount', 'Allow negative amount in inventory'),
('SettingsOptions::product_quick_view_thumbnail_width', 'Product quick view thumbnail width'),
('SettingsOptions::product_quick_view_thumbnail_height', 'Product quick view thumbnail height'),
('SettingsOptions::product_admin_mini_icon_width', 'Admin panel: product mini-icon thumbnail width'),
('SettingsOptions::product_admin_mini_icon_height', 'Admin panel: product mini-icon thumbnail height'),
('SettingsOptions::company_newsletter_email', 'Reply-To newsletter e-mail address'),
('SettingsOptions::edp_key_ttl', 'Download key TTL (for electronically distributed products), hours'),
('SettingsOptions::low_stock_threshold', 'Low stock notification threshold'),
('SettingsOptions::columns_in_products_list', 'Number of columns in the product list'),
('SettingsOptions::show_products_from_subcategories', 'Show products from subcategories of the selected category'),
('SettingsOptions::display_options_modifiers', 'Display modifiers for product options'),
('SettingsOptions::default_options_type', 'Options type'),
('SettingsOptions::default_tracking', 'Track inventory'),
('SettingsOptions::default_exceptions_type', 'Exceptions type'),
('SettingsOptions::default_zero_price_action', 'Zero price action'),
('SettingsOptions::default_min_qty', 'Minimum quantity to buy per product'),
('SettingsOptions::default_max_qty', 'Maximum quantity to buy per product'),
('SettingsOptions::default_qty_step', 'Quantity step'),
('SettingsOptions::default_list_qty_count', 'Number of available quantities'),
('SettingsOptions::exception_style', 'Exception style'),
('SettingsOptions::product_cart_thumbnail_width', 'Product cart page thumbnail width'),
('SettingsOptions::product_cart_thumbnail_height', 'Product cart page thumbnail height'),
('SettingsOptions::show_out_of_stock_products', 'Show out of stock products'),
('SettingsOptions::category_lists_thumbnail_width', 'Categories list thumbnail width'),
('SettingsOptions::taxes_using_default_address', 'Estimate taxes using default address on cart/checkout pages'),
('SettingsOptions::show_prices_taxed_clean', 'Display prices with taxes on category/product pages'),
('SettingsOptions::cart_prices_w_taxes', 'Display prices with taxes on cart/checkout pages'),
('SettingsOptions::in_stock_field', 'Show number of available products'),
('SettingsOptions::thumbnails_gallery', 'Display mini thumbnail images as a gallery'),
('SettingsOptions::quantity_changer', 'Use ''Value changer'' for the Quantity field'),
('SettingsOptions::top_pagination', 'Display the ''Pagination section'' on the top of the listed object'),
('SettingsOptions::default_image_previewer', 'Default image previewer'),
('SettingsOptions::category_lists_thumbnail_height', 'Categories list thumbnail height'),
('SettingsOptions::default_product_details_view', 'Product detailed page view'),
('SettingsOptions::product_details_in_tab', 'Display product details in tabs'),
('SettingsOptions::display_track_orders', 'Display track my orders section'),
('SettingsOptions::header_10070', 'Products list layouts settings'),
('SettingsOptions::default_products_view_templates', 'Available product list views'),
('SettingsOptions::default_products_view', 'Product list default view'),
('SettingsOptions::save_selected_view', 'Use the selected view for current category or search page only'),
('SettingsOptions::available_product_list_sortings', 'Available product list sortings'),
('SettingsOptions::default_products_sorting', 'Product list default sorting'),
('SettingsOptions::enable_quick_view', 'Enable quick view'),
('SettingsOptions::header_10080', 'Common settings'),
('SettingsOptions::date_format', 'Date format'),
('SettingsOptions::category_details_thumbnail_width', 'Category details page thumbnail width'),
('SettingsOptions::time_format', 'Time format'),
('SettingsOptions::category_details_thumbnail_height', 'Category details page thumbnail height'),
('SettingsOptions::header_7024', 'Promotions'),
('SettingsOptions::timezone', 'Time zone'),
('SettingsOptions::category_detailed_image_width', 'Detailed category image width'),
('SettingsOptions::use_single_coupon', 'Allow customers to use single discount coupon only'),
('SettingsOptions::calendar_date_format', 'Calendar date format'),
('SettingsOptions::category_detailed_image_height', 'Detailed category image height'),
('SettingsOptions::header_7005', 'Users'),
('SettingsOptions::user_multiple_profiles', 'Allow users to create multiple profiles for one account'),
('SettingsOptions::calendar_week_format', 'Calendar week starts from'),
('SettingsOptions::min_order_amount', 'Minimum order amount'),
('SettingsOptions::min_order_amount_type', 'Define minimum order amount by'),
('SettingsOptions::allow_anonymous_shopping', 'Allow shopping for unlogged customers'),
('SettingsOptions::disable_anonymous_checkout', 'Disable anonymous checkout'),
('SettingsOptions::checkout_redirect', 'Allow checkout only from cart'),
('SettingsOptions::allow_usergroup_signup', 'Allow customer to signup for user group'),
('SettingsOptions::approve_user_profiles', 'Administrator must activate new user accounts'),
('SettingsOptions::address_position', 'Profile address section order'),
('SettingsOptions::changes_warning', 'Unsaved changes warning'),
('SettingsOptions::notice_displaying_time', 'Notice displaying time (to turn off the autohide function enter 0)'),
('SettingsOptions::quick_registration', 'Quick registration'),
('SettingsOptions::agree_terms_conditions', 'Ask customers to agree with terms &amp; conditions during checkout'),
('SettingsOptions::estimate_shipping_cost', 'Estimate shipping cost on cart page'),
('SettingsOptions::allow_create_account_after_order', 'Offer guest to create an account after successful order'),
('SettingsOptions::disregard_options_for_discounts', 'Disregard product options when calculating quantity discounts'),
('SettingsOptions::header_8057', 'Proxy server for outgoing connections'),
('SettingsOptions::proxy_host', 'Proxy host'),
('SettingsOptions::proxy_port', 'Proxy port'),
('SettingsOptions::proxy_user', 'Proxy user'),
('SettingsOptions::proxy_password', 'Proxy password'),
('SettingsOptions::header_15000', 'Search options'),
('SettingsOptions::search_objects', 'Search also in'),
('SettingsOptions::mailer_smtp_ecrypted_connection', 'Use Encrypted Connection'),
('SettingsOptions::configure_sign_in_step', 'Configure "Sign in" step'),
('SettingsOptions::sign_in_default_action', 'Default option for the "New customer" section at the "Sign in"'),
('SettingsOptions::display_shipping_step', 'Display "Shipping method" step'),
('SettingsOptions::email_templates', 'Email templates mode'),
('SettingsOptions::phone_validation_mode', 'Supported phone numbers'),
('SettingsOptions::display_payment_step', 'Display "Payment method" step'),
('SettingsOptions::enable_edp', 'Enable selling downloadable products'),
('SettingsOptions::enable_compare_products', 'Allow customers to compare products'),
('SettingsOptions::monitor_core_changes', 'Monitor changes in core files'),
('SettingsOptions::show_unavailable_shipping_methods', 'Show unavailable shippings'),
('SettingsOptions::product_variant_mini_icon_width', 'Product variant selector thumbnail width'),
('SettingsOptions::product_variant_mini_icon_height', 'Product variant selector thumbnail height'),
('SettingsOptions::show_delete_account_button', 'Show "Delete my account" button'),
('SettingsTooltips::log_lifetime', 'Enter 0 if you don''t want any automatic removal of old logs.'),
('SettingsTooltips::cron_password', 'Use: http://www.example.com/admin.php?dispatch=profiles.password_reminder&cron_password=key_value.'),
('SettingsTooltips::default_min_qty', 'Sell no less than X units of a product in an order.'),
('SettingsTooltips::default_max_qty', 'Sell no more than X units of a product in an order.'),
('SettingsTooltips::default_qty_step', 'Increase or decrease the number of purchased product units only by X.'),
('SettingsTooltips::default_list_qty_count', 'Replace product quantity selector with a dropdown list with X variants.'),
('SettingsTooltips::show_prices_taxed_clean', 'Only if the tax calculation method is based on unit price.'),
('SettingsTooltips::cart_prices_w_taxes', 'Only if the tax calculation method is based on unit price.'),
('SettingsTooltips::agree_terms_conditions', 'The text of terms & conditions is in the "terms_and_conditions_content" language variable.'),
('SettingsTooltips::configure_sign_in_step', 'This step can be hidden only if it doesn''t have any required contact info fields and anonymous checkout is allowed.'),
('SettingsTooltips::display_shipping_step', 'If the step is hidden, the first active method will be used by default.'),
('SettingsTooltips::display_payment_step', 'If the step is hidden, the first active method will be used by default.'),
('SettingsTooltips::secure_storefront', 'SSL certificate must be installed on your server.'),
('SettingsTooltips::secure_admin', 'SSL certificate must be installed on your server.'),
('SettingsTooltips::order_start_id', 'Use a number between 1 and 10000000 or leave empty for auto-filling.'),
('SettingsTooltips::user_multiple_profiles', 'A profile is a combination of shipping and billing address.'),
('SettingsTooltips::image_file_size', 'The maximum size of an uploaded image file in megabytes. Leave empty to use the server settings.'),
('SettingsTooltips::thumbnail_background_color', 'Leave empty for transparent background.'),
('SettingsTooltips::checkout_redirect', 'Show the Checkout button only on the Cart Content page.'),
('SettingsTooltips::quick_registration', 'Require only contact information for registration.'),
('SettingsTooltips::show_unavailable_shipping_methods', 'Show real-time shipping methods even if their servers haven''t returned the rates'),
('SettingsTooltips::show_delete_account_button', 'Customers will see it on their profile page on the site.'),
('SettingsVariants::default_products_sorting::position', 'Default'),
('SettingsVariants::feedback_type::manual', 'Manual feedback'),
('SettingsVariants::feedback_type::auto', 'Automatic feedback'),
('SettingsVariants::date_format::%d/%m/%Y', '29/09/2005 (day/month/year)'),
('SettingsVariants::time_format::%H:%M', '15:43'),
('SettingsVariants::allow_anonymous_shopping::allow_shopping', 'Allow'),
('SettingsVariants::string_type::digits', 'Digits only'),
('SettingsVariants::calendar_date_format::month_first', '09/30/2008 (month/day/year)'),
('SettingsVariants::calendar_week_format::sunday_first', 'Sunday'),
('SettingsVariants::address_position::billing_first', 'Billing first'),
('SettingsVariants::log_type_general::runtime', 'Runtime'),
('SettingsVariants::default_state_update_for_all::not_active', 'Not Active'),
('SettingsVariants::date_format::%d-%m-%Y', '29-09-2005 (day-month-year)'),
('SettingsVariants::time_format::%H.%M', '15.43'),
('SettingsVariants::min_order_amount_type::products_with_shippings', 'Products with shipping'),
('SettingsVariants::allow_anonymous_shopping::hide_add_to_cart', 'Hide the "Add to cart" button'),
('SettingsVariants::string_type::letters', 'Letters only'),
('SettingsVariants::calendar_date_format::day_first', '30/09/2008 (day/month/year)'),
('SettingsVariants::calendar_week_format::monday_first', 'Monday'),
('SettingsVariants::address_position::shipping_first', 'Shipping first'),
('SettingsVariants::log_type_general::deprecated', 'Deprecated features'),
('SettingsVariants::default_state_update_for_all::active', 'Active'),
('SettingsVariants::date_format::%d.%m.%Y', '29.09.2005 (day.month.year)'),
('SettingsVariants::time_format::%I:%M %p', '3:43 PM'),
('SettingsVariants::min_order_amount_type::only_products', 'Products'),
('SettingsVariants::allow_anonymous_shopping::hide_price_and_add_to_cart', 'Hide price and the "Add to cart" button'),
('SettingsVariants::string_type::mixed', 'Mixed'),
('SettingsVariants::date_format::%m/%d/%Y', '09/29/2005 (month/day/year)'),
('SettingsVariants::time_format::%I.%M %p', '3.43 PM'),
('SettingsVariants::log_type_orders::create', 'Create'),
('SettingsVariants::log_type_orders::delete', 'Delete'),
('SettingsVariants::log_type_orders::update', 'Update'),
('SettingsVariants::log_type_products::create', 'Create'),
('SettingsVariants::log_type_products::delete', 'Delete'),
('SettingsVariants::log_type_products::update', 'Update'),
('SettingsVariants::log_type_users::create', 'Create'),
('SettingsVariants::log_type_users::delete', 'Delete'),
('SettingsVariants::log_type_users::update', 'Update'),
('SettingsVariants::log_type_categories::create', 'Create'),
('SettingsVariants::log_type_categories::delete', 'Delete'),
('SettingsVariants::log_type_categories::update', 'Update'),
('SettingsVariants::date_format::%m-%d-%Y', '09-29-2005 (month-day-year)'),
('SettingsVariants::time_format::%H:%M:%S', '15:43:55'),
('SettingsVariants::month::%B, %Y', 'January, 2006'),
('SettingsVariants::log_type_orders::status', 'Change'),
('SettingsVariants::log_type_users::session', 'Session'),
('SettingsVariants::log_type_users::failed_login', 'Failed logins'),
('SettingsVariants::log_type_products::low_stock', 'Low stock'),
('SettingsVariants::log_type_database::restore', 'Restore'),
('SettingsVariants::log_type_database::backup', 'Backup'),
('SettingsVariants::log_type_database::optimize', 'Optimize'),
('SettingsVariants::log_type_database::error', 'Errors'),
('SettingsVariants::log_type_requests::http', 'HTTP/HTTPS'),
('SettingsVariants::date_format::%m.%d.%Y', '09.29.2005 (month.day.year)'),
('SettingsVariants::time_format::%H.%M.%S', '15.43.55'),
('SettingsVariants::date_format::%Y/%m/%d', '2005/09/29 (year/month/day)'),
('SettingsVariants::time_format::%I:%M:%S %p', '3:43:55 PM'),
('SettingsVariants::date_format::%Y-%m-%d', '2005-09-29 (year-month-day)'),
('SettingsVariants::time_format::%I.%M.%S %p', '3.43.55 PM'),
('SettingsVariants::date_format::%Y.%m.%d', '2005.09.29 (year.month.day)'),
('SettingsVariants::exception_style::hide', 'Hide exception'),
('SettingsVariants::alternative_currency::use_only_selected', 'Show prices in selected currency only'),
('SettingsVariants::date_format::%b %e, %Y', 'Sep 29, 2005 (month day, year)'),
('SettingsVariants::default_products_sorting::product', 'Product name'),
('SettingsVariants::day::%a, %b %e', 'Tue, Jan 3'),
('SettingsVariants::week::%U', '1 week');
INSERT INTO `[[dbprefix]]original_values` VALUES
('SettingsVariants::month::%b', 'Jan'),
('SettingsVariants::year::%y', '06'),
('SettingsVariants::mailer_send_method::smtp', 'via SMTP server'),
('SettingsVariants::tax_calculation::unit_price', 'Unit price'),
('SettingsVariants::date_format::%d %b %Y', '29 Sep 2005 (day month year)'),
('SettingsVariants::date_format::%A, %B %e, %Y', 'Thursday, September 29, 2005 (day of week, month day, year)'),
('SettingsVariants::date_format::%A, %e %B %Y', 'Thursday, 29 September 2005 (day of week, day month year)'),
('SettingsVariants::day::%B %e, %Y', 'January 3, 2006'),
('SettingsVariants::exception_style::warning', 'Show warning on exception'),
('SettingsVariants::default_options_type::P', 'Simultaneous'),
('SettingsVariants::default_options_type::S', 'Sequential'),
('SettingsVariants::default_exceptions_type::F', 'Forbidden'),
('SettingsVariants::default_exceptions_type::A', 'Allowed'),
('SettingsVariants::default_zero_price_action::R', 'Do not allow customers to add the product to cart'),
('SettingsVariants::default_zero_price_action::P', 'Allow customers to add the product to cart'),
('SettingsVariants::default_zero_price_action::A', 'Ask customer to enter the price'),
('SettingsVariants::alternative_currency::use_selected_and_alternative', 'Show prices in default and selected currencies'),
('SettingsVariants::default_products_sorting::price', 'Price'),
('SettingsVariants::day::%m.%e.%y', '01.03.06'),
('SettingsVariants::week::%m.%e', '01.03'),
('SettingsVariants::month::%m', '01'),
('SettingsVariants::mailer_send_method::mail', 'via php mail function'),
('SettingsVariants::timezone::Pacific/Apia', '(GMT-11:00) Samoa'),
('SettingsVariants::tax_calculation::subtotal', 'Subtotal'),
('SettingsVariants::default_products_sorting::null', 'None'),
('SettingsVariants::day::%a %b %e, %Y', 'Tue Jan 3, 2006'),
('SettingsVariants::week::%U, %b', '1, Jan'),
('SettingsVariants::mailer_send_method::sendmail', 'via sendmail program'),
('SettingsVariants::timezone::Pacific/Honolulu', '(GMT-10:00) Hawaii'),
('SettingsVariants::day::%b %e', 'Jan 3'),
('SettingsVariants::month::%m-%Y', '01-2006'),
('SettingsVariants::timezone::America/Anchorage', '(GMT-09:00) Alaska'),
('SettingsVariants::timezone::America/Los_Angeles', '(GMT-08:00) Pacific Time (US & Canada); Tijuana'),
('SettingsVariants::timezone::America/Denver', '(GMT-07:00) Mountain Time (US & Canada)'),
('SettingsVariants::timezone::America/Chihuahua', '(GMT-07:00) Chihuahua, Mazatlan'),
('SettingsVariants::timezone::America/Phoenix', '(GMT-07:00) Arizona'),
('SettingsVariants::timezone::America/Regina', '(GMT-06:00) Saskatchewan'),
('SettingsVariants::timezone::America/Mexico_City', '(GMT-06:00) Guadalajara, Mexico City, Monterrey'),
('SettingsVariants::timezone::America/Chicago', '(GMT-06:00) Central Time (US & Canada)'),
('SettingsVariants::timezone::America/Guatemala', '(GMT-06:00) Central America'),
('SettingsVariants::timezone::America/New_York', '(GMT-05:00) Eastern Time (US & Canada)'),
('SettingsVariants::timezone::America/Bogota', '(GMT-05:00) Bogota, Lima, Quito'),
('SettingsVariants::timezone::America/Santiago', '(GMT-04:00) Santiago'),
('SettingsVariants::timezone::America/La_Paz', '(GMT-04:00) Caracas, La Paz'),
('SettingsVariants::timezone::America/Halifax', '(GMT-04:00) Atlantic Time (Canada)'),
('SettingsVariants::timezone::America/St_Johns', '(GMT-03:30) Newfoundland'),
('SettingsVariants::timezone::America/Nuuk', '(GMT-03:00) Greenland'),
('SettingsVariants::timezone::America/Sao_Paulo', '(GMT-03:00) Brasilia'),
('SettingsVariants::timezone::Atlantic/South_Georgia', '(GMT-02:00) Mid-Atlantic'),
('SettingsVariants::timezone::Atlantic/Cape_Verde', '(GMT-01:00) Cape Verde Is.'),
('SettingsVariants::timezone::Atlantic/Azores', '(GMT-01:00) Azores'),
('SettingsVariants::timezone::Atlantic/Reykjavik', '(GMT) Reykjavik, Monrovia'),
('SettingsVariants::timezone::Europe/London', '(GMT) Greenwich Mean Time: Edinburgh, Lisbon, London'),
('SettingsVariants::timezone::Europe/Berlin', '(GMT+01:00) Amsterdam, Berlin, Bern, Rome, Stockholm, Vienna'),
('SettingsVariants::timezone::Europe/Budapest', '(GMT+01:00) Belgrade, Bratislava, Budapest, Ljubljana, Prague'),
('SettingsVariants::timezone::Europe/Paris', '(GMT+01:00) Brussels, Copenhagen, Madrid, Paris'),
('SettingsVariants::timezone::Europe/Warsaw', '(GMT+01:00) Sarajevo, Skopje, Warsaw, Zagreb'),
('SettingsVariants::timezone::Africa/Lagos', '(GMT+01:00) West Central Africa'),
('SettingsVariants::timezone::Europe/Istanbul', '(GMT+03:00) Istanbul'),
('SettingsVariants::timezone::Europe/Athens', '(GMT+02:00) Athens'),
('SettingsVariants::timezone::Asia/Beirut', '(GMT+02:00) Beirut'),
('SettingsVariants::timezone::Europe/Bucharest', '(GMT+02:00) Bucharest'),
('SettingsVariants::timezone::Africa/Cairo', '(GMT+02:00) Cairo'),
('SettingsVariants::timezone::Africa/Johannesburg', '(GMT+02:00) Harare, Pretoria'),
('SettingsVariants::timezone::Europe/Kyiv', '(GMT+02:00) Helsinki, Kyiv, Riga, Sofia, Tallinn, Vilnius'),
('SettingsVariants::timezone::Asia/Jerusalem', '(GMT+02:00) Jerusalem'),
('SettingsVariants::timezone::Asia/Baghdad', '(GMT+03:00) Baghdad'),
('SettingsVariants::timezone::Asia/Riyadh', '(GMT+03:00) Kuwait, Riyadh'),
('SettingsVariants::timezone::Europe/Moscow', '(GMT+03:00) Moscow, St. Petersburg'),
('SettingsVariants::timezone::Europe/Minsk', '(GMT+03:00) Minsk'),
('SettingsVariants::timezone::Africa/Nairobi', '(GMT+03:00) Nairobi'),
('SettingsVariants::timezone::Asia/Tehran', '(GMT+03:30) Tehran'),
('SettingsVariants::timezone::Asia/Dubai', '(GMT+04:00) Abu Dhabi, Muscat'),
('SettingsVariants::timezone::Asia/Yerevan', '(GMT+04:00) Baku, Tbilisi, Yerevan'),
('SettingsVariants::timezone::Asia/Kabul', '(GMT+04:30) Kabul'),
('SettingsVariants::timezone::Asia/Yekaterinburg', '(GMT+05:00) Ekaterinburg'),
('SettingsVariants::timezone::Asia/Tashkent', '(GMT+05:00) Islamabad, Karachi, Tashkent'),
('SettingsVariants::timezone::Asia/Kolkata', '(GMT+05:30) Chennai, Kolkata, Mumbai, New Delhi'),
('SettingsVariants::timezone::Asia/Kathmandu', '(GMT+05:45) Kathmandu'),
('SettingsVariants::timezone::Asia/Novosibirsk', '(GMT+07:00) Novosibirsk'),
('SettingsVariants::timezone::Asia/Dhaka', '(GMT+06:00) Nur-Sultan, Dhaka'),
('SettingsVariants::timezone::Asia/Colombo', '(GMT+06:00) Sri Jayawardenepura'),
('SettingsVariants::timezone::Asia/Yangon', '(GMT+06:30) Yangon'),
('SettingsVariants::timezone::Asia/Bangkok', '(GMT+07:00) Bangkok, Hanoi, Jakarta'),
('SettingsVariants::timezone::Asia/Krasnoyarsk', '(GMT+07:00) Krasnoyarsk'),
('SettingsVariants::timezone::Asia/Shanghai', '(GMT+08:00) Beijing, Chongqing, Hong Kong'),
('SettingsVariants::timezone::Asia/Irkutsk', '(GMT+08:00) Irkutsk, Ulaanbaatar'),
('SettingsVariants::timezone::Asia/Singapore', '(GMT+08:00) Kuala Lumpur, Singapore'),
('SettingsVariants::timezone::Australia/Perth', '(GMT+08:00) Perth'),
('SettingsVariants::timezone::Asia/Taipei', '(GMT+08:00) Taipei'),
('SettingsVariants::timezone::Asia/Tokyo', '(GMT+09:00) Osaka, Sapporo, Tokyo'),
('SettingsVariants::timezone::Asia/Seoul', '(GMT+09:00) Seoul'),
('SettingsVariants::timezone::Asia/Yakutsk', '(GMT+09:00) Yakutsk'),
('SettingsVariants::timezone::Australia/Adelaide', '(GMT+09:30) Adelaide'),
('SettingsVariants::timezone::Australia/Darwin', '(GMT+09:30) Darwin'),
('SettingsVariants::timezone::Australia/Brisbane', '(GMT+10:00) Brisbane'),
('SettingsVariants::timezone::Australia/Sydney', '(GMT+10:00) Canberra, Melbourne, Sydney'),
('SettingsVariants::timezone::Pacific/Port_Moresby', '(GMT+10:00) Guam, Port Moresby'),
('SettingsVariants::timezone::Australia/Hobart', '(GMT+10:00) Hobart'),
('SettingsVariants::timezone::Asia/Vladivostok', '(GMT+10:00) Vladivostok'),
('SettingsVariants::timezone::Pacific/Guadalcanal', '(GMT+11:00) Magadan, Solomon Is., New Caledonia'),
('SettingsVariants::timezone::Pacific/Auckland', '(GMT+12:00) Auckland, Wellington'),
('SettingsVariants::timezone::Pacific/Fiji', '(GMT+12:00) Fiji'),
('SettingsVariants::timezone::Asia/Kamchatka', '(GMT+12:00) Kamchatka, Marshall Is.'),
('SettingsVariants::timezone::Pacific/Tongatapu', '(GMT+13:00) Nuku''alofa'),
('SettingsVariants::email_templates::old', 'Old (stored on file system)'),
('SettingsVariants::email_templates::new', 'New (nice and editable via admin panel)'),
('SettingsVariants::phone_validation_mode::international_format', 'International phone number'),
('SettingsVariants::phone_validation_mode::any_digits', 'Any digits and +-()'),
('SettingsVariants::phone_validation_mode::any_symbols', 'Any symbols'),
('SettingsVariants::phone_validation_mode::phone_number_with_country_selection', 'Phone number with country selection'),
('SettingsVariants::mailer_smtp_ecrypted_connection::none', 'None'),
('SettingsVariants::mailer_smtp_ecrypted_connection::tls', 'TLS'),
('SettingsVariants::mailer_smtp_ecrypted_connection::ssl', 'SSL'),
('SettingsVariants::configure_sign_in_step::new_customer_first', 'Display "New customer" first'),
('SettingsVariants::configure_sign_in_step::returning_customer_first', 'Display "Returning customer" first'),
('SettingsVariants::configure_sign_in_step::hide', 'Hide step completely'),
('SettingsVariants::sign_in_default_action::register', 'Register'),
('SettingsVariants::sign_in_default_action::checkout_as_guest', 'Checkout as guest'),
('SettingsVariants::log_type_requests::shipping', 'Realtime shipping errors'),
('SettingsVariants::timezone::Atlantic/Bermuda', '(GMT-03:00) Bermuda'),
('SettingsVariants::timezone::Asia/Almaty', '(GMT+06:00) Almaty'),
('SettingsVariants::timezone::Indian/Cocos', '(GMT+06:30) Cocos'),
('SettingsVariants::timezone::Pacific/Pitcairn', '(GMT-08:00) Pitcairn'),
('SettingsVariants::timezone::America/Vancouver', '(GMT-08:00) Vancouver'),
('SettingsVariants::timezone::Pacific/Gambier', '(GMT-09:00) Gambier'),
('SettingsVariants::timezone::Australia/Lord_Howe', '(GMT+10:30) Lord Howe'),
('SettingsVariants::timezone::Pacific/Chatham', '(GMT+12:45) Chatham'),
('SettingsVariants::timezone::Africa/Casablanca', '(GMT+01:00) Casablanca'),
('SettingsVariants::timezone::Europe/Dublin', '(GMT+01:00) Dublin'),
('SettingsVariants::timezone::Pacific/Midway', '(GMT-11:00) United States Minor Outlying Islands'),
('SettingsVariants::timezone::Asia/Urumqi', '(GMT+06:00) Urumqi'),
('ProfileFields::firstname', 'First name'),
('ProfileFields::lastname', 'Last name'),
('ProfileFields::company', 'Company'),
('ProfileFields::email', 'E-mail'),
('ProfileFields::phone', 'Phone'),
('ProfileFields::b_firstname', 'First name'),
('ProfileFields::s_firstname', 'First name'),
('ProfileFields::b_lastname', 'Last name'),
('ProfileFields::s_lastname', 'Last name'),
('ProfileFields::b_address', 'Address'),
('ProfileFields::b_address_2', 'Address'),
('ProfileFields::s_address', 'Address'),
('ProfileFields::s_address_2', 'Address'),
('ProfileFields::b_city', 'City'),
('ProfileFields::s_city', 'City'),
('ProfileFields::b_state', 'State/province'),
('ProfileFields::s_state', 'State/province'),
('ProfileFields::b_country', 'Country'),
('ProfileFields::s_country', 'Country'),
('ProfileFields::b_zipcode', 'Zip/postal code'),
('ProfileFields::s_zipcode', 'Zip/postal code'),
('ProfileFields::b_phone', 'Phone'),
('ProfileFields::s_phone', 'Phone'),
('ProfileFields::s_address_type', 'Address type'),
('SettingsSections::hidpi::general', 'General'),
('SettingsOptions::hidpi::default_upload_high_res_image', 'Consider all uploaded images HiDPI'),
('Languages::text_hidpi_support_enabled', 'HiDPI support is enabled'),
('Languages::hidpi.upload_high_res_image', 'I’m uploading a HiDPI image.'),
('Languages::hidpi.upload_high_res_image.tooltip', 'If this checkbox is ticked, the source image will be displayed two times downscaled. This setting only affects the displaying of the source image and not its thumbnail. If you want an image to be displayed in the original size, untick this checkbox.'),
('Languages::hidpi.restore_images', 'Image restoration'),
('Languages::hidpi.text_restore_images', 'The previous version of the HiDPI display support add-on shrank the uploaded images. There’s no need for that now. But to make your images look nice and sharp you need to click Restore.'),
('Languages::hidpi.restore_btn', 'Restore'),
('Languages::hidpi.warning_restore_images', '<strong>Attention!</strong> This procedure is non—reversible: when you revert the upgrade, the image restoration manipulations will not be reverted. So, please make sure to perform a backup. The procedure can take some time—it depends on the number of images in your store.'),
('Languages::hidpi.notice.images_were_not_restored', 'Some of the old images in your store are still low-quality. To use the highest quality possible, please <a href="[convert_url]">restore high-quality images</a>. The process is automatic.'),
('SettingsTooltips::hidpi::default_upload_high_res_image', 'Make the "I''m uploading a HiDPI image" checkboxes ticked by default everywhere where images are uploaded. You''ll be able to untick those checkboxes when necessary.'),
('Addons::name::hidpi', 'HiDPI displays support'),
('Addons::description::hidpi', 'Support for Retina displays'),
('SettingsSections::social_buttons::twitter', 'Twitter'),
('SettingsOptions::social_buttons::twitter_enable', 'Show Twitter button'),
('SettingsOptions::social_buttons::twitter_via', 'Via'),
('SettingsOptions::social_buttons::twitter_size', 'Button size'),
('SettingsVariants::social_buttons::twitter_size::medium', 'Medium'),
('SettingsVariants::social_buttons::twitter_size::large', 'Large'),
('SettingsOptions::social_buttons::twitter_display_count', 'Display count'),
('SettingsVariants::social_buttons::twitter_display_count::none', 'None'),
('SettingsVariants::social_buttons::twitter_display_count::horizontal', 'Horizontal'),
('SettingsVariants::social_buttons::twitter_display_count::vertical', 'vertical'),
('SettingsOptions::social_buttons::twitter_display_on', 'Display on'),
('SettingsVariants::social_buttons::twitter_display_on::products', 'Product details pages'),
('SettingsVariants::social_buttons::twitter_display_on::pages', 'Pages'),
('SettingsSections::social_buttons::facebook', 'Facebook'),
('SettingsOptions::social_buttons::facebook_enable', 'Show Facebook button'),
('SettingsOptions::social_buttons::facebook_app_id', 'Facebook app ID'),
('SettingsOptions::social_buttons::facebook_href', 'The URL of the page to like'),
('SettingsOptions::social_buttons::facebook_send', 'Include a Send button with the Like button'),
('SettingsOptions::social_buttons::facebook_width', 'Width of the Like button (px)'),
('SettingsOptions::social_buttons::facebook_layout', 'Button layout'),
('SettingsVariants::social_buttons::facebook_layout::standard', 'Standard'),
('SettingsVariants::social_buttons::facebook_layout::button_count', 'With count'),
('SettingsVariants::social_buttons::facebook_layout::box_count', 'With large count'),
('SettingsOptions::social_buttons::facebook_show_faces', 'Display profile photos'),
('SettingsOptions::social_buttons::facebook_action', 'Button verb'),
('SettingsVariants::social_buttons::facebook_action::like', 'Like'),
('SettingsVariants::social_buttons::facebook_action::recommend', 'Recommend'),
('SettingsOptions::social_buttons::facebook_lang', 'Language'),
('SettingsVariants::social_buttons::facebook_lang::af_ZA', 'Afrikaans'),
('SettingsVariants::social_buttons::facebook_lang::ar_AR', 'Arabic'),
('SettingsVariants::social_buttons::facebook_lang::az_AZ', 'Azerbaijani'),
('SettingsVariants::social_buttons::facebook_lang::be_BY', 'Belarusian'),
('SettingsVariants::social_buttons::facebook_lang::bg_BG', 'Bulgarian'),
('SettingsVariants::social_buttons::facebook_lang::bn_IN', 'Bengali'),
('SettingsVariants::social_buttons::facebook_lang::bs_BA', 'Bosnian'),
('SettingsVariants::social_buttons::facebook_lang::ca_ES', 'Catalan'),
('SettingsVariants::social_buttons::facebook_lang::cs_CZ', 'Czech'),
('SettingsVariants::social_buttons::facebook_lang::cy_GB', 'Welsh'),
('SettingsVariants::social_buttons::facebook_lang::da_DK', 'Danish'),
('SettingsVariants::social_buttons::facebook_lang::de_DE', 'German'),
('SettingsVariants::social_buttons::facebook_lang::el_GR', 'Greek'),
('SettingsVariants::social_buttons::facebook_lang::en_GB', 'English (UK)'),
('SettingsVariants::social_buttons::facebook_lang::en_PI', 'English (Pirate)'),
('SettingsVariants::social_buttons::facebook_lang::en_UD', 'English (Upside Down)'),
('SettingsVariants::social_buttons::facebook_lang::en_US', 'English (US)'),
('SettingsVariants::social_buttons::facebook_lang::eo_EO', 'Esperanto'),
('SettingsVariants::social_buttons::facebook_lang::es_ES', 'Spanish (Spain)'),
('SettingsVariants::social_buttons::facebook_lang::es_LA', 'Spanish'),
('SettingsVariants::social_buttons::facebook_lang::et_EE', 'Estonian'),
('SettingsVariants::social_buttons::facebook_lang::eu_ES', 'Basque'),
('SettingsVariants::social_buttons::facebook_lang::fa_IR', 'Persian'),
('SettingsVariants::social_buttons::facebook_lang::fb_LT', 'Leet Speak'),
('SettingsVariants::social_buttons::facebook_lang::fi_FI', 'Finnish'),
('SettingsVariants::social_buttons::facebook_lang::fo_FO', 'Faroese'),
('SettingsVariants::social_buttons::facebook_lang::fr_CA', 'French (Canada)'),
('SettingsVariants::social_buttons::facebook_lang::fr_FR', 'French (France)'),
('SettingsVariants::social_buttons::facebook_lang::fy_NL', 'Frisian'),
('SettingsVariants::social_buttons::facebook_lang::ga_IE', 'Irish'),
('SettingsVariants::social_buttons::facebook_lang::gl_ES', 'Galician'),
('SettingsVariants::social_buttons::facebook_lang::he_IL', 'Hebrew'),
('SettingsVariants::social_buttons::facebook_lang::hi_IN', 'Hindi'),
('SettingsVariants::social_buttons::facebook_lang::hr_HR', 'Croatian'),
('SettingsVariants::social_buttons::facebook_lang::hu_HU', 'Hungarian'),
('SettingsVariants::social_buttons::facebook_lang::hy_AM', 'Armenian'),
('SettingsVariants::social_buttons::facebook_lang::id_ID', 'Indonesian'),
('SettingsVariants::social_buttons::facebook_lang::is_IS', 'Icelandic'),
('SettingsVariants::social_buttons::facebook_lang::it_IT', 'Italian'),
('SettingsVariants::social_buttons::facebook_lang::ja_JP', 'Japanese'),
('SettingsVariants::social_buttons::facebook_lang::ka_GE', 'Georgian'),
('SettingsVariants::social_buttons::facebook_lang::km_KH', 'Khmer'),
('SettingsVariants::social_buttons::facebook_lang::ko_KR', 'Korean'),
('SettingsVariants::social_buttons::facebook_lang::ku_TR', 'Kurdish'),
('SettingsVariants::social_buttons::facebook_lang::la_VA', 'Latin'),
('SettingsVariants::social_buttons::facebook_lang::lt_LT', 'Lithuanian'),
('SettingsVariants::social_buttons::facebook_lang::lv_LV', 'Latvian'),
('SettingsVariants::social_buttons::facebook_lang::mk_MK', 'Macedonian'),
('SettingsVariants::social_buttons::facebook_lang::ml_IN', 'Malayalam'),
('SettingsVariants::social_buttons::facebook_lang::ms_MY', 'Malay'),
('SettingsVariants::social_buttons::facebook_lang::nb_NO', 'Norwegian (bokmal)'),
('SettingsVariants::social_buttons::facebook_lang::ne_NP', 'Nepali'),
('SettingsVariants::social_buttons::facebook_lang::nl_NL', 'Dutch'),
('SettingsVariants::social_buttons::facebook_lang::nn_NO', 'Norwegian (nynorsk)'),
('SettingsVariants::social_buttons::facebook_lang::pa_IN', 'Punjabi'),
('SettingsVariants::social_buttons::facebook_lang::pl_PL', 'Polish'),
('SettingsVariants::social_buttons::facebook_lang::ps_AF', 'Pashto'),
('SettingsVariants::social_buttons::facebook_lang::pt_BR', 'Portuguese (Brazil)'),
('SettingsVariants::social_buttons::facebook_lang::pt_PT', 'Portuguese (Portugal)'),
('SettingsVariants::social_buttons::facebook_lang::ro_RO', 'Romanian'),
('SettingsVariants::social_buttons::facebook_lang::ru_RU', 'Russian'),
('SettingsVariants::social_buttons::facebook_lang::sk_SK', 'Slovak'),
('SettingsVariants::social_buttons::facebook_lang::sl_SI', 'Slovenian'),
('SettingsVariants::social_buttons::facebook_lang::sq_AL', 'Albanian'),
('SettingsVariants::social_buttons::facebook_lang::sr_RS', 'Serbian'),
('SettingsVariants::social_buttons::facebook_lang::sv_SE', 'Swedish'),
('SettingsVariants::social_buttons::facebook_lang::sw_KE', 'Swahili'),
('SettingsVariants::social_buttons::facebook_lang::ta_IN', 'Tamil'),
('SettingsVariants::social_buttons::facebook_lang::te_IN', 'Telugu'),
('SettingsVariants::social_buttons::facebook_lang::th_TH', 'Thai'),
('SettingsVariants::social_buttons::facebook_lang::tl_PH', 'Filipino'),
('SettingsVariants::social_buttons::facebook_lang::tr_TR', 'Turkish'),
('SettingsVariants::social_buttons::facebook_lang::uk_UA', 'Ukrainian'),
('SettingsVariants::social_buttons::facebook_lang::vi_VN', 'Vietnamese'),
('SettingsVariants::social_buttons::facebook_lang::zh_CN', 'Simplified Chinese (China)'),
('SettingsVariants::social_buttons::facebook_lang::zh_HK', 'Traditional Chinese (Hong Kong)'),
('SettingsVariants::social_buttons::facebook_lang::zh_TW', 'Traditional Chinese (Taiwan)'),
('SettingsOptions::social_buttons::facebook_action_font', 'Button font'),
('SettingsVariants::social_buttons::facebook_action_font::arial', 'Arial'),
('SettingsVariants::social_buttons::facebook_action_font::lucida grande', 'Lucida grande'),
('SettingsVariants::social_buttons::facebook_action_font::segoe ui', 'Segoe ui'),
('SettingsVariants::social_buttons::facebook_action_font::tahoma', 'Tahoma'),
('SettingsVariants::social_buttons::facebook_action_font::trebuchet ms', 'Trebuchet ms'),
('SettingsVariants::social_buttons::facebook_action_font::verdana', 'Verdana'),
('SettingsOptions::social_buttons::facebook_colorscheme', 'Color scheme'),
('SettingsVariants::social_buttons::facebook_colorscheme::light', 'Light'),
('SettingsVariants::social_buttons::facebook_colorscheme::dark', 'Dark'),
('SettingsOptions::social_buttons::facebook_display_on', 'Display on'),
('SettingsVariants::social_buttons::facebook_display_on::products', 'Product details pages'),
('SettingsVariants::social_buttons::facebook_display_on::pages', 'Pages'),
('SettingsSections::social_buttons::vkontakte', 'Vkontakte'),
('SettingsOptions::social_buttons::vkontakte_enable', 'Show Vkontakte button'),
('SettingsOptions::social_buttons::vkontakte_appid', 'Vkontakte app ID'),
('SettingsOptions::social_buttons::vkontakte_button_style', 'Button layout'),
('SettingsVariants::social_buttons::vkontakte_button_style::full', 'Button with a text counter'),
('SettingsVariants::social_buttons::vkontakte_button_style::button', 'Button with a little counter'),
('SettingsVariants::social_buttons::vkontakte_button_style::mini', 'Mini button'),
('SettingsVariants::social_buttons::vkontakte_button_style::Vertical', 'Mini button, counter on top'),
('SettingsOptions::social_buttons::vkontakte_height', 'Button height (px)'),
('SettingsOptions::social_buttons::vkontakte_width', 'Button width (px)'),
('SettingsOptions::social_buttons::vkontakte_buttons_name', 'Button name'),
('SettingsVariants::social_buttons::vkontakte_buttons_name::like', 'Like'),
('SettingsVariants::social_buttons::vkontakte_buttons_name::interesting', 'It''s interesting'),
('SettingsOptions::social_buttons::vkontakte_display_on', 'Display on'),
('SettingsVariants::social_buttons::vkontakte_display_on::products', 'Product details pages'),
('SettingsVariants::social_buttons::vkontakte_display_on::pages', 'Pages'),
('SettingsSections::social_buttons::yandex', 'Yandex'),
('SettingsOptions::social_buttons::yandex_enable', 'Show Yandex.Share block'),
('SettingsOptions::social_buttons::yandex_share_code', 'Yandex.Share code'),
('SettingsOptions::social_buttons::yandex_display_on', 'Display on'),
('SettingsVariants::social_buttons::yandex_display_on::products', 'Product details pages'),
('SettingsVariants::social_buttons::yandex_display_on::pages', 'Pages'),
('SettingsSections::social_buttons::pinterest', 'Pinterest'),
('SettingsOptions::social_buttons::pinterest_enable', 'Show Pinterest button'),
('SettingsOptions::social_buttons::pinterest_size', 'Button size'),
('SettingsVariants::social_buttons::pinterest_size::20', 'Small'),
('SettingsVariants::social_buttons::pinterest_size::28', 'Large'),
('SettingsOptions::social_buttons::pinterest_shape', 'Shape'),
('SettingsVariants::social_buttons::pinterest_shape::rect', 'Rectangular'),
('SettingsVariants::social_buttons::pinterest_shape::round', 'Circular'),
('SettingsOptions::social_buttons::pinterest_display_on', 'Display on'),
('SettingsVariants::social_buttons::pinterest_display_on::products', 'Product details pages'),
('SettingsVariants::social_buttons::pinterest_display_on::pages', 'Pages'),
('Languages::facebook', 'Facebook'),
('Languages::facebook_obj_type', 'Facebook object type'),
('Languages::fb_activities', 'Activities'),
('Languages::fb_businesses', 'Businesses'),
('Languages::fb_groups', 'Groups'),
('Languages::fb_organizations', 'Organizations'),
('Languages::fb_people', 'People'),
('Languages::fb_places', 'Places'),
('Languages::fb_products_entertainment', 'Products and Entertainment'),
('Languages::fb_websites', 'Websites'),
('Languages::text_recommendation_notes', 'Your friend has recommended this page to you. Please follow the link:'),
('Languages::sb_share', 'Share'),
('Languages::social_buttons.facebook_cookie_title', 'Facebook'),
('Languages::social_buttons.facebook_cookie_description', 'Facebook cookies enable Facebook-related functionality, such as Facebook button on the product page. Here is <a href="https://www.facebook.com/about/privacy/previous" target="_blank">Facebook privacy policy</a>.'),
('Languages::social_buttons.pinterest_cookie_title', 'Pinterest'),
('Languages::social_buttons.pinterest_cookie_description', 'Pinterest cookies enable Pinterest-related functionality, such as Pinterest button on the product page. Here is <a href="https://policy.pinterest.com/en/privacy-policy" target="_blank">Pinterest privacy policy</a>.'),
('Languages::social_buttons.twitter_cookie_title', 'Twitter'),
('Languages::social_buttons.twitter_cookie_description', 'Twitter cookies enable Twitter-related functionality, such as the Twitter button on the product page. Here is <a href="https://twitter.com/en/privacy" target="_blank">Twitter privacy policy</a>.'),
('Languages::social_buttons.vkontakte_cookie_title', 'VK'),
('Languages::social_buttons.vkontakte_cookie_description', 'VK cookies enable VK-related functionality, such as VK button on the product page. Here is <a href="https://m.vk.com/privacy" target="_blank">VK privacy policy</a>.'),
('Languages::social_buttons.yandex_cookie_title', 'Yandex'),
('Languages::social_buttons.yandex_cookie_description', 'Yandex helps us display the buttons of multiple social networks (for example, on product pages). Here is <a href="https://yandex.com/legal/confidential/" target="_blank">Yandex privacy policy</a>.'),
('SettingsTooltips::social_buttons::yandex_share_code', 'You can configure the block and get the code at <a href="http://api.yandex.ru/share/" target="_blank">http://api.yandex.ru/share/</a>'),
('SettingsTooltips::social_buttons::twitter_via', 'User name to attribute the Tweet to (i.e. ''via @username'')'),
('SettingsTooltips::social_buttons::facebook_app_id', 'Specify any Facebook app ID, otherwise the button will not be shown'),
('SettingsTooltips::social_buttons::facebook_href', 'Leave empty to use an actual page URL'),
('SettingsTooltips::social_buttons::facebook_show_faces', 'Enable to display profile photos below the button (standard layout only)'),
('SettingsTooltips::social_buttons::vkontakte_width', 'Only for the button with text counter'),
('Addons::name::social_buttons', 'Social buttons'),
('Addons::description::social_buttons', 'Adds the buttons for sharing products and pages in social media (Twitter, Facebook, etc.). Helps social networks and messengers to display better previews for the links to your site'),
('Languages::paypal_checkout.paypal_checkout', 'PayPal Complete Payments'),
('Languages::paypal_checkout.paypal', 'PayPal'),
('Languages::paypal_checkout.client_id', 'App Client ID'),
('Languages::paypal_checkout.secret', 'App Secret'),
('Languages::paypal_checkout.order_id', 'Order ID in PayPal'),
('Languages::paypal_checkout.capture_id', 'Capture ID in PayPal'),
('Languages::paypal_checkout.webhook_help_message', 'Specify the following URL when configuring a webhook for your REST application:'),
('Languages::paypal_checkout.webhook', 'PayPal Complete Payments webhook: [payload]'),
('Languages::paypal_checkout.settings.account', 'Account settings'),
('Languages::paypal_checkout.settings.enable_funding', 'Funding sources to show on checkout'),
('Languages::paypal_checkout.funding.card', 'Credit or debit cards'),
('Languages::paypal_checkout.funding.credit', 'PayPal Credit'),
('Languages::paypal_checkout.funding.venmo', 'Venmo'),
('Languages::paypal_checkout.funding.sepa', 'SEPA-Lastschrift'),
('Languages::paypal_checkout.funding.bancontact', 'Bancontact'),
('Languages::paypal_checkout.funding.eps', 'eps'),
('Languages::paypal_checkout.funding.giropay', 'giropay'),
('Languages::paypal_checkout.funding.ideal', 'iDEAL'),
('Languages::paypal_checkout.funding.mybank', 'MyBank'),
('Languages::paypal_checkout.funding.p24', 'Przelewy24'),
('Languages::paypal_checkout.funding.sofort', 'Sofort'),
('Languages::paypal_checkout.settings.enable_cards', 'Cards to show on checkout'),
('Languages::paypal_checkout.card.visa', 'Visa'),
('Languages::paypal_checkout.card.mastercard', 'Mastercard'),
('Languages::paypal_checkout.card.amex', 'American Express'),
('Languages::paypal_checkout.card.discover', 'Discover'),
('Languages::paypal_checkout.card.jcb', 'JCB'),
('Languages::paypal_checkout.card.elo', 'Elo'),
('Languages::paypal_checkout.card.hiper', 'Hiper'),
('Languages::paypal_checkout.debug_id', 'PayPal Debug ID'),
('Languages::paypal_checkout.paypal_cookie_title', 'PayPal'),
('Languages::paypal_checkout.paypal_cookie_description', 'PayPal is a payment provider. It allows us to accept payments, if you choose a payment method powered by PayPal. Here is <a href="https://www.paypal.com/us/webapps/mpp/ua/privacy-full" target="_blank">PayPal privacy statement</a>.'),
('Languages::paypal_checkout.funding.paylater', 'PayPal Pay Later'),
('Languages::paypal_checkout.funding.mercadopago', 'Mercado Pago'),
('Languages::paypal_checkout.funding.blik', 'BLIK'),
('Languages::paypal_checkout.settings.style', 'Button appearance'),
('Languages::paypal_checkout.style.shape', 'Shape'),
('Languages::paypal_checkout.shape.pill', 'Pill'),
('Languages::paypal_checkout.shape.rect', 'Rectangular'),
('Languages::paypal_checkout.style.color', 'Color'),
('Languages::paypal_checkout.color.gold', 'Gold'),
('Languages::paypal_checkout.color.blue', 'Blue'),
('Languages::paypal_checkout.color.silver', 'Silver'),
('Languages::paypal_checkout.color.black', 'Black'),
('Languages::paypal_checkout.style.height', 'Height'),
('SettingsSections::paypal_checkout::general', 'General'),
('Addons::name::paypal_checkout', 'PayPal Complete Payments'),
('Addons::description::paypal_checkout', 'A PayPal solution for online stores. Lets you accept payments through PayPal and other means.'),
('Languages::onboarding_guide.guide_title', 'Welcome to your marketplace!<br>Get ready to receive your first order'),
('Languages::onboarding_guide.sb_guide_title', 'Welcome to your online store!<br>Get ready to receive your first order'),
('Languages::onboarding_guide.completed_steps_progress', '[completed] out of [total] complete'),
('Languages::onboarding_guide.dismiss', 'Dismiss'),
('Languages::onboarding_guide.step_close', 'Close'),
('Languages::onboarding_guide.step_complete', 'Complete'),
('Languages::onboarding_guide.explore_interface_title', 'Explore the Multi-Vendor No-Code interface'),
('Languages::onboarding_guide.explore_interface_description', 'Discover how to effortlessly launch your marketplace in just 5 minutes. Learn the ins and outs of the intuitive interface and get ready to dive into the world of hassle-free marketplace creation.'),
('Languages::onboarding_guide.personalize_your_marketplace_title', 'Personalize your marketplace'),
('Languages::onboarding_guide.sb_personalize_your_marketplace_title', 'Personalize your online store'),
('Languages::onboarding_guide.personalize_your_marketplace_description', 'Choose the style of your marketplace. Provide your contact information for customers and sellers.'),
('Languages::onboarding_guide.sb_personalize_your_marketplace_description', 'Choose the style of your online store. Provide your contact information for customers.'),
('Languages::onboarding_guide.make_changes_on_the_fly_title', 'Make changes on the fly'),
('Languages::onboarding_guide.make_changes_on_the_fly_description', 'Use the no-code tools to tailor the marketplace to your needs. Edit any texts; rearrange the blocks; change the colors, fonts, and style. When you see the storefront as an admin, you can use these tools any time.'),
('Languages::onboarding_guide.sb_make_changes_on_the_fly_description', 'Use the no-code tools to tailor the online store to your needs. Edit any texts; rearrange the blocks; change the colors, fonts, and style. When you see the storefront as an admin, you can use these tools any time.'),
('Languages::onboarding_guide.theme_and_logo', 'Theme & logo'),
('Languages::onboarding_guide.business_details', 'Business details'),
('Languages::onboarding_guide.languages_and_currency', 'Languages & Currency'),
('Languages::onboarding_guide.select_theme', 'Select theme'),
('Languages::onboarding_guide.current_theme', 'Current theme'),
('Languages::onboarding_guide.custom_theme', 'Custom theme'),
('Languages::onboarding_guide.upload_logo', 'Upload logo'),
('Languages::onboarding_guide.activate', 'Activate'),
('Languages::onboarding_guide.next', 'Next'),
('Languages::onboarding_guide.back', 'Back'),
('Languages::onboarding_guide.save', 'Save'),
('Languages::onboarding_guide.edit_colors', 'Edit colors'),
('Languages::onboarding_guide.modify_colors_fonts_backgrounds', 'Modify colors, fonts, and backgrounds'),
('Languages::onboarding_guide.edit_texts', 'Edit or translate any texts'),
('Languages::onboarding_guide.edit_blocks', 'Fine-tune page layouts'),
('Languages::onboarding_guide.configure_payment_options', 'Set up payments'),
('Languages::onboarding_guide.select_payment_options', 'Choose how you plan to accept payments. Select one of the following scenarios:'),
('Languages::onboarding_guide.single_payment_with_automatic_split', 'Multi-party payment (automatic disbursements)'),
('Languages::onboarding_guide.single_payment_with_automatic_split_description', 'There are special payment methods for marketplaces: PayPal Complete Payments (Multiparty) and Stripe Connect. A customer still makes one payment for all the products; the payment method splits the money between you and sellers automatically. Note that sellers will need accounts with PayPal or Stripe as well.'),
('Languages::onboarding_guide.single_rus_payment_with_automatic_split_description', 'There are special payment methods for marketplaces: YooKassa For Marketplaces and Tinkoff Multiparty. A customer still makes one payment for all the products; the payment method splits the money between you and sellers automatically. Note that sellers will need accounts with YooKassa or Tinkoff as well.'),
('Languages::onboarding_guide.single_payment_to_you', 'Single payment to the marketplace'),
('Languages::onboarding_guide.single_payment_to_you_description', 'A customer makes one payment for all the products in the cart. The money ends up on your account, with the record of what you own to each seller. You periodically distribute the money between sellers.'),
('Languages::onboarding_guide.separate_payments_to_sellers', 'Separate payments to sellers'),
('Languages::onboarding_guide.separate_payments_to_sellers_description', 'A customer pays to each seller separately. It becomes the seller’s responsibility to pay the commission to you (we have ways for that). Sellers will be able to set up their own shipping methods and promotions.'),
('Languages::onboarding_guide.configure_payment_methods', 'Configure payment methods'),
('Languages::onboarding_guide.configure_payment_methods_description', 'CS-Cart allows you to set up various payment methods; most of them automatically process the full up-front payment. But for now, let’s set up "Cash on Delivery" just to see how it works.'),
('Languages::onboarding_guide.view_checkout_page', 'View checkout page'),
('Languages::onboarding_guide.view_checkout_page_description', 'Once configured, your payment method will appear at the checkout page:'),
('Languages::onboarding_guide.missing_products', 'Missing products'),
('Languages::onboarding_guide.create_at_least_one_product_to_proceed_to_checkout', 'Create at least one product to proceed to checkout'),
('Languages::onboarding_guide.manage_sellers', 'Manage sellers'),
('Languages::onboarding_guide.create_one_vendor', 'Add a seller'),
('Languages::onboarding_guide.create_vendor_description', 'Sellers—referred to as "vendors" in the admin panel—are essential for a marketplace. They provide products and services to customers. A seller can create an account themselves, or you can do it for them in the admin panel. Let’s add one seller via the admin panel.'),
('Languages::onboarding_guide.view_storefront', 'See sellers on the storefront'),
('Languages::onboarding_guide.view_invoice', 'View invoice'),
('Languages::onboarding_guide.logos_updated', 'Theme and email logos updated'),
('Languages::onboarding_guide.set_default_currency', 'Set default currency'),
('Languages::onboarding_guide.manage_currencies', 'Manage currencies'),
('Languages::onboarding_guide.set_default_languages', 'Set default languages'),
('Languages::onboarding_guide.manage_languages', 'Manage languages'),
('Languages::onboarding_guide.preview_an_email', 'Preview an email'),
('Languages::onboarding_guide.preview_an_email_description', 'Once you’re done, see how your data appears in an email to the new sellers who register at your marketplace.'),
('Languages::onboarding_guide.sb_preview_an_email_description', 'Once you’re done, see how your data appears in an email to the newly-registered customers.'),
('Languages::onboarding_guide.customize_vendor_panel_design', 'Customize seller panel'),
('Languages::onboarding_guide.edit_vendor_panel_style', 'Sellers work with their own dedicated control panel. You can make it look the way you need. Set its colors, edit the menu, add blocks with info to the seller''s dashboard.'),
('Languages::onboarding_guide.edit_structure', 'Edit menus and onboarding'),
('Languages::onboarding_guide.manage_products', 'Manage products'),
('Languages::onboarding_guide.manage_products_description', 'You as the marketplace owner can control all products sold on your platform. But sellers manage products through their own dashboard. See how they can add products one by one or in bulk.'),
('Languages::onboarding_guide.sb_manage_products_description', 'Products are how your online store makes money; they include commodities, services, or anything else offered for a price. You can add products one by one or in bulk.'),
('Languages::onboarding_guide.add_one_product', 'Add one product'),
('Languages::onboarding_guide.import_csv_or_xml', 'Import CSV or XML'),
('Languages::onboarding_guide.view_product_page', 'View the latest added product'),
('Languages::onboarding_guide.premoderation', 'If you do not see the created product on the storefront, you may have the <b>Vendor data premoderation</b> module enabled'),
('Languages::onboarding_guide.view_product_page_description', 'See your new products on the storefront.'),
('Languages::onboarding_guide.preview_seller_onboarding', 'Preview seller onboarding'),
('Languages::onboarding_guide.walk_the_seller_path', 'Walk the seller path'),
('Languages::onboarding_guide.customize_onboarding_process', 'Prospective sellers can request to join your marketplace on their own. See for yourself how that process works: the information they provide, the emails they receive, etc. You can adjust all of it, or even make your marketplace invite-only.'),
('Languages::onboarding_guide.set_up_commissions_and_fees', 'Configure commissions and fees'),
('Languages::onboarding_guide.set_up_seller_plans', 'Set up seller plans'),
('Languages::onboarding_guide.set_up_seller_plans_description', 'A marketplace usually earns you money from monthly fees and/or commissions from sales. Seller plans let you set the size and frequency of those payments.'),
('Languages::onboarding_guide.view_seller_plans', 'Preview seller plans'),
('Languages::onboarding_guide.view_seller_plans_description', 'See how your configured seller plans appear to your prospective sellers on the storefront.'),
('Languages::onboarding_guide.reset_onboarding', 'Reset onboarding'),
('Languages::onboarding_guide.reset', 'Reset'),
('Languages::onboarding_guide.configure_shippings_title', 'Set up shipping'),
('Languages::onboarding_guide.configure_shippings_description', 'CS-Cart provides your customers with shipping rates depending on the customer''s address and order. You can set the rules for these rates yourself, or receive rates in real time from shipping companies like UPS or DHL. You can also make shipping methods available in some locations and unavailable in others.'),
('Languages::onboarding_guide.configure_shippings_label', 'Let''s set up a shipping method called "Pickup from store" to see how it works.'),
('Languages::onboarding_guide.configure_shippings', 'Configure shipping methods'),
('Addons::name::onboarding_guide', 'Onboarding guide'),
('Addons::description::onboarding_guide', 'Introduces the marketplace to administrators and allows quickly set up basic functionality.'),
('Languages::help_center.help', 'Help'),
('Languages::help_center.help_center', 'Help Center'),
('Languages::help_center.growth_center', 'Growth center'),
('Languages::help_center.loading', 'Loading...'),
('Languages::help_center.no_data_relevant', 'Relevant information is not available for this section.'),
('Languages::help_center.no_data', 'Information is not available for this section.'),
('Languages::help_center.see_all_n_results', 'See all [n] results...'),
('Languages::help_center.customer_care', 'Customer Care'),
('Languages::help_center.ask', 'Ask us a question'),
('Languages::help_center.customer_care.view_all_tickets', 'View all tickets'),
('Languages::help_center.customer_care.all_tickets', 'All tickets'),
('Languages::help_center.customer_care.no_support_tickets', 'No support tickets found.'),
('Languages::help_center.customer_care.submit_ticket', 'Submit a ticket'),
('Languages::help_center.customer_care.service_unavailable', 'Your Customer Care subscription is not active'),
('Languages::help_center.customer_care.service_unavailable_description', 'Prolong the subscription to keep receiving support.'),
('Languages::help_center.customer_care.prolong_subscription', 'Prolong subscription'),
('Languages::help_center.customer_care.sign_in_text', 'Sign in with your Help Desk account <br>to contact Customer Care and see your latest tickets.'),
('Languages::help_center.customer_care.status.resolved', 'Resolved'),
('Languages::help_center.customer_care.status.open', 'Open'),
('Languages::help_center.customer_care.few_tickets_require_your_attention', 'A few tickets from Customer Care team require your attention. <a href="[url]" target="[target]">Click here to view tickets</a>'),
('Addons::name::help_center', 'Help center'),
('Addons::description::help_center', 'Adds a help button with links to relevant documentation and/or videos to various pages in the admin panel.'),
('SettingsSections::tags::general', 'General'),
('SettingsOptions::tags::tags_for_products', 'Tags for products'),
('SettingsOptions::tags::tags_for_pages', 'Tags for pages'),
('Languages::sign_in_to_enter_tags', 'Sign in to enter tags'),
('Languages::tag_cloud', 'Tag cloud'),
('Languages::tags', 'Tags'),
('Languages::block_tags', 'Tags'),
('Languages::block_tags_description', 'Product tags'),
('Languages::addons.tags.add_a_tag', 'add a tag'),
('Languages::items_marked_by_tag', 'Items marked by the "[tag]" tag:'),
('Languages::tag', 'Tag'),
('Languages::add_tag', 'Add tag'),
('Languages::n_tags', '[n] tag|[n] tags'),
('Addons::name::tags', 'Tags'),
('Addons::description::tags', 'Enables product tags'),
('SettingsSections::rss_feed::general', 'General'),
('SettingsOptions::rss_feed::managing_editor', 'Content editor'),
('SettingsOptions::rss_feed::display_rss_feed_in_category', 'Show RSS feed for each category'),
('SettingsOptions::rss_feed::category_max_products_items', 'Max product number per category'),
('Languages::rss_feed', 'RSS feed'),
('Languages::feed_title', 'Feed title'),
('Languages::feed_description', 'Feed description'),
('Languages::rss_sort_by', 'Sort items by'),
('Languages::rss_display_sku', 'Display SKU'),
('Languages::rss_display_image', 'Display image'),
('Languages::rss_display_price', 'Display gross price'),
('Languages::rss_display_original_price', 'Display net price'),
('Languages::rss_display_add_to_cart', 'Display add to cart button'),
('Languages::rss_created', 'Created'),
('Languages::rss_updated', 'Updated'),
('Languages::block_rss_feed', 'RSS feed'),
('Languages::block_rss_feed_description', 'RSS feed subscription icon'),
('Languages::addons.rss_feed.icon', 'RSS feed subscription icon'),
('SettingsTooltips::rss_feed::managing_editor', 'Enter the content editor''s email and real name, e.g. john@example.com (John Doe)'),
('SettingsTooltips::rss_feed::display_rss_feed_in_category', 'RSS icon near category title.'),
('Addons::name::rss_feed', 'RSS feed'),
('Addons::description::rss_feed', 'Generates RSS feeds for products and blog posts'),
('SettingsSections::newsletters::general', 'General'),
('SettingsOptions::newsletters::newsletters_per_pass', 'Newsletters sent per step'),
('SettingsOptions::newsletters::elm_advanced_mailing_server_options', 'Advanced mailing server options'),
('SettingsOptions::newsletters::mailer_send_method', 'Method of sending e-mails'),
('SettingsVariants::newsletters::mailer_send_method::smtp', 'via SMTP server'),
('SettingsVariants::newsletters::mailer_send_method::mail', 'via php mail function'),
('SettingsVariants::newsletters::mailer_send_method::default', 'use default settings'),
('SettingsOptions::newsletters::elm_smtp_server_settings', 'SMTP server settings'),
('SettingsOptions::newsletters::mailer_smtp_host', 'SMTP host'),
('SettingsOptions::newsletters::mailer_smtp_username', 'SMTP username'),
('SettingsOptions::newsletters::mailer_smtp_password', 'SMTP password'),
('SettingsOptions::newsletters::mailer_smtp_ecrypted_connection', 'Use Encrypted Connection'),
('SettingsVariants::newsletters::mailer_smtp_ecrypted_connection::none', 'None'),
('SettingsVariants::newsletters::mailer_smtp_ecrypted_connection::tls', 'TLS'),
('SettingsVariants::newsletters::mailer_smtp_ecrypted_connection::ssl', 'SSL'),
('SettingsOptions::newsletters::mailer_smtp_auth', 'Use SMTP authentication'),
('SettingsSections::newsletters::promotions', 'Promotions'),
('SettingsOptions::newsletters::coupon', 'Choose a promotion whose promo code will be given at subscription'),
('Languages::news_plain', 'Plain'),
('Languages::text_signup_for_subscriptions', 'Sign up for our newsletters!'),
('Languages::tmpl_subscription', 'Newsletters: subscription form'),
('Languages::unsubscribe_link', 'Unsubscribe link'),
('Languages::ne_add_subscribers_from_users', 'Add subscribers from the list of users'),
('Languages::ne_warning_subscr_email_exists', '<b>[email]</b> is already in the subscribers list'),
('Languages::warning_subscribers_import', 'Some mailing lists from the input file could not be found in the database. Certain imported subscribers will be left unassigned.'),
('Languages::subscribers_menu_item_text', 'Subscribers'),
('Languages::block_mailing_lists', 'Newsletter subscription'),
('Languages::block_mailing_lists_description', 'Email field for newsletter subscription'),
('Languages::block_lite_checkout_newsletters', 'Checkout: Newsletters'),
('Languages::block_lite_checkout_newsletters_description', 'Ability to sign up for newsletters'),
('Languages::privileges.view_newsletters', 'Can view'),
('Languages::privileges.manage_newsletters', 'Can edit'),
('Languages::privilege_groups.newsletters', 'Newsletters'),
('Languages::warning_newsletter_no_recipients', 'Newsletter hasn''t been sent because no recipients were found matching the selected criteria.'),
('Languages::text_newsletter_sent', 'The newsletter(s) have been sent successfully.'),
('Languages::email_cannot_be_empty', 'E-mail cannot be empty'),
('Languages::sending_email_to', 'Sending email to [email]...'),
('Languages::text_subscriber_added', 'Your e-mail has been successfully added to our free e-mail updates list'),
('Languages::error_email_already_subscribed', 'Your e-mail is already subscribed.'),
('Languages::text_subscriber_removed', 'Your e-mail has been successfully removed from our free e-mail updates list'),
('Languages::text_subscriber_activated', 'Your email has been successfully activated'),
('Languages::link_message_for_test_letter', 'The link will be displayed in a live newsletter'),
('Languages::newsletters', 'Newsletters'),
('Languages::autoresponders', 'Autoresponders'),
('Languages::campaigns', 'Campaigns'),
('Languages::sent', 'Sent'),
('Languages::subscribers_num', 'Number of subscribers'),
('Languages::editing_mailing_list', 'Editing mailing list'),
('Languages::from_name', 'From name'),
('Languages::from_email', 'From email'),
('Languages::reply_to', 'Reply to'),
('Languages::register_autoresponder', 'Confirmation email'),
('Languages::no_autoresponder', 'No autoresponder'),
('Languages::newsletters.autoresponder_used_in_mailing_list', 'You are trying to change status of the autoresponder which is used in one of the mailing lists as a confirmation email. Please check and update the lists on <a target="_blank" href="[link]">this page</a>.'),
('Languages::show_on_checkout', 'Show at checkout'),
('Languages::hide_on_checkout', 'Hide at checkout'),
('Languages::addons.newsletters.show_on_registration_and_profile', 'Show on the Registration and Profile Details pages'),
('Languages::addons.newsletters.hide_on_registration_and_profile', 'Hide on the Registration and Profile Details pages'),
('Languages::show_on_separate_page', 'Show on separate page'),
('Languages::campaign_stats', 'Campaign statistics'),
('Languages::add_campaign', 'Add campaign'),
('Languages::new_campaign', 'New campaign'),
('Languages::newsletter_templates', 'Newsletter templates'),
('Languages::newsletter_autoresponders', 'Newsletter autoresponders'),
('Languages::add_newsletter', 'Add newsletter'),
('Languages::add_template', 'Add template'),
('Languages::add_autoresponder', 'Add autoresponder'),
('Languages::more_subjects', 'Random subjects (one per line)'),
('Languages::body_html', 'HTML body'),
('Languages::no_template', 'No template'),
('Languages::load', 'Load'),
('Languages::campaign', 'Campaign'),
('Languages::send_to', 'Send to'),
('Languages::add_recipients_from_users', 'Add recipients from users'),
('Languages::customers_with_abandoned', 'Customers with abandoned');
INSERT INTO `[[dbprefix]]original_values` VALUES
('Languages::cart_or_wishlist', 'Cart or Wishlist'),
('Languages::which_is', 'which is'),
('Languages::days_old', 'days old'),
('Languages::send_to_test_email', 'Send to test email'),
('Languages::save_and_send', 'Save and send'),
('Languages::newsletter', 'Newsletter'),
('Languages::newsletter_template', 'Newsletter template'),
('Languages::newsletter_autoresponder', 'Newsletter autoresponder'),
('Languages::mailing_list', 'Mailing list'),
('Languages::confirmed', 'Confirmed'),
('Languages::subscribed_to', 'Subscribed to [num] lists'),
('Languages::subscribed', 'Subscribed'),
('Languages::text_success_subscription', 'You have been successfully subscribed to our free e-mail updates and promotions!'),
('Languages::text_unsubscribe_instructions', 'We respect your privacy and do not send unsolicited e-mail to users who have not requested correspondence. You have received this e-mail because you requested to receive our free updates and promotions.<br /><br /> If you wish to unsubscribe, please follow the link below:'),
('Languages::updates_subscription', 'updates and promotions subscription'),
('Languages::ult_shared_with', 'Shared with:'),
('Languages::tt_addons_newsletters_views_mailing_lists_update_from_email', 'Email of a sender.'),
('Languages::tt_addons_newsletters_views_mailing_lists_update_from_name', 'Name of a sender (e.g. company name).'),
('Languages::tt_addons_newsletters_views_mailing_lists_update_reply_to', 'Email to send replies to.'),
('Languages::tt_addons_newsletters_views_newsletters_update_more_subjects', 'If several subjects are specified, email subject is randomly picked from this list.'),
('Languages::tt_addons_newsletters_views_newsletters_update_users', 'If the message text contains the unsubscribe link, it will be empty for these users.'),
('Languages::add_mailing_lists', 'Add mailing list'),
('Languages::manage_subscribers', 'Manage subscribers'),
('Languages::new_mailing_lists', 'New mailing list'),
('Languages::newsletters.new_subscribers', 'New subscribers'),
('Languages::subscribers_promo_subject', 'Thank you for subscribing! Use the coupon code [coupon] in our special offer "[promotion]".'),
('Languages::subscribers_no_promo', 'No promotion'),
('Languages::promotion_cond_subscribed', 'Customer is subscribed'),
('Languages::addons.newsletters.email_exists_in_list', '<b>[email]</b> is already in the mailing list'),
('Languages::email_template.newsletters_newsletter', 'Newsletter'),
('Languages::email_template.newsletters_promotion', 'Newsletters: promotion'),
('Languages::activation_key', 'Activation key'),
('Languages::unsubscribe_key', 'Unsubscribe key'),
('Languages::subscribers_date', 'Subscribers date'),
('Languages::mailing_list_date', 'Mailing list date'),
('Languages::gdpr_newsletters', 'Personal data from newsletters'),
('Languages::newsletters.subscribe_to_newsletters', 'Newsletters: Subscribe to newsletters'),
('Languages::newsletters.agreement_text_short_subscribe_to_newsletters', 'I agree to have my personal data <u>processed as follows</u> and I want to subscribe for the following newsletters:'),
('Languages::newsletters.agreement_text_full_subscribe_to_newsletters', '<p>When you sign up for a specific newsletter, we ([company]) add your email address to a corresponding mailing list. While it is there, we know that we can contact you by email regarding that topic.</p> <p>You can always have your email address removed from our mailing lists. There are multiple ways to do it:</p><ul> <li>Once your account is registered, just sign in and unsubscribe from newsletters in profile settings.</li> <li>Use the “Unsubscribe” link in our newsletters that you receive.</li> <li>Send an email to [email].</li> </ul> <p>We may use a third-party email service (MailChimp and/or Mad Mimi) to send newsletters. Some members of our staff can view mailing lists with email addresses. That way they’ll be able to remove your email address from the mailing list, should you request us to do so.</p> <p>Please note that mailing lists are independent from each other. If you decide not to receive newsletters at all, you’ll have to unsubscribe from all the mailing lists. Even if you do that, you’ll still receive account-related emails (such as order status notifications, password reset emails, and more). It is essential for operating an online store.</p> <p>If you decide that you no longer want to use our store and would like to have your personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('Languages::newsletters.use_for_subscribe_form', 'Subscribe form'),
('Languages::newsletters.default_mailing_list', 'Default mailing list'),
('Addons::name::newsletters', 'Newsletters'),
('Addons::description::newsletters', 'Lets you configure newsletter sending'),
('SettingsSections::email_marketing::general', 'General'),
('SettingsOptions::email_marketing::em_show_on_checkout', 'Newsletter checkbox on checkout'),
('SettingsOptions::email_marketing::em_checkout_enabled', 'Tick off by default'),
('SettingsOptions::email_marketing::em_double_opt_in', 'Double opt-in'),
('SettingsOptions::email_marketing::em_welcome_letter', 'Send a welcome letter with the unsubscribe link'),
('SettingsOptions::email_marketing::em_service', 'Email integration provider'),
('SettingsVariants::email_marketing::em_service::dummy', '--'),
('SettingsVariants::email_marketing::em_service::mailchimp', 'MailChimp'),
('SettingsVariants::email_marketing::em_service::madmimi', 'MadMimi'),
('SettingsOptions::email_marketing::em_token', ''),
('SettingsOptions::email_marketing::em_lastsync', ''),
('SettingsSections::email_marketing::mailchimp', 'MailChimp'),
('SettingsOptions::email_marketing::em_mailchimp_api_key', 'API key'),
('SettingsOptions::email_marketing::em_mailchimp_list', 'List'),
('SettingsSections::email_marketing::madmimi', 'MadMimi'),
('SettingsOptions::email_marketing::em_madmimi_username', 'E-mail'),
('SettingsOptions::email_marketing::em_madmimi_api_key', 'API key'),
('SettingsOptions::email_marketing::em_madmimi_list', 'List'),
('Languages::email_marketing.subscription_confirmed', 'Thank you for subscribing to our newsletter'),
('Languages::email_marketing.text_subscription_confirmed', 'Your subscription has been confirmed. No extra actions is required.'),
('Languages::email_marketing.subscription_pending', 'Email confirmation is required!'),
('Languages::email_marketing.text_subscription_pending', 'Thank you for subscribing to our newsletter.<p>A confirmation email has been sent to you. Please use the link in the email to confirm your subscription</p>'),
('Languages::email_marketing.confirm_subscription', 'Please confirm subscription'),
('Languages::email_marketing.text_confirm_subscription', 'We received a subscription request from you. Please confirm it:<p><a href="[href]">Click here to confirm your subscription to our newsletter</a></p>If you received this email by mistake, simply delete it. You won''t be subscribed if you don''t click the confirmation link above.'),
('Languages::email_marketing.subscription_confirmed_2', 'Subscription confirmed'),
('Languages::email_marketing.text_subscription_confirmed_2', 'Your subscription to our newsletter has been confirmed. Thank you for subscribing!'),
('Languages::email_marketing.email_subscribed', 'You were subscribed to our newsletter'),
('Languages::email_marketing.text_email_subscribed', 'Thank you for subscribing to our newsletter. <p>If at any time you wish to stop receiving our emails, <a href="[href]">click on this link to unsubscribe</a>.</p>'),
('Languages::email_marketing.email_subscribed_2optin', 'Subscription confirmed'),
('Languages::email_marketing.text_email_subscribed_2optin', 'Your subscription to our newsletter has been confirmed.<p>If at any time you wish to stop receiving our emails, <a href="[href]">click on this link to unsubscribe</a>.</p>'),
('Languages::email_marketing.unsubscribe_successful', 'Unsubscribe successful'),
('Languages::email_marketing.text_unsubscribe_successful', 'Your email has been removed from our list.'),
('Languages::email_marketing.export_all', 'Export all'),
('Languages::email_marketing.enter_api_key_and_save', 'Enter API key and save first'),
('Languages::email_marketing.warning_email_exists', '[email] is already subscribed'),
('Languages::email_marketing.new_subscriber', 'New subscriber'),
('Languages::email_marketing.sync', 'Sync'),
('Languages::email_marketing.text_subscribe', 'Subscribe to our newsletter'),
('Languages::email_marketing.tmpl_subscription', 'Email marketing: Newsletter subscription form'),
('Languages::privileges.manage_email_marketing', 'Can edit'),
('Languages::privileges.view_email_marketing', 'Can view'),
('Languages::privilege_groups.email_marketing', 'Email marketing'),
('Languages::email_marketing.error_no_list', 'Please select mailing list in add-on settings to start import'),
('Languages::email_template.email_marketing_confirmation', 'Email marketing: subscription confirmation'),
('Languages::email_template.email_marketing_welcome', 'Email marketing: welcome letter'),
('Languages::email_template.email_marketing_welcome_2optin', 'Email marketing: welcome letter (2optin)'),
('Languages::email_marketing.use_for_subscribe_form', 'Email marketing subscribe form'),
('Addons::name::email_marketing', 'E-mail marketing'),
('Addons::description::email_marketing', 'Synchronizes your newsletter subscriber lists with MailChimp and Mad Mimi'),
('SettingsSections::attachments::general', 'General'),
('SettingsOptions::attachments::allow_save_attachments_to_server', 'Save attachments to your server'),
('Languages::attachments', 'Attachments'),
('Languages::new_attachment', 'New attachment'),
('Languages::add_attachment', 'Add attachment'),
('Languages::editing_attachment', 'Editing attachment'),
('Languages::attachments.attachments_need_located_root_dir', 'Please specify the attachments directory within the store root directory. Put the attachments to import in this directory.'),
('Languages::attachments.error_exim_get_attachments_for_products', 'Could not import attachments for some of the products. Either those attachments don''t exist (or can''t be accessed), or the paths to those attachments in the imported file are incorrect.'),
('Languages::advanced_import_attachments', 'Product attachments'),
('Languages::attachments.attachments_delimiter', 'Attachments delimiter'),
('Languages::attachments.attachments_delimiter.description', 'Delimiter between attachments of a product.'),
('Languages::attachments.delete_attachments', 'Delete existing attachments'),
('Languages::attachments.delete_attachments_tooltip', 'If you enable this setting, then the existing attachments of the imported products will be replaced with the attachments specified in the imported file (if no attachments are specified, the old attachments will remain). If the setting is disabled, the new attachments will simply be added to the existing attachments.'),
('Languages::attachments.attachments_directory', 'Attachments directory'),
('Languages::attachments.cant_upload_file', 'Couldn''t load file [url] for product [product]'),
('SettingsTooltips::attachments::allow_save_attachments_to_server', 'Attachments listed as URLs in the imported file will be downloaded to your server.'),
('Addons::name::attachments', 'Attachments'),
('Addons::description::attachments', 'Makes it possible to attach files to products'),
('Addons::name::customers_also_bought', 'Customers also bought'),
('Addons::description::customers_also_bought', 'Makes it possible to create a special block for the products often purchased along with the current one'),
('SettingsSections::vendor_communication::vendor_to_customer', 'For customers'),
('SettingsOptions::vendor_communication::show_on_product', 'Contact button on product pages'),
('SettingsOptions::vendor_communication::show_on_messages', 'Contact button at "Messages" menu'),
('SettingsOptions::vendor_communication::show_on_order', 'Contact button on detailed order page'),
('Languages::vendor_communication.messages', 'Messages'),
('Languages::vendor_communication.message_center', 'Message center'),
('Languages::vendor_communication.message_center_name', 'Message center'),
('Languages::vendor_communication.author', 'Author'),
('Languages::vendor_communication.date', 'Date'),
('Languages::vendor_communication.message', 'Message'),
('Languages::vendor_communication.contact_vendor', 'Contact vendor'),
('Languages::vendor_communication.ask_a_question', 'Ask a question'),
('Languages::vendor_communication.contact_vendor_name', 'Contact [vendor_name]'),
('Languages::vendor_communication.created_at', 'Created on'),
('Languages::vendor_communication.new_thread_created', 'Your message has been sent to <b>[vendor_name]</b>.<br/><br/>The vendor''s reply will be sent to the email address of your account. To view your message history, please <a href="[thread_url]">go to the Message Center</a> located in the "Messages" section of the "My account" menu.'),
('Languages::vendor_communication.message_sent', 'Your message has been sent to <b>[vendor_name]</b>.<br/><br/>We''ll notify you about a reply. To view your message history, please <a href="[thread_url]" target="_blank">go to the Message Center</a> located in the "Messages" section of the "My account" menu.'),
('Languages::vendor_communication.cannot_update_thread', 'Cannot update thread'),
('Languages::vendor_communication.cannot_create_thread', 'Cannot create thread'),
('Languages::email_template.vendor_communication.notify_admin', 'Ask seller a question: Admin Notification'),
('Languages::email_template.vendor_communication.notify_customer', 'Ask seller a question: Customer Notification'),
('Languages::vendor_communication.you_have_new_message', 'You have a new <a href="[thread_url]">message</a> from [message_from].'),
('Languages::vendor_communication.subject_email', 'You have a new message from [message_from]'),
('Languages::vendor_communication.thread', 'Thread #[thread_id]'),
('Languages::vendor_communication.contact_with', '#[thread_id]. Communication with [thread_company]'),
('Languages::vendor_communication.ticket', 'Thread'),
('Languages::vendor_communication.no_messages_found', 'No messages found'),
('Languages::vendor_communication.customer_name', 'Customer name'),
('Languages::vendor_communication.error_message', 'Please enter your message'),
('Languages::vendor_communication.type_message', 'Type a message...'),
('Languages::vendor_communication.you', 'You'),
('Languages::vendor_communication.order_details', 'Order details'),
('Languages::vendor_communication.import_details', 'Import details'),
('Languages::vendor_communication.thread_deleted', 'Thread has been deleted'),
('Languages::vendor_communication.threads_deleted', 'Threads have been deleted'),
('Languages::vendor_communication.cannot_delete_thread', 'Cannot delete thread'),
('Languages::vendor_communication.cannot_delete_threads', 'Cannot delete threads'),
('Languages::vendor_communication.cannot_post_message', 'Cannot post message'),
('Languages::vendor_communication.no_threads_found', 'No threads found'),
('Languages::vendor_communication.required_field_is_missing', 'The [field_name] field is required'),
('Languages::vendor_communication.invalid_thread_object_type', 'Provided thread object type is invalid'),
('Languages::vendor_communication.please_log_in_to_contact_vendor', 'Please sign in to contact the vendor'),
('Languages::privileges.manage_vendor_communication', 'Can edit'),
('Languages::privileges.view_vendor_communication', 'Can view'),
('Languages::privilege_groups.vendor_communication', 'Message center: customer-to-vendor communication'),
('Languages::vendor_communication.your_message_to_vendor_name', 'Your message to [vendor_name]'),
('Languages::vendor_communication.please_log_in_to_be_notified', 'Please sign in so that we can notify you about a reply'),
('Languages::vendor_communication', 'Message center'),
('Languages::vendor_communication.event.message_received.name', 'Customer-to-vendor: New message received'),
('Languages::vendor_communication.event.vendor_to_admin_message_received.name', 'Vendor-to-admin: New message received'),
('Languages::internal_template.vendor_communication_message_received', 'New message received'),
('Languages::vendor_communication.new_message.title', '[company_name] has a new message from [customer]'),
('Languages::vendor_communication.new_message.message', 'Click this notification to see the message'),
('Languages::vendor_communication.contact_admin', 'Contact administrator'),
('Languages::vendor_communication.communication', 'Communication'),
('Languages::vendor_communication.message_center_vendor_name', 'Message center'),
('Languages::vendor_communication.tab_vendor_to_admin', 'Vendor communication'),
('Languages::vendor_communication.tab_vendor_to_customer', 'Customer communication'),
('Languages::vendor_communication.tab_vendor_to_admin_for_vendor_panel', 'Admin communication'),
('Languages::vendor_communication.menu_item_vendor_to_admin', 'Vendor messages'),
('Languages::vendor_communication.menu_item_vendor_to_customer', 'Customer messages'),
('Languages::vendor_communication.menu_item_vendor_to_admin_for_vendor_panel', 'Admin messages'),
('Languages::vendor_communication.your_message_to_admin', 'Your message to administrator'),
('Languages::vendor_communication.some_threads_have_not_been_created', 'Some threads have not been created: [count]'),
('Languages::vendor_communication.vendor_to_admin.message_sent', 'Your message has been sent to <b>[name]</b>.<br/><br/>To view your message history, please <a href="[thread_url]">go to the Message Center</a> located in the "Vendors" menu.'),
('Languages::vendor_communication.vendor_to_customer.message_sent', 'Your message has been sent to <b>[name]</b>.<br/><br/>To view your message history, please <a href="[thread_url]">go to the Message Center</a> located in the "Customers" menu.'),
('Languages::vendor_communication.vendor_to_admin.message_list_sent', 'Your messages have been sent.<br/><br/>To view your message history, please <a href="[thread_url]">go to the Message Center</a> located in the "Vendors" menu.'),
('Languages::privilege_groups.admin_communication', 'Message center: vendor-to-admin communication'),
('Languages::customer_to_admin_communication.event.message_received.name', 'Customer-to-Admin: New message received'),
('Languages::vendor_communication.start_communication', 'Start communication'),
('Languages::privilege_groups.order_communication', 'Message center: communication with customer'),
('Languages::vendor_communication.communication_vendor_to_admin', 'Communication with vendor'),
('Languages::vendor_communication.communication_vendor_to_customer', 'Communication with customer'),
('Languages::vendor_communication.communication_vendor_to_admin_with_admin', 'Communication with administrator'),
('Languages::vendor_communication.contact_customer', 'Contact customer'),
('Languages::vendor_communication.subject', 'Subject'),
('Languages::vendor_communication.admin', 'Admin'),
('Languages::vendor_communication.your_message_to_customer', 'Your message to customer'),
('Languages::vendor_communication.event.order_message_received.name', 'Order communication: New message received'),
('Languages::vendor_communication.scroll_to_top', 'Scroll to top'),
('Languages::vendor_communication.send_message', 'Send message'),
('Languages::vendor_communication.dashboard.todo.messages_from_customers', '<strong>[n] message</strong> from customer.|<strong>[n] messages</strong> from customers.'),
('Languages::vendor_communication.dashboard.todo.messages_from_administrator', '<strong>[n] message</strong> from marketplace administration.|<strong>[n] messages</strong> from marketplace administration.'),
('Languages::vendor_communication.dashboard.todo.messages_from_vendors', '<strong>[n] message</strong> from vendor.|<strong>[n] messages</strong> from vendors.'),
('SettingsTooltips::vendor_communication::show_on_product', 'Show the "Ask a question" button on product pages.'),
('SettingsTooltips::vendor_communication::show_on_order', 'Show the "Start communication" button on detailed order page.'),
('Addons::name::vendor_communication', 'Message center'),
('Addons::description::vendor_communication', 'Allows customers, vendors, and administrators to contact each other via the built-in chat.'),
('Languages::advanced_import.never', 'Never'),
('Languages::advanced_import.last_status.X', '&mdash;'),
('Languages::advanced_import.last_status.S', 'Success'),
('Languages::advanced_import.last_status.P', 'In progress'),
('Languages::advanced_import.last_status.F', 'Failure'),
('Languages::advanced_import.user_upload', 'User upload'),
('Languages::advanced_import.last_launch', 'Last import'),
('Languages::advanced_import.last_status', 'Status'),
('Languages::advanced_import.file', 'File'),
('Languages::advanced_import.has_modifiers', 'Has modifiers'),
('Languages::advanced_import.import_products', 'Import products'),
('Languages::advanced_import.import_products_w_preset', 'Import products: [preset]'),
('Languages::advanced_import.import_file', 'Import file'),
('Languages::advanced_import.fields_mapping', 'Fields mapping'),
('Languages::advanced_import.fields_mapping.description', 'This table contains the list of columns from the imported file. For each column you''d like to import, select a corresponding product property in [product]. Then check what sort of data will be imported from that column, and use modifiers to change that data, if necessary. Remember to save your changes.'),
('Languages::advanced_import.column_header', 'Column name in the imported file'),
('Languages::advanced_import.product_property', 'Product property in [product]'),
('Languages::advanced_import.first_line_import_value', 'Example of the imported value'),
('Languages::advanced_import.editing_preset', 'Editing preset: [preset]'),
('Languages::advanced_import.add_preset', 'Add preset'),
('Languages::advanced_import.new_preset', 'New import'),
('Languages::advanced_import.properties', 'Properties'),
('Languages::advanced_import.modifier', 'Modifier'),
('Languages::advanced_import.modifier_title', 'A modifier is a rule that alters values in a column'),
('Languages::advanced_import.example_imported_title', 'For example, here''s a value in the first line of your file:'),
('Languages::advanced_import.example_modified_title', 'And here is how this value will be imported:'),
('Languages::advanced_import.options', 'Options'),
('Languages::advanced_import.images_delimiter', 'Images delimiter'),
('Languages::advanced_import.images_delimiter.description', 'Delimiter between images of a product.'),
('Languages::advanced_import_images', 'Product images'),
('Languages::advanced_import.remove_images', 'Remove additional images'),
('Languages::advanced_import.import_fields', 'Import fields'),
('Languages::advanced_import.advanced_products_import', 'Products'),
('Languages::advanced_import.coming_soon', '... coming soon'),
('Languages::advanced_import.cant_load_file_for_company', 'File can''t be loaded for the specified company'),
('Languages::advanced_import.cant_load_file', 'File can''t be loaded'),
('Languages::advanced_import.uploading_file', 'Uploading file for the preset: [preset]'),
('Languages::advanced_import.previewing_fields_mapping', 'Previewing fields mapping for the preset: [preset]'),
('Languages::advanced_import.preset_not_found', 'Preset not found'),
('Languages::advanced_import.modifiers_list', 'Modifiers list'),
('Languages::advanced_import.invalid_number_of_parameters_provided', 'Invalid number of parameters provided for modifier: <b>[modifier]</b>: expected [expected_count], got [actual_count].'),
('Languages::advanced_import.invalid_function_firs_character', 'The modifier name cannot start with character <b>[character]</b>.'),
('Languages::advanced_import.unrecognized_modifier', 'The modifier <b>[modifier]</b> does not exist.'),
('Languages::advanced_import.unexpected_parameter_passed', 'Expected <b>[delimiter]</b> or <b>[closer]</b> got <b>[char]</b>.'),
('Languages::advanced_import.invalid_modifier_message', 'The modifier <b>[modifier]</b> is invalid. [message]'),
('Languages::advanced_import.modifier_number_of_parameters', 'Number of parameters'),
('Languages::advanced_import.modifiers_description', 'Use these functions in the <b>Modifier</b> column to alter the values in the fields from the imported file. Enter the functions as follows: <b>function(parameter, parameter)</b>. Please note that nesting of functions isn''t supported.'),
('Languages::advanced_import.modifiers_self_referencing_info', 'Most functions allow you to use the non-modified value of the imported field by using <b>$value</b> as a parameter. If there are any exceptions, they will be mentioned in function descriptions.'),
('Languages::advanced_import.modifier_description.sum', '<b>sum</b>&mdash;sums up two numbers provided as parameters. <ul><li>Examples:</li><ul><li><b>sum(1, 3)</b> equals <i>4</i></li> <li><b>sum(7, $value)</b> equals <i>7 + the value of the imported field</i></li></ul></ul>'),
('Languages::advanced_import.modifier_description.sub', '<b>sub</b>&mdash;subtracts the second parameter from the first. <ul><li>Examples:</li><ul><li><b>sub(3, 1)</b> equals <i>2</i></li> <li><b>sub($value, 7)</b> equals <i>the value of the imported field - 7</i></li></ul></ul>'),
('Languages::advanced_import.modifier_description.mul', '<b>mul</b>&mdash;multiplies the numbers provided as parameters. <ul><li>Examples:</li><ul><li><b>mul(3, 1)</b> equals <i>3</i></li> <li><b>mul($value, 7)</b> equals <i>the value of the imported field × 7</i></li></ul></ul>'),
('Languages::advanced_import.modifier_description.div', '<b>div</b>&mdash;divides the first parameter by the second. <ul><li>Examples:</li><ul><li><b>div(9, 3)</b> equals <i>3</i></li> <li><b>div($value, 7)</b> equals <i>the value of the imported field ÷ 7</i></li></ul></ul>'),
('Languages::advanced_import.modifier_description.concat', '<b>concat</b>&mdash;concatenates all the provided parameters. <ul><li>Examples:</li><ul><li><b>concat(''abc'', def)</b> will result in <i>abcdef</i></li> <li><b>concat(''PRODUCT_'', $value, ''_CODE'')</b> will result in <i>PRODUCT_$value_CODE</i>, but <b>$value</b> will be replaced with the the value of the imported field</li></ul></ul>'),
('Languages::advanced_import.modifier_description.replace', '<b>replace</b>&mdash;replaces all occurrences of the search string with the replacement string. <br>The order of parameters is important: <b>replace(''search'', ''replace'', ''subject'')</b>. <ul><li>Examples:</li><ul><li><b>replace(''a'', !, "banana")</b> will result in <i>b!n!n!</i></li> <li><b>replace("t-shirt", ''T-Shirt'', $value)</b> will replace every occurrence of <i>t-shirt</i> with <i>T-Shirt</i> in every entry in the column.</li></ul></ul>'),
('Languages::advanced_import.modifier_description.w_replace', '<b>w_replace</b>&mdash;replaces all occurrences of the search string with the replacement string using wildcards. <br>The order of parameters is important: <b>w_replace(''search'', ''replace'', ''subject'')</b>. <br>Supported wildcards: <b>?</b>&mdash;any single character; <b>*</b>&mdash;any number of characters to the end of the word. <ul><li>Examples</li><ul><li><b>w_replace(''banan?'', bananas, banana banans bananz)</b> will result in <i>bananas bananas bananas</i></li> <li><b>w_replace("ban*", ''bananas'', banana banans bananz)</b> will also result in <i>bananas bananas bananas</i></li></ul></ul>'),
('Languages::advanced_import.modifier_description.rand', '<b>rand</b>&mdash;generates a random number from 1 to the maximum value provided as the parameter. <ul><li>Examples:</li><ul><li><b>rand(999)</b> may result in any number from 1 to 999.</li></ul></ul>'),
('Languages::advanced_import.modifier_description.if', '<b>if</b>&mdash;checks the expression in the first parameter. If the first parameter is <i>true</i>, the function returns the second parameter. Otherwise the function returns the third parameter.<ul><li>Examples:</li><ul><li><b>if($value>"0", "In Stock", "Out of stock")</b> will result in <i>In Stock</i> if <i>$value > 0</i> is <i>true</i>; otherwise the result will be <i>Out of stock</i></li></ul><li>Available operations for the expression are:<ul><li><b>=</b>&mdash;checks for equality: <i>if($value=100, ...)</i></li><li><b>!=</b>&mdash;checks for inequality: <i>if($value!=100, ...)</i></li><li><b>&gt;</b>&mdash;checks if the first value is greater than the second: <i>if($value&gt;100, ...)</i></li><li><b>&lt;</b>&mdash;checks if the first value is less than the second: <i>if($value&lt;100, ...)</i></li><li><b>&gt;=</b>&mdash;checks if the first value is greater than or equal to the second: <i>if($value&gt;=100, ...)</i></li><li><b>&lt;=</b>&mdash;checks if the first value is less than or equal to the second: <i>if($value&lt;=100, ...)</i></li></ul></li><li>Notes:<ul><li>If you use single ('') or double (") quotes in the first parameter, make sure that the first parameter is either wrapped in quotes entirely, or that there is no end quote in the middle of the parameter. For example, <i>if("My value"=$value, ...)</i> will not work, but <i>if("My value=$value", ...)</i> will.</ul></li></ul>'),
('Languages::advanced_import.modifier_description.case', '<b>case</b>&mdash;odd parameters are expressions, and the following even parameters are corresponding values. The function checks the expressions and returns the value corresponding to the first expression that ends up being <i>true</i>.<ul><li>Examples:</li><ul><li><b>case($value>100, "More than 100", $value>70, "More than 70", $value>20, "More than 20", $value>0, "In stock", $value=0, "Out of stock")</b> will result in <i>More than 70</i> if the <i>$value</i> in the imported file is a number between 71 and 100</li></ul><li>Notes:<ul><li>This function shares expression rules and available operations with the <b>if</b> function.</li><li>Only even numbers of parameters are supported: <b>2, 4, 6, 8</b>, etc.</li></ul></li></ul>'),
('Languages::advanced_import.modifier_self_reference_is_unsupported', 'This function doesn''t support the use of a non-modified value from the imported file.'),
('Languages::advanced_import.preset_last_view', 'Preset'),
('Languages::advanced_import.show_more', 'Show more'),
('Languages::advanced_import.show_less', 'Show less'),
('Languages::advanced_import.target_node', 'XML target node'),
('Languages::advanced_import.target_node.description', 'The full path to the XML node with the information about an imported entity. The nodes nested in the specified node will be used as columns of the imported file. Here is an example of the path: yml_catalog/shop/offers/offer'),
('Languages::advanced_import.fetching_schema_failed_check_target_node', 'Please make sure that the <b>XML target node</b> field is filled in properly.'),
('Languages::advanced_import.general_settings', 'General settings'),
('Languages::advanced_import.additional_settings', 'Additional settings'),
('Languages::advanced_import.delete_additional_images', 'Delete existing additional images'),
('Languages::advanced_import.delete_additional_images_tooltip', 'If you enable this setting, then the existing additional images of the imported products will be replaced with the images specified in the imported file (if no images are specified, the old images will remain). If the setting is disabled, the new additional images will simply be added to the existing images.'),
('Languages::advanced_import.fetching_schema_failed_check_file', 'Before you can run the import, please make sure that:<ul><li>You have created the import preset by using the Create button. If you see Save instead of Create, then you''ve already done that.</li><li>You have specified the correct XML target node on the File tab and saved the preset.</li><li>You have matched the imported information with the product properties in CS-Cart on the Fields mapping tab and saved the preset.</li></ul>If you see this message, you haven''t completed point 1 or 2.'),
('Languages::advanced_import.test_import', 'Perform test import'),
('Languages::advanced_import.test_import_tooltip', 'If you enable this setting, only the first [n] product will be processed.|If you enable this setting, only the first [n] products will be processed.'),
('Languages::advanced_import.import_strategy', 'Import strategy'),
('Languages::advanced_import.import_strategy_tooltip', 'If you select "Update existing products only", products that don''t exist in the database of your store will be skipped during import.<br>If you select "Create new products only", products that exist in the database of your store will be skipped during import.'),
('Languages::advanced_import.import_all', 'Import all products from the file'),
('Languages::advanced_import.create_new_products_only', 'Create new products only'),
('Languages::advanced_import.cant_save_preset_invalid_modifiers', 'The preset can''t be saved because it contains invalid modifiers'),
('Languages::advanced_import.some_product_properties_not_found', 'Some previously mapped product properties are no longer available. For example, this can happen when you disable a product feature.'),
('Languages::advanced_import.missing_parameters_list_closer', 'The expected <b>[closer]</b> after the parameters list is missing.'),
('Languages::advanced_import.run_import_via_cron_message', 'You can run the import automatically at certain time intervals. To do it, add the following command to CRON:'),
('Languages::advanced_import.cannot_detect_csv_delimiter', 'Cannot detect delimiter automatically. Please specify the correct delimiter manually in the additional settings on the "File" tab.'),
('Languages::advanced_import.incorrect_delimiter', 'Specified (or auto detected) delimiter seems to be incorrect. Please specify the correct delimiter manually in the additional settings on the "File" tab.'),
('Languages::advanced_import.file_will_be_deleted_are_you_sure_to_proceed', 'Deleting this import preset will also delete the file attached to it. Are you sure you want to proceed?'),
('Languages::advanced_import.common_preset', 'All vendors'),
('Languages::advanced_import.your_presets', 'Vendor''s presets'),
('Languages::advanced_import.common_presets', 'Marketplace presets'),
('Languages::advanced_import.file_not_loaded', 'File was not loaded. Please reload the page and try again.'),
('Languages::advanced_import.local_file_selected', 'Local file selected'),
('Languages::advanced_import.text_popup_file_editor_notice_full_link', 'You can upload and download files via <a class="advanced-import-file-editor-opener" data-target-input-id="[target]">[link_text]</a>'),
('Languages::advanced_import.text_popup_file_editor_notice_with_image_size_info', 'You can upload and download files via <a class="advanced-import-file-editor-opener" data-target-input-id="[target]">[link_text]</a>. The maximum size of image files is [file_size] MB.'),
('Languages::advanced_import.text_allowed_to_upload_file_extension_with_image_size_info', 'The following file extensions are supported: <b>[ext]</b>. The maximum size of image files is [file_size] MB.'),
('Languages::advanced_import.file_extension_was_not_supported_by_owner', 'Couldn''t use your file [name]. This import preset only allows the following extensions: [ext].'),
('Languages::advanced_import.save_selected_file', 'Save selected file'),
('Languages::advanced_import.fields_delimiter', 'XML node delimiter'),
('Languages::advanced_import.fields_delimiter.description', 'Delimiter between similar nodes.'),
('Languages::advanced_import.link_to_file', 'Link to file'),
('Languages::advanced_import.export_example', 'Export example'),
('Languages::advanced_import.cant_export_example', 'The example file can not be exported. Fill the fields mapping of current preset.'),
('Languages::advanced_import.archive_with_images', 'Archive with images'),
('Languages::advanced_import.step_map_fields', 'Next step: map fields'),
('Addons::name::advanced_import', 'Advanced products import'),
('Addons::description::advanced_import', 'Allows you to match the fields in the imported file with the product properties. These matchings and other import settings can also be saved as presets for later use.'),
('SettingsSections::geo_maps::general', 'General'),
('SettingsOptions::geo_maps::provider', 'Provider'),
('SettingsVariants::geo_maps::provider::google', 'Google'),
('SettingsVariants::geo_maps::provider::yandex', 'Yandex'),
('SettingsOptions::geo_maps::show_shippings_on_product', 'Show shipping cost and time on product pages'),
('SettingsSections::geo_maps::yandex', 'Yandex'),
('SettingsOptions::geo_maps::yandex_api_key', 'API key'),
('SettingsOptions::geo_maps::yandex_suggest_api_key', 'Geosuggest API key'),
('SettingsOptions::geo_maps::yandex_commercial', 'I use the paid version of the API'),
('SettingsOptions::geo_maps::yandex_map', ''),
('SettingsSections::geo_maps::google', 'Google'),
('SettingsOptions::geo_maps::google_api_notice', ''),
('SettingsOptions::geo_maps::google_api_key', 'API key'),
('SettingsOptions::geo_maps::google_map', ''),
('Languages::geo_maps.select_your_city', 'Select your city'),
('Languages::geo_maps.your_city', 'Your city'),
('Languages::geo_maps.location_detection_disabled', 'Your location could not be determined. Try enabling the location services on your device or disabling the tracking protection.'),
('Languages::block_geo_maps_customer_location', 'Customer location'),
('Languages::block_geo_maps_customer_location_description', 'Customer city and city selection form'),
('Languages::geo_maps.shipping_address_on_map', 'Shipping address on map'),
('Languages::geo_maps.cannot_select_location', 'This location couldn''t be selected due to technical reasons. If you encounter any difficulties when placing an order, please contact us.'),
('Languages::geo_maps.shipping_time_and_rates', 'Shipping time and rates'),
('Languages::geo_maps.shipping_group_pickup', 'Pick-up'),
('Languages::geo_maps.shipping_group_delivery', 'Shipping'),
('Languages::geo_maps.from_pickup_points', '[shipping], [n] pickup point|[shipping], [n] pickup points'),
('Languages::geo_maps.shipping_about', 'about'),
('Languages::geo_maps.shipping_from', 'from'),
('Languages::geo_maps.shipping_time', 'Shipping time'),
('Languages::geo_maps.no_shippings', 'Sorry, we couldn''t find any shipping options for your location. Please contact us, and we''ll see what we can do about it.'),
('Languages::geo_maps.no_shippings_short', 'Shipping to your location isn''t available.'),
('Languages::geo_maps.text_settings_google_api_notice', 'Learn more about setting up API key <a target="_blank" href="https://docs.cs-cart.com/4.10.x/user_guide/addons/maps_and_geolocation/#configuration">in the documentation</a>.'),
('Languages::geo_maps.settings_is_configured_correctly_notice', 'If you see the map here, everything is configured correctly, and the maps are working on the map provider end.'),
('Languages::geo_maps.google_maps_cookie_title', 'Google Maps'),
('Languages::geo_maps.google_maps_cookie_description', 'Google Maps is a service that allows us to show the maps and various locations on those maps, or automatically determine your location. Here is <a href="https://policies.google.com/privacy" target="_blank">Google privacy policy;</a> we also recommend Google''s concise and comprehensive <a href="https://support.google.com/maps/answer/10400210" target="_blank">note on privacy</a>.'),
('Languages::geo_maps.yandex_maps_cookie_title', 'Yandex Maps'),
('Languages::geo_maps.yandex_maps_cookie_description', 'Yandex Maps is a service that allows us to show the maps and various locations on those maps, or automatically determine your location. Here is <a href="https://yandex.com/legal/confidential/" target="_blank">Yandex privacy policy</a>.'),
('SettingsTooltips::geo_maps::yandex_api_key', 'Get the API key and Geosuggest API key here: <a href="https://developer.tech.yandex.ru/" target="_blank">https://developer.tech.yandex.ru</a>'),
('SettingsTooltips::geo_maps::google_api_key', 'Get the API key here: <a href=" https://console.developers.google.com" target="_blank"> https://console.developers.google.com</a>'),
('Addons::name::geo_maps', 'Maps and geolocation'),
('Addons::description::geo_maps', 'Enables Google or Yandex maps and geolocation functionality in your store.'),
('SettingsSections::gift_certificates::general', 'General'),
('SettingsOptions::gift_certificates::min_amount', 'Minimal amount'),
('SettingsOptions::gift_certificates::max_amount', 'Maximal amount'),
('SettingsOptions::gift_certificates::code_prefix', 'GC Code prefix'),
('SettingsOptions::gift_certificates::cert_per_page', 'Gift certificates per page'),
('SettingsOptions::gift_certificates::free_products_allow', 'Allow to use free products'),
('SettingsOptions::gift_certificates::redeem_shipping_cost', 'Allow to redeem shipping cost with gift certificate'),
('Languages::gift_certificates.actions.gift_certificate_statuses', 'Gift certificate statuses'),
('Languages::gift_certificate', 'Gift certificate'),
('Languages::gift_certificates', 'Gift certificates'),
('Languages::gift_certificate_info', 'Gift certificate info'),
('Languages::gift_certificate_verification', 'Gift certificate verification'),
('Languages::gift_cert_code', 'Gift certificate code'),
('Languages::gift_cert_debit', 'Debit balance'),
('Languages::gift_cert_from', 'From'),
('Languages::gift_cert_to', 'To'),
('Languages::promotion_bonus_gift_certificate', 'Gift certificate'),
('Languages::purchase_gift_certificate', 'Purchase Gift Certificate'),
('Languages::text_gift_certificate_logo', 'Logo for <b>gift certificates</b>'),
('Languages::text_gift_cert_amount_alert', 'Amount should be between [min] and [max]'),
('Languages::text_gift_cert_has_been_deleted', 'Gift certificate has been deleted successfully.'),
('Languages::error_gift_cert_code', 'The gift certificate code you entered is invalid. Please try again.'),
('Languages::gift_add_products', 'Add products for a gift'),
('Languages::gift_comment', 'Message'),
('Languages::certificate_verification', 'Validate/Redeem gift certificate'),
('Languages::detailed_info', 'Detailed information'),
('Languages::history', 'History'),
('Languages::gift_certificate_statuses', 'Gift certificate statuses'),
('Languages::gift_certificates.recipient_email', 'Recipient email'),
('Languages::text_gift_cert_applied', 'Gift certificate has been applied'),
('Languages::certificate_already_used', 'This gift certificate is already in use'),
('Languages::certificate_code_not_available', 'Gift certificate cannot be applied. Please contact the store administration.'),
('Languages::certificate_code_not_valid', 'Gift certificate code is not valid'),
('Languages::warning_gift_cert_deny', 'The following gift certificates have been deleted or cancelled by administrator and have been removed from your cart: [codes]. Please contact the store administrator or try another one.'),
('Languages::text_gift_cert_cannot_delete', 'Gift certificate [code] cannot be deleted because it is used in order(s) [ids].'),
('Languages::gift_cert_amount_changed', 'Gift certificate amount has been changed.'),
('Languages::purchased', 'Purchased'),
('Languages::used', 'Used'),
('Languages::create_gift_certificate_for_customer', 'Create Gift Certificate for this customer'),
('Languages::gift_certificate_created', 'Gift Certificate has been created'),
('Languages::related_gift_cert', 'Related gift certificates'),
('Languages::add_gift_certificate', 'Add gift certificate'),
('Languages::gift_certificate_status', 'Gift certificate status'),
('Languages::current_amount', 'Current amount'),
('Languages::mail', 'Mail'),
('Languages::statuses', 'statuses'),
('Languages::new_certificate', 'New certificate'),
('Languages::editing_certificate', 'Editing certificate'),
('Languages::shop_now', 'Shop now'),
('Languages::theme_editor.gift_cert', 'Gift Certificate'),
('Languages::theme_editor_logo.gift_cert', 'Gift Certificate'),
('Languages::promo_code_or_certificate', 'Gift certificate or promo code'),
('Languages::gift_certificate_added_to_cart', 'Gift certificate was added to your cart'),
('Languages::gift_certificates_verify', 'Gift certificate verification'),
('Languages::block_gift_certificates_verify', 'Gift certificate verification'),
('Languages::block_gift_certificates_verify_description', 'Gift certificate input and validation'),
('Languages::gift_cert_error_amount', 'Amount should not be higher than [max] and less than [min]'),
('Languages::privileges.manage_gift_certificates', 'Can edit'),
('Languages::privilege_groups.gift_certificates', 'Gift certificates'),
('Languages::change_gift_certificate_status', 'Change gift certificate status to'),
('Languages::gift_cert_with_products', 'Purchasing products and gift certificates together is impossible. Please, place the current order and repeat your attempt.'),
('Languages::gc_redeem_and_add_free_products', 'Redeem & add free products to cart'),
('Languages::email_template.gift_certificates_notification', 'Gift certificate'),
('Languages::template_document_gift_certificate_default', 'Gift certificates: default'),
('Languages::document_preview_gift_certificate_not_found', 'Couldn''t find a gift certificate. Preview only works with existing data. Please create a gift certificate and use Preview again.'),
('Languages::gift_certificates.certificate_purchase_form', 'Gift certificate purchase form'),
('Languages::gift_certificates.event.gift_certificate.status_changed.name', 'Gift certificate status changed to [status]'),
('Languages::gift_certificates.event.gift_certificate.updated.name', 'Gift certificate updated'),
('Languages::logo_section.gift_cert', 'Gift certificate logo'),
('Addons::name::gift_certificates', 'Gift certificates'),
('Addons::description::gift_certificates', 'Adds a built-in gift certificate system'),
('SettingsSections::store_locator::general', 'General'),
('SettingsOptions::store_locator::print_map', 'Show map in order-related documents'),
('SettingsOptions::store_locator::show_locations_at_geolocator', 'Use list of cities instead of a map'),
('Languages::store_locator_menu_description', 'Set up locations for pick up and manage inventory by location.'),
('Languages::store_locator.actions.store_locator', 'Stores'),
('Languages::view_on_map', 'View on map'),
('Languages::get_api_key', 'Obtaining an API Key'),
('Languages::block_store_locator', 'Store locator'),
('Languages::store_locator', 'Stores & pickup points'),
('Languages::block_store_locator_description', 'Store locator block'),
('Languages::text_address_not_found', 'Address not found'),
('Languages::select_coordinates', 'Select coordinates'),
('Languages::set', 'Set'),
('Languages::editing_store_location', 'Editing store location'),
('Languages::new_store_location', 'New store location'),
('Languages::add_store_location', 'Add store location'),
('Languages::coordinates', 'Coordinates'),
('Languages::latitude_short', 'lat'),
('Languages::longitude_short', 'long'),
('Languages::all_stores', 'All stores'),
('Languages::privileges.manage_store_locator', 'Can edit'),
('Languages::privilege_groups.store_locator', 'Store locator'),
('Languages::privileges.view_store_locator', 'Can view'),
('Languages::store_locator.text_pickup_instruction', 'The "Customer pick-up" shipping method offers a customer to choose a store to pick up a product from. The stores can be created in the "Store location" add-on<br /><b>Store creation:</b> <a href="[store_locator]">Store location</a>'),
('Languages::store_locator.select_stores', 'Select stores'),
('Languages::store_locator.pick_up_points', 'Pick-up points'),
('Languages::store_locator.stores_position', 'The "Position" field in the store settings'),
('Languages::store_locator.shipping_position', 'Order selected in the shipping method settings'),
('Languages::store_locator.selected_fields', 'Selected stores'),
('Languages::store_locator.available_fields', 'Available stores'),
('Languages::store_locator.display_ml', 'Map and list'),
('Languages::store_locator.display_l', 'List'),
('Languages::store_locator.display_m', 'Map'),
('Languages::store_locator.display', 'Locations list view on the checkout page'),
('Languages::store_locator.pickup', 'Pickup'),
('Languages::store_locator.pickup_avail', 'Available for pick-up'),
('Languages::store_locator.work_time', 'Working hours'),
('Languages::carrier_store_locator', 'Pickup'),
('Languages::destination_nothing_found', 'No suitable destination has been found'),
('Languages::stores_nothing_found', 'No stores have been found'),
('Languages::pickup', 'Pickup'),
('Languages::pickup_id', 'Pickup ID'),
('Languages::pickup_avail', 'Pickup avail'),
('Languages::pickup_surcharge', 'Pickup surcharge'),
('Languages::pickup_address', 'Pickup address'),
('Languages::pickup_phone', 'Pickup phone'),
('Languages::pickup_time', 'Pickup time'),
('Languages::pickup_destinations_ids', 'Pickup destinations ids'),
('Languages::store_locator.show_pickup_points_only', 'Hide places where I can''t pick up my order'),
('Languages::store_locator.stores_and_pickup_points', 'Stores and pickup points'),
('Languages::store_locator.surcharge_changes_hint', 'In previous versions, the surcharge was added to the standard rates that were specified for a shipping method. Now this surcharge isn''t taken into account during shipping rate calculation. We left it here for your convenience, so that you could see it and adjust the rates on the shipping method editing page accordingly.'),
('Languages::store_locator.main_destination', 'Located in rate area'),
('Languages::tt_addons_store_locator_views_store_locator_update_store_locator.main_destination', 'Determines the shipping rates for this pickup point. The rates are specified on the shipping method editing page. If you don''t select a rate area for a pickup point, then the pickup point won''t appear at checkout.'),
('Languages::store_locator.show_to', 'Show to'),
('Languages::show_to', 'Show to'),
('Languages::tt_addons_store_locator_views_store_locator_update_store_locator.show_to', 'Allows you to offer this pickup point to the residents of other rate areas at checkout.'),
('Languages::store_locator.shipping_price_from', 'from [price]'),
('Languages::store_locator.use_two_fingers_for_move_map', 'Use two fingers to move the map'),
('Languages::store_locator.scroll_to_top', 'Scroll to top'),
('Languages::store_locator.no_rate_area', 'No rate area');
INSERT INTO `[[dbprefix]]original_values` VALUES
('Languages::store_locator.name', 'Name'),
('Languages::store_locator.pickup_locations', 'Pickup Locations'),
('Languages::store_locator.any_rate_area', 'Any rate area'),
('Languages::store_locator.pickup_from_store', 'Pickup from store'),
('Languages::store_locator.any_vendor', 'Any vendor'),
('Languages::store_locator.any', 'Any'),
('Languages::store_locator.shipping_price_from_to', 'from [from_price] to [to_price]'),
('SettingsTooltips::store_locator::print_map', 'Print the map on the packing slip and invoice'),
('SettingsTooltips::store_locator::show_locations_at_geolocator', 'Affects the Customer Geolocation block. The list will be generated from cities that have stores and pickup points.'),
('Addons::name::store_locator', 'Stores and pickup points'),
('Addons::description::store_locator', 'Allows you to mark your physical stores on the map and offer your customers to collect orders from there, if a corresponding shipping method is configured.'),
('SettingsSections::product_variations::general', 'General'),
('SettingsOptions::product_variations::variations_allow_own_images', 'Allow own images for child variations'),
('SettingsOptions::product_variations::variations_allow_own_features', 'Allow own feature values for child variations'),
('SettingsOptions::product_variations::variations_allow_auto_change_default_variation', 'Change default variation when it gets hidden or runs out of stock'),
('SettingsOptions::product_variations::variations_show_all_possible_feature_variants', 'Show all possible feature variants'),
('SettingsOptions::product_variations::quantity_discount_on_different_variations', 'Give quantity discount on different product variations'),
('Languages::product_variations.product_type', 'Product type'),
('Languages::product_variations.product_type.catalog_item', 'Catalog item'),
('Languages::product_variations.product_type.variation_of_catalog_item', 'Variation of a catalog item'),
('Languages::product_variations.belongs_to_catalog_item', 'Belongs to catalog item:'),
('Languages::product_variations.variations', 'Variations'),
('Languages::product_variations.variation_of_product', 'Variation of catalog item <a href="[url]">[product]</a>'),
('Languages::product_variations.group_code', 'Variation group'),
('Languages::product_variations.group_code.placeholder', 'Set custom group code here'),
('Languages::product_variations.group_code.description', 'Use the group code on a product editing page or during import to add the product to this group as a variation. A group code can contain only digits, Latin characters, and the following signs: "-" and "_".'),
('Languages::product_variations.group_code.link', 'Add to variation group'),
('Languages::product_variations.add_variations', 'Add variations'),
('Languages::product_variations.link_existing', 'Use existing products'),
('Languages::product_variations.create_new', 'Create new products'),
('Languages::product_variations.add_variations_description', 'Add variations to generate a group of similar products that differ in color, size, etc. Or add this product to an existing group by entering the group code.'),
('Languages::product_variations.manage', 'Manage variations'),
('Languages::product_variations.edit_features', 'Edit features'),
('Languages::product_variations.delete', 'Disband group'),
('Languages::product_variations.remove_variation', 'Remove variation from group'),
('Languages::product_variations.delete_product', 'Delete product'),
('Languages::product_variations.mark_main_product', 'Set as default variation'),
('Languages::product_variations.no_available_features', 'This product doesn''t have features that allow grouping products. Please make sure that:<ol><li>You have created at least one feature with <b>Purpose:</b> <i>Variations as separate products</i> or <i>Variations as one product</i>.</li><li>You have specified the value of that feature for the product.</li></ol><a href=[manage_features_href]>Manage features</a>'),
('Languages::product_feature.purpose.group_catalog_item', 'Variations as separate products'),
('Languages::product_feature.purpose.group_catalog_item.description', 'For cases when a few similar products differ visibly by a feature, and have different names (for example, multiple "Color" variants of a T-shirt). These products will appear as separate positions in the catalog. Customers will also be able to select the desired feature value on the product page. To achieve this, <b>set up variations for products with this feature</b>.'),
('Languages::product_feature.feature_style.dropdown', 'Drop-down list'),
('Languages::product_feature.feature_style.dropdown_images', 'Images'),
('Languages::product_feature.feature_style.dropdown_labels', 'Text labels'),
('Languages::product_feature.purpose.group_variation_catalog_item', 'Variations as one product'),
('Languages::product_feature.purpose.group_variation_catalog_item.description', 'For cases when a few similar products differ by a feature, but have the same name and similar appearance (for example, multiple "Size" variants of a T-shirt). These products will occupy a single position in the catalog. Customers will be able to select the desired feature value on the product page. To achieve this, <b>set up variations for products with this feature</b>.'),
('Languages::product_variations.warning.before_edit_variations_save_product', 'Before you can edit variations, please save the product.'),
('Languages::product_variations.error.group_not_found', 'Variation group #[id] not found'),
('Languages::product_variations.error.product_not_found_in_group', 'Product #[product_id] not found in variation group "[group_code]"'),
('Languages::product_variations.error.cannot_mark_main_product_child_product', 'Product #[product_id] in group "[group_code]" isn''t a variation, so it can''t become default for a catalog item'),
('Languages::product_variations.error.generate_combinations_is_empty', 'Couldn''t generate variations. Please specify the values of features to generate variations.'),
('Languages::product_variations.error.generate_products_is_empty', 'No new products were created'),
('Languages::product_variations.error.product_not_found', 'Product #[product_id] not found'),
('Languages::product_variations.error.group_not_found_by_product', 'Couldn''t find variation group for #[product_id] "[product]"'),
('Languages::product_variations.error.feature_combination_is_invalid_for_product', 'Wrong combination of features for product #[product_id] "[product]"'),
('Languages::product_variations.error.product_ids_empty', 'Products couldn''t be found'),
('Languages::product_variations.select_variation', 'Select a Variation'),
('Languages::product_variations.error.group_code_is_required', 'Variation group code must be specified'),
('Languages::product_variations.error.group_code_is_invalid', 'Couldn''t set this code for variation group. A group code can contain only digits, Latin characters, and the following signs: "-" and "_"'),
('Languages::product_variations.error.group_code_is_duplicate', 'The specified variation group code is already in use'),
('Languages::product_variations.error.features_is_empty', 'Features couldn''t be found'),
('Languages::product_variations.error.no_available_products', 'No suitable products were found'),
('Languages::product_variations.error.product_has_not_required_features', 'Product #[product_id] "[product]" doesn''t have the required features to become a variation. Please set feature values for that product.'),
('Languages::product_variations.error.product_with_features_combination_exits', 'Product #[product_id] "[product]" has the exact same combination of feature values as a variation that already exists in the group.'),
('Languages::product_variations.error.product_company_does_not_match_to_group_company.ult', 'Product #[product_id] "[product]" can''t be added to the variation group because all products in a variation group must belong to the same storefront.'),
('Languages::product_variations.error.product_company_does_not_match_to_group_company.mve', 'Product #[product_id] "[product]" can''t be added to the variation group because all products in a variation group must belong to the same vendor.'),
('Languages::product_variations.variations_filling', 'Variations'),
('Languages::product_variations.variations_list', 'Variations'),
('Languages::variations_in_stock', 'Only "in stock" products'),
('Languages::product_variations.hide_add_to_wishlist_button', 'Hide add to wish list button'),
('Languages::product_variations.variations_list_block_name', 'Variations list'),
('Languages::product_variations.variations_list_tab_name', 'View all variations as list'),
('Languages::product_variations.show_variation_thumbnails', 'Show variation thumbnails'),
('Languages::product_variations.show_product_code', 'Show product code'),
('Languages::product_variations.exim.result_notice', 'Data is imported successfully.<br />New products - <b>[new]</b>;<br />Updated products - <b>[exist]</b>;<br />Skipped products - <b>[skipped]</b>;<br />Total - <b>[total]</b>;<br />Created variations - <b>[variation_created]</b>;<br />Updated variations - <b>[variation_updated]</b>;<br />Disbanded variations - <b>[variation_removed]</b>.'),
('Languages::variation_group_id', 'Variation group ID'),
('Languages::variation_group_code', 'Variation group code'),
('Languages::variation_parent_product_id', 'Variation parent product ID'),
('Languages::variation_sub_group_id', 'Variation sub group ID'),
('Languages::product_variations.feature_used_by_variation_group.tooltip', 'This feature is used by variation group [code]. To choose a different value of this feature for a product, switch to the "Variations" tab of the product editing page. New values can be added on the feature editing page.'),
('Languages::product_variations.variations_naming_strategy.key_value', 'Color: Red, Size: Small'),
('Languages::product_variations.variations_naming_strategy.value', 'Red, Small'),
('Languages::product_variations.feature_can_be_deleted', 'Couldn''t delete a feature or its variant because at least one variation group is based on it. Please delete <a href="[href]">these products</a> or disband their product groups, and try again.'),
('Languages::product_variations.notice.old_product_variations_exists', 'Your store still has old product variations. They currently appear as separate products, without the ability to switch between them. To make them work as before the upgrade, <a href="[convert_url]">convert old variations to new variations</a>. It''s easy and automatic.'),
('Languages::product_variations.notice.is_old_product_variation', 'This product is an old variation that hasn''t been converted yet. To make it work as before the upgrade, <a href="[convert_url]">convert old variations to new variations</a>.'),
('Languages::variation_set_as_default', 'Variation set as default'),
('Languages::product_variations.cant_edit_feature_categories', 'Couldn''t restrict the feature''s availability in categories. <a href="[href]">Some product variations with that feature</a> are still available in the categories where you tried to restrict the feature. Please remove the variation groups from those categories and try again.'),
('Languages::product_variations.too_many_combinations', 'Sorry, there are too many possible variations that can be generated. To prevent heavy load, we won''t display them here. Please create the products with the right feature values manually or via import, and add them to the group.'),
('Languages::product_variations.generator.features.placeholder', 'Search for features that can generate variations'),
('Languages::product_variations.generator.warning.new_features_add', 'You can add a new feature if you disband the group in the actions menu and create variations again.'),
('Languages::product_variations.generator.feature_variants.placeholder', 'Type to search'),
('Languages::product_variations.generator.feature_variants.add_all_variants', 'Add all variants'),
('Languages::product_variations.generator.table.title', 'Modify the variations to be created:'),
('Languages::product_variations.generator.create_btn', 'Create [n] variation|Create [n] variations'),
('Languages::product_variations.allow_own_features_setting_changing', 'You''ve disabled the <b>Allow own feature values for child variations</b> setting. Please export <a href="[url]">all your default variations</a> (use "Export found products" in the gear button) and reimport them. This will apply their feature values to existing child variations.'),
('Languages::product_variations.allow_own_images_setting_changing', 'You''ve disabled the <b>Allow own images for child variations</b> setting. Please export <a href="[url]">all your default variations</a> (use "Export found products" in the gear button) and reimport them. This will apply their images to existing child variations.'),
('Languages::product_variations.add_all_variants', 'Add all variants'),
('Languages::product_variations.error.not_available_feature_purpose', 'Couldn''t create variation group based on these features; please use the features with the purpose that is eligible for creating variations (group_catalog_item or group_variation_catalog_item).'),
('Languages::product_variations.error.cannot_set_as_default_out_of_stock', 'Couldn''t set variation #[product_id] as default, because it is out of stock. A variation that is in stock was used as default instead.'),
('Languages::product_variations.error.variations_as_separate_products_exceeds_the_limit', 'You’re trying to add more products than allowed by your plan limits. <b>[available_count]</b> products could be added.'),
('Languages::product_variations.error.limit_creating_new_products_exhausted_with_url', 'You can’t add more products at this time. You may need to <a href="[url_upgrade_plan]" target="_blank">upgrade the plan</a> before adding new products.'),
('Languages::product_variations.error.limit_creating_new_products_exhausted', 'You can’t add more products at this time. You may need to upgrade the plan before adding new products.'),
('Languages::product_variations.too_many_combinations_display', 'There are too many possible variations to preview them here. But you can still create them, if they don''t exist already.'),
('SettingsTooltips::product_variations::variations_allow_own_images', 'If child variations aren''t allowed to have their own images, they will use the images from the default variation of the catalog item.'),
('SettingsTooltips::product_variations::variations_allow_auto_change_default_variation', 'Ensure that customers always see the products that are in stock first. We recommend leaving this setting enabled for better filtering of variations.'),
('SettingsTooltips::product_variations::variations_allow_own_features', 'If child variations aren''t allowed to have their own values for features, they will use the values from the default variation of the catalog item.'),
('SettingsTooltips::product_variations::variations_show_all_possible_feature_variants', 'Show a feature variant even if it is not available for this variation.'),
('SettingsTooltips::product_variations::quantity_discount_on_different_variations', 'All variations in the same group will count to the quantity that is eligible for a discount.'),
('Addons::name::product_variations', 'Product Variations'),
('Addons::description::product_variations', 'Create products with different feature variants (for example, a different color or size), and let customers select the desired variant.'),
('SettingsSections::recaptcha::general', 'General'),
('SettingsOptions::recaptcha::notice', ''),
('SettingsOptions::recaptcha::recaptcha_v2_settings', 'reCAPTCHA v2 settings'),
('SettingsOptions::recaptcha::recaptcha_site_key', 'Site key'),
('SettingsOptions::recaptcha::recaptcha_secret', 'Secret'),
('SettingsOptions::recaptcha::recaptcha_theme', 'Theme'),
('SettingsVariants::recaptcha::recaptcha_theme::light', 'Light'),
('SettingsVariants::recaptcha::recaptcha_theme::dark', 'Dark'),
('SettingsOptions::recaptcha::recaptcha_size', 'Size'),
('SettingsVariants::recaptcha::recaptcha_size::normal', 'Normal'),
('SettingsVariants::recaptcha::recaptcha_size::compact', 'Compact'),
('SettingsOptions::recaptcha::recaptcha_type', 'Type'),
('SettingsVariants::recaptcha::recaptcha_type::image', 'Image'),
('SettingsVariants::recaptcha::recaptcha_type::audio', 'Audio'),
('SettingsOptions::recaptcha::recaptcha_v3_settings', 'reCAPTCHA v3 settings'),
('SettingsOptions::recaptcha::recaptcha_v3_site_key', 'Site key'),
('SettingsOptions::recaptcha::recaptcha_v3_secret', 'Secret'),
('SettingsOptions::recaptcha::recaptcha_v3_success_score', 'Required rating to pass the check'),
('SettingsVariants::recaptcha::recaptcha_v3_success_score::0.9', '0.9 (even some humans can''t pass)'),
('SettingsVariants::recaptcha::recaptcha_v3_success_score::0.8', '0.8'),
('SettingsVariants::recaptcha::recaptcha_v3_success_score::0.7', '0.7'),
('SettingsVariants::recaptcha::recaptcha_v3_success_score::0.6', '0.6'),
('SettingsVariants::recaptcha::recaptcha_v3_success_score::0.5', '0.5 (recommended value)'),
('SettingsVariants::recaptcha::recaptcha_v3_success_score::0.4', '0.4'),
('SettingsVariants::recaptcha::recaptcha_v3_success_score::0.3', '0.3'),
('SettingsVariants::recaptcha::recaptcha_v3_success_score::0.2', '0.2'),
('SettingsVariants::recaptcha::recaptcha_v3_success_score::0.1', '0.1 (bots are welcome)'),
('SettingsOptions::recaptcha::use_for_settings', 'Antibot settings'),
('SettingsOptions::recaptcha::recaptcha_use_for_value', ''),
('SettingsOptions::recaptcha::recaptcha_use_for', ''),
('SettingsOptions::recaptcha::settings_proxy', ''),
('SettingsSections::recaptcha::forbidden_countries', 'Excluded countries'),
('SettingsOptions::recaptcha::forbidden_countries_notice', ''),
('SettingsOptions::recaptcha::forbidden_countries', 'Excluded countries'),
('Languages::error_validator_recaptcha', 'Please confirm you are not a robot.'),
('Languages::recaptcha_settings_notice', '<p>The instructions on how to get the <b>site key</b> and <b>secret</b> are available <b><a target="_blank" href="https://developers.google.com/recaptcha/docs/start">here</a></b>.</p>'),
('Languages::recaptcha.text_settings_notice', '<p>The instructions on how to get the <b>site key</b> and <b>secret</b> are available <b><a target="_blank" href="https://developers.google.com/recaptcha/intro">here</a></b>.<br>Please note that the add-on currently supports only <b>Google reCAPTCHA v2: Checkbox</b> and <b>Google reCAPTCHA v3</b></p>'),
('Languages::recaptcha.text_forbidden_countries_notice', '<p>Google reCAPTACHA will be disabled for the selected countries. Instead, visitors from those countries will be asked to type a few symbols they see on the screen.</p>'),
('Languages::recaptcha.error_recaptcha_v3_failed', 'Sorry, the anti-bot validation has failed. If you''re seeing this message, please contact us and let us know about it.'),
('Languages::recaptcha.recaptcha_v2', 'reCAPTCHA v2'),
('Languages::recaptcha.recaptcha_v3', 'reCAPTCHA v3'),
('Languages::recaptcha.none', 'none'),
('Languages::recaptcha.recaptcha_cookie_title', 'Google reCAPTCHA'),
('Languages::recaptcha.recaptcha_cookie_description', 'Google reCAPTCHA is a service that provides anti-bot protection and verifies that site visitors are humans. Here is <a href="https://policies.google.com/privacy" target="_blank">Google privacy policy</a>; we also recommend Google''s concise and comprehensive <a href="https://support.google.com/maps/answer/10400210" target="_blank">note on privacy</a>.'),
('Addons::name::recaptcha', 'Google reCAPTCHA'),
('Addons::description::recaptcha', 'Adds the support of Google reCAPTCHA to protect your store against bots'),
('SettingsSections::product_bundles::general', 'General'),
('SettingsOptions::product_bundles::show_bundles', 'Show bundles'),
('SettingsVariants::product_bundles::show_bundles::before_product_description', 'Before product description'),
('SettingsVariants::product_bundles::show_bundles::in_a_product_tab', 'In a product tab'),
('Languages::product_bundles.tab_title', 'Bundles with this product'),
('Languages::product_bundles.product_bundles', 'Product bundles'),
('Languages::product_bundles.promo_image', 'Promo image'),
('Languages::product_bundles.display_in_promotions', 'Display in promotions'),
('Languages::product_bundles.bundle_products', 'Bundle products'),
('Languages::product_bundles.price_for_all', 'Price for all'),
('Languages::product_bundles.share_discount', 'Share discount'),
('Languages::product_bundles.product_bundle_name', 'Bundle name'),
('Languages::product_bundles.products_in_bundle', 'Products in bundle'),
('Languages::product_bundles.total_cost', 'Total cost'),
('Languages::product_bundles.add_new_bundle', 'Add new bundle'),
('Languages::product_bundles.delete_product_in_bundle', 'The <b>[bundle_name]</b> bundle was disabled, because of the products from this bundle was deleted.|The <b>[bundle_name]</b> bundle were disabled, because one of the products from these bundles was deleted.'),
('Languages::product_bundles.new_bundle', 'New bundle'),
('Languages::product_bundles.active_bundles', 'Active bundles'),
('Languages::product_bundles.specify_features', 'Specify features'),
('Languages::product_bundles.any_variation', 'Any variation'),
('Languages::product_bundles.specify_options', 'Specify options'),
('Languages::product_bundles.total_list_price', 'Total list price'),
('Languages::product_bundles.order_discount', 'Order discount'),
('Languages::product_bundles.add_all_to_cart', 'Add all to cart'),
('Languages::product_bundles.sign_in_to_view_price', 'Sign in to view price'),
('Languages::product_bundles.bundle_details', 'Bundle details'),
('Languages::product_bundles.search_in_products', 'Bundles with product'),
('Languages::product_bundles.internal_feature_name_tooltip', 'This name is shown only in the Administration panel to help you distinguish between multiple product bundles that have the same displayed name.'),
('Languages::product_bundles.show_on_product_page', 'Show on products page'),
('Languages::product_bundles.confirm_text_on_empty_bundle', 'Are you sure you want to create a bundle without products?'),
('Languages::product_bundles.confirm_text_with_one_product_bundle', 'Are you sure you want to create a bundle with 1 product?'),
('Languages::product_bundles.specify_options_first', 'Product options should be specified'),
('Languages::privileges.view_product_bundles', 'Can view'),
('Languages::privileges.manage_product_bundles', 'Can edit'),
('Languages::privilege_groups.product_bundles', 'Product bundles'),
('Languages::block_product_bundles', 'Product bundles'),
('Languages::block_product_bundles_description', 'Product bundles form'),
('Languages::product_bundles.template_product_bundles', 'Product bundles'),
('Addons::name::product_bundles', 'Product bundles'),
('Addons::description::product_bundles', 'Allows you to create product bundles and set up discounts for them.'),
('SettingsSections::rma::general', 'General'),
('SettingsOptions::rma::returnable', 'Returnable'),
('SettingsOptions::rma::return_period', 'Return period (days)'),
('SettingsOptions::rma::display_product_return_period', 'Display product return period'),
('SettingsOptions::rma::dont_take_weekends_into_account', 'Do not take weekends into account when calculating product return period'),
('Languages::rma.actions.request_statuses', 'RMA request statuses'),
('Languages::returned_products', 'Returned products'),
('Languages::rma_return', 'Return'),
('Languages::no_return_requests_found', 'No return requests found'),
('Languages::returned_product', 'Returned product'),
('Languages::returns', 'Returns'),
('Languages::returns_info', 'Returns info'),
('Languages::return_info', 'Return information'),
('Languages::order_returns', 'Order returns'),
('Languages::return_registration', 'Request a replacement or a refund'),
('Languages::return_requests', 'Return requests'),
('Languages::return_status', 'Return status'),
('Languages::return_period', 'Return period'),
('Languages::what_you_would_like_to_do', 'What would you like to do'),
('Languages::rma_notify_supplier', 'Notify supplier'),
('Languages::add_reason', 'Add reason'),
('Languages::new_reason', 'New reason'),
('Languages::type_comment', 'Type comments here'),
('Languages::return_requests_note', 'Go to the list of your return requests'),
('Languages::privileges.manage_rma', 'Can edit'),
('Languages::privilege_groups.rma', 'Return merchandise authorization (RMA)'),
('Languages::rma.text_return_change_warning', 'The status of return request will change from [old_status] to [new_status].'),
('Languages::returnable', 'Returnable'),
('Languages::returnable_product', 'Returnable product'),
('Languages::rma_request_statuses', 'RMA request statuses'),
('Languages::return_products_information', 'Return products information'),
('Languages::declined_products_information', 'Declined products information'),
('Languages::rma_reasons', 'RMA reasons'),
('Languages::rma_actions', 'RMA actions'),
('Languages::rma', 'RMA'),
('Languages::return_period_days', 'Return period (days)'),
('Languages::all_actions', 'All actions'),
('Languages::decline_products', 'Decline products'),
('Languages::create_gift_certificate', 'Create gift certificate'),
('Languages::accept_products', 'Accept products'),
('Languages::rma.recalculate_order', 'Recalculate order'),
('Languages::rma.manually_recalculate_order', 'Set the new order total manually'),
('Languages::rma.dont_recalculate_order', 'Don''t recalculate order'),
('Languages::delete_this_return', 'Delete this return'),
('Languages::update_totals_and_inventory', 'Update totals and inventory'),
('Languages::request_statuses', 'request statuses'),
('Languages::email_template.rma_slip_notification', 'RMA slip'),
('Languages::template_document_rma_packing_slip_default', 'Return request: packing slip'),
('Languages::document_preview_return_request_not_found', 'Couldn''t find a return request. Preview only works with existing data. Please create a return request and use Preview again.'),
('Languages::event.rma.status_changed.name', 'Return request status changed to [status]'),
('Languages::rma.choose_change_return_status', 'What to do with the order'),
('Languages::rma.please_confirm_decision', 'Please confirm your decision.'),
('Languages::rma.order_total_will_changed', 'The order total will be set to'),
('Languages::rma.shipping_costs_will_changed', 'Shipping costs will be set to'),
('Languages::rma.return_action', 'Return'),
('SettingsTooltips::rma::returnable', 'This will be the default value for new products.'),
('SettingsTooltips::rma::return_period', 'This will be the default value for new products.'),
('Addons::name::rma', 'RMA'),
('Addons::description::rma', 'Adds a return management system'),
('Languages::blog.new_post', 'New blog post'),
('Languages::blog.editing_post', 'Editing blog post'),
('Languages::blog', 'Blog'),
('Languages::blog.add_post', 'Add blog post'),
('Languages::blog.recent_posts', 'Blog: recent posts'),
('Languages::blog.recent_posts_scroller', 'Blog: recent posts scroller'),
('Languages::blog.view_post', 'View post'),
('Languages::recent_blog_posts', 'Recent blog posts'),
('Languages::blog.posts', 'Posts'),
('Languages::blog.post', 'Post'),
('Languages::block_blog', 'Recent posts'),
('Languages::block_vendor_blog', 'Vendor recent posts'),
('Languages::blog.text_links', 'Blog: text links'),
('Languages::blog.read_more', 'Read more'),
('Languages::post_description', 'Post description'),
('Languages::ttc_post_description', 'Use the &lt;!--CUT--&gt; tag (switch to source code to insert it) to hide part of the post. Only the part above the tag is shown in the list of all posts.<br /><br />Make sure to <strong>close all HTML tags</strong> above the &lt;!--CUT--&gt; tag!'),
('Languages::blog_functionality_notes', '<p>Use this page to manage your blog. This is how you should organize your blog posts:</p><ul><li>Blog is a usual post that has the <b>Root level page</b> as the Parent page.</li><li>Choose <b>Blog</b> as the Parent page for your blog posts.</li></ul>'),
('Languages::n_posts', '[n] post|[n] posts'),
('Addons::name::blog', 'Blog'),
('Addons::description::blog', 'Lets you start your blog easily'),
('SettingsSections::bestsellers::general', 'General'),
('SettingsOptions::bestsellers::final_sale_from', 'Minimum final sale discount (%)'),
('SettingsOptions::bestsellers::sales_amount_from', 'Minimum sales amount to define bestsellers'),
('SettingsSections::bestsellers::newest', 'Newest'),
('SettingsOptions::bestsellers::period', 'Period'),
('SettingsVariants::bestsellers::period::all', 'All days'),
('SettingsVariants::bestsellers::period::today', 'Today'),
('SettingsVariants::bestsellers::period::last_days', 'Last days'),
('SettingsOptions::bestsellers::last_days', 'Last days'),
('Languages::sort_by_bestsellers_asc', 'Sort by Bestselling: Low to High'),
('Languages::sort_by_bestsellers_desc', 'Sort by Bestselling'),
('Languages::sort_by_on_sale_asc', 'Sort by discount: Low to High'),
('Languages::sort_by_on_sale_desc', 'Sort by discount: High to Low'),
('Languages::sales_amount', 'Sales amount'),
('Languages::bestselling', 'Bestselling'),
('Languages::on_sale', 'On sale'),
('Languages::similar', 'Similar'),
('Languages::percent_range', 'Price range (in % of the main product''s price)'),
('Languages::similar_category', 'Of the same category'),
('Languages::similar_subcats', 'Consider subcategories'),
('Languages::similar_in_stock', 'Only "in stock" products'),
('Languages::final_sale', 'Final sale'),
('Addons::name::bestsellers', 'Bestsellers & On-Sale Products'),
('Addons::description::bestsellers', 'Collects best selling & on sale product data and adds block fillings to show such products'),
('SettingsSections::seo::general', 'General'),
('SettingsOptions::seo::seo_product_type', 'Product SEO URL format'),
('SettingsVariants::seo::seo_product_type::product_file_nohtml', '/product-name/'),
('SettingsVariants::seo::seo_product_type::product_file', '/product-name.html'),
('SettingsVariants::seo::seo_product_type::product_category_nohtml', '/category-name/[subcategory-name/]product-name/'),
('SettingsVariants::seo::seo_product_type::product_category', '/category-name/[subcategory-name/]product-name.html'),
('SettingsOptions::seo::seo_category_type', 'Category SEO URL format'),
('SettingsVariants::seo::seo_category_type::category', '/parent-category/category-[page-2].html'),
('SettingsVariants::seo::seo_category_type::category_nohtml', '/parent-category/category/[page-2/]'),
('SettingsVariants::seo::seo_category_type::file', '/category[-page-2].html'),
('SettingsVariants::seo::seo_category_type::root_category', '/category/[page-2/]'),
('SettingsOptions::seo::seo_page_type', 'Page SEO URL format'),
('SettingsVariants::seo::seo_page_type::page', '/parent-page/page.html'),
('SettingsVariants::seo::seo_page_type::page_nohtml', '/parent-page/page/'),
('SettingsVariants::seo::seo_page_type::file', '/page.html'),
('SettingsVariants::seo::seo_page_type::root_page', '/page/'),
('SettingsOptions::seo::seo_other_type', 'Other SEO URL format'),
('SettingsVariants::seo::seo_other_type::directory', '/item/'),
('SettingsVariants::seo::seo_other_type::file', '/item.html'),
('SettingsOptions::seo::seo_language', 'Show additional language in the URL'),
('SettingsOptions::seo::single_url', 'Use single URL for all languages'),
('SettingsOptions::seo::non_latin_symbols', 'Allow non-latin symbols in URL'),
('Languages::seo.actions.redirects_manager', '301 redirects'),
('Languages::controller_description', 'If you want to specify a SEO-name for the URL, e.g. http://example.com/index.php?dispatch=<b>categories.catalog</b>, you need to enter the "<b>categories.catalog</b>" value into the "<b>The value of the "dispatch" parameter from the URL</b>" field and specify the SEO name in the "<b>SEO name</b>" field.'),
('Languages::seo_name', 'SEO name'),
('Languages::warning_seo_urls_disabled', 'SEO-friendly URLs are disabled. Check your web server and URL manipulation engine settings.'),
('Languages::dispatch_value', 'Dispatch value'),
('Languages::url_dispatch_part', 'The value of the "dispatch" parameter from the URL'),
('Languages::new_rule', 'New rule'),
('Languages::seo_add_rule', 'Add rule'),
('Languages::seo_rules', 'SEO rules'),
('Languages::seo_page_title', 'page [n]'),
('Languages::privileges.manage_seo_rules', 'Can edit'),
('Languages::privilege_groups.seo', 'SEO'),
('Languages::privileges.view_seo_rules', 'Can view'),
('Languages::seo.redirects_manager', '301 redirects'),
('Languages::seo.old_url', 'Old URL'),
('Languages::seo.new_url', 'New URL'),
('Languages::seo.new_redirect', 'New Redirect'),
('Languages::seo.add_redirect', 'Add redirect'),
('Languages::seo.error_old_url_exists', 'The URL you''re redirecting from is already exist'),
('Languages::seo.rich_snippets', 'Google rich snippets preview'),
('Languages::seo.rich_snippets_rating', 'Rating'),
('Languages::seo.rich_snippets_reviews', '[n] review|[n] reviews'),
('Languages::seo.create_redirect', 'Create redirect from old URL'),
('Languages::seo.error_incorrect_url', 'Incorrect format for <b>[url]</b> URL. For example, if your URL is <b>http://example.com/path/to/object</b>, you need to enter <b>/path/to/object</b>'),
('Languages::tt_addons_seo_views_seo_redirects_manage_seo.old_url', 'For example, if your URL is <b>http://example.com/path/to/object</b>, you need to enter <b>/path/to/object</b>'),
('Languages::seo.important_language_text', '<b>Warning!</b> The <b>SEO</b> add-on is currently configured to use a single URL for all languages. If you hide, disable, or delete a default language of one of the storefronts, the SEO URLs will be changed.'),
('Languages::seo.product_feature.feature_code.notice', 'A suitable code can help this feature appear with the product in search engines. Supported codes:'),
('Languages::seo.brand', 'Brand'),
('Languages::seo.feature_code.brand.description', 'Name used by an organization or business person for labeling a product'),
('Languages::seo.isbn', 'ISBN'),
('Languages::seo.feature_code.isbn.description', 'International Standard Book Number'),
('Languages::seo.gtin', 'GTIN'),
('Languages::seo.feature_code.gtin.description', 'Global Trade Item Number'),
('Languages::seo.MPN', 'MPN'),
('Languages::seo.feature_code.mpn.description', 'Manufacturer Part Number'),
('Languages::seo.storefront_frontend_default_language_warning', 'The <a href="[link]">SEO</a> add-on is currently configured to use a single URL for all languages. If you change a default language of this storefront, the SEO URLs will be changed.'),
('Languages::seo.secondary_storefront_frontend_default_language_warning', 'The <a href="[link]">SEO</a> add-on is currently configured to use a single URL for all languages using the default language of the default storefront. If you change the default language of the selected storefront, the SEO URLs will not be changed.'),
('Languages::seo.default_storefront_frontend_default_language_warning', 'The <a href="[link]">SEO</a> add-on is currently configured to use a single URL for all languages. If you change a default language of the default storefront, the SEO URLs will be changed for all storefronts.'),
('Languages::seo.error_at_creation_seo_name', 'The following SEO name already exists in your store: <b>[names]</b>. <p> The following SEO name was used instead: <b>[new_names]</b>.|The following SEO names already exist in your store: <b>[names]</b>. The following SEO names were used instead: <b>[new_names]</b>.'),
('Languages::seo.error_incorrect_seo_name', 'The following SEO name had incorrect format: <b>[names]</b>. <p> The following SEO name was used instead: <b>[new_names]</b>.|The following SEO names had incorrect format: <b>[names]</b>. The following SEO names were used instead: <b>[new_names]</b>.'),
('Addons::name::seo', 'SEO'),
('Addons::description::seo', 'Adds Search engine-friendly URLs support'),
('SettingsSections::reward_points::general', 'General'),
('SettingsOptions::reward_points::point_rate', 'Points Exchange Rate (PER - the number of points equal to 1 conventional unit)'),
('SettingsOptions::reward_points::auto_price_in_points', '"Price in points" is calculated automatically on PER basis'),
('SettingsOptions::reward_points::price_in_points_with_discounts', '"Price in points" is recalculated taking into account discounts'),
('SettingsOptions::reward_points::points_with_discounts', '"Points" is recalculated taking into account discounts'),
('SettingsOptions::reward_points::price_in_points_order_discount', '"Price in points" is recalculated taking into account order discounts'),
('SettingsOptions::reward_points::reward_points_order_discount', '"Points" is recalculated taking into account order discounts'),
('SettingsOptions::reward_points::higher_level_extract', 'If the product and the product category do not have defined reward points but the higher level category has such reward points, extract data from it'),
('SettingsOptions::reward_points::several_points_action', 'If several reward points can be applied, set'),
('SettingsVariants::reward_points::several_points_action::minimal_absolute', 'Absolute minimal value'),
('SettingsVariants::reward_points::several_points_action::minimal_percentage', 'Minimal percentage value'),
('SettingsVariants::reward_points::several_points_action::maximal_absolute', 'Absolute maximal value'),
('SettingsVariants::reward_points::several_points_action::maximal_percentage', 'Maximal percentage value'),
('SettingsOptions::reward_points::consider_zero_values', 'Apply zero reward point values'),
('SettingsOptions::reward_points::log_per_page', 'Log lines per page'),
('Languages::reward_points', 'Reward points'),
('Languages::reward_points_log', 'Reward points log'),
('Languages::promotion_cond_reward_points', 'Points on user account'),
('Languages::points', 'Points'),
('Languages::points_in_use', 'Points in use'),
('Languages::points_in_use_lower', 'points in use'),
('Languages::points_lower', 'points'),
('Languages::points_in_use_lowercase', '[n] point in use|[n] points in use'),
('Languages::points_lowercase', '[n] point|[n] points'),
('Languages::points_to_use', 'Points to use'),
('Languages::point_payment', 'Point payment'),
('Languages::point_price', 'Price in points'),
('Languages::text_increase_points_in_use', 'The points used in the order were added to user account.'),
('Languages::text_points_used_in_order', 'Points were used in order'),
('Languages::text_point_in_account', 'You have'),
('Languages::pay_by_points', 'Allow payment by points'),
('Languages::override_per', 'Override global PER'),
('Languages::override_gc_points_brief', 'Override global/category points'),
('Languages::text_points_exceed_points_on_account', 'The number of the points entered by you exceeds the number of points at your account.'),
('Languages::text_points_exceed_points_that_can_be_applied', 'The number of points entered by you exceeds the number of points that can be applied to this order.'),
('Languages::text_points_cannot_applied_because_subtotal_redeemed', 'Points cannot be applied because the subtotal is completely redeemed.'),
('Languages::text_cannot_apply_points_to_this_order_because_total', 'Unfortunately, you cannot apply points to this order, because the total cost is zero.'),
('Languages::text_cannot_apply_points_to_this_order_because_user', 'Unfortunately, you cannot apply points to this order, because you do not have enough points at the account.'),
('Languages::text_order_status_has_not_been_changed', 'The order status has not been changed, because the user did not have enough points.'),
('Languages::price_in_points_increased', 'Price in points has been increased by'),
('Languages::price_in_points_decreased', 'Price in points has been decreased by'),
('Languages::earned_points', 'Points earned per product'),
('Languages::override_g_points', 'Override global point value for all products in this category'),
('Languages::amount_type', 'Amount type'),
('Languages::maximum', 'Maximum'),
('Languages::earned_point_modifier', 'Earned point modifier'),
('Languages::override_gc_points', 'Override global/category point value for this product'),
('Languages::view_user_points', 'View user points'),
('Languages::log', 'Log'),
('Languages::subtract', 'Subtract'),
('Languages::change_points', 'Change points'),
('Languages::add_subtract_points', 'Add & subtract points'),
('Languages::cleanup_log', 'Cleanup log'),
('Languages::we_would_like_to_inform', 'We would like to inform you that'),
('Languages::reward_points_subj_added_to', '[n] point have been added to your account.|[n] points have been added to your account.'),
('Languages::reward_points_subj_subtracted_from', '[n] point have been subtracted from your account.|[n] points have been subtracted from your account.'),
('Languages::privileges.manage_reward_points', 'Can edit'),
('Languages::privilege_groups.reward_points', 'Reward points'),
('Languages::email_template.reward_points_notification', 'Reward points'),
('Languages::grant_point', 'Grant reward points'),
('SettingsTooltips::reward_points::consider_zero_values', 'The reward points rules with the zero values should be considered'),
('Addons::name::reward_points', 'Reward points'),
('Addons::description::reward_points', 'Lets customers earn and spend points for purchases'),
('SettingsSections::google_analytics::general', 'General'),
('SettingsOptions::google_analytics::tracking_code', 'Google Analytics account number'),
('SettingsOptions::google_analytics::track_ecommerce', 'Track e-commerce transactions'),
('Languages::google_analytics.google_analytics_cookies_title', 'Google Analytics'),
('Languages::google_analytics.google_analytics_cookies_description', 'Google Analytics is a service that provides us with website analytics: the number of unique visitors, the most and least popular pages, etc. Here is <a href="https://support.google.com/analytics/answer/6004245" target="_blank">Google Analytics statement on privacy</a>.'),
('Languages::google_analytics.google_ads_cookies_title', 'Google Ads'),
('Languages::google_analytics.google_ads_cookies_description', 'Google Ads is a service that allows us to make personalized offers for you. This permission allows us to set cookies and send some of your data related to advertising to Google. Here is <a href="https://safety.google/privacy/ads-and-data/" target="_blank">how Google handles ad-related data</a>.'),
('Addons::name::google_analytics', 'Google Analytics'),
('Addons::description::google_analytics', 'Integrates a Google Analytics service with the store'),
('SettingsSections::facebook_pixel::general', 'General'),
('SettingsOptions::facebook_pixel::pixel_id', 'Facebook Pixel Identifier'),
('SettingsOptions::facebook_pixel::track_all_page_views', 'Track all page views'),
('SettingsOptions::facebook_pixel::track_add_to_cart', 'Track adding product to cart'),
('SettingsOptions::facebook_pixel::track_order_placed', 'Track placing order'),
('Languages::facebook_pixel.facebook_pixel_cookies_title', 'Facebook Pixel'),
('Languages::facebook_pixel.facebook_pixel_cookies_description', 'Facebook Pixel is a tool that allows us to measure ad efficiency by tracking that the browser or device that received the ad also visited a product page, added product to cart, or placed an order. Here is <a href="https://www.facebook.com/about/privacy/previous" target="_blank">Facebook privacy policy</a>.'),
('Addons::name::facebook_pixel', 'Facebook Pixel'),
('Addons::description::facebook_pixel', 'Integrates a Facebook Pixel with the store'),
('SettingsSections::call_requests::general', 'General'),
('SettingsOptions::call_requests::general', 'General'),
('SettingsOptions::call_requests::info', ''),
('SettingsOptions::call_requests::phone', 'Rewrite phone'),
('SettingsOptions::call_requests::phone_prefix_length', 'Highlight first chars [Deprecated]'),
('SettingsOptions::call_requests::phone_mask', 'Phone mask [Deprecated]'),
('SettingsOptions::call_requests::buy_now_with_one_click', 'Enable the "Buy now with one click" option'),
('SettingsOptions::call_requests::order_status', 'Order status'),
('Languages::privileges.manage_call_requests', 'Can edit'),
('Languages::privileges.view_call_requests', 'Can view'),
('Languages::privilege_groups.call_requests', 'Call requests'),
('Languages::call_requests', 'Call requests'),
('Languages::call_requests.request_call', 'Request call'),
('Languages::call_requests.buy_now_with_one_click', 'Buy now with 1-click'),
('Languages::call_requests.error_validate_call_form', 'Please enter your email or phone number'),
('Languages::call_requests.request_recieved', 'We have received your request! Our manager will contact you soon.'),
('Languages::call_requests.order_placed', 'We have received your request! The order #[order_id] has been successfully created. Our manager will contact you soon.'),
('Languages::call_requests.phone_from_settings', 'Phone from settings'),
('Languages::call_requests.enter_phone_or_email_text', 'Please enter your phone number or email (for our manager to contact you)'),
('Languages::call_requests.status.new', 'New'),
('Languages::call_requests.status.in_progress', 'In progress'),
('Languages::call_requests.status.completed', 'Completed'),
('Languages::call_requests.status.no_answer', 'No answer'),
('Languages::call_requests.responsible', 'Responsible'),
('Languages::call_requests.notes', 'Notes'),
('Languages::call_requests.requested_product', 'Requested product'),
('Languages::call_requests.convenient_time', 'Convenient time'),
('Languages::call_requests.awaiting_call', 'Awaiting call'),
('Languages::call_requests.order_exists', 'Order exists'),
('Languages::call_requests.person_name_and_phone', 'Name and phone'),
('Languages::call_requests.no_name_specified', 'No name specified'),
('Languages::call_requests.use_for_call_requests', 'Call request and buy now with one click form'),
('Languages::block_call_request', 'Call request'),
('Languages::block_call_request_description', 'Store phone number and form for requesting a call'),
('Languages::tmpl_call_request', 'Call request form'),
('Languages::call_requests.text_call_request', 'Customer [customer] is <a href="[href]">awaiting your call</a> on [phone_number].'),
('Languages::call_requests.text_call_request_call_time', 'The convenient call time is between [time_from] and [time_to].'),
('Languages::call_requests.text_buy_with_one_click_request', 'Сustomer [customer] is <a href="[href]">awaiting your call</a> on [phone_number], regarding the purchase of the product <a href="[product_href]">[product_name]</a>.'),
('Languages::call_requests.error_validator_phone', 'The phone number in the <b>[field]</b> field is invalid.'),
('Languages::email_template.call_requests_buy_with_one_click', 'Call requests: buy with one click notification'),
('Languages::email_template.call_requests_call_request', 'Call requests: call request notification'),
('Languages::call_request.work_time', 'Mon-Fr 9a.m.-6p.m.'),
('Languages::call_requests.request_call_request_form', 'Call requests: request form'),
('Languages::call_requests.agreement_text_full_request_call_request_form', '<p>We ([company]) will use the data you provide here to contact you regarding your call request or order. That data will remain in our system, visible to our staff (or the relevant vendor), until you withdraw your consent. If you’d like to have your personal data removed, send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('Languages::call_requests.agreement_text_short_request_call_request_form', 'I agree to have my personal data <u>processed as follows.</u>'),
('Languages::gdpr_call_requests', 'Personal data from call requests'),
('Languages::call_requests.event.request_created.name', 'Call requests: request created'),
('Languages::call_requests.event.request_about_product_created.name', 'Call requests: request about product created'),
('Languages::call_requests.dashboard.analytics_card.recent_call_requests', 'Recent call requests'),
('Languages::call_requests.dashboard.analytics_card.view_call_requests', 'View call requests'),
('SettingsTooltips::call_requests::phone_mask', 'Leave empty to use automatic country-based phone pattern, or type in a custom pattern. You can use spaces, commas, +, -, and digits. Note that 9 represents any digit; if you need a 9, type \\\\9. Examples: +9 (999) 999 99 99, 99999999, 999 999 99 or +99-99-9999-9999.'),
('SettingsTooltips::call_requests::phone_prefix_length', 'Including parenthesis, spaces, etc. Use to highlight country code, area code, and phone prefix.'),
('Addons::name::call_requests', 'Call requests'),
('Addons::description::call_requests', 'Adds the "Buy now with one click" and "Request call" buttons'),
('Languages::use_for_form_builder', 'Custom forms'),
('Languages::new_form', 'New form'),
('Languages::editing_form', 'Editing form'),
('Languages::form_builder', 'Form builder'),
('Languages::form_submit_text', 'Form submit text'),
('Languages::email_to', 'E-mail to'),
('Languages::add_form', 'Add form'),
('Languages::base', 'Base'),
('Languages::multiple_checkboxes', 'Multiple checkboxes'),
('Languages::multiple_selectbox', 'Multiple selectbox'),
('Languages::separator', 'Separator'),
('Languages::special', 'Special'),
('Languages::countries_list', 'Countries list'),
('Languages::states_list', 'States list'),
('Languages::referer', 'Referer'),
('Languages::email_template.form_builder_form', 'Contact form'),
('Languages::addons.form_builder.form_fields', 'Form fields'),
('Languages::addons.form_builder.form_name', 'Form name'),
('Languages::addons.form_builder.other_subject', 'Other subject (specify below)'),
('Languages::addons.form_builder.email_subject_field', 'E-mail subject field'),
('Languages::ttc_addons.form_builder.email_subject_field', 'Fields of type "Select box" or "Input field" can be used'),
('Addons::name::form_builder', 'Form builder'),
('Addons::description::form_builder', 'Lets you create custom forms (e.g. Contact us)'),
('SettingsSections::barcode::general', 'General'),
('SettingsOptions::barcode::elm_image', 'Image'),
('SettingsOptions::barcode::elm_image_info', 'Example Image'),
('SettingsOptions::barcode::elm_configs', 'Configs'),
('SettingsOptions::barcode::type', 'Type'),
('SettingsVariants::barcode::type::C128A', 'Code 128-A'),
('SettingsVariants::barcode::type::C128B', 'Code 128-B'),
('SettingsVariants::barcode::type::C128C', 'Code 128-C'),
('SettingsVariants::barcode::type::I25', 'Interleaved 2 of 5'),
('SettingsVariants::barcode::type::C39', 'Code 39'),
('SettingsOptions::barcode::output', 'Output'),
('SettingsVariants::barcode::output::png', 'Portable Network Graphics (PNG)');
INSERT INTO `[[dbprefix]]original_values` VALUES
('SettingsVariants::barcode::output::jpeg', 'Joint Photographic Experts Group (JPEG)'),
('SettingsOptions::barcode::text', 'Text'),
('SettingsVariants::barcode::text::N', 'Disabled'),
('SettingsVariants::barcode::text::Y', 'Enabled'),
('SettingsOptions::barcode::height', 'Height,px'),
('SettingsOptions::barcode::width', 'Width,px'),
('SettingsOptions::barcode::prefix', 'Barcode prefix'),
('SettingsOptions::barcode::elm_specification', 'Specification'),
('SettingsOptions::barcode::elm_spec_descr', 'Spec Description'),
('Languages::please_enable_the_add_on_to_see_barcode', 'Please enable the add-on to see a code example.'),
('Addons::name::barcode', 'Order barcode'),
('Addons::description::barcode', 'Makes it possible to configure and attach barcodes to orders'),
('SettingsSections::polls::general', 'General'),
('SettingsOptions::polls::polls_votes_on_page', 'Votes on page'),
('SettingsOptions::polls::polls_comments_on_page', 'Answers on page'),
('Languages::use_for_polls', 'Polls'),
('Languages::tmpl_polls_central', 'Central'),
('Languages::tmpl_polls_side', 'Side box'),
('Languages::polls_answers_with_comments', 'Answers with comments'),
('Languages::polls_have_completed', 'You have already completed this poll.'),
('Languages::polls_total_votes', 'Total votes'),
('Languages::polls', 'Polls'),
('Languages::new_poll', 'New poll'),
('Languages::editing_poll', 'Editing poll'),
('Languages::text_you_have_already_filled_this_poll', 'You have already completed this poll'),
('Languages::block_polls', 'Polls'),
('Languages::poll', 'Poll'),
('Languages::questions', 'Questions'),
('Languages::poll_statistics', 'Poll statistics'),
('Languages::add_polls_and_close', 'Add polls and close'),
('Languages::add_polls', 'Add polls'),
('Languages::required_not_answered', 'You should answer all the mandatory questions'),
('Languages::thanks_for_voting', 'Thank you for taking time to complete this poll.'),
('Languages::poll_show_results', 'Poll results visible to'),
('Languages::poll_results_nobody', 'nobody'),
('Languages::poll_results_voted', 'voted users'),
('Languages::poll_results_everybody', 'everybody (in a pop-up)'),
('Languages::poll_header', 'Poll header'),
('Languages::poll_footer', 'Poll footer'),
('Languages::poll_results', 'Poll message'),
('Languages::new_question', 'New question'),
('Languages::add_question', 'Add question'),
('Languages::editing_question', 'Editing question'),
('Languages::add_poll', 'Add poll'),
('Languages::polls_total_submited', 'Total number of submitted poll forms'),
('Languages::polls_total_completed', 'Number of poll forms completed in full'),
('Languages::polls_first_submited', 'First poll form submitted'),
('Languages::polls_last_submited', 'Last poll form submitted'),
('Languages::statistics_by_questions', 'Statistics by questions'),
('Languages::view_answers', 'View answers'),
('Languages::polls_votes', 'Votes'),
('Languages::answers', 'Answers'),
('Languages::question_text', 'Question text'),
('Languages::select_single_type', 'Select single option'),
('Languages::select_one_or_more_type', 'Select one or more options'),
('Languages::text_answer_type', 'Provide a textual answer'),
('Languages::answer_text', 'Answer text'),
('Languages::text_box', 'Text box'),
('Languages::tt_addons_polls_hooks_pages_tabs_content_post_poll_results', 'Message that is displayed in the storefront after the poll is completed.'),
('Languages::n_polls', '[n] poll|[n] polls'),
('Addons::name::polls', 'Polls'),
('Addons::description::polls', 'Adds a possibility to add customized polls to the site'),
('SettingsSections::access_restrictions::general', 'General'),
('SettingsOptions::access_restrictions::elm_administrator_area_settings', 'Administrator area settings'),
('SettingsOptions::access_restrictions::admin_reverse_ip_access', 'Allow login to the admin area from specified IPs only'),
('SettingsOptions::access_restrictions::unsuccessful_attempts_login', 'Block IP after a number of unsuccessful attempts'),
('SettingsOptions::access_restrictions::number_unsuccessful_attempts', 'Number of unsuccessful attempts'),
('SettingsOptions::access_restrictions::login_intervals', 'Time between unsuccessful login attempts (seconds)'),
('SettingsOptions::access_restrictions::time_block', 'Time for which the IP should be blocked (hours)'),
('SettingsOptions::access_restrictions::elm_customer_and_affiliate_area_settings', 'Customer area settings'),
('SettingsOptions::access_restrictions::unsuccessful_attempts_login_customer', 'Block IP after a number of unsuccessful attempts'),
('SettingsOptions::access_restrictions::number_unsuccessful_attempts_customer', 'Number of unsuccessful attempts'),
('SettingsOptions::access_restrictions::login_intervals_customer', 'Time between unsuccessful login attempts (seconds)'),
('SettingsOptions::access_restrictions::time_block_customer', 'Time for which the IP should be blocked (hours)'),
('Languages::access_restrictions', 'Access restrictions'),
('Languages::add_ips', 'Add IPs'),
('Languages::new_ips', 'New IPs'),
('Languages::add_domains', 'Add domains'),
('Languages::new_domains', 'New domains'),
('Languages::add_emails', 'Add e-mail addresses'),
('Languages::new_emails', 'New e-mail addresses'),
('Languages::new_credit_card', 'New credit card'),
('Languages::add_credit_card', 'Add credit card'),
('Languages::privileges.manage_access_restrictions', 'Can edit'),
('Languages::privilege_groups.access_restrictions', 'Access restrictions'),
('Languages::domain', 'Domain'),
('Languages::warning_of_ip_adding', 'The entered IP address <b>[entered_ip]</b> forbids access to the administration panel from your computer (your IP is <b>[your_ip]</b>).'),
('Languages::text_cc_number_is_blocked', 'The credit card number <b>[cc_number]</b> is blocked by the administrator. Please contact the store administrator or try another one.'),
('Languages::text_not_valid_ip', '<b>[ip]</b> is not a valid ip address.'),
('Languages::text_not_valid_domain', '<b>[domain]</b> is not a valid domain name.'),
('Languages::text_not_valid_cc_number', '<b>[cc_number]</b> is not a valid credit card number.'),
('Languages::text_email_is_blocked', 'The e-mail address <b>[email]</b> is blocked by the administrator. Please contact the store administrator or try another one.'),
('Languages::text_ips_denied', 'You are not allowed to access this area'),
('Languages::text_ip_blocked_failed_login', 'The IP was blocked after [number] unsuccessful logins'),
('Languages::text_ip_is_blocked', 'Your IP address is blocked.'),
('Languages::store_admin', 'Store administrator'),
('Languages::your_ip_added', 'Your IP address <b>[ip]</b> has been added to the access restrictions table.'),
('Languages::your_ip_enabled', 'Your IP address <b>[ip]</b> has been enabled in the access restrictions table.'),
('Languages::your_ip_removed', 'Your IP address <b>[ip]</b> has been removed from the access restrictions table.'),
('Languages::ip_from', 'IP from'),
('Languages::ip_to', 'IP to'),
('Languages::text_access_notice', 'You can use the wildcards for the "Domain", "E-mail" and "Credit Card" tabs: <br /><b>*</b> - can represent any number of characters, including zero<br /><b>?</b> - can represent any single character.'),
('Languages::ips', 'IPs'),
('Languages::make_permanent', 'Make permanent'),
('Languages::credit_card_number', 'Credit card number'),
('Addons::name::access_restrictions', 'Access restrictions'),
('Addons::description::access_restrictions', 'Lets you limit storefront and administrator area access to certain IP-addresses with different options'),
('SettingsSections::banners::general', 'General'),
('SettingsOptions::banners::banner_multilang', 'Enable multi-language Images/URLs'),
('Languages::banners.new_banner', 'New banner'),
('Languages::banners.editing_banner', 'Editing banner'),
('Languages::add_banner', 'Add banner'),
('Languages::banner', 'Banner'),
('Languages::banners', 'Banners'),
('Languages::banner_code', 'Banner code'),
('Languages::banner_code_for_some_products', 'Banner code for some products'),
('Languages::manage_banners', 'Manage banners'),
('Languages::block_banners', 'Banners'),
('Languages::block_banners_description', 'Visual and text banners'),
('Languages::privileges.view_banners', 'Can view'),
('Languages::privileges.manage_banners', 'Can edit'),
('Languages::privilege_groups.banners', 'Banners'),
('Languages::add_banners', 'Add banners'),
('Languages::add_banners_and_close', 'Add banners and close'),
('Languages::graphic_banner', 'Graphic banner'),
('Languages::text_banner', 'Text banner'),
('Languages::conversion', 'Conversion'),
('Languages::banner_details_notes', 'After you create a banner here, you should use the <strong>Layout editor</strong> to add it to the storefront.<br /><br />Go to <a href="[layouts_href]" target="_blank">Design → Layouts</a>, switch to the location where you want the banner to appear, and add a new block with type <strong>Banners</strong>.<br /><br />In this block settings, go to the <strong>Content</strong> tab, pick the <strong>Manual</strong> filling, and click on the <strong>Add banners</strong> button.<br /><br />You will see the list of all the banners in your store. Pick the one(s) you need and click on the <strong>Add banners and close</strong> button.<br /><br />Finally, click on the <strong>Create</strong> button to save your changes.'),
('Languages::n_banners', '[n] banner|[n] banners'),
('Addons::name::banners', 'Banners management'),
('Addons::description::banners', 'Allows you to create text and visual banners'),
('SettingsSections::discussion::products', 'Products'),
('SettingsOptions::discussion::product_posts_per_page', 'Posts per page'),
('SettingsOptions::discussion::product_post_approval', 'Administrator must approve posts submitted by'),
('SettingsVariants::discussion::product_post_approval::any', 'Any customer'),
('SettingsVariants::discussion::product_post_approval::anonymous', 'Only anonymous customers'),
('SettingsVariants::discussion::product_post_approval::disabled', 'No approval needed'),
('SettingsOptions::discussion::product_post_ip_check', 'Only one post from one IP is allowed'),
('SettingsOptions::discussion::product_discussion_type', 'Default value'),
('SettingsOptions::discussion::product_share_discussion', 'Share discussions with all stores'),
('SettingsOptions::discussion::product_review_after_purchase', 'Only buyers can post'),
('SettingsSections::discussion::categories', 'Categories'),
('SettingsOptions::discussion::category_posts_per_page', 'Posts per page'),
('SettingsOptions::discussion::category_post_approval', 'Administrator must approve posts submitted by'),
('SettingsVariants::discussion::category_post_approval::any', 'Any customer'),
('SettingsVariants::discussion::category_post_approval::anonymous', 'Only anonymous customers'),
('SettingsVariants::discussion::category_post_approval::disabled', 'No approval needed'),
('SettingsOptions::discussion::category_post_ip_check', 'Only one post from one IP is allowed'),
('SettingsOptions::discussion::category_discussion_type', 'Default value'),
('SettingsSections::discussion::orders', 'Orders'),
('SettingsOptions::discussion::order_posts_per_page', 'Posts per page'),
('SettingsOptions::discussion::order_initiate', 'Allow customer to initiate discussion'),
('SettingsSections::discussion::pages', 'Pages'),
('SettingsOptions::discussion::page_posts_per_page', 'Posts per page'),
('SettingsOptions::discussion::page_post_approval', 'Administrator must approve posts submitted by'),
('SettingsVariants::discussion::page_post_approval::any', 'Any customer'),
('SettingsVariants::discussion::page_post_approval::anonymous', 'Only anonymous customers'),
('SettingsVariants::discussion::page_post_approval::disabled', 'No approval needed'),
('SettingsOptions::discussion::page_post_ip_check', 'Only one post from one IP is allowed'),
('SettingsOptions::discussion::page_discussion_type', 'Default value'),
('SettingsOptions::discussion::page_share_discussion', 'Share discussions with all stores'),
('SettingsSections::discussion::testimonials', 'Testimonials'),
('SettingsOptions::discussion::home_page_posts_per_page', 'Posts per page'),
('SettingsOptions::discussion::home_page_post_approval', 'Administrator must approve posts submitted by'),
('SettingsVariants::discussion::home_page_post_approval::any', 'Any customer'),
('SettingsVariants::discussion::home_page_post_approval::anonymous', 'Only anonymous customers'),
('SettingsVariants::discussion::home_page_post_approval::disabled', 'No approval needed'),
('SettingsOptions::discussion::home_page_post_ip_check', 'Only one post from one IP is allowed'),
('SettingsOptions::discussion::home_page_testimonials', 'Testimonials'),
('SettingsOptions::discussion::testimonials_from_all_stores', 'Show testimonials from all stores'),
('Languages::use_for_discussion', 'Comments and reviews forms'),
('Languages::discussion_title_category', 'Reviews'),
('Languages::discussion_title_giftreg', 'Guestbook'),
('Languages::discussion_title_order', 'Communication'),
('Languages::discussion_title_page', 'Comments'),
('Languages::discussion_title_product', 'Reviews'),
('Languages::discussion_title_return', 'Communication'),
('Languages::no_posts_found', 'No posts found'),
('Languages::your_rating', 'Your rating'),
('Languages::comments_and_reviews', 'Comments and reviews'),
('Languages::discussion.comments_and_reviews_menu', 'Comments'),
('Languages::discussion_title_home_page', 'Testimonials'),
('Languages::text_enabled_testimonials_notice', 'Testimonials are disabled. To enable, please go to <a href="[link]">Comments and reviews: options</a> and select the "Communication", "Rating" or "Communication and Rating" value in "Testimonials" field.'),
('Languages::discussion_title_company', 'Reviews'),
('Languages::communication_and_rating', 'Communication and Rating'),
('Languages::communication', 'Communication'),
('Languages::cant_find_thread', 'Thread can not be found.'),
('Languages::error_already_posted', 'You have posted in this discussion already'),
('Languages::text_thank_you_for_post', 'Thank you for your post'),
('Languages::text_post_pended', 'Your post will be checked before it gets published.'),
('Languages::discussion', 'Comments and reviews'),
('Languages::text_new_post_notification', 'This is a notification of a new post to'),
('Languages::text_approval_notice', 'This post needs approving'),
('Languages::latest_reviews', 'Latest comments & reviews'),
('Languages::comment_by', 'Comment by'),
('Languages::and', 'and'),
('Languages::add_post', 'Add post'),
('Languages::not_approved', 'Not approved'),
('Languages::discussion_manager', 'Comments and reviews'),
('Languages::testimonials', 'Testimonials'),
('Languages::privileges.view_discussions', 'Can view'),
('Languages::privileges.manage_discussions', 'Can edit'),
('Languages::privilege_groups.discussions', 'Comments and reviews'),
('Languages::block_testimonials', 'Testimonials'),
('Languages::block_testimonials_description', 'User testimonials'),
('Languages::sort_by_rating_asc', 'Sort by rating: Low to High'),
('Languages::sort_by_rating_desc', 'Sort by rating'),
('Languages::reviews', 'review|reviews'),
('Languages::write_review', 'Write a review'),
('Languages::discussion_tab_products', 'Product Reviews'),
('Languages::discussion_tab_categories', 'Category Reviews'),
('Languages::discussion_tab_pages', 'Page Comments'),
('Languages::discussion_tab_orders', 'Order Communication'),
('Languages::discussion_tab_home_page', 'Testimonials'),
('Languages::discussion_tab_companies', 'Company Reviews'),
('Languages::email_template.discussion_notification', 'Comments and reviews notification'),
('Languages::show_rating', 'Show review rating'),
('Languages::gdpr_discussions_data', 'Personal data from discussions'),
('Languages::discussion.add_new_review', 'Discussion: new review'),
('Languages::discussion.agreement_text_full_add_new_review', '<p>Your name will appear next to your review or comment, visible to everyone. We ([company]) also save your IP address as a security precaution, but in can only be viewed by our staff. It will remain in our system until you withdraw your consent. If you’d like to have your personal data removed, send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('Languages::discussion.agreement_text_short_add_new_review', 'I agree to have my personal data <u>processed as follows.</u>'),
('Languages::discussion.please_log_in_to_write_a_review', 'Please sign in to write a review'),
('Languages::discussion.you_have_to_buy_product_before_writing_review', 'You can''t write a review for this product. Customers can write reviews only for the products they bought. If you actually bought this product from us, but are still seeing this message, please contact us.'),
('Languages::discussion.you_have_to_buy_from_vendor_before_writing_review', 'You can''t write a review for this vendor. Customers can write reviews for a vendor only after they buy something from that vendor. If you actually placed an order with this vendor, but are still seeing this message, please contact us.'),
('Languages::discussion.event.products.new_post', 'Products: new review posted'),
('Languages::discussion.event.testimonials.new_post', 'Testimonials: new review posted'),
('Languages::discussion.event.orders.new_post', 'Order communication: new message added'),
('Languages::discussion.event.categories.new_post', 'Categories: new review posted'),
('Languages::discussion.event.pages.new_post', 'Pages: new comment posted'),
('Languages::discussion.event.vendors.new_post', 'Vendors: new review posted'),
('SettingsTooltips::discussion::product_share_discussion', 'Show all comments and reviews of a product on all storefronts that the product is shared with'),
('SettingsTooltips::discussion::page_share_discussion', 'Show all comments and reviews of a page on all storefronts that the page is shared with'),
('SettingsTooltips::discussion::product_discussion_type', 'Determines if comments and/or reviews are allowed for newly-created products. Doesn''t affect existing products.'),
('SettingsTooltips::discussion::product_review_after_purchase', 'Allow leaving reviews for a product only to those who bought that product.'),
('SettingsTooltips::discussion::category_discussion_type', 'Determines if comments and/or reviews are allowed for newly-created categories. Doesn''t affect existing categories.'),
('SettingsTooltips::discussion::page_discussion_type', 'Determines if comments and/or reviews are allowed for newly-created pages. Doesn''t affect existing pages.'),
('Addons::name::discussion', 'Comments and reviews'),
('Addons::description::discussion', 'Lets customers leave comments to categories, pages, etc., review vendors and write testimonials'),
('SettingsSections::watermarks::general', 'General'),
('SettingsOptions::watermarks::watermark', 'Watermark'),
('SettingsOptions::watermarks::watermark_settings', ''),
('SettingsOptions::watermarks::apply_to_product', 'Product watermarks'),
('SettingsOptions::watermarks::use_for_product_icons', 'Resized images'),
('SettingsOptions::watermarks::use_for_product_detailed', 'Original size images'),
('SettingsOptions::watermarks::apply_to_categories', 'Category watermarks'),
('SettingsOptions::watermarks::use_for_category_icons', 'Resized images'),
('SettingsOptions::watermarks::use_for_category_detailed', 'Original size images'),
('SettingsOptions::watermarks::images_access_info', 'Images access'),
('Languages::wt_watermarks', 'Watermarks'),
('Languages::wt_graphic_watermark', 'Graphic watermark'),
('Languages::wt_text_watermark', 'Text watermark'),
('Languages::wt_watermark_vertical_position', 'Watermark vertical position'),
('Languages::wt_watermark_horizontal_position', 'Watermark horizontal position'),
('Languages::wt_watermark_position', 'Watermark position'),
('Languages::wt_watermark_image', 'Watermark image'),
('Languages::wt_watermark_text', 'Watermark text'),
('Languages::wt_font', 'Font'),
('Languages::wt_font_color', 'Font color'),
('Languages::wt_font_size_icon', 'Font size (thumbnail)'),
('Languages::wt_font_size_detailed', 'Font size (larger image)'),
('Languages::wt_watermark_icon', 'Thumbnail watermark'),
('Languages::wt_watermark_detailed', 'Popup larger image watermark'),
('Languages::wt_fail_apply_graphic_watermark', 'Failed to apply the watermark to [image_type]. The watermark image is not added.'),
('Languages::wt_icons', 'thumbnails'),
('Languages::wt_detailed', 'popup larger images'),
('Languages::wt_images_access_description', 'To deny access to your original images, please add the following instructions to the ''.htaccess'' file in the ''images'' directory of your installation. It will protect your original images. Even if an original image is opened, the corresponding watermarked image will be show instead.'),
('Languages::wt_watermarks_access_description', 'To generate watermarked images automatically even if they are requested not from your store pages, please add the ''.htaccess'' file with the following instructions to the ''images/watermarked'' directory of your installation.'),
('Languages::wt_access_note', 'Please note, if you disable or uninstall the ''Watermarks'' add-on, you should remove these instructions from ''.htaccess'' files manually. Otherwise category and product images will be unavailable.'),
('Languages::wt_access_warning', 'Watermark creating is disabled. If there are any "Rewrite watermarks rules" instructions in the "images/.htaccess" file, you should remove them manually. Otherwise category and product images will be unavailable.'),
('Languages::wt_images_access_info', 'Images access'),
('Addons::name::watermarks', 'Watermarks'),
('Addons::description::watermarks', 'Allows you to add watermarks to product and category images'),
('SettingsSections::product_reviews::general', ''),
('SettingsOptions::product_reviews::notice', ''),
('SettingsOptions::product_reviews::reviews_per_page', 'Reviews per page'),
('SettingsOptions::product_reviews::review_approval', 'Administrator must approve posts submitted by'),
('SettingsVariants::product_reviews::review_approval::any', 'Any customer'),
('SettingsVariants::product_reviews::review_approval::anonymous', 'Only anonymous customers'),
('SettingsVariants::product_reviews::review_approval::disabled', 'No approval needed'),
('SettingsOptions::product_reviews::review_ip_check', 'Allow one review per IP address'),
('SettingsOptions::product_reviews::review_fields', 'Review fields'),
('SettingsVariants::product_reviews::review_fields::advanced', 'Comment with advantages and disadvantages'),
('SettingsVariants::product_reviews::review_fields::simple', 'Only comment'),
('SettingsOptions::product_reviews::review_after_purchase', 'Only buyers can post'),
('SettingsOptions::product_reviews::review_ask_for_customer_location', 'Ask for customer location'),
('SettingsVariants::product_reviews::review_ask_for_customer_location::none', 'None'),
('SettingsVariants::product_reviews::review_ask_for_customer_location::country', 'Country'),
('SettingsVariants::product_reviews::review_ask_for_customer_location::city', 'City'),
('SettingsOptions::product_reviews::split_reviews_by_storefronts', 'Split reviews by storefront'),
('SettingsOptions::product_reviews::images_upload_allowed', ''),
('SettingsOptions::product_reviews::product_variations', ''),
('SettingsOptions::product_reviews::split_reviews_for_variations_as_separate_products', ''),
('Languages::product_reviews.use_for_reviews', 'Comments and reviews forms'),
('Languages::product_reviews.title_giftreg', 'Guestbook'),
('Languages::product_reviews.title', 'Reviews'),
('Languages::product_reviews.no_reviews_found', 'No reviews found'),
('Languages::product_reviews.your_rating', 'Your rating'),
('Languages::product_reviews.comments_and_reviews', 'Comments and reviews'),
('Languages::product_reviews.rating', 'Rating'),
('Languages::product_reviews.date', 'Date'),
('Languages::product_reviews.error_already_posted', 'You have posted in this review already'),
('Languages::product_reviews.text_thank_you_for_post', 'Thank you for your post'),
('Languages::product_reviews.text_review_pended', 'Your review will be checked before it gets published.'),
('Languages::product_reviews.reviews', 'Reviews: [n]'),
('Languages::product_reviews.n_reviews', 'review|reviews'),
('Languages::product_reviews.text_new_post_notification', 'This is a notification of a new post to product'),
('Languages::product_reviews.text_new_reply_notification', 'This is a notification of a new reply to your product review'),
('Languages::product_reviews.text_approval_notice', 'This review needs approving'),
('Languages::product_reviews.latest_reviews', 'Latest reviews'),
('Languages::product_reviews.comment_by', 'Comment by'),
('Languages::product_reviews.and', 'and'),
('Languages::product_reviews.approve', 'Approve'),
('Languages::product_reviews.disapprove', 'Disapprove'),
('Languages::product_reviews.approved', 'Approved'),
('Languages::product_reviews.not_approved', 'Not approved'),
('Languages::product_reviews.manager', 'Comments and reviews'),
('Languages::privileges.view_product_reviews', 'Can view'),
('Languages::privileges.manage_product_reviews', 'Can edit'),
('Languages::privilege_groups.product_reviews', 'Product reviews'),
('Languages::product_reviews.product_reviews', 'Product reviews'),
('Languages::product_reviews.menu_title', 'Reviews'),
('Languages::product_reviews.write_review', 'Write a review'),
('Languages::email_template.product_reviews_notification', 'Product reviews: New review notification'),
('Languages::email_template.product_reviews_reply_notification', 'Product reviews: Reply notification'),
('Languages::product_reviews.show_rating', 'Show review rating'),
('Languages::product_reviews.show_reviews', 'Show reviews'),
('Languages::product_reviews.show_review', 'Show review'),
('Languages::product_reviews.show_n_reviews', 'Show [n] review|Show [n] reviews'),
('Languages::product_reviews.scroll_to_reviews', 'Scroll to reviews'),
('Languages::product_reviews.show_review_images', 'Show review images'),
('Languages::product_reviews.scroll_to_review_images', 'Scroll to review images'),
('Languages::gdpr_product_reviews', 'Personal data from reviews'),
('Languages::product_reviews.add_new_review', 'reviews: new review'),
('Languages::product_reviews.agreement_text_full_add_new_review', '<p>Your name will appear next to your review or comment, visible to everyone. We ([company]) also save your IP address as a security precaution, but in can only be viewed by our staff. It will remain in our system until you withdraw your consent. If you’d like to have your personal data removed, send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('Languages::product_reviews.terms_n_conditions', 'Select this check box to accept the [terms_href]'),
('Languages::product_reviews.terms_n_conditions_name', 'Terms and Conditions'),
('Languages::product_reviews.terms_and_conditions_content', '<p>Please read these Terms and Conditions ("Terms", "Terms and Conditions") carefully before using the <a href="http://www.mywebsite.com">http://www.mywebsite.com</a> website and the My Mobile App mobile application (the "Service") operated by My Company ("us", "we", or "our").</p><p><strong>By accessing or using the Service you agree to be bound by these Terms. If you disagree with any part of the Terms then you may not access the Service.</strong></p><p><strong>Purchases</strong></p><p>If you wish to purchase any product or service made available through the Service ("Purchase"), you may be asked to supply certain information relevant to your Purchase including, without limitation, your ...</p><p><strong>Content</strong></p><p>Our Service allows you to post, link, store, share and otherwise make available certain information, text, graphics, videos, or other material ("Content"). You are responsible for the ...</p><p><strong>Changes</strong></p><p>We reserve the right, at our sole discretion, to modify or replace these Terms at any time. If a revision is material we will try to provide at least 30 days'' notice prior to any new terms taking effect. What constitutes a material change will be determined at our sole discretion.</p><p><strong>Contact Us</strong></p><p>If you have any questions about these Terms, please contact us.</p>'),
('Languages::product_reviews.moderation_rules', 'Before submitting a review, make sure that it does not violate the moderation rules: it does not contain links to third-party resources and insults.'),
('Languages::product_reviews.agreement_text_short_add_new_review', 'I agree to have my personal data <u>processed as follows.</u>'),
('Languages::product_reviews.please_log_in_to_write_a_review', 'Please sign in to write a review'),
('Languages::product_reviews.you_have_to_buy_product_before_writing_review', 'You can''t write a review for this product. Customers can write reviews only for the products they bought. If you actually bought this product from us, but are still seeing this message, please contact us.'),
('Languages::product_reviews.event.new_post', 'New review posted'),
('Languages::product_reviews.event.new_reply', 'New reply was added to review'),
('Languages::product_reviews.helpfulness', 'Helpfulness'),
('Languages::product_reviews.vote_up', 'Vote up'),
('Languages::product_reviews.vote_down', 'Vote down'),
('Languages::sort_by_product_review_timestamp_desc', 'Sort by date: Newest to Oldest'),
('Languages::sort_by_product_review_timestamp_asc', 'Sort by date: Oldest to Newest'),
('Languages::sort_by_helpfulness_asc', 'Helpful last'),
('Languages::sort_by_helpfulness_desc', 'Helpful first'),
('Languages::sort_by_rating_value_desc', 'Sort by rating: High to Low'),
('Languages::sort_by_rating_value_asc', 'Sort by rating: Low to High'),
('Languages::product_reviews.advantages', 'Advantages'),
('Languages::product_reviews.disadvantages', 'Disadvantages'),
('Languages::product_reviews.comments', 'Comments'),
('Languages::product_reviews.comment', 'Comment'),
('Languages::product_reviews.disabled', 'Disabled'),
('Languages::product_reviews.vendor', 'Vendor'),
('Languages::product_reviews.vendor_reply', 'Vendor reply'),
('Languages::product_reviews.type_message', 'Type a message...'),
('Languages::product_reviews.verified_purchase', 'Verified purchase'),
('Languages::product_reviews.reviews_lower', 'reviews'),
('Languages::product_reviews.review', 'Review'),
('Languages::product_reviews.write_your_review', 'Write your review'),
('Languages::product_reviews.add_images', 'Add a photo'),
('Languages::product_reviews.write_review_anonymously', 'Write your review anonymously'),
('Languages::product_reviews.submit_review', 'Submit review'),
('Languages::product_reviews.with_photo', 'With photo'),
('Languages::product_reviews.without_photo', 'Without photo'),
('Languages::product_reviews.customer_photos', 'Customer photos'),
('Languages::product_reviews.review_status', 'Review status'),
('Languages::product_reviews.star', 'star'),
('Languages::product_reviews.stars', 'stars'),
('Languages::product_reviews.n_stars', '[n] star|[n] stars'),
('Languages::product_reviews.out_of_five', 'out of 5'),
('Languages::product_reviews.review_this_product', 'Review this product'),
('Languages::product_reviews.review_this_product_description', 'Share your thoughts with other customers'),
('Languages::product_reviews.reply', 'Reply'),
('Languages::product_reviews.first_and_last_name', 'First and last name'),
('Languages::product_reviews.text_thank_you_for_review', 'Thank you for your review'),
('Languages::product_reviews.excellent', 'Excellent!'),
('Languages::product_reviews.very_good', 'Very Good'),
('Languages::product_reviews.average', 'Average'),
('Languages::product_reviews.fair', 'Fair'),
('Languages::product_reviews.poor', 'Poor'),
('Languages::product_reviews.five_star_icon', '★★★★★'),
('Languages::product_reviews.four_star_icon', '★★★★'),
('Languages::product_reviews.three_star_icon', '★★★'),
('Languages::product_reviews.two_star_icon', '★★'),
('Languages::product_reviews.one_star_icon', '★'),
('Languages::product_reviews.product_details', 'Product details'),
('Languages::product_reviews.rating_4_and_up', 'Rating 4+'),
('Languages::product_reviews.event.new_post.title', 'New review posted for a product'),
('Languages::product_reviews.event.new_post.message', 'A new review has been posted for product [product]. Click this notification to see the review.'),
('Languages::product_reviews.copy_old_reviews_warning', 'You have product reviews in the old "Comments and reviews" add-on. While that add-on is installed, you''ll be able copy those reviews to the new "Product reviews" add-on <a class="cm-post" href="[url]">in its settings</a>.'),
('Languages::product_reviews.copy_old_reviews_notice', '<h4 class="subheader hand" data-toggle="collapse" data-target="#collapsable_addon_product_reviews_notice">Copy reviews from the "Comments and reviews" add-on<span class="icon-caret-down"></span></h4><div id="collapsable_addon_product_reviews_notice" class="in collapse" style="height: auto;"><ol><li>Only reviews that have both a score and a user''s comment will be copied. Go to your products and check the “Reviews" setting on the "Add-ons" tab. You might have to allow communication and rating first.</li><li>A review without a score or without a comment will not be copied. To transfer it, you must first manually add the missing score or comment by editing the review.</li><li>While the old "Comments and reviews" add-on is installed, the reviews won''t be removed from there. That way, you can choose to move to "Product reviews" whenever all your reviews are ready.</li><li>If you ever need to copy the reviews from the old add-on again in the future, just uninstall and reinstall the "Product reviews" add-on. This will remove all its reviews from the database, and you''ll be able to import the reviews from the "Comments and reviews" add-on again.</li></ol><a class="cm-post btn btn-primary" href="[url]">Copy product reviews</a></div>'),
('Languages::product_reviews.update_reply', 'Update reply'),
('Languages::product_reviews.add_reply', 'Add reply'),
('Languages::product_reviews.max_number_image_message', 'A review can have up to [max_image_number] images.'),
('Languages::product_reviews.uploader_drop_zone_description', 'Drop images here'),
('Languages::product_reviews.uploader_drop_zone_info', 'Photo up to [max_size]'),
('Languages::product_reviews.admin_reply', 'Administrator reply'),
('Languages::product_reviews.company_reply', '[company_name] reply'),
('Languages::product_reviews.hide_name', 'Hide my name in the review'),
('Languages::product_reviews.product_is_rated_n_out_of_five_stars', 'The product is rated [n] out of 5 stars'),
('Languages::product_reviews.click_to_see_reviews', 'Click to see the reviews'),
('Languages::product_reviews.split_reviews_for_variations_as_separate_products', 'Split reviews for variations as separate products'),
('Languages::privileges.create_product_reviews', 'Can create'),
('Languages::product_reviews.upgrade_notification.title_administators_add_ability_create_product_reviews', 'Administrators can now create product reviews'),
('Languages::product_reviews.upgrade_notification.message_administators_add_ability_create_product_reviews', 'Previously, administrators could edit existing product reviews in the admin panel, but couldn''t post new ones. We''ve changed that: now the administrators who could edit reviews can add new reviews on the "Reviews" tab of the product editing page. Note that this change doesn''t affect vendors'' administrators in CS-Cart Multi-Vendor in any way. The most that they can do is leave a reply to a product review.<br><br>You can keep the old behavior if you''d like. Through user groups, you can now allow administrators to create or edit reviews (or do both of those things).<br><br><a target="_blank" href="[usergroups_url]" class="btn">Set administrator privileges</a>'),
('Languages::product_reviews.exim_error_incorrect_field_value', 'Specified [field] ''[value]'' was not found. The product review with comment ''[comment]'' was skipped.'),
('Languages::product_reviews.exim_error_empty_field', 'The value of the <b>[field]</b> field can not be empty. The product review with comment ''[comment]'' was skipped.'),
('Languages::product_reviews', 'Product reviews'),
('Languages::images_delimiter', 'Images delimiter'),
('Languages::text_images_delimiter', 'Images path delimiter for product review images (e.g. "Image1.png///Image2.png")'),
('SettingsTooltips::product_reviews::review_after_purchase', 'Allow leaving reviews for a product only to those who bought that product.'),
('Addons::name::product_reviews', 'Product reviews'),
('Addons::description::product_reviews', 'Allows your customers to leave reviews for products. That can build up trust, provide social proof, and add user-generated content to your site.'),
('Languages::add_to_wishlist', 'Add to wish list'),
('Languages::clear_wishlist', 'Clear wish list'),
('Languages::view_wishlist', 'View wish list'),
('Languages::wishlist_content', 'Wish list content'),
('Languages::wishlist', 'Wish list'),
('Languages::wishlist_short', 'Wish list'),
('Languages::wishlist_note', 'Go to your wishlist'),
('Languages::text_failed_gift_certificate_addition', 'Failed to add the certificate. Make sure the summary amount is not zero.'),
('Languages::text_gift_cert_added_to_wishlist', 'The gift certificate has been added to the wish list'),
('Languages::product_added_to_wl', 'The product was added to your Wish list'),
('Languages::product_in_wishlist', 'This product is already in the wish list'),
('Languages::wishlist_products', 'Wish list products'),
('Addons::name::wishlist', 'Wish List'),
('Addons::description::wishlist', 'Lets customers store items in personal wish lists'),
('SettingsSections::image_zoom::general', 'General'),
('SettingsOptions::image_zoom::cz_animation_time', 'Animation time'),
('SettingsOptions::image_zoom::cz_zoom_position', 'Zoom position'),
('SettingsVariants::image_zoom::cz_zoom_position::3', 'Upper right corner'),
('SettingsVariants::image_zoom::cz_zoom_position::5', 'Bottom right corner'),
('SettingsVariants::image_zoom::cz_zoom_position::13', 'Upper left corner'),
('SettingsVariants::image_zoom::cz_zoom_position::11', 'Bottom left corner'),
('SettingsTooltips::image_zoom::cz_animation_time', 'Duration of the animation effects in milliseconds.'),
('SettingsTooltips::image_zoom::cz_zoom_position', 'Specifies position of zoom window.'),
('Addons::name::image_zoom', 'Image zoom'),
('Addons::description::image_zoom', 'Shows zoomed image on product image hover'),
('SettingsSections::google_sitemap::general', 'General'),
('SettingsOptions::google_sitemap::information', 'Information'),
('SettingsOptions::google_sitemap::clear_url', 'Clear cache'),
('SettingsOptions::google_sitemap::cron_command', ''),
('SettingsOptions::google_sitemap::site_setting', 'Homepage settings'),
('SettingsOptions::google_sitemap::site_change', 'Update frequency'),
('SettingsOptions::google_sitemap::site_priority', 'Priority'),
('SettingsOptions::google_sitemap::products_setting', 'Products settings'),
('SettingsOptions::google_sitemap::include_products', 'Include in sitemap'),
('SettingsOptions::google_sitemap::products_change', 'Update frequency'),
('SettingsOptions::google_sitemap::products_priority', 'Priority'),
('SettingsOptions::google_sitemap::categories_setting', 'Categories settings'),
('SettingsOptions::google_sitemap::include_categories', 'Include in sitemap'),
('SettingsOptions::google_sitemap::categories_change', 'Update frequency'),
('SettingsOptions::google_sitemap::categories_priority', 'Priority'),
('SettingsOptions::google_sitemap::pages_setting', 'Pages settings'),
('SettingsOptions::google_sitemap::include_pages', 'Include in sitemap'),
('SettingsOptions::google_sitemap::pages_change', 'Update frequency'),
('SettingsOptions::google_sitemap::pages_priority', 'Priority'),
('SettingsOptions::google_sitemap::extended_setting', 'Brand/Manufacturer feature pages settings'),
('SettingsOptions::google_sitemap::include_extended', 'Include in sitemap'),
('SettingsOptions::google_sitemap::extended_change', 'Update frequency'),
('SettingsOptions::google_sitemap::extended_priority', 'Priority'),
('Languages::google_sitemap.text_regenerate', 'If products, categories, etc. were added or changed, please <a class="cm-ajax cm-comet btn btn-primary" href="[regenerate_url]">Regenerate a sitemap</a><br /><br /> [sitemap_available_in_customer]'),
('Languages::google_sitemap.text_auto_regenerate', 'You can run the regeneration of the site map automatically at certain time intervals. To do it, add the following command to CRON:'),
('Languages::google_sitemap.text_select_storefront', 'To generate a sitemap, please select storefront first.'),
('Languages::sitemap_available_in_customer', 'Sitemap is available by this link: <a href="[sitemap_url]">[sitemap_url]</a><br /><br />Sitemap can be reached by the URL <a href="[http_location]/sitemap.xml">[http_location]/sitemap.xml</a>'),
('Languages::always', 'Always'),
('Languages::hourly', 'Hourly'),
('Languages::daily', 'Daily'),
('Languages::weekly', 'Weekly'),
('Languages::monthly', 'Monthly'),
('Languages::yearly', 'Yearly'),
('Languages::google_sitemap.generate_map', 'The sitemap is not generated yet. Please go to add-on settings and press "Regenerate a sitemap" button'),
('Languages::google_sitemap.map_generated', 'The sitemap was generated successfully'),
('Languages::google_sitemap.export_progress_entry', '[storefront]: [object]'),
('Addons::name::google_sitemap', 'Google sitemap'),
('Addons::description::google_sitemap', 'Creates a sitemap.xml for Google'),
('Languages::required_products', 'Required products'),
('Languages::required_products_added', 'The following required product(s) were added to your cart'),
('Languages::required_products_out_of_stock', 'This product cannot be added to your cart, because following required product(s) are out of stock:'),
('Addons::name::required_products', 'Required products'),
('Addons::description::required_products', 'Makes it possible to specify products required for purchase'),
('SettingsSections::data_feeds::general', 'General'),
('SettingsOptions::data_feeds::cron_password', 'Cron password'),
('Languages::data_feeds', 'Data feeds'),
('Languages::data_feed', 'Data feed'),
('Languages::export_by_cron', 'Export by cron'),
('Languages::export_by_cron_to', 'Export by cron to'),
('Languages::add_new_datafeed', 'New data feed'),
('Languages::add_datafeed', 'Add data feed'),
('Languages::datafeed_name', 'Data feed name'),
('Languages::save_directory', 'Server directory'),
('Languages::ftp_url', 'FTP server'),
('Languages::ftp_url_hint', 'The format is: FTPHOST[:PORT][/DIRECTORY]. Example: ftp.yourhost.com:21/home/username/folder'),
('Languages::ftp_user', 'FTP username'),
('Languages::ftp_pass', 'FTP password'),
('Languages::fields', 'Fields'),
('Languages::field_name', 'Field name'),
('Languages::field_type', 'Field type'),
('Languages::map_fields', 'Fields mapping'),
('Languages::update_datafeed', 'Editing data feed'),
('Languages::datafeed.description', 'Only the products that meet <strong>all</strong> of the conditions below will be exported:'),
('Languages::export_cron_hint', 'Use the following line to run the script according to schedule'),
('Languages::exported_items', 'Exported items'),
('Languages::ftp_connection_problem', 'Unable connect to FTP server. Please, check FTP connection information'),
('Languages::categories_in', 'Categories in'),
('Languages::products_in', 'Products in'),
('Languages::local_export', 'Download'),
('Languages::upload_to_ftp', 'Upload to FTP server'),
('Languages::cron_export', 'Cron export settings'),
('Languages::export_to_server', 'Export to server'),
('Languages::export_to_ftp', 'FTP server options'),
('Languages::ftp', 'FTP'),
('Languages::check_server_export_settings', 'Check server export settings'),
('Languages::exclude_disabled_products', 'Exclude disabled products'),
('Languages::data_feeds.exclude_shared_products', 'Exclude shared products'),
('Languages::general_settings', 'General settings'),
('Languages::enclosure', 'Enclosure'),
('Languages::data_feed.error_exim_no_data_exported', 'No data exported'),
('Languages::data_feeds.text_tooltip_field_name', 'The name of the column in the data feed file.'),
('Languages::data_feeds.text_tooltip_field_type', 'The type of data from your store which will be exported to this column of the data feed file.'),
('Addons::name::data_feeds', 'Data feeds'),
('Addons::description::data_feeds', 'Makes it possible to create product data feeds in CSV'),
('SettingsSections::price_list::general', 'General'),
('SettingsOptions::price_list::price_list_info', ''),
('SettingsOptions::price_list::price_list_fields', 'Fields'),
('SettingsOptions::price_list::price_list_sorting', 'Sort by'),
('SettingsOptions::price_list::group_by_category', 'Group by category'),
('SettingsOptions::price_list::include_options', 'Include product options'),
('Languages::price_list', 'Price list'),
('Languages::generating_pdf', 'Generating PDF. Please, be patient...'),
('Languages::generating_xls', 'Generating XLS. Please, be patient...'),
('Languages::price_list_ziparchive_not_installed', 'Impossible to create XML price list. Please add zip support in PHP on your server. Follow <a href="http://www.php.net/manual/en/zip.installation.php">http://www.php.net/manual/en/zip.installation.php</a>.'),
('Languages::price_list.text_select_storefront', 'To generate a price list, please select storefront first.'),
('Languages::price_list.text_regenerate', '<p>If products, categories or selected fields were added or changed, please regenerate a price list:<br />[buttons]</p><p>Generated price lists are available by these links<br/>[links]</p>'),
('Addons::name::price_list', 'Price list'),
('Addons::description::price_list', 'Generates configurable price list in PDF or XLS'),
('SettingsSections::janrain::general', 'General'),
('SettingsOptions::janrain::general_info', 'General info'),
('SettingsOptions::janrain::apikey', 'API Key'),
('SettingsOptions::janrain::appdomain', 'Application Domain'),
('Languages::janrain_general_info', '<p>Get these values and configure social login at <a href="http://janrain.com" target="_blank">janrain.com</a></p>'),
('Languages::janrain_social_login', 'Social login'),
('Languages::janrain_need_update_profile', 'The "Password" field and some other mandatory fields are empty at the moment. Please update your profile.'),
('Languages::janrain_cant_create_profile', 'Unfortunately, we failed to create a customer and log in to the store due to one of the following reasons:<br />- You logged in to our store earlier using some other OpenID provider in which the same email is used.<br />- You have already registered in our store using your email.<br />Please contact the store owner to resolve the problems.'),
('Languages::janrain.janrain_cookies_title', 'Janrain'),
('Languages::janrain.janrain_cookies_description', 'Janrain is a service that allows you to sign into the website with your accounts from various social networks. It was acquired by Akamai in 2019; here is <a href="https://www.akamai.com/site/en/documents/akamai/akamai-privacy-statement.pdf" target="_blank">Akamai privacy statement</a>.'),
('Addons::name::janrain', 'Janrain'),
('Addons::description::janrain', 'Adds the Social Login feature; allows customers use Facebook, Twitter, etc. to log in on the store'),
('SettingsSections::catalog_mode::general', 'General'),
('SettingsOptions::catalog_mode::main_store_mode', 'Store operation mode'),
('SettingsVariants::catalog_mode::main_store_mode::catalog', 'Catalog'),
('SettingsVariants::catalog_mode::main_store_mode::store', 'Store'),
('SettingsOptions::catalog_mode::add_to_cart_empty_buy_now_url', 'Allow purchasing products with empty Buy Now URL'),
('Languages::catalog_mode', 'Catalog Mode'),
('Languages::text_catalog_mode_zero_price_action_notice', 'In order that the "Buy now" button could be displayed on the product details page, please set "Zero price action" as "Allow customers to add the product to cart".'),
('Languages::buy_now_url', 'Buy Now URL'),
('Addons::name::catalog_mode', 'Catalog mode'),
('Addons::description::catalog_mode', 'Allows you to use the store as a product catalog'),
('SettingsSections::hybrid_auth::general', 'General'),
('SettingsOptions::hybrid_auth::icons_pack', 'Icons pack'),
('SettingsOptions::hybrid_auth::autogen_email', 'Autogeneration email'),
('Languages::hybrid_auth_menu_description', 'Connect users via Facebook, Twitter, Google, etc.'),
('Languages::hybrid_auth', 'Social login'),
('Languages::hybrid_auth.linked_provider', 'Linked'),
('Languages::hybrid_auth.not_linked_provider', 'Not linked'),
('Languages::hybrid_auth.providers', 'Providers'),
('Languages::hybrid_auth.add_provider', 'Add provider'),
('Languages::hybrid_auth.new_provider', 'New provider'),
('Languages::hybrid_auth.editing_provider', 'Editing provider'),
('Languages::hybrid_auth.callback_url', 'Callback URL'),
('Languages::hybrid_auth.social_login', 'Or sign-in with another identity provider'),
('Languages::hybrid_auth.unspecified_error', 'Unspecified error'),
('Languages::hybrid_auth.configuration_error', 'Hybriauth configuration error'),
('Languages::hybrid_auth.provider_error_configuration', 'Provider not properly configured'),
('Languages::hybrid_auth.wrong_provider', 'Unknown or disabled provider'),
('Languages::hybrid_auth.missing_credentials', 'Missing provider application credentials'),
('Languages::hybrid_auth.failed_auth', 'Authentication failed. The user has canceled the authentication or the provider refused the connection'),
('Languages::hybrid_auth.connecting_provider', 'Contacting <b>[provider]</b>. Please wait...'),
('Languages::hybrid_auth.cant_create_profile', 'Unfortunately, we failed to create a customer and log in to the store due to one of the following reasons:<br />- You logged in to our store earlier using some other OpenID provider in which the same email is used.<br />- You have already registered in our store using your email.<br />Please contact the store owner to resolve the problems.'),
('Languages::hybrid_auth.password_generated', 'We are glad to inform you that you have been successfully registered in the store. A password was generated for you'),
('Languages::hybrid_auth.change_password', 'You can change your password here');
INSERT INTO `[[dbprefix]]original_values` VALUES
('Languages::hybrid_auth.link_provider', 'Social network accounts'),
('Languages::hybrid_auth.text_link_provider', 'Assign your social network account to this one and use it to log in'),
('Languages::hybrid_auth.text_user_is_already_link', 'This social network account is already being used'),
('Languages::hybrid_auth.connect_social', 'Connect social account'),
('Languages::hybrid_auth.connect_social_title', 'Such user already exists'),
('Languages::hybrid_auth.text_connect_social', '<p>The user with the e-mail specified during social login already exists.</p><p>If you want to assign a social network account to the registered user, please log in.</p>'),
('Languages::hybrid_auth.specify_email', 'Specify email'),
('Languages::hybrid_auth.specify_email_title', 'The e-mail was not specified.'),
('Languages::hybrid_auth.text_specify_email', '<p>When logging through the social network the e-mail was not specified.</p><p>Please enter your e-mail and click Continue.</p>'),
('Languages::public_key', 'Public key'),
('Languages::paypal_seamless', 'Use seamless checkout'),
('Languages::paypal_sandbox', 'Test mode'),
('Languages::privileges.manage_providers', 'Can edit'),
('Languages::privileges.view_providers', 'Can view'),
('Languages::privilege_groups.social_login', 'Social login'),
('Languages::hybrid_auth.instruction_facebook', 'Use the application ID and Secret key that you''ve received after creating an application on <a href=''https://developers.facebook.com/apps'' target=''_blank''>Facebook Developers</a>.'),
('Languages::hybrid_auth.instruction_facebook_login', 'Use the application ID and Secret key that you''ve received after creating an application on <a href="https://developers.facebook.com/apps" target="_blank">Facebook Developers</a>. After that copy the value of the <b>Valid OAuth redirect URIs</b> field to the corresponding setting of the <b>Facebook Login</b> product in your Facebook application.'),
('Languages::hybrid_auth.instruction_google', 'Use ID and Secret key that you''ve received after creating a project on <a href=''https://code.google.com/apis/console/?pli=1'' target=''_blank''>Google</a>.'),
('Languages::hybrid_auth.instruction_paypal', 'Use the application ID and Secret key that you''ve received after creating an application on <a href=''https://developer.paypal.com/developer/applications'' target=''_blank''>PayPal Developers</a>.'),
('Languages::hybrid_auth.instruction_twitter', 'Use ID (Consumer key) and Secret key that you''ve received after creating an application on <a href=''https://apps.twitter.com/'' target=''_blank''>Twitter</a>.'),
('Languages::hybrid_auth.instruction_yahoo', 'Use ID (Identificator) and Secret key that you''ve received after creating an application on <a href=''https://developer.yahoo.com/apps/create/'' target=''_blank''>Yahoo</a>.'),
('Languages::hybrid_auth.instruction_live', 'Use the application ID and Secret key that you''ve received after adding an application on <a href=''https://account.live.com/developers/applications/create'' target=''_blank''>Live</a>.'),
('Languages::hybrid_auth.instruction_linkedin', 'Use ID (Consumer key) and Secret key that you''ve received after creating an application on <a href=''https://www.linkedin.com/developer/apps'' target=''_blank''>LinkedIn Developers</a>.'),
('Languages::hybrid_auth.instruction_foursquare', 'Use the application ID and Secret key that you''ve received after creating an application on <a href=''https://foursquare.com/developers/apps'' target=''_blank''>Fousquare</a>.'),
('Languages::email_template.hybrid_auth_create_profile', 'Create user profile via social login'),
('Languages::hybrid_auth.provider_not_found', 'Provider [provider] not found'),
('Languages::hybrid_auth.facebook_oauth_redirect_uris', 'Valid OAuth redirect URIs'),
('Languages::hybrid_auth.live_redirect_urls', 'Redirect URLs'),
('Languages::hybrid_auth.linkedin_api_version', 'API version'),
('Languages::ttc_hybrid_auth.linkedin_api_version', 'LinkedIn <a target="_blank" href="https://docs.microsoft.com/en-us/linkedin/consumer/integrations/self-serve/migration-faq?context=linkedin/consumer/context">deprecated API v1</a>, but old apps still use it. If you''re configuring LinkedIn app for the first time now, use API v2. Old LinkedIn apps configured some time ago may still be using v1.'),
('Languages::hybrid_auth.linkedin_api_v1', 'v1'),
('Languages::hybrid_auth.linkedin_api_v2', 'v2'),
('Languages::hybrid_auth.instruction_paypal_application', 'Use the application ID and Secret key that you''ve received after creating an application on <a href=''https://developer.paypal.com/developer/applications'' target=''_blank''>PayPal Developers</a>. Please enable all Personal Profile scope attributes and at least one scope attribute in Address and in Account Information in your PayPal application settings.'),
('SettingsTooltips::hybrid_auth::icons_pack', 'Directory with the social networks icons. A path to the directory: media/images/addons/addons/hybrid_auth/icons/.'),
('SettingsTooltips::hybrid_auth::autogen_email', 'Enables the email auto generation in case that a social network does not pass the address.'),
('Addons::name::hybrid_auth', 'Social login'),
('Addons::description::hybrid_auth', 'Adds the Social Login feature; allows customers use Facebook, Twitter, etc. to log in on the store'),
('SettingsSections::zapier::general', ''),
('SettingsOptions::zapier::text_general', ''),
('Languages::privileges.manage_zapier_hooks', 'Can edit'),
('Languages::privileges.view_zapier_hooks', 'Can view'),
('Languages::privilege_groups.zapier_hooks', 'Zapier hooks'),
('Languages::zapier.text_settings_general', 'Learn more about setting up integration <a target="_blank" href="[docs_url]user_guide/addons/zapier/index.html">in the documentation</a>.'),
('Addons::name::zapier', 'Integration with Zapier'),
('Addons::description::zapier', 'Allows you to integrate CS-Cart with over 4 000 other apps through Zapier.'),
('Languages::price_per_unit', 'Price per unit'),
('Languages::unit_name', 'Unit name'),
('Languages::unit_name_field_description', 'For example, ''ml'' or ''g'' without quotes.'),
('Languages::units_in_product', 'Units in product'),
('Languages::units_in_product_field_description', 'Required for automatic calculation of price per unit.'),
('Languages::show_price_per_x_units', 'Show price per X units'),
('Languages::show_price_per_x_units_field_description', 'For cases when you want to show price ''per 250 ml'' instead of ''per ml''.'),
('Addons::name::price_per_unit', 'Price per unit'),
('Addons::description::price_per_unit', 'Allows you to display price per unit on catalog and product pages.'),
('SettingsSections::gdpr::general', 'General'),
('SettingsOptions::gdpr::gdpr_cookie_consent', 'Cookie consent'),
('SettingsVariants::gdpr::gdpr_cookie_consent::none', 'None'),
('SettingsVariants::gdpr::gdpr_cookie_consent::implicit', 'Implicit'),
('SettingsVariants::gdpr::gdpr_cookie_consent::explicit', 'Explicit'),
('SettingsOptions::gdpr::privacy_policy_page', 'Privacy policy page'),
('SettingsOptions::gdpr::gdpr_cookie_consent_texts', ''),
('SettingsSections::gdpr::gdpr', 'GDPR'),
('SettingsOptions::gdpr::gdpr_settings', ''),
('SettingsOptions::gdpr::gdpr_settings_data', ''),
('Languages::gdpr.gdpr_user_data', 'GDPR user data'),
('Languages::gdpr_user_data', 'User personal data'),
('Languages::gdpr_user_profiles', 'Personal data from user profiles'),
('Languages::gdpr_product_subscriptions', 'Personal data from product subscriptions'),
('Languages::gdpr_agreements', 'Personal data from GDPR agreements'),
('Languages::gdpr.anonymize', 'Anonymize'),
('Languages::gdpr.text_anonymize_question', 'Once you anonymize someone, all their personal information will be replaced with randomly-generated data. This action can not be undone, unless you restore the database from a backup. Are you sure you want to proceed?'),
('Languages::gdpr.view_and_edit', 'View and edit'),
('Languages::gdpr_orders_data', 'Personal data from orders'),
('Languages::gdpr.full_agreement', 'Full agreement text'),
('Languages::gdpr.short_agreement', 'Short agreement text'),
('Languages::gdpr.checkout.place_order.personal_data_processing', 'Checkout: Place order: Personal data processing'),
('Languages::gdpr.checkout.place_order.agreement_text_full_personal_data_processing', '<p>We ([company]) send account-related emails (such as order status notifications, password reset emails, and more) to the provided email address. For that reason we need to store your email address while you remain our customer.</p> <p>We use the information in the billing/shipping address section and may send it to a shipping or payment method provider to:</p> <ul> <li>Determine what shipping and payment methods are available for your location. </li> <li>Complete the payment or shipping process via the provider that you choose at checkout when you submit the order.</li> </ul> <p>Some members of our staff and/or vendors who sell products in our store and use its administration panel may be able to access your data. We value your privacy, so the access to data is provided on a need-to-know basis in order to operate the store. For example, a vendor only receives your data if you ordered something from them, so that the vendor can fulfil that order.</p> <p>If you decide that you no longer want to use our store and would like to have your personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('Languages::gdpr.checkout.place_order.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows.</u>'),
('Languages::gdpr.user.registration.personal_data_processing', 'Customer: registration'),
('Languages::gdpr.user.registration.agreement_text_full_personal_data_processing', '<p>Email addresses distinguish customers from each other. You sign in to the store by entering the email address and the password you provide here.</p> <p>We ([company]) also send account-related emails (such as order status notifications, password reset emails, and more) to the provided email address. For that reason we need to store your email address while you remain our customer.</p> <p>Other profile fields that may or not be present on this page are stored alongside your email address. We may use this information to contact you, if the necessity arises.</p> <p>Some members of our staff and/or vendors who sell products in our store and use its administration panel may be able to access your data. We value your privacy, so the access to data is provided on a need-to-know basis in order to operate the store. For example, a vendor only receives your data if you ordered something from them, so that the vendor can fulfil that order.</p> <p>If you decide that you no longer want to use our store and would like to have your personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('Languages::gdpr.user.registration.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows.</u>'),
('Languages::gdpr.profiles.update.personal_data_processing', 'Profiles: update'),
('Languages::gdpr.profiles.update.agreement_text_full_personal_data_processing', '<p>Email addresses distinguish customers from each other. You sign in to the store by entering the email address and the password you provide here.</p> <p>We ([company]) also send account-related emails (such as order status notifications, password reset emails, and more) to the provided email address. For that reason we need to store your email address while you remain our customer.</p> <p>Other profile fields that may or not be present on this page are stored alongside your email address. We may use this information to contact you, if the necessity arises.</p> <p>We use the information in the billing/shipping address section and may send it to a shipping or payment method provider to:</p> <ul> <li>Determine what shipping and payment methods are available for your location.</li> <li>Complete the payment or shipping process via the provider that you choose at checkout when you submit the order.</li> </ul> <p>Some members of our staff and/or vendors who sell products in our store and use its administration panel may be able to access your data. We value your privacy, so the access to data is provided on a need-to-know basis in order to operate the store. For example, a vendor only receives your data if you ordered something from them, so that the vendor can fulfil that order.</p> <p>If you decide that you no longer want to use our store and would like to have your personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p> '),
('Languages::gdpr.profiles.update.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows.</u>'),
('Languages::gdpr.vendor.apply.personal_data_processing', 'Vendor: apply for vendor'),
('Languages::gdpr.vendor.apply.agreement_text_full_personal_data_processing', '<p>Because vendors sell products in our marketplace, we ([company]) have to request certain information about them. For example, the company name and description of a vendor are shown to customers and serve to distinguish vendors from each other; the address is used for shipping rate calculation.</p> <p>However, we also request some personal data, such as first name/last name and emails address. Those are necessary for creating a vendor’s administrator account in our system. Vendors work with the marketplace through such accounts. Email addresses are necessary because they distinguish administrators from each other. You sign in to the store by entering the email address you provide here. Names are necessary because a single vendor can have multiple administrators—it is easier to handle accountability that way.</p> <p>We also send account-related emails (such as order status notifications, password reset emails, and more) to the provided email address. For that reason we need to store your email address while you remain our customer. If you decide that you no longer want to work with our marketplace and would like to have personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('Languages::gdpr.vendor.apply.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows.</u>'),
('Languages::gdpr.products.subscribe.personal_data_processing', 'Products: subscribe'),
('Languages::gdpr.products.subscribe.agreement_text_full_personal_data_processing', '<p>We ([company]) will add your email address to a special mailing list for this product. Once the product is in stock, you’ll get an email about it automatically, and your email address will be removed from the product’s mailing list.</p> <p>The data will be visible to some members of our staff. If you’d like to have your personal data removed, send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('Languages::gdpr.products.subscribe.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows.</u>'),
('Languages::gdpr.checkout.profiles_update.personal_data_processing', 'Checkout: profiles update'),
('Languages::gdpr.checkout.profiles_update.agreement_text_full_personal_data_processing', '<p>We ([company]) send account-related emails (such as order status notifications, password reset emails, and more) to the provided email address. For that reason we need to store your email address while you remain our customer.</p> <p>We use the information in the billing/shipping address section and may send it to a shipping or payment method provider to:</p> <ul> <li>Determine what shipping and payment methods are available for your location. </li> <li>Complete the payment or shipping process via the provider that you choose at checkout when you submit the order.</li> </ul> <p>Some members of our staff and/or vendors who sell products in our store and use its administration panel may be able to access your data. We value your privacy, so the access to data is provided on a need-to-know basis in order to operate the store. For example, a vendor only receives your data if you ordered something from them, so that the vendor can fulfil that order.</p> <p>If you decide that you no longer want to use our store and would like to have your personal data removed from our database (or if you’d like to get all the personal data associated with your account that we have), please send an email to [email].</p> <p>If you believe that your personal data has been misused, you have the right to lodge a complaint with a supervisory authority. We’re obliged by EU General Data Protection Regulation to let you know about this right; we don’t actually intend to misuse your data.</p>'),
('Languages::gdpr.checkout.profiles_update.agreement_text_short_personal_data_processing', 'I agree to have my personal data <u>processed as follows</u>.'),
('Languages::gdpr.export_to_xml', 'Export to XML'),
('Languages::gdpr.agreement_required_error', 'Your agreement is required to proceed.'),
('Languages::gdpr.user_anonymized', 'User has been anonymized.'),
('Languages::gdpr.check_other_sources_for_personal_data', '<p>Please note that anonymization doesn''t affect any backups and logs that you might have. If necessary, please do the following:</p><ol><li>Clear the logs under <b>Administration → Logs</b>.</li><li>Secure and delete the backups you might have under <b>Administration → Backup/Restore</b>.</li></ol>'),
('Languages::gdpr.cookie_consent', 'Cookie consent'),
('Languages::gdpr.cookie_consent_message', '<p>This website uses cookies (small pieces of data saved on your computer). Some cookies are added by the website itself: they help to show you the content of your cart, keep you signed in once you enter your email and password, preserve your preferences, and do a lot of other useful things. We use these cookies only to make the site work properly for you. Even your agreement to our use of cookies is stored as a cookie.</p><p>Other cookies may be used by third-party services (such as PayPal, YouTube, Google Maps, Facebook, etc.) to store the data about how you use those third-party services on the website. We have no control over how third parties use cookies, but those cookies are also important for proper functioning of the website. For example, some of the PayPal functionality may not work without PayPal cookies.</p><p>Without cookies, many things can go wrong. That''s why we ask that you agree to cookies being used before you proceed. If you don''t want any cookies but would like to continue using the website, please configure your browser to block cookies, and then you''ll be able to "agree" to their use, while we won''t treat that as your consent.</p>'),
('Languages::gdpr.cookie_consent_accept', 'I agree'),
('Languages::gdpr.cookie_consent_decline', 'No, take me out of here'),
('Languages::gdpr.uk_cookies_law', 'Cookies are used on this site to provide the best user experience. If you continue, we assume that you agree to receive cookies from this site.'),
('Languages::block_gdpr', 'GDPR'),
('Languages::gdpr', 'GDPR'),
('Languages::block_gdpr_description', 'Allows registered users to request their personal data or anonymization'),
('Languages::gdpr.user_profile_actions_description', '<p>As customers interact with the store, they provide personal data for various purposes. When you place an order, we need to know where to ship it; when you subscribe for an email newsletter, we need to know where to send it, and so on. We keep this data organized, so that you always could:</p> <ol> <li>Request that we send you all your personal data. In that case we’ll send you an XML file by email. That file will contain all your personal data we have.</li> <li>Request to be forgotten. In that case your account will be deactivated, and all your personal data will be removed. If necessary, you’ll be able to register a new account with the same email address in the future.</li> </ol> <p>Please note that we’ll need some time to process either of those requests. We may contact you regarding your request by email or through other means.</p>'),
('Languages::gdpr.send_my_data', 'Send me my data'),
('Languages::gdpr.send_my_data_description', '<p>We’ll send you an XML file with all your personal data we have. Please note that we’ll need some time to process this request, so the email with your XML file won’t be sent immediately. If you have any comments regarding your request, please leave them in the field below.</p>'),
('Languages::gdpr.email_subject_personal_data_request', 'Personal Data Copy Request: [customer_email]'),
('Languages::gdpr.email_body_personal_data_request', '<p><a href="[user_profile_url]" target="_blank">[user]</a> with the email address [customer_email] has requested a copy of personal data with the following comment:</p> <p>[comment]</p> <p>Click the link at the beginning of this message and use the corresponding button on the customer profile page in the Administration panel to get the data in the XML format. After that, send the XML file to the customer.</p>'),
('Languages::gdpr.remove_my_data', 'Remove my data'),
('Languages::gdpr.remove_my_data_description', '<p>We’ll deactivate your account and remove all your personal data from it. After that you won’t be able to sign in. However, you’ll be able to register a new account with the same email address in the future. Please note that we’ll need some time to process this request, so your account won’t be deactivated immediately. If you have any comments regarding your request, please leave them in the field below.</p>'),
('Languages::gdpr.email_subject_anonymization_request', 'Personal Data Removal Request: [customer_email]'),
('Languages::gdpr.email_body_anonymization_request', '<p><a href="[user_profile_url]" target="_blank">[user]</a> with the email address [customer_email] has requested the removal of personal data with the following comment:</p> <p>[comment]</p> <p>Click the link at the beginning of this message and use the corresponding button on the customer profile page in the Administration panel to anonymize the customer.</p> <p>Please note that <b>this action will replace all the personal data of the customer</b> with randomly generated data. It’s best to make sure that all business with the customer (such as orders and return requests) is concluded before you do that.</p>'),
('Languages::gdpr.user_action_request_success', 'Your request has been sent successfully.'),
('Languages::gdpr.user_action_request_fail', 'An error has occurred during the attempt to send your request. Please try again or send a message to the following email address: <a href="mailto:[email]">[email]</a>'),
('Languages::gdpr.agreement_variables_hint', '<p>The texts of the agreements listed below may have <b>[email]</b> or <b>[company]</b> in them. Those are placeholders that will be automatically replaced with actual data when customers see the agreements. If you only have one storefront, the data for the placeholders will be taken from <a href="[company_settings_url]" target="_blank">Settings → Company</a>. If you have multiple storefronts, the data will be taken from the settings of the storefront that a customer visits:</p><ul><li><b>[company]</b> will be taken from <i>Company name</i>.</li><li><b>[email]</b> will be taken from <i>User department e-mail address</i>.</li></ul>'),
('Languages::gdpr.agreement_variables_hint_mve', '<p>The texts of the agreements listed below may have <b>[email]</b> or <b>[company]</b> in them. Those are placeholders that will be automatically replaced with actual data when customers see the agreements. The data for placeholders will be taken from <a href="[company_settings_url]" target="_blank">Settings → Company</a>:</p><ul><li><b>[company]</b> will be taken from <i>Company name</i>.</li><li><b>[email]</b> will be taken from <i>User department e-mail address</i>.</li></ul>'),
('Languages::gdpr.strictly_necessary_cookies_title', 'Strictly necessary cookies'),
('Languages::gdpr.strictly_necessary_cookies_description', 'These cookies are essential for the website to work properly. For example, they let you place an order, or help the site remember that you''ve signed into your account. That''s why they can''t be disabled through the site. You can configure your browser to disable even these cookies, but important parts of the site won''t work without them.'),
('Languages::gdpr.performance_cookies_title', 'Performance cookies'),
('Languages::gdpr.performance_cookies_description', 'These cookies allow us to see how the website works. The information that these cookies help to collect is anonymous; it is typically presented in numbers. For example, these cookies help us see how often errors occur, how many unique visitors we have, or how long each page is viewed on average. Thanks to these cookies, we can improve the site for you.'),
('Languages::gdpr.functional_cookies_title', 'Functional cookies'),
('Languages::gdpr.functional_cookies_description', 'These cookies enable additional functionality at the website. They may be set by third-party providers whose services we''ve added to the website. Those services may include many things, like maps, geolocation for preliminary shipping rate calculation, or the ability to sign in with your social network account. Without functional cookies, the parts of the site associated with these services may not work properly.'),
('Languages::gdpr.marketing_cookies_title', 'Marketing cookies'),
('Languages::gdpr.marketing_cookies_description', 'These cookies are used by our advertising partners. They help them to measure promotion efficiency and serve you ads that are more relevant and less repetitive. This is usually achieved by remembering the browser and device that saw the ad. Turning these cookies off won''t reduce the number of ads you see on the internet, but will make them less personalized.'),
('Languages::gdpr.eway_cookies_title', 'eWAY'),
('Languages::gdpr.eway_cookies_description', 'eWAY is a payment provider. It allows us to accept payments, if you choose a payment method powered by eWAY. Here is <a href="https://www.eway.com.au/privacy-policy/" target="_blank">eWAY privacy policy</a>.'),
('Languages::gdpr.klaro_privacy_policy_title', 'You can find out more in this document: {privacyPolicy}.'),
('Languages::gdpr.klaro_privacy_policy_name', 'Privacy policy'),
('Languages::gdpr.klaro_service', 'service'),
('Languages::gdpr.klaro_services', 'services'),
('Languages::gdpr.klaro_accept_all', 'Accept all'),
('Languages::gdpr.klaro_accept_selected', 'Accept selected'),
('Languages::gdpr.klaro_close', 'Close'),
('Languages::gdpr.klaro_consent_modal_description', 'Here you can assess and customize the services (and their respective cookies) that we''d like to use on this website. You''re in charge! Enable or disable services as you see fit.'),
('Languages::gdpr.klaro_consent_modal_title', 'Cookies we would like to use'),
('Languages::gdpr.klaro_consent_notice_change_description', 'There were changes since your last visit, please renew your consent.'),
('Languages::gdpr.klaro_consent_notice_title', 'Cookie Consent'),
('Languages::gdpr.klaro_consent_notice_description', 'Hi! Could we please enable some additional services that require cookies? You can always change or withdraw your consent later.'),
('Languages::gdpr.klaro_consent_notice_learn_more', 'Let me choose'),
('Languages::gdpr.klaro_consent_notice_testing', 'Testing mode!'),
('Languages::gdpr.klaro_contextual_consent_accept_always', 'Always'),
('Languages::gdpr.klaro_contextual_consent_accept_once', '''Yes'''),
('Languages::gdpr.klaro_contextual_consent_description', 'Do you want to load external content supplied by {title}?'),
('Languages::gdpr.klaro_decline', 'I decline'),
('Languages::gdpr.klaro_ok', 'That''s ok'),
('Languages::gdpr.klaro_powered_by', 'Realized with Klaro!'),
('Languages::gdpr.klaro_service_purpose', 'purpose'),
('Languages::gdpr.klaro_service_purposes', 'purposes'),
('Languages::gdpr.klaro_service_required_description', 'This service is always required'),
('Languages::gdpr.disable_all_description', 'Use this switch to enable or disable all services.'),
('Languages::gdpr.disable_all_title', 'Enable or disable all services'),
('Languages::gdpr.opt_out_description', 'This service is enabled by default (but you can opt out)'),
('Languages::gdpr.opt_out_title', '(opt-out)'),
('Languages::gdpr.klaro_service_required_title', '(always required)'),
('Languages::gdpr.cookie_consent_texts', 'Cookie consent texts'),
('Languages::gdpr.site_functionality_cookies_title', 'Site functionality'),
('Languages::gdpr.site_functionality_cookies_description', 'These cookies serve the essential functions of the site. For example, they help the site remember that you put something in the cart or signed into your account.'),
('SettingsTooltips::gdpr::gdpr_cookie_consent', '"Implicit consent" is a simple notification that the site uses cookies. "Explicit consent" means that visitors can select the services that can or can''t set cookies.'),
('Addons::name::gdpr', 'GDPR Compliance (EU)'),
('Addons::description::gdpr', 'Helps you to comply with GDPR (a European Union regulation on personal data) by showing customers info about their personal data, asking their consent for its processing, and by offering ways to delete or export personal data.'),
('Languages::shopify_import.shopify_products_import', 'Shopify products'),
('Languages::shopify_import.sync_data_name', 'Import products from Shopify'),
('Languages::shopify_import.choose_import_mode', 'Choose import mode'),
('Languages::shopify_import.import_for_all_vendors', 'I''m launching my marketplace and setting up products for all vendors to use'),
('Languages::shopify_import.import_for_specific_vendor', 'I''m importing these products for a specific vendor'),
('Languages::shopify_import.depends_on_common_products_addon', 'This option needs <a href="[link]">Common products for vendors</a> add-on to be installed'),
('Languages::shopify_import.invalid_csv_file_format', 'Uploaded CSV-file has invalid format or empty. Only files exported from Shopify supported.'),
('Languages::shopify_import.products_without_sku', 'The SKU value is missing for some products. These products are always imported as new objects.'),
('Languages::shopify_import.last_status.S', 'Success'),
('Languages::shopify_import.last_status.F', 'Failure'),
('Addons::name::shopify_import', 'Import from Shopify'),
('Addons::description::shopify_import', 'Allows you to import products from Shopify.'),
('Addons::name::tech_support_chat', 'Technical support chat'),
('Addons::description::tech_support_chat', 'Adds live chat with the technical support team in the Administration panel'),
('Addons::name::my_changes', 'My Changes (example add-on)'),
('Addons::description::my_changes', 'A dummy add-on to let devs see how add-ons work. You can also use it to introduce small changes not worthy of a separate add-on');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]pages`
--

CREATE TABLE `[[dbprefix]]pages` (
  `page_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `parent_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `id_path` varchar(255) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'A',
  `page_type` char(1) NOT NULL DEFAULT 'T',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `timestamp` int(11) NOT NULL DEFAULT '0',
  `usergroup_ids` varchar(255) NOT NULL DEFAULT '0',
  `localization` varchar(255) NOT NULL DEFAULT '',
  `new_window` tinyint(3) NOT NULL DEFAULT '0',
  `use_avail_period` char(1) NOT NULL DEFAULT 'N',
  `avail_from_timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `avail_till_timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `facebook_obj_type` varchar(64) NOT NULL,
  PRIMARY KEY (`page_id`),
  KEY `localization` (`localization`),
  KEY `parent_id` (`parent_id`),
  KEY `id_path` (`id_path`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=41 ;

--
-- Dumping data for table `[[dbprefix]]pages`
--

INSERT INTO `[[dbprefix]]pages` VALUES
(1, 1, 0, '1', 'A', 'T', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(2, 1, 0, '2', 'A', 'T', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(3, 1, 0, '3', 'A', 'T', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(4, 1, 0, '4', 'A', 'T', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(5, 1, 0, '5', 'A', 'T', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(6, 1, 0, '6', 'A', 'T', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(19, 1, 0, '19', 'A', 'T', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(20, 1, 0, '20', 'A', 'T', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(21, 1, 0, '21', 'A', 'T', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(22, 1, 0, '22', 'A', 'T', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(23, 1, 0, '23', 'A', 'T', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(7, 1, 0, '7', 'A', 'B', 0, 1415336000, '0', '', 0, 'N', 0, 0, ''),
(8, 1, 7, '7/8', 'A', 'B', 0, 1415316000, '0', '', 0, 'N', 0, 0, ''),
(30, 1, 0, '30', 'A', 'F', 0, 1208808000, '0', '', 0, 'N', 0, 0, ''),
(40, 1, 0, '40', 'A', 'P', 0, 1251115200, '0', '', 0, 'N', 0, 0, '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]page_descriptions`
--

CREATE TABLE `[[dbprefix]]page_descriptions` (
  `page_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `page` varchar(255) DEFAULT '0',
  `description` mediumtext,
  `meta_keywords` varchar(255) NOT NULL DEFAULT '',
  `meta_description` varchar(255) NOT NULL DEFAULT '',
  `page_title` varchar(255) NOT NULL DEFAULT '',
  `link` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`page_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]page_descriptions`
--

INSERT INTO `[[dbprefix]]page_descriptions` VALUES
(1, 'en', 'Our team', 'We have the best team ever!', '', '', '', ''),
(2, 'en', 'About our company', 'Put your company description here. HTML tags can be used in this description.', '', '', '', ''),
(3, 'en', 'Privacy policy', '<h1><span style="font-size: x-large;">Privacy Policy</span></h1>\n<p>&nbsp;</p>\n<h3>What information do we collect?</h3>\n<p>We collect information from you when you register on our site, place an order, subscribe to our newsletter or fill out a form.</p>\n<p>When ordering or registering on our site, as appropriate, you may be asked to enter your: name, e-mail address or mailing address. You may, however, visit our site anonymously.</p>\n<p>&nbsp;</p>\n<h3>What do we use your information for?</h3>\n<p>Any of the information we collect from you may be used in one of the following ways:</p>\n<ul>\n<li>To personalize your experience<br /> (your information helps us to better respond to your individual needs)</li>\n<li>To improve our website<br /> (we continually strive to improve our website offerings based on the information and feedback we receive from you)</li>\n<li>To improve customer service<br /> (your information helps us to more effectively respond to your customer service requests and support needs)</li>\n<li>To process transactions\n<ul>\n<li>Your information, whether public or private, will not be sold, exchanged, transferred, or given to any other company for any reason whatsoever, without your consent, other than for the express purpose of delivering the purchased product or service requested.</li>\n</ul>\n</li>\n<li>To administer a contest, promotion, survey or other site feature</li>\n<li>To send periodic emails<br />\n<ul>\n<li>The email address you provide for order processing, may be used to send you information and updates pertaining to your order, in addition to receiving occasional company news, updates, related product or service information, etc.</li>\n</ul>\nNote: If at any time you would like to unsubscribe from receiving future emails, we include detailed unsubscribe instructions at the bottom of each email.</li>\n</ul>\n<p>&nbsp;</p>\n<h3>How do we protect your information?</h3>\n<p>We implement a variety of security measures to maintain the safety of your personal information when you place an order or enter, submit, or access your personal information.</p>\n<p>We offer the use of a secure server. All supplied sensitive information is transmitted via Secure Socket Layer (SSL) technology and then encrypted into our Payment gateway providers database only to be accessible by those authorized with special access rights to such systems, and are required to keep the information confidential.</p>\n<p>&nbsp;</p>\n<h3>Do we use cookies?</h3>\n<p>Yes (Cookies are small files that a site or its service provider transfers to your computers hard drive through your Web browser (if you allow) that enables the sites or service providers systems to recognize your browser and capture and remember certain information).</p>\n<p>We use cookies to help us remember and process the items in your shopping cart, understand and save your preferences for future visits and keep track of advertisements.</p>\n<p>&nbsp;</p>\n<h3>Do we disclose any information to outside parties?</h3>\n<p>We do not sell, trade, or otherwise transfer to outside parties your personally identifiable information. This does not include trusted third parties who assist us in operating our website, conducting our business, or servicing you, so long as those parties agree to keep this information confidential. We may also release your information when we believe release is appropriate to comply with the law, enforce our site policies, or protect ours or others rights, property, or safety. However, non-personally identifiable visitor information may be provided to other parties for marketing, advertising, or other uses.</p>\n<p>&nbsp;</p>\n<h3>Third party links</h3>\n<p>Occasionally, at our discretion, we may include or offer third party products or services on our website. These third party sites have separate and independent privacy policies. We therefore have no responsibility or liability for the content and activities of these linked sites. Nonetheless, we seek to protect the integrity of our site and welcome any feedback about these sites.</p>\n<p>&nbsp;</p>\n<h3>Online Privacy Policy Only</h3>\n<p>This online privacy policy applies only to information collected through our website and not to information collected offline.</p>\n<p>&nbsp;</p>\n<h3>Your Consent</h3>\n<p>By using our site, you consent to our privacy policy.</p>\n<p>&nbsp;</p>\n<h3>Changes to our Privacy Policy</h3>\n<p>If we decide to change our privacy policy, we will post those changes on this page, and/or update the Privacy Policy modification date below.</p>\n<p>This policy was last modified on 01.12.2012</p>', '', '', '', ''),
(4, 'en', 'Free Returns', '<p>To guarantee customer satisfaction, we offer free returns for the products that for some reasons did not met our customer''s expectations.</p><p>You can create a return request right from your customer account.</p>', '', '', '', ''),
(5, 'en', 'Free Shipping', '<h2>On orders $19 and up</h2>\n<p>We will ship any product costing $19+ for free.</p><p><span style="color: rgb(165, 165, 165);">This offer is not applicable to e-goods and products with price lowered under $19 by a promotion or gift certificate.</span></p>', '', '', '', ''),
(6, 'en', 'Low Price Guarantee', '<p>We guarantee the lowest prices on the products presented in our store.</p><p>If you find a lower price for any of our products, offered by a designated online retailer, save the link and contact us.</p><p>After we verify that our competitor''s price is more attractive, we will lower ours to be at least as low!</p>', '', '', '', ''),
(19, 'en', 'Why Buy Gift Certificates', '<h1 class="ty-main-title">Why Gift Certificate Is The Best Present Nowadays\n\n</h1>\n\n<div class="ty-list-container clearfix">\n\n  <div class="ty-column4">\n\n      <div class="ty-gift-certificate__item">\n\n          <div class="ty-list-image" style="margin-bottom: 15px;">\n\n              <img src="images/companies/1/pages/gift1.jpg">\n\n          </div>\n\n          <div class="ty-list-text big" style="padding-top: 0;">\n\n                    How often do find yourself wondering what present you should buy for someone?\n\n              <br>\n\n                Choosing presents for friends is easier because you know their habits and preferences. But what about the people whom you know less?\n\n          </div>\n\n      </div>\n\n  </div>\n\n  <div class="ty-column4">\n\n      <div class="ty-gift-certificate__item">\n\n          <div class="ty-list-image" style="margin-bottom: 15px;">\n\n              <img src="images/companies/1/pages/gift2.jpg">\n\n          </div>\n\n          <div class="ty-list-text big" style="padding-top: 0;">\n\n                   There is hardly such a person who wants their present to gather dust in the cupboard and get thrown away during cleaning or given as a gift to someone else.\n\n          </div>\n\n      </div>\n\n  </div>\n\n  <div class="ty-column4">\n\n      <div class="ty-gift-certificate__item">\n\n          <div class="ty-list-image" style="margin-bottom: 15px;">\n\n              <img src="images/companies/1/pages/gift3.jpg">\n\n          </div>\n\n          <div class="ty-list-text big" style="padding-top: 0;">\n\n                   Not only does a present show care, but it also reminds about the person who gave it.\n\n          </div>\n\n      </div>\n\n  </div>\n\n  <div class="ty-column4">\n\n      <div class="ty-gift-certificate__item">\n\n          <div class="ty-list-image" style="margin-bottom: 15px;">\n\n              <img src="images/companies/1/pages/gift4.jpg">\n\n          </div>\n\n          <div class="ty-list-text big" style="padding-top: 0;">\n\n                   Give your friends a gift certificate of our store, and you can be sure that they will choose a present to their liking and will remember that you care!\n\n          </div>\n\n      </div>\n\n  </div>\n\n</div>\n\n<div style="margin-bottom: 40px;" class="ty-buttons-container ty-main-buttons ty-center">\n\n  <a href="index.php?dispatch=gift_certificates.add" class="ty-btn__primary ty-btn__big ty-btn">Buy a gift certificate</a>\n\n</div>\n\n', '', '', '', ''),
(20, 'en', 'Contacts', '<h1 class="ty-main-title">Contacts</h1>\r\n\r\n	<div class="ty-column4">\r\n		\r\n			<h4>\r\n				Address:\r\n			</h4>\r\n			<div>\r\n				3993 Hanover Street,\r\n				<br>\r\n				New York, NY 10016\r\n			</div>\r\n			<h4>\r\n				Email:\r\n			</h4>\r\n			<div>\r\n				<a href="mailto:sales@example.com">sales@example.com</a>\r\n			</div>\r\n			<h4>\r\n				Phone number:\r\n			</h4>\r\n			<div>\r\n				+19177227425\r\n			</div>\r\n			<div>\r\n				(call is free)\r\n			</div>\r\n	</div>\r\n	<div class="ty-column4 ty-float-right ty-notice">\r\n		<div>\r\n			<h5>\r\n				Working hours of the online store consultants:\r\n			</h5>\r\n			<p>\r\n				10 am — 6 pm\r\n			</p>\r\n			<p>\r\n				Monday to Friday\r\n			</p>\r\n			\r\n		</div>\r\n	</div>\r\n	<div class="ty-column1">\r\n		<iframe src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d17110.85805287818!2d-74.02359550400968!3d40.700381497733645!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x89c25a1666f508b9%3A0xb2e05654995e0aba!2zSGFub3ZlciBTdCwgTmV3IFlvcmssIE5ZIDEwMDA1LCDQodCo0JA!5e0!3m2!1sru!2sru!4v1475502492077" width="100%" height="400" frameborder="0" style="border:0" allowfullscreen="">\r\n		</iframe>\r\n	</div>\r\n	<div class="ty-column2">\r\n		<div>\r\n			<h3>\r\n			How to Reach Us\r\n			</h3>\r\n			<p>\r\n				We are located near Hanover St. bus stop. Once you get off the bus, walk towards the bank and turn left by the entrance. Walk 200 meters and turn right. Now go down the street until you see the Demo Store sign. Enter the doors under this sign.\r\n			</p>\r\n		</div>\r\n	</div>', '', '', '', ''),
(21, 'en', 'Returns and Exchanges', '<h1 class="ty-main-title">Policy on Returns and Exchanges</h1>\r\n<div class="ty-list-container ty-decimal">\r\n	<div class="ty-column5">\r\n		<div class="ty-refund__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/refund_b1.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				<span class="ty-list-item">1</span>Pack all the items in the original packing. Items bought as sets must be returned in sets.\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column5">\r\n		<div class="ty-refund__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/refund_b2.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				<span class="ty-list-item">2</span>Fill in the return request form attached to the order.\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column5">\r\n		<div class="ty-refund__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/refund_b3.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				<span class="ty-list-item">3</span>Attach a copy of the sales check, specify the method of refund (a postal order or a transfer to the bank account).\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column5">\r\n		<div class="ty-refund__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/refund_b1.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				<span class="ty-list-item">4</span>Send the parcel to this address:<br>\r\n				3993 Hanover Street, New York, NY 10016\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column5">\r\n		<div class="ty-refund__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/refund_b5.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				<span class="ty-list-item">5</span>After you have sent the parcel, please inform us of that by sending an email to <a href="mailto:sales@example.com">sales@example.com</a>.\r\n			</div>\r\n		</div>\r\n	</div>\r\n</div>\r\n<h2 class="ty-main-title">Eligibility of Items for Return or Exchange</h2>\r\n<div class="ty-list-container ty-column2">\r\n	<div class="ty-column3-1">\r\n		<div class="ty-list-image">\r\n		</div>\r\n	</div>\r\n	<div class="ty-column3-2">\r\n		<div class="ty-list-text big">\r\n			Customers have the right to return any purchased items without defining the reason within\r\n			<span class="ty-red">14 (fourteen) calendar days</span> from the moment of receiving those items from the Seller or the Seller''s representatives. The items can be returned if their consumer properties, factory labels, and ready-for-sale condition are preserved.\r\n			<br>\r\n			<br>\r\n			To return the items, Customers must submit the copy of proof of purchase and fill in the return request form.\r\n			<br>\r\n			<br>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column3-1">\r\n	</div>\r\n	<div class="ty-column3-1">\r\n		<div class="ty-list-image">\r\n		</div>\r\n	</div>\r\n	<div class="ty-column3-2">\r\n		<div class="ty-list-text big">\r\n			Rules on returning and exchanging Items with discovered defects:\r\n			<br>\r\n			<br>\r\n			Customers are entitled to notify the Seller of any discovered defects and demand to rectify them within\r\n			<span class="ty-red">30 (thirty) calendar days</span> from the moment of the receiving the Items from the Seller or the Seller''s representatives. The only exception are defects caused by improper handling of the Items by the Customer.\r\n			<br>\r\n			<br>\r\n			Customers have the right to refuse to take Items and ask for a money refund. In this case the Items must be returned to the Seller, and their consumer properties, factory labels, and ready-for-sale condition are preserved.\r\n			<br>\r\n			<br>\r\n			To return the Items, you must submit the copy of proof of purchase and fill in the return request form.\r\n			<br>\r\n			<br>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column3-2">\r\n	</div>\r\n</div>\r\n<div class="ty-about-container ty-flag-left ty-list-container">\r\n	<div class="ty-notice clearfix">\r\n		<div class="ty-about-banner ty-column7">\r\n			<img src="images/companies/1/pages/about_flag.png">\r\n		</div>\r\n		<div class="ty-about-description ty-column2 ty-list-text big">\r\n				Our return and refund policy is described above. According to NYS law, stores are legally required to post their refund policy. If a store does not post any return policy, the law requires the store to accept returns within 30 days of purchase.\r\n		</div>\r\n	</div>\r\n</div>', '', '', '', ''),
(22, 'en', 'Payment and shipping', '<h1 class="ty-main-title">Shipping</h1>\r\n<div class="ty-list-container">\r\n	<div class="ty-column4">\r\n		<div class="ty-delivery__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/delivery_calc.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				The cost and delivery time of your order are estimated online at the checkout.\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column4">\r\n		<div class="ty-delivery__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/delivery_calc_w.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				The estimation is performed according to the weight of items and their destination.\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column4">\r\n		<div class="ty-delivery__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/delivery_ship.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				We deliver orders anywhere in the U.S. and to 230 countries all over the world.\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column4">\r\n		<div class="ty-delivery__item">\r\n		</div>\r\n	</div>\r\n</div>\r\n<div class="ty-column1" style="\r\n    background-color: #ffee3c; padding-top:30px;">\r\n	<div class="clearfix">\r\n		<div class="ty-column7" style="\r\n    text-align: center;\r\n">\r\n			<img src="images/companies/1/pages/delivery_car.jpg" data-pin-nopin="true">\r\n		</div>\r\n		<div class="ty-column2">\r\n			<p>\r\n				If your order total amounts to\r\n			</p>\r\n			<p style="font-size: 2em; padding: 0px;">\r\n				3000$ or more,\r\n			</p>\r\n			<p class="subheader">\r\n				we will deliver your order to any place in the U.S. or Canada\r\n			</p>\r\n			<h2 class="ty-uppercase" style="margin: 0px;">FOR FREE</h2>\r\n		</div>\r\n	</div>\r\n</div>\r\n<h2 class="ty-main-title2">Shipping methods</h2>\r\n<div class="ty-list-container">\r\n	<div class="ty-column4">\r\n		<div class="ty-delivery__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/delivery_person.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				A courier can deliver your order right to your doorstep.\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column4">\r\n		<div class="ty-delivery__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/delivery_own.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				You can also receive your order in one of Customer\r\n              Pick Up Centers.\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column4">\r\n		<div class="ty-delivery__item">\r\n		</div>\r\n	</div>\r\n	<div class="ty-column4">\r\n		<div class="ty-delivery__item">\r\n		</div>\r\n	</div>\r\n</div>\r\n<h2 style="padding-top: 60px" class="ty-main-title">Payment</h2>\r\n<div class="ty-list-container">\r\n	<div class="ty-column5">\r\n		<div class="ty-delivery__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/payment_person.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				Pay the courier on delivery.\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column5">\r\n		<div class="ty-delivery__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/payment_ccard.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				Pay with a Visa or Master Visa card either when you place an order in our store, or right on delivery—the courier has the terminal.\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column5">\r\n		<div class="ty-delivery__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/payment_sbrf.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				Print and pay the receipt, then send the scanned copy of the received payment document to\r\n				<a href="mailto:sales@example.com">sales@example.com</a>.\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column5">\r\n		<div class="ty-delivery__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/payment_bill.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				Cashless payment (invoices). This method is best for organizations. Place an order, print the received invoice, pay it, and contact us to know the order delivery date.\r\n			</div>\r\n		</div>\r\n	</div>\r\n	<div class="ty-column5">\r\n		<div class="ty-delivery__item">\r\n			<div class="ty-list-image">\r\n				<img src="images/companies/1/pages/payment_mobile.jpg">\r\n			</div>\r\n			<div class="ty-list-text big">\r\n				Payment via mobile phone\r\n			</div>\r\n		</div>\r\n	</div>\r\n</div>\r\n<div style="padding: 48px 0 48px; height: 1px;">\r\n</div>', '', '', '', ''),
(23, 'en', 'Reward points', '<h1 class="ty-main-title">\r\n	Save Money—Pay in Reward Points\r\n</h1>\r\n\r\n	<div class="ty-column2">\r\n		<img class="ty-image" src="images/companies/1/pages/reward-points-1.png">\r\n	</div>\r\n	<div class="ty-column2">\r\n		<div class="ty-column1 ty-notice">\r\n		<p>\r\n			When you purchase goods in our store, you get reward points.\r\n		</p>\r\n		<p>\r\n			You can use them at any time—we think that earned reward points shouldn’t expire, like it happens in some other stores.\r\n		</p>\r\n		</div>\r\n		<div class="ty-column1">\r\n			<h3>See how many points you have</h3>\r\n			<div >\r\n				<img class="ty-image" src="images/companies/1/pages/reward-points-3.png">\r\n			</div>\r\n		</div>\r\n	</div>\r\n	\r\n	<div class="ty-column1 ty-notice">\r\n		<h3>Use your reward points</h3>\r\n		<div >\r\n			<img src="images/companies/1/pages/reward-points-2.png">\r\n		</div>\r\n		<div class="ty-column1">\r\n			<p>\r\n<br>				When on the checkout page, enter the amount of reward points you want to spend in the field on the right. The sum you have to pay will be recalculated automatically.\r\n			</p>\r\n		</div>\r\n	</div>\r\n	\r\n', '', '', '', ''),
(7, 'en', 'Blog', '', '', '', '', ''),
(8, 'en', 'Check out CS-Cart Marketplace', '<p>CS-Cart is feature-packed out of the box. But if you’re looking for something more for your project, we have CS-Cart Marketplace — the official store with add-ons and themes for CS-Cart.</p><div style="text-align: center; margin: 15px auto;"><a class="button ty-btn ty-btn__primary" href="https://marketplace.cs-cart.com/" title="GO TO MARKETPLACE" target="_blank">GO TO MARKETPLACE</a></div><p>Make your CS-Cart store more powerful, beautiful, functional, and user-friendly.</p><!--CUT--><p>CS-Cart Marketplace can help you:<ul><li>extend the functionality of your site;</li><li>create a unique look and feel for it;</li><li>get extra tools for promoting the site, and more;</li><li>save your time for what’s really important.</li></ul></p><p>Filter add-ons by their developer and field of use; choose them by rating, reviews, and compatibility with your CS-Cart version. If you have questions on some add-on or theme, contact its developer right from the product page.</p>', '', '', '', ''),
(30, 'en', 'Contact us', 'You can send us a message using the form below.', '', '', '', ''),
(40, 'en', 'Poll of the week', '', '', '', '', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]payments`
--

CREATE TABLE `[[dbprefix]]payments` (
  `payment_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `usergroup_ids` varchar(255) NOT NULL DEFAULT '0',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'A',
  `template` varchar(128) NOT NULL DEFAULT '',
  `processor_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `processor_params` text,
  `a_surcharge` decimal(13,3) NOT NULL DEFAULT '0.000',
  `p_surcharge` decimal(13,3) NOT NULL DEFAULT '0.000',
  `tax_ids` varchar(255) NOT NULL DEFAULT '',
  `localization` varchar(255) NOT NULL DEFAULT '',
  `payment_category` varchar(20) NOT NULL DEFAULT 'tab1',
  PRIMARY KEY (`payment_id`),
  KEY `c_status` (`usergroup_ids`,`status`),
  KEY `position` (`position`),
  KEY `localization` (`localization`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=12 ;

--
-- Dumping data for table `[[dbprefix]]payments`
--

INSERT INTO `[[dbprefix]]payments` VALUES
(1, 1, '0', 10, 'A', 'views/orders/components/payments/cc.tpl', 0, '', '0.000', '0.000', '', '', 'tab1'),
(2, 1, '0', 40, 'A', 'views/orders/components/payments/phone.tpl', 0, '', '0.000', '0.000', '', '', 'tab3'),
(5, 1, '0', 50, 'D', 'views/orders/components/payments/money.tpl', 0, '', '0.000', '0.000', '', '', 'tab3'),
(6, 1, '0', 60, 'D', 'views/orders/components/payments/cod.tpl', 0, '', '0.000', '0.000', '', '', 'tab3'),
(7, 1, '0', 70, 'D', 'views/orders/components/payments/po.tpl', 0, '', '0.000', '0.000', '', '', 'tab3'),
(8, 1, '0', 80, 'D', 'views/orders/components/payments/personal_check.tpl', 0, '', '0.000', '0.000', '', '', 'tab3'),
(10, 1, '0', 100, 'D', 'views/orders/components/payments/government_check.tpl', 0, '', '0.000', '0.000', '', '', 'tab3'),
(11, 1, '0', 110, 'D', 'views/orders/components/payments/travellers_check.tpl', 0, '', '0.000', '0.000', '', '', 'tab3');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]payment_descriptions`
--

CREATE TABLE `[[dbprefix]]payment_descriptions` (
  `payment_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `payment` varchar(128) NOT NULL DEFAULT '',
  `description` varchar(255) NOT NULL DEFAULT '',
  `instructions` mediumtext,
  `surcharge_title` varchar(255) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`payment_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]payment_descriptions`
--

INSERT INTO `[[dbprefix]]payment_descriptions` VALUES
(1, 'Credit card', 'Visa, Mastercard, etc...', '', '', 'en'),
(2, 'Phone ordering', 'Call +16175550123', '<h2>When I should use phone ordering?</h2><p>Order by phone is useful when regular payment methods like credit card are unavailable or considered insecure.</p><p>Our operators are happy to take your order per phone every business day from 9 a.m. to 5 p.m. UTC.</p>', '', 'en'),
(5, 'Money Order', 'US Banks Only', 'Type instructions to pay by visiting your retail store in here.', '', 'en'),
(6, 'C.O.D', 'Cashiers Check or Cash Only', 'Type instructions to pay by visiting your retail store in here.', '', 'en'),
(7, 'Purchase Order', '', 'Type instructions to pay by visiting your retail store in here.', '', 'en'),
(8, 'Personal Check', 'US Funds Only', 'Type instructions to pay by visiting your retail store in here.', '', 'en'),
(10, 'Government Check', 'US Funds Only', 'Type instructions to pay by visiting your retail store in here.', '', 'en'),
(11, 'Traveller''s Check', 'US Funds Only', 'Type instructions to pay by visiting your retail store in here.', '', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]payment_processors`
--

CREATE TABLE `[[dbprefix]]payment_processors` (
  `processor_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `processor` varchar(255) NOT NULL DEFAULT '',
  `processor_script` varchar(255) NOT NULL DEFAULT '',
  `processor_template` varchar(255) NOT NULL DEFAULT '',
  `admin_template` varchar(255) NOT NULL DEFAULT '',
  `callback` char(1) NOT NULL DEFAULT 'N',
  `type` char(1) NOT NULL DEFAULT 'P',
  `addon` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`processor_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=102 ;

--
-- Dumping data for table `[[dbprefix]]payment_processors`
--

INSERT INTO `[[dbprefix]]payment_processors` VALUES
(2, 'Authorize.Net AIM', 'authorizenet_aim.php', 'views/orders/components/payments/cc.tpl', 'authorizenet_aim.tpl', 'Y', 'P', ''),
(5, 'Virtual Merchant', 'virtual_merchant.php', 'views/orders/components/payments/cc.tpl', 'virtual_merchant.tpl', 'N', 'P', ''),
(6, '2Checkout', '2checkout.php', 'views/orders/components/payments/cc_outside.tpl', '2checkout.tpl', 'N', 'P', ''),
(7, 'ThaiePay', 'thaiepay.php', 'views/orders/components/payments/cc_outside.tpl', 'thaiepay.tpl', 'N', 'P', ''),
(10, 'FirstData Connect', 'firstdata_connect.php', 'views/orders/components/payments/cc_outside.tpl', 'firstdata_connect.tpl', 'N', 'P', ''),
(13, 'HSBC', 'hsbc.php', 'views/orders/components/payments/cc_outside.tpl', 'hsbc.tpl', 'N', 'P', ''),
(14, 'Opayo direct', 'sagepay_direct.php', 'views/orders/components/payments/cc_sagepay_direct.tpl', 'sagepay_direct.tpl', 'Y', 'P', ''),
(15, 'Opayo form', 'sagepay_form.php', 'views/orders/components/payments/cc_outside.tpl', 'sagepay_form.tpl', 'N', 'P', ''),
(19, 'Deprecated eWAY Direct Payment', 'eway_direct.php', 'views/orders/components/payments/cc.tpl', 'eway_direct.tpl', 'Y', 'P', ''),
(20, 'Nochex', 'nochex.php', 'views/orders/components/payments/cc_outside.tpl', 'nochex.tpl', 'Y', 'P', ''),
(21, 'Deprecated eWAY', 'eway_form.php', 'views/orders/components/payments/cc_outside.tpl', 'eway_form.tpl', 'N', 'P', ''),
(24, 'iDEAL Buckaroo', 'ideal_xml.php', 'views/orders/components/payments/cc_outside.tpl', 'ideal_xml.tpl', 'N', 'P', ''),
(26, 'Redsys', 'servired.php', 'views/orders/components/payments/cc_outside.tpl', 'servired.tpl', 'N', 'P', ''),
(27, 'Innovative', 'innovative.php', 'views/orders/components/payments/cc.tpl', 'innovative.tpl', 'Y', 'P', ''),
(28, 'DPS PX Post', 'dps_post.php', 'views/orders/components/payments/cc.tpl', 'dps_post.tpl', 'Y', 'P', ''),
(29, 'DPS PX Access', 'dps_access.php', 'views/orders/components/payments/cc_outside.tpl', 'dps_access.tpl', 'N', 'P', ''),
(30, 'Sage Payment Solutions', 'sage_payment.php', 'views/orders/components/payments/cc.tpl', 'sage_payment.tpl', 'Y', 'P', ''),
(31, 'Worldpay', 'worldpay.php', 'views/orders/components/payments/cc_outside.tpl', 'worldpay.tpl', 'N', 'P', ''),
(32, 'Payer', 'pay_read.php', 'views/orders/components/payments/cc_outside.tpl', 'pay_read.tpl', 'N', 'P', ''),
(33, 'ChronoPay', 'chronopay_form.php', 'views/orders/components/payments/cc_outside.tpl', 'chronopay_form.tpl', 'N', 'P', ''),
(37, 'Barclaycard ePDQ', 'epdq.php', 'views/orders/components/payments/cc_outside.tpl', 'epdq.tpl', 'Y', 'P', ''),
(39, 'ECHO (Intuit Payment Solutions)', 'echo.php', 'views/orders/components/payments/cc.tpl', 'echo.tpl', 'Y', 'P', ''),
(40, 'SCB', 'scb.php', 'views/orders/components/payments/cc_outside.tpl', 'scb.tpl', 'N', 'P', ''),
(42, 'Atos', 'atos.php', 'views/orders/components/payments/cc_outside.tpl', 'atos.tpl', 'N', 'P', ''),
(43, 'PayBox', 'paybox.php', 'views/orders/components/payments/cc_outside.tpl', 'paybox.tpl', 'N', 'P', ''),
(44, 'Ingenico (ex Ogone Direct)', 'ogone_direct.php', 'views/orders/components/payments/cc.tpl', 'ogone_direct.tpl', 'Y', 'P', ''),
(45, 'Ingenico (ex Ogone Web)', 'ogone_web.php', 'views/orders/components/payments/cc_outside.tpl', 'ogone_web.tpl', 'N', 'P', ''),
(48, 'SP Plus', 'spplus.php', 'views/orders/components/payments/cc_outside.tpl', 'spplus.tpl', 'N', 'P', ''),
(49, 'Intuit Merchant Services (QuickBooks Payments)', 'qbms.php', 'views/orders/components/payments/cc.tpl', 'qbms.tpl', 'Y', 'P', ''),
(50, 'CM-CIC', 'cmcic.php', 'views/orders/components/payments/cc_outside.tpl', 'cmcic.tpl', 'N', 'P', ''),
(52, 'Westpac', 'westpac.php', 'views/orders/components/payments/cc_outside.tpl', 'westpac.tpl', 'N', 'P', ''),
(53, 'FRIbetaling', 'fribetaling.php', 'views/orders/components/payments/cc.tpl', 'fribetaling.tpl', 'N', 'P', ''),
(54, 'Alpha e-Pay', 'deltapay.php', 'views/orders/components/payments/cc_outside.tpl', 'deltapay.tpl', 'N', 'P', ''),
(55, 'PayJunction', 'payjunction.php', 'views/orders/components/payments/cc.tpl', 'payjunction.tpl', 'Y', 'P', ''),
(56, 'iDEAL', 'ideal_basic.php', 'views/orders/components/payments/cc_outside.tpl', 'ideal_basic.tpl', 'N', 'P', ''),
(58, 'Datatrans', 'datatrans.php', 'views/orders/components/payments/cc_outside.tpl', 'datatrans.tpl', 'N', 'P', ''),
(59, 'Total Web Solutions Pay Page', 'totalwebpp.php', 'views/orders/components/payments/cc_outside.tpl', 'totalwebpp.tpl', 'N', 'P', ''),
(62, 'DIBS', 'dibs.php', 'views/orders/components/payments/cc_outside.tpl', 'dibs.tpl', 'N', 'P', ''),
(63, 'iTransact Standard Form', 'itransact_standard_form.php', 'views/orders/components/payments/cc.tpl', 'itransact.tpl', 'N', 'P', ''),
(64, 'iTransact Split Form', 'itransact_split_form.php', 'views/orders/components/payments/cc_outside.tpl', 'itransact.tpl', 'N', 'P', ''),
(65, 'Gate2Shop', 'gate2shop.php', 'views/orders/components/payments/cc_outside.tpl', 'gate2shop.tpl', 'N', 'P', ''),
(68, 'WorldNet TPS XML Gateway', 'worldnettpsxml.php', 'views/orders/components/payments/cc.tpl', 'worldnettpsxml.tpl', 'Y', 'P', ''),
(69, 'CRE Secure', 'cresecure.php', 'views/orders/components/payments/cc_outside.tpl', 'cresecure.tpl', 'N', 'P', ''),
(70, 'Winbank (Piraeus) Redirection', 'piraeus.php', 'views/orders/components/payments/cc_outside.tpl', 'piraeus.tpl', 'Y', 'P', ''),
(71, 'Sofort Banking', 'directebanking.php', 'views/orders/components/payments/cc_outside.tpl', 'directebanking.tpl', 'Y', 'P', ''),
(73, 'Payment 21 Simple API', 'p21_simple_api.php', 'views/orders/components/payments/p21_simple_api.tpl', 'p21_simple_api.tpl', 'N', 'P', ''),
(74, 'PayTrace', 'paytrace.php', 'views/orders/components/payments/cc.tpl', 'paytrace.tpl', 'Y', 'P', ''),
(75, 'Skrill QuickCheckout (ex Moneybookers)', 'skrill_qc.php', 'views/orders/components/payments/cc_outside.tpl', 'skrill_qc.tpl', 'Y', 'P', ''),
(76, 'Skrill eWallet (ex Moneybookers)', 'skrill_ewallet.php', 'views/orders/components/payments/cc_outside.tpl', 'skrill_ew.tpl', 'Y', 'P', ''),
(77, 'Worldpay Cardsave', 'cardsave_hosted.php', 'views/orders/components/payments/cc_outside.tpl', 'cardsave_hosted.tpl', 'N', 'P', ''),
(79, 'Merchant Warrior', 'merchant_warrior.php', 'views/orders/components/payments/cc.tpl', 'merchant_warrior.tpl', 'N', 'P', ''),
(80, 'Deprecated eWAY Shared Payment', 'eway_shared.php', 'views/orders/components/payments/cc_outside.tpl', 'eway_shared.tpl', 'Y', 'P', ''),
(81, 'PayLeap', 'payleap.php', 'views/orders/components/payments/cc.tpl', 'payleap.tpl', 'N', 'P', ''),
(82, 'DirectOne', 'direct_one.php', 'views/orders/components/payments/cc_outside.tpl', 'direct_one.tpl', 'N', 'P', ''),
(83, 'eMerchantPay (Secure Payment Form)', 'emerchantpay.php', 'views/orders/components/payments/cc_outside.tpl', 'emerchantpay.tpl', 'N', 'P', ''),
(84, 'Paysite-cash', 'paysitecash.php', 'views/orders/components/payments/cc_outside.tpl', 'paysitecash.tpl', 'N', 'P', ''),
(90, 'Deko', 'pay4later.php', 'views/orders/components/payments/cc_outside.tpl', 'pay4later.tpl', 'N', 'P', ''),
(92, 'eWAY Direct Payment (Rapid API)', 'eway_rapidapi_direct.php', 'views/orders/components/payments/cc_eway.tpl', 'eway_rapidapi.tpl', 'N', 'P', ''),
(95, 'eWAY Responsive Shared (Rapid API)', 'eway_rapidapi_rsp.php', 'views/orders/components/payments/cc_outside.tpl', 'eway_rapidapi_rsp.tpl', 'N', 'P', ''),
(98, 'Global Payments Remote', 'realex_remote.php', 'views/orders/components/payments/cc.tpl', 'realex_remote.tpl', 'N', 'P', ''),
(99, 'Global Payments Redirect', 'realex_redirect.php', 'views/orders/components/payments/cc_outside.tpl', 'realex_redirect.tpl', 'N', 'P', ''),
(100, 'RocketGate Native', 'rocketgate-native.php', 'views/orders/components/payments/cc.tpl', 'rocketgate-native.tpl', 'N', 'P', ''),
(101, 'PayPal Complete Payments', 'paypal_checkout.php', 'addons/paypal_checkout/views/orders/components/payments/paypal_checkout.tpl', 'paypal_checkout.tpl', 'Y', 'P', 'paypal_checkout');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]polls`
--

CREATE TABLE `[[dbprefix]]polls` (
  `page_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `start_date` int(11) unsigned NOT NULL DEFAULT '0',
  `end_date` int(11) unsigned NOT NULL DEFAULT '0',
  `show_results` char(1) NOT NULL DEFAULT 'V',
  PRIMARY KEY (`page_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]polls`
--

INSERT INTO `[[dbprefix]]polls` VALUES
(40, 0, 0, 'V');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]polls_answers`
--

CREATE TABLE `[[dbprefix]]polls_answers` (
  `answer_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `vote_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `item_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `comment` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`answer_id`,`vote_id`,`item_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]polls_votes`
--

CREATE TABLE `[[dbprefix]]polls_votes` (
  `vote_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `page_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `ip_address` varbinary(40) NOT NULL DEFAULT '',
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `time` int(11) NOT NULL DEFAULT '0',
  `type` char(1) NOT NULL DEFAULT '',
  PRIMARY KEY (`vote_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]poll_descriptions`
--

CREATE TABLE `[[dbprefix]]poll_descriptions` (
  `object_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `page_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `type` char(1) NOT NULL DEFAULT 'P',
  `description` mediumtext,
  PRIMARY KEY (`object_id`,`lang_code`,`type`),
  KEY `page_id` (`page_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]poll_descriptions`
--

INSERT INTO `[[dbprefix]]poll_descriptions` VALUES
(40, 40, 'en', 'H', ''),
(40, 40, 'en', 'F', ''),
(40, 40, 'en', 'R', ''),
(1, 40, 'en', 'I', 'How often do you buy DVDs?'),
(2, 40, 'en', 'I', 'Once per week.'),
(3, 40, 'en', 'I', 'Every day.'),
(4, 40, 'en', 'I', 'Will buy my first right now!'),
(5, 40, 'en', 'I', 'Never, I prefer cinema.'),
(6, 40, 'en', 'I', 'Suggest your answer:');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]poll_items`
--

CREATE TABLE `[[dbprefix]]poll_items` (
  `item_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `parent_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `type` char(1) NOT NULL DEFAULT 'Q',
  `position` smallint(5) NOT NULL DEFAULT '0',
  `required` char(1) NOT NULL DEFAULT '',
  `page_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`item_id`),
  KEY `parent_id` (`parent_id`),
  KEY `type` (`type`),
  KEY `page_id` (`page_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=7 ;

--
-- Dumping data for table `[[dbprefix]]poll_items`
--

INSERT INTO `[[dbprefix]]poll_items` VALUES
(1, 40, 'Q', 1, 'Y', 40),
(2, 1, 'A', 1, '', 40),
(3, 1, 'A', 2, '', 40),
(4, 1, 'A', 3, '', 40),
(5, 1, 'A', 4, '', 40),
(6, 1, 'O', 5, '', 40);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]privileges`
--

CREATE TABLE `[[dbprefix]]privileges` (
  `privilege` varchar(32) NOT NULL DEFAULT '',
  `is_default` char(1) NOT NULL DEFAULT 'N',
  `section_id` varchar(32) NOT NULL DEFAULT '',
  `group_id` varchar(32) NOT NULL DEFAULT '',
  `is_view` char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (`privilege`),
  KEY `section_id` (`section_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]privileges`
--

INSERT INTO `[[dbprefix]]privileges` VALUES
('edit_order', 'Y', 'orders', 'orders', 'N'),
('create_order', 'Y', 'orders', 'orders', 'N'),
('view_orders', 'Y', 'orders', 'orders', 'Y'),
('change_order_status', 'Y', 'orders', 'orders', 'N'),
('delete_orders', 'Y', 'orders', 'orders', 'N'),
('update_order_details', 'Y', 'orders', 'orders', 'N'),
('view_reports', 'Y', 'orders', 'sales_reports', 'Y'),
('manage_reports', 'Y', 'orders', 'sales_reports', 'N'),
('view_catalog', 'Y', 'products', 'products', 'Y'),
('manage_catalog', 'Y', 'products', 'products', 'N'),
('view_users', 'Y', 'users', 'users', 'Y'),
('manage_users', 'Y', 'users', 'users', 'N'),
('view_usergroups', 'Y', 'users', 'user_groups', 'Y'),
('manage_usergroups', 'Y', 'users', 'user_groups', 'N'),
('view_shipping', 'Y', 'administration', 'shipping', 'Y'),
('manage_shipping', 'Y', 'administration', 'shipping', 'N'),
('view_taxes', 'Y', 'administration', 'taxes', 'Y'),
('manage_taxes', 'Y', 'administration', 'taxes', 'N'),
('view_locations', 'Y', 'administration', 'locations', 'Y'),
('manage_locations', 'Y', 'administration', 'locations', 'N'),
('view_payments', 'Y', 'administration', 'payments', 'Y'),
('manage_payments', 'Y', 'administration', 'payments', 'N'),
('view_settings', 'Y', 'settings', 'settings', 'Y'),
('update_settings', 'Y', 'settings', 'settings', 'N'),
('view_languages', 'Y', 'administration', 'languages', 'Y'),
('manage_languages', 'Y', 'administration', 'languages', 'N'),
('manage_translation', 'Y', 'design', 'edit_on_site', 'N'),
('manage_storage', 'Y', 'administration', 'storage', 'N'),
('view_static_data', 'Y', 'design', 'static_data', 'Y'),
('manage_static_data', 'Y', 'design', 'static_data', 'N'),
('upgrade_store', 'Y', 'administration', 'upgrade_center', 'N'),
('view_currencies', 'Y', 'administration', 'currencies', 'Y'),
('manage_currencies', 'Y', 'administration', 'currencies', 'N'),
('backup_restore', 'Y', 'administration', 'backup_restore', 'N'),
('edit_files', 'Y', 'administration', 'files', 'N'),
('edit_blocks', 'Y', 'design', 'blocks', 'N'),
('manage_sitemap', 'Y', 'website', 'sitemap', 'N'),
('manage_design', 'Y', 'design', 'design', 'N'),
('manage_themes', 'Y', 'design', 'themes', 'N'),
('view_pages', 'Y', 'website', 'blog_and_pages', 'Y'),
('manage_pages', 'Y', 'website', 'blog_and_pages', 'N'),
('view_logs', 'Y', 'administration', 'logs', 'Y'),
('delete_logs', 'Y', 'administration', 'logs', 'N'),
('manage_promotions', 'Y', 'marketing', 'promotions', 'N'),
('manage_order_statuses', 'Y', 'administration', 'order_statuses', 'N'),
('exim_access', 'Y', 'administration', 'exim', 'N'),
('manage_email_templates', 'Y', 'design', 'email_templates', 'N'),
('manage_document_templates', 'Y', 'design', 'documents', 'N'),
('view_file_changes', 'Y', 'administration', 'file_changes', 'Y'),
('manage_internal_templates', 'Y', 'design', 'internal_templates', 'N'),
('manage_notification_settings', 'Y', 'administration', 'notification_settings', 'N'),
('view_stores', 'Y', 'administration', 'stores', 'Y'),
('manage_stores', 'Y', 'administration', 'stores', 'N'),
('manage_admin_usergroups', 'Y', 'users', 'user_groups', 'N'),
('disable_sanitize_html', 'Y', 'administration', 'disable_sanitize_html', 'N'),
('view_newsletters', 'Y', 'marketing', 'newsletters', 'Y'),
('manage_newsletters', 'Y', 'marketing', 'newsletters', 'N'),
('view_email_marketing', 'Y', 'marketing', 'email_marketing', 'Y'),
('manage_email_marketing', 'Y', 'marketing', 'email_marketing', 'N'),
('manage_vendor_communication', 'Y', 'users', 'vendor_communication', 'N'),
('view_vendor_communication', 'Y', 'users', 'vendor_communication', 'Y'),
('manage_order_communication', 'Y', 'orders', 'order_communication', 'N'),
('view_order_communication', 'Y', 'orders', 'order_communication', 'Y'),
('manage_gift_certificates', 'Y', 'marketing', 'gift_certificates', 'N'),
('manage_store_locator', 'Y', 'administration', 'store_locator', 'N'),
('view_store_locator', 'Y', 'administration', 'store_locator', 'Y'),
('view_product_bundles', 'Y', 'marketing', 'product_bundles', 'Y'),
('manage_product_bundles', 'Y', 'marketing', 'product_bundles', 'N'),
('view_rma', 'Y', 'orders', 'rma', 'Y'),
('manage_rma', 'Y', 'orders', 'rma', 'N'),
('manage_seo_rules', 'Y', 'website', 'seo', 'N'),
('view_seo_rules', 'Y', 'website', 'seo', 'Y'),
('manage_reward_points', 'Y', 'marketing', 'reward_points', 'N'),
('manage_call_requests', 'Y', 'orders', 'call_requests', 'N'),
('view_call_requests', 'Y', 'orders', 'call_requests', 'Y'),
('manage_access_restrictions', 'Y', 'addons', 'access_restrictions', 'N'),
('view_banners', 'Y', 'marketing', 'banners', 'Y'),
('manage_banners', 'Y', 'marketing', 'banners', 'N'),
('view_discussions', 'Y', 'website', 'discussions', 'Y'),
('manage_discussions', 'Y', 'website', 'discussions', 'N'),
('view_product_reviews', 'Y', 'products', 'product_reviews', 'Y'),
('manage_product_reviews', 'Y', 'products', 'product_reviews', 'N'),
('create_product_reviews', 'Y', 'products', 'product_reviews', 'N'),
('manage_providers', 'Y', 'website', 'social_login', 'N'),
('view_providers', 'Y', 'website', 'social_login', 'Y'),
('manage_zapier_hooks', 'Y', 'administration', 'zapier_hooks', 'N'),
('view_zapier_hooks', 'Y', 'administration', 'zapier_hooks', 'Y');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]products`
--

CREATE TABLE `[[dbprefix]]products` (
  `product_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `product_code` varchar(64) NOT NULL DEFAULT '',
  `product_type` char(1) NOT NULL DEFAULT 'P',
  `status` char(1) NOT NULL DEFAULT 'A',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `list_price` decimal(12,2) NOT NULL DEFAULT '0.00',
  `amount` mediumint(8) NOT NULL DEFAULT '0',
  `weight` decimal(13,3) NOT NULL DEFAULT '0.000',
  `length` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `width` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `height` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `shipping_freight` decimal(12,2) NOT NULL DEFAULT '0.00',
  `low_avail_limit` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `updated_timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `usergroup_ids` varchar(255) NOT NULL DEFAULT '0',
  `is_edp` char(1) NOT NULL DEFAULT 'N',
  `edp_shipping` char(1) NOT NULL DEFAULT 'N',
  `unlimited_download` char(1) NOT NULL DEFAULT 'N',
  `tracking` char(1) DEFAULT NULL,
  `free_shipping` char(1) NOT NULL DEFAULT 'N',
  `zero_price_action` char(1) DEFAULT NULL,
  `is_pbp` char(1) NOT NULL DEFAULT 'N',
  `is_op` char(1) NOT NULL DEFAULT 'N',
  `is_oper` char(1) NOT NULL DEFAULT 'N',
  `is_returnable` char(1) NOT NULL DEFAULT 'Y',
  `return_period` int(11) unsigned NOT NULL DEFAULT '10',
  `avail_since` int(11) unsigned NOT NULL DEFAULT '0',
  `out_of_stock_actions` char(1) NOT NULL DEFAULT 'N',
  `localization` varchar(255) NOT NULL DEFAULT '',
  `min_qty` smallint(5) unsigned DEFAULT NULL,
  `max_qty` smallint(5) unsigned DEFAULT NULL,
  `qty_step` smallint(5) unsigned DEFAULT NULL,
  `list_qty_count` smallint(5) unsigned DEFAULT NULL,
  `tax_ids` varchar(255) NOT NULL DEFAULT '',
  `age_verification` char(1) NOT NULL DEFAULT 'N',
  `age_limit` tinyint(4) NOT NULL DEFAULT '0',
  `options_type` char(1) DEFAULT NULL,
  `exceptions_type` char(1) DEFAULT NULL,
  `details_layout` varchar(50) NOT NULL DEFAULT '',
  `shipping_params` varchar(255) NOT NULL DEFAULT '',
  `facebook_obj_type` varchar(64) NOT NULL,
  `parent_product_id` int(11) unsigned NOT NULL DEFAULT '0',
  `buy_now_url` varchar(255) NOT NULL,
  `units_in_product` decimal(12,3) unsigned NOT NULL DEFAULT '0.000',
  `show_price_per_x_units` decimal(12,3) unsigned NOT NULL DEFAULT '1.000',
  PRIMARY KEY (`product_id`),
  KEY `age_verification` (`age_verification`,`age_limit`),
  KEY `status` (`status`),
  KEY `idx_parent_product_id` (`parent_product_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=285 ;

--
-- Dumping data for table `[[dbprefix]]products`
--

INSERT INTO `[[dbprefix]]products` VALUES
(1, 'D00014MK1P', 'P', 'A', 1, '6499.99', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1383893806, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(4, 'E0004UBR1Y', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1170104400, 1383895417, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(5, 'B0005QJH6U', 'P', 'A', 1, '1199.99', 9, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1383893734, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(6, 'T0006UROBG', 'P', 'A', 1, '0.00', 12, '0.000', 0, 0, 0, '0.00', 0, 1328733200, 1328733200, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(7, 'A0007DQ1TL', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(8, 'W0008TGVI1', 'P', 'A', 1, '949.99', 9, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1383894057, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(9, 'F0009ORD06', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(10, 'L00102FQ97', 'P', 'A', 1, '0.00', 7, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(11, 'Z0011CZSNI', 'P', 'A', 1, '0.00', 49, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(12, 'U0012O5AF0', 'P', 'A', 1, '31.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1383893547, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(13, 'J00133PNYZ', 'P', 'A', 1, '12.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1383893653, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(14, 'M0014IVPFH', 'P', 'A', 1, '0.00', 14, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(15, 'H0015EXYM6', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(16, 'H00162EP2P', 'P', 'A', 1, '0.00', 6, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(17, 'G0017HS88V', 'P', 'A', 1, '0.00', 19, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(18, 'W0018W504I', 'P', 'A', 1, '0.00', 3, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(19, 'J001933ZYZ', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(20, 'M00209NIOG', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(21, 'J00216UKRV', 'P', 'A', 1, '0.00', 3, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(22, 'F0022TLB3Q', 'P', 'A', 1, '0.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(23, 'G0023968XZ', 'P', 'A', 1, '699.99', 1, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1383893895, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(24, 'R0024KODQ2', 'P', 'A', 1, '0.00', 13, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(25, 'R0025KFF65', 'P', 'A', 1, '0.00', 11, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(26, 'K00264EGJK', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(27, 'G0027IR79N', 'P', 'A', 1, '0.00', 39, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(28, 'R0028P1EHQ', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(29, 'T0029EAW9R', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(30, 'H00305TUE7', 'P', 'A', 1, '0.00', 23, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(31, 'D0031VJD0L', 'P', 'A', 1, '0.00', 30, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(32, 'T0032Q3082', 'P', 'A', 1, '0.00', 23, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(33, 'W00336L5NA', 'P', 'A', 1, '0.00', 19, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(34, 'W00341JAWN', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(35, 'Z0035X590V', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(36, 'B0036NZ0FU', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(37, 'L00379540B', 'P', 'A', 1, '0.00', 25, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(38, 'U003826PEJ', 'P', 'A', 1, '0.00', 30, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(39, 'X0039CB6XW', 'P', 'A', 1, '0.00', 14, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(40, 'A0040LYF7M', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(41, 'I0041AGKCY', 'P', 'A', 1, '0.00', 0, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(42, 'K0042BKTKR', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(43, 'N0043XCGKY', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(44, 'A0044UQ78W', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(45, 'Q0045PT1DZ', 'P', 'A', 1, '0.00', 16, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(46, 'T00466CBMY', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(47, 'J0047KCW09', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(48, 'O0048N7QAG', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(49, 'Q0049IN199', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(50, 'V0050M1GB0', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(51, 'H0051EAJD8', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(52, 'I0052GDLN3', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(53, 'B0053N10L0', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(54, 'I0054QMMPO', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(55, 'N005510VYI', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(56, 'L0056LL3EL', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(57, 'R0057SFAR6', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(58, 'I0058SG177', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(59, 'Q0059PALYI', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(60, 'O0060X7Y9Y', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(62, 'F00620YZ55', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(63, 'J0063Z8JWN', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(64, 'V0064ZVR98', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(65, 'O0065SHTHB', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684303, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(66, 'B00666E71X', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1328733200, 1328733200, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(67, 'J00670N9NC', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(68, 'U00684Y11J', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(69, 'U0069R50SC', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(70, 'Y0070SQYFT', 'P', 'A', 1, '0.00', 13, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(71, 'O0071FR7HZ', 'P', 'A', 1, '0.00', 14, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(72, 'N007221KA0', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(73, 'M0073Q30SG', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(74, 'S0074AE6U7', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(75, 'B00755AJUD', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(76, 'W00769N690', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328558400, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(78, 'L0078RO9Y9', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(79, 'Z0079TIUPW', 'P', 'A', 1, '98.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1383893667, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(80, 'M0080Z1B49', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(81, 'Y0081TT6SI', 'P', 'A', 1, '0.00', 40, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328684302, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(82, 'S0082Z8OYM', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328684999, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(83, 'X0083AILW7', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328684974, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(84, 'P0084TFPRL', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328685169, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(85, 'W0085XKO7V', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328685451, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(86, 'I0086KA0W2', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328688698, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(87, 'U008775P3X', 'P', 'A', 1, '0.00', 12, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328685629, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(88, 'E0088Z4YB8', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328685844, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(89, 'O0089OKQAX', 'P', 'A', 1, '0.00', 12, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328685961, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(90, 'Y0090CLU50', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328686050, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(91, 'W00918CYVW', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328686174, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(92, 'I00927PN4T', 'P', 'A', 1, '0.00', 2, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328686330, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(93, 'Y0093T69G8', 'P', 'A', 1, '0.00', 14, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328686601, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(94, 'A0094VY6U3', 'P', 'A', 1, '0.00', 19, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328686804, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(95, 'S0095VELIH', 'P', 'A', 1, '0.00', 24, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328686885, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(96, 'C0096T88CH', 'P', 'A', 1, '0.00', 4, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328686991, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(97, 'T0097H98EI', 'P', 'A', 1, '0.00', 25, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328687366, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(112, 'E011296HKW', 'P', 'A', 1, '0.00', 17, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328689291, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(113, 'P011376198', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328689575, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(100, 'V0100ZBORU', 'P', 'A', 1, '0.00', 22, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328687796, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(101, 'E01010TOGW', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328689008, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(102, 'E01027HIDS', 'P', 'A', 1, '0.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328687921, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(103, 'S0103G26P3', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328687966, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(104, 'N0104CXAWS', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328688139, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(105, 'M01052HXOG', 'P', 'A', 1, '0.00', 3, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328688147, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(106, 'C0106D3GWB', 'P', 'A', 1, '0.00', 12, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328688843, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(107, 'F01072HXUI', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328688367, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(108, 'I0108TD8BL', 'P', 'A', 1, '0.00', 30, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328688407, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(109, 'C01099FRFC', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328688446, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(110, 'E01105O46P', 'P', 'A', 1, '0.00', 13, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328688591, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(111, 'F0111O12WW', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328688824, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(114, 'U0114N9X4E', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328689543, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(115, 'N0115R3FDX', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328689740, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(116, 'P01160R6WH', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328689786, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(117, 'C0117E8CC7', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328690045, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(118, 'H0118GRDLH', 'P', 'A', 1, '0.00', 35, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328689973, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(119, 'R0119703TC', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328690116, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(120, 'B0120TBX2K', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328690335, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(121, 'L012149RZH', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328690204, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(122, 'J01223DYAH', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328690244, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(123, 'C0123RSXUU', 'P', 'A', 1, '0.00', 25, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328690301, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(124, 'D01245K7FF', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328690327, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(125, 'Y01252CY9O', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328690651, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(126, 'F01262AH0T', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328690546, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(127, 'A0127P1V0T', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328690720, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(128, 'K0128RATX3', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328690844, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(129, 'O0129GKRU9', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328691025, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(130, 'T0130501N7', 'P', 'A', 1, '0.00', 25, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328691276, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(131, 'I0131TAKCI', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328691363, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(132, 'S0132PANHE', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328691987, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(133, 'I0133JJ7IC', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328692141, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(134, 'Y0134XZKTS', 'P', 'A', 1, '0.00', 13, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328692258, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000');
INSERT INTO `[[dbprefix]]products` VALUES
(135, 'B0135ZGE8V', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328692319, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(136, 'A0136VBI1A', 'P', 'A', 1, '0.00', 0, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328693936, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'B', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(137, 'H0137J8TMV', 'P', 'A', 1, '0.00', 0, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328694507, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'S', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(138, 'G0138IU32J', 'P', 'A', 1, '0.00', 0, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328694760, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'B', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(139, 'Z0139588PS', 'P', 'A', 1, '0.00', 0, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328694906, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'S', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(140, 'C0140WY5XY', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328696163, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(141, 'Y01413SJOB', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328696220, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(142, 'H0142DQBME', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328696273, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(143, 'Z01433JOK5', 'P', 'A', 1, '0.00', 7, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328696320, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(144, 'M0144TJFHE', 'P', 'A', 1, '0.00', 11, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328696362, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(145, 'Y0145WPLX9', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328696844, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(146, 'A0146P0NT5', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328696889, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(147, 'Q014797842', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328696954, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(148, 'H0148VPS1T', 'P', 'A', 1, '219.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328697030, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(149, 'E0149D04B9', 'P', 'A', 1, '89.99', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328698021, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(150, 'K01502P8VF', 'P', 'A', 1, '600.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328697243, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(151, 'C0151LG8CS', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328697520, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(152, 'D0152X65HT', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328697739, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(153, 'Q0153SHXQ0', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328698232, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(154, 'T0154F3MKH', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328698232, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(155, 'N01552LVJT', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328698318, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(156, 'F01564IPN2', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328698458, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(157, 'G0157AX10M', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328698521, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(158, 'N0158NC3UY', 'P', 'A', 1, '0.00', 4, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1329220941, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(159, 'L0159TYZDW', 'P', 'A', 1, '0.00', 3, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1329220807, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(160, 'L0160MZ4DS', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328699050, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(161, 'N0161QCS4X', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700156, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(162, 'A0162LEU0L', 'P', 'A', 1, '0.00', 3, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1329220610, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(163, 'W0163ME90H', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700219, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(164, 'O01648JXQC', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700230, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(165, 'N0165BQMZZ', 'P', 'A', 1, '0.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700168, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(166, 'A01662K0D9', 'P', 'A', 1, '0.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328733200, 1328733200, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(167, 'H0167T7K2E', 'P', 'A', 1, '599.95', 5, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1383894566, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(168, 'C016809TC9', 'P', 'A', 1, '0.00', 4, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700319, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(169, 'A016998ZXV', 'P', 'A', 1, '0.00', 14, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700431, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(170, 'J0170YXQXC', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700503, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(171, 'Q0171LINQ9', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700521, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(172, 'Y0172YCAWT', 'P', 'A', 1, '334.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1383894530, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(173, 'N0173TLFE1', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700782, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(174, 'K0174R9CUN', 'P', 'A', 1, '0.00', 45, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700956, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(175, 'S0175KUFJJ', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700937, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(176, 'Y01761IUK5', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700929, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(177, 'J0177S9SI3', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328700950, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(178, 'G0178014M3', 'P', 'A', 1, '0.00', 35, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328701112, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(179, 'B0179UHL46', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328701156, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(180, 'Q01802L8VS', 'P', 'A', 1, '0.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328701330, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(181, 'A0181ZSJSS', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328701333, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(182, 'N0182YV5QV', 'P', 'A', 1, '0.00', 30, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328701354, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(183, 'E0183D500N', 'P', 'A', 1, '0.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328701396, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(184, 'D0184CU1VL', 'P', 'A', 1, '0.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328701507, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(185, 'B0185I7U24', 'P', 'A', 1, '0.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328701513, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(186, 'N01868E9SB', 'P', 'A', 1, '0.00', 49, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328701615, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(187, 'D0187LXFZO', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328701677, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(188, 'M0188MVCYL', 'P', 'A', 1, '0.00', 99, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328702181, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(189, 'O0189UKMNW', 'P', 'A', 1, '0.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328702455, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(190, 'O019015C2L', 'P', 'A', 1, '0.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328702498, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(191, 'Q0191PBM44', 'P', 'A', 1, '0.00', 45, '0.000', 0, 0, 0, '0.00', 0, 1328644800, 1328702508, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(192, 'E01923M6DA', 'P', 'A', 1, '0.00', 25, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328772768, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(205, 'Y0205HGGEI', 'P', 'A', 1, '0.00', 35, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328792701, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(194, 'P01947A0SW', 'P', 'A', 1, '0.00', 40, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328765436, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(195, 'I0195ZFDB8', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328765616, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(196, 'I0196BBF6I', 'P', 'A', 1, '0.00', 24, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328766330, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(197, 'A019737E4S', 'P', 'A', 1, '0.00', 50, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328766216, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(198, 'K01984N7PI', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328766747, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(199, 'Y0199F6AC6', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328766870, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(200, 'X02002U30A', 'P', 'A', 1, '0.00', 12, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328771918, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(201, 'V02011EWI8', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328772038, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(202, 'T0202OTGXT', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328772204, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(203, 'R02034W1ZL', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328772336, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(204, 'B0204ZOC1I', 'P', 'A', 1, '0.00', 25, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328773218, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(206, 'Q0206MCK7B', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328792777, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(207, 'W0207TLU5R', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328792688, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(208, 'F0208V084C', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328792728, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(209, 'G0209Y9N72', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328792337, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(210, 'D0210M5AN1', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328792316, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(211, 'H021184FO0', 'P', 'A', 1, '0.00', 5, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328792295, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(212, 'P0212CTOEA', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328792641, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(213, 'R0213E2U6B', 'P', 'A', 1, '0.00', 20, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328785857, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(214, 'K02149B2ZX', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328733200, 1328733200, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(215, 'O02154E04H', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328777255, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(227, 'L0227FHI2Y', 'P', 'A', 1, '0.00', 13, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328786258, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(217, 'H0217E3OE9', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328777310, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(218, 'B0218UO9WS', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328777475, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(219, 'M0219A3GX3', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328733200, 1328733200, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(220, 'P0220KHOS3', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328778133, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(221, 'X0221UHBTA', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328733200, 1328733200, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(222, 'P0222KUH4T', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328782543, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(223, 'O0223AQI3W', 'P', 'A', 1, '0.00', 9, '0.000', 0, 0, 0, '0.00', 0, 1328733200, 1328733200, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(224, 'Y0224Y3QQU', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328784992, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(225, 'E0225PPZPL', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328785170, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(226, 'P02266IOPQ', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328785951, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(228, 'I0228OF40N', 'P', 'A', 1, '0.00', 25, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328786599, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(229, 'V0229W5J8F', 'P', 'A', 1, '0.00', 15, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328786767, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(230, 'B0230S7Q0V', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328787153, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(231, 'S0231YYSMK', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328787275, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(232, 'S0232MRZ1Y', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328787367, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(233, 'H023315I7E', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328787558, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(234, 'R0234XOWI6', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328787623, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(235, 'N02351Q6BY', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328787673, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(236, 'A0236BQ31M', 'P', 'A', 1, '0.00', 4, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328787726, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(237, 'B0237HI9M0', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328787824, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(238, 'Q0238LW6GY', 'P', 'A', 1, '552.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1383894378, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(239, 'L0239KVQ9F', 'P', 'A', 1, '552.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1383894640, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(240, 'E0240Y27BE', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1359662400, 1383904964, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(241, 'I0241GCXF9', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1383854400, 1383907142, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(242, 'G0242JXP9R', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328788259, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(243, 'U02431526C', 'P', 'A', 1, '0.00', 10, '0.000', 0, 0, 0, '0.00', 0, 1328731200, 1328788276, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '6', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(244, 'B00F3IUN27', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1383854400, 1384347268, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(245, 'B00F3IUN24', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1383854400, 1384347290, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(246, 'B00F3F0GLU', 'P', 'A', 1, '0.00', 1, '0.000', 0, 0, 0, '0.00', 0, 1383854400, 1384348113, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(247, 'B00F3F0GTA', 'P', 'A', 1, '310.00', 21, '0.000', 0, 0, 0, '0.00', 0, 1433192400, 1433245608, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'N', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(248, 'L2571ODER9', 'P', 'A', 1, '0.00', 1, '3.620', 0, 0, 0, '0.00', 0, 1411934400, 1414482790, '0', 'N', 'N', 'N', NULL, 'N', NULL, 'Y', 'N', 'N', 'Y', 10, 0, 'N', '', NULL, NULL, NULL, NULL, '', 'N', 0, NULL, NULL, 'default', 'a:5:{s:16:"min_items_in_box";i:1;s:16:"max_items_in_box";i:1;s:10:"box_length";i:35;s:9:"box_width";i:9;s:10:"box_height";i:27;}', '', 0, '', '0.000', '1.000'),
(278, 'TSHIRT1', 'P', 'A', 1, '75.00', 90, '0.000', 0, 0, 0, '0.00', 0, 1504253345, 1504254135, '0', 'N', 'N', 'N', 'B', 'N', 'R', 'N', 'N', 'N', 'Y', 10, 0, 'N', '', 0, 0, 0, 0, '', 'N', 0, '', '', 'bigpicture_template', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(279, 'TSHIRT2', 'V', 'A', 1, '75.00', 90, '0.000', 0, 0, 0, '0.00', 0, 1504253345, 1504254020, '0', 'N', 'N', 'N', 'B', 'N', 'R', 'N', 'N', 'N', 'Y', 10, 0, 'N', '', 0, 0, 0, 0, '', 'N', 0, '', '', 'bigpicture_template', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 278, '', '0.000', '1.000'),
(280, 'TSHIRT3', 'P', 'A', 1, '50.00', 90, '0.000', 0, 0, 0, '0.00', 0, 1504253345, 1504254057, '0', 'N', 'N', 'N', 'B', 'N', 'R', 'N', 'N', 'N', 'Y', 10, 0, 'N', '', 0, 0, 0, 0, '', 'N', 0, '', '', 'bigpicture_template', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(281, 'TSHIRT4', 'V', 'A', 1, '75.00', 0, '0.000', 0, 0, 0, '0.00', 0, 1504253345, 1504253883, '0', 'N', 'N', 'N', 'B', 'N', 'R', 'N', 'N', 'N', 'Y', 10, 0, 'N', '', 0, 0, 0, 0, '', 'N', 0, '', '', 'bigpicture_template', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 280, '', '0.000', '1.000'),
(282, 'TSHIRT5', 'P', 'A', 1, '75.00', 90, '0.000', 0, 0, 0, '0.00', 0, 1504253345, 1504254102, '0', 'N', 'N', 'N', 'B', 'N', 'R', 'N', 'N', 'N', 'Y', 10, 0, 'N', '', 0, 0, 0, 0, '', 'N', 0, '', '', 'bigpicture_template', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 0, '', '0.000', '1.000'),
(283, 'TSHIRT6', 'V', 'A', 1, '75.00', 0, '0.000', 0, 0, 0, '0.00', 0, 1504253345, 1504254252, '0', 'N', 'N', 'N', 'B', 'N', 'R', 'N', 'N', 'N', 'Y', 10, 0, 'N', '', 0, 0, 0, 0, '', 'N', 0, '', '', 'bigpicture_template', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 282, '', '0.000', '1.000'),
(284, 'TSHIRT7', 'V', 'A', 1, '75.00', 0, '0.000', 0, 0, 0, '0.00', 0, 1504253345, 1504254252, '0', 'N', 'N', 'N', 'B', 'N', 'R', 'N', 'N', 'N', 'Y', 10, 0, 'N', '', 0, 0, 0, 0, '', 'N', 0, '', '', 'bigpicture_template', 'a:5:{s:16:"min_items_in_box";i:0;s:16:"max_items_in_box";i:0;s:10:"box_length";i:0;s:9:"box_width";i:0;s:10:"box_height";i:0;}', '', 282, '', '0.000', '1.000');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]products_categories`
--

CREATE TABLE `[[dbprefix]]products_categories` (
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `category_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `link_type` char(1) NOT NULL DEFAULT 'M',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `category_position` smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`category_id`,`product_id`),
  KEY `link_type` (`link_type`),
  KEY `pt` (`product_id`,`link_type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]products_categories`
--

INSERT INTO `[[dbprefix]]products_categories` VALUES
(12, 224, 'M', 0, 0),
(1, 190, 'M', 0, 0),
(4, 190, 'M', 0, 0),
(5, 191, 'M', 0, 0),
(6, 191, 'M', 0, 0),
(7, 224, 'M', 0, 0),
(8, 190, 'A', 0, 0),
(8, 193, 'M', 0, 0),
(9, 190, 'A', 0, 0),
(9, 193, 'M', 0, 0),
(10, 190, 'A', 0, 0),
(10, 193, 'M', 0, 0),
(11, 224, 'M', 0, 0),
(13, 222, 'M', 0, 0),
(14, 191, 'M', 0, 0),
(15, 224, 'M', 0, 0),
(16, 194, 'M', 0, 0),
(17, 222, 'M', 0, 0),
(18, 194, 'M', 0, 0),
(19, 194, 'M', 0, 0),
(20, 222, 'M', 0, 0),
(21, 194, 'M', 0, 0),
(22, 195, 'M', 0, 0),
(23, 195, 'M', 0, 0),
(24, 195, 'M', 0, 0),
(25, 195, 'M', 0, 0),
(26, 220, 'M', 0, 0),
(27, 225, 'M', 0, 0),
(28, 225, 'M', 0, 0),
(29, 176, 'M', 0, 0),
(30, 176, 'M', 0, 0),
(31, 225, 'M', 0, 0),
(32, 176, 'M', 0, 0),
(33, 176, 'M', 0, 0),
(34, 225, 'M', 0, 0),
(35, 220, 'M', 0, 0),
(36, 220, 'M', 0, 0),
(37, 185, 'M', 0, 0),
(38, 225, 'M', 0, 0),
(39, 185, 'M', 0, 0),
(40, 185, 'M', 0, 0),
(41, 225, 'M', 0, 0),
(42, 185, 'M', 0, 0),
(43, 185, 'M', 0, 0),
(44, 221, 'M', 0, 0),
(45, 221, 'M', 0, 0),
(46, 221, 'M', 0, 0),
(47, 247, 'M', 0, 0),
(48, 186, 'M', 0, 0),
(49, 186, 'M', 0, 0),
(50, 186, 'M', 0, 0),
(51, 186, 'M', 0, 0),
(52, 202, 'M', 0, 0),
(53, 202, 'M', 0, 0),
(54, 202, 'M', 0, 0),
(55, 187, 'M', 0, 0),
(56, 187, 'M', 0, 0),
(57, 187, 'M', 0, 0),
(58, 188, 'M', 0, 0),
(59, 188, 'M', 0, 0),
(60, 176, 'M', 0, 0),
(62, 189, 'M', 0, 0),
(63, 189, 'M', 0, 0),
(64, 189, 'M', 0, 0),
(65, 189, 'M', 0, 0),
(66, 189, 'M', 0, 0),
(67, 236, 'M', 0, 0),
(68, 236, 'M', 0, 0),
(69, 236, 'M', 0, 0),
(70, 236, 'M', 0, 0),
(71, 236, 'M', 0, 0),
(72, 240, 'M', 0, 0),
(73, 240, 'M', 0, 0),
(74, 240, 'M', 0, 0),
(75, 240, 'M', 0, 0),
(76, 240, 'M', 0, 0),
(78, 226, 'M', 0, 0),
(117, 237, 'M', 0, 0),
(79, 226, 'M', 0, 0),
(80, 226, 'M', 0, 0),
(81, 226, 'M', 0, 0),
(82, 246, 'M', 0, 0),
(83, 246, 'M', 0, 0),
(84, 246, 'M', 0, 0),
(85, 246, 'M', 0, 0),
(86, 238, 'M', 0, 0),
(87, 246, 'M', 0, 0),
(88, 247, 'M', 0, 0),
(89, 247, 'M', 0, 0),
(90, 247, 'M', 0, 0),
(91, 227, 'M', 0, 0),
(92, 227, 'M', 0, 0),
(93, 248, 'M', 0, 0),
(94, 248, 'M', 0, 0),
(95, 248, 'M', 0, 0),
(96, 248, 'M', 0, 0),
(97, 242, 'M', 0, 0),
(112, 243, 'M', 0, 0),
(113, 237, 'M', 0, 0),
(100, 242, 'M', 0, 0),
(101, 238, 'M', 0, 0),
(102, 227, 'M', 0, 0),
(103, 242, 'M', 0, 0),
(104, 242, 'M', 0, 0),
(105, 238, 'M', 0, 0),
(106, 238, 'M', 0, 0),
(107, 227, 'M', 0, 0),
(108, 242, 'M', 0, 0),
(109, 227, 'M', 0, 0),
(110, 243, 'M', 0, 0),
(111, 243, 'M', 0, 0),
(114, 243, 'M', 0, 0),
(115, 208, 'M', 0, 0),
(116, 243, 'M', 0, 0),
(118, 244, 'M', 0, 0),
(119, 244, 'M', 0, 0),
(120, 237, 'M', 0, 0),
(121, 244, 'M', 0, 0),
(122, 208, 'M', 0, 0),
(123, 244, 'M', 0, 0),
(124, 208, 'M', 0, 0),
(125, 237, 'M', 0, 0),
(126, 251, 'M', 0, 0),
(127, 209, 'M', 0, 0),
(128, 251, 'M', 0, 0),
(129, 209, 'M', 0, 0),
(130, 251, 'M', 0, 0),
(131, 209, 'M', 0, 0),
(132, 179, 'A', 0, 0),
(132, 182, 'M', 0, 0),
(133, 179, 'M', 0, 0),
(133, 182, 'A', 0, 0),
(134, 179, 'A', 0, 0),
(134, 182, 'M', 0, 0),
(135, 179, 'A', 0, 0),
(135, 182, 'M', 0, 0),
(136, 249, 'M', 0, 0),
(137, 249, 'M', 0, 0),
(138, 249, 'M', 0, 0),
(139, 249, 'M', 0, 0),
(140, 180, 'M', 0, 0),
(141, 180, 'M', 0, 0),
(142, 180, 'M', 0, 0),
(143, 180, 'M', 0, 0),
(144, 180, 'M', 0, 0),
(145, 179, 'M', 0, 0),
(146, 179, 'M', 0, 0),
(147, 179, 'M', 0, 0),
(148, 179, 'M', 0, 0),
(149, 179, 'M', 0, 0),
(150, 210, 'M', 0, 0),
(151, 210, 'M', 0, 0),
(152, 210, 'M', 0, 0),
(153, 181, 'M', 0, 0),
(154, 181, 'M', 0, 0),
(155, 181, 'M', 0, 0),
(156, 181, 'M', 0, 0),
(157, 181, 'M', 0, 0),
(158, 253, 'M', 0, 0),
(159, 253, 'M', 0, 0),
(160, 210, 'M', 0, 0),
(161, 198, 'M', 0, 0),
(162, 253, 'M', 0, 0),
(163, 198, 'M', 0, 0),
(164, 198, 'M', 0, 0),
(165, 198, 'M', 0, 0),
(166, 198, 'M', 0, 0),
(167, 199, 'A', 0, 0),
(167, 197, 'M', 0, 0),
(167, 198, 'A', 0, 0),
(161, 199, 'A', 0, 0),
(165, 199, 'A', 0, 0),
(166, 199, 'A', 0, 0),
(163, 199, 'A', 0, 0),
(164, 199, 'A', 0, 0),
(168, 197, 'M', 0, 0),
(168, 198, 'A', 0, 0),
(168, 199, 'A', 0, 0),
(169, 197, 'M', 0, 0),
(169, 198, 'A', 0, 0),
(169, 199, 'A', 0, 0),
(170, 212, 'M', 0, 0),
(171, 252, 'M', 0, 0),
(172, 199, 'M', 0, 0),
(173, 199, 'M', 0, 0),
(174, 252, 'M', 0, 0),
(175, 199, 'M', 0, 0),
(176, 252, 'M', 0, 0),
(177, 212, 'M', 0, 0),
(178, 252, 'M', 0, 0),
(179, 212, 'M', 0, 0),
(180, 200, 'M', 0, 0),
(181, 212, 'M', 0, 0),
(182, 252, 'M', 0, 0),
(183, 200, 'M', 0, 0),
(184, 200, 'M', 0, 0),
(185, 214, 'M', 0, 0),
(186, 214, 'M', 0, 0),
(187, 214, 'M', 0, 0),
(188, 213, 'M', 0, 0),
(189, 200, 'M', 0, 0),
(190, 200, 'M', 0, 0),
(191, 231, 'M', 0, 0),
(204, 232, 'M', 0, 0),
(205, 171, 'M', 0, 0),
(194, 232, 'M', 0, 0),
(195, 232, 'M', 0, 0),
(196, 232, 'M', 0, 0),
(197, 229, 'M', 0, 0),
(197, 231, 'A', 0, 0),
(198, 229, 'M', 0, 0),
(199, 229, 'M', 0, 0),
(200, 230, 'M', 0, 0),
(201, 230, 'M', 0, 0),
(202, 230, 'M', 0, 0),
(203, 230, 'M', 0, 0),
(192, 232, 'M', 0, 0),
(206, 171, 'M', 0, 0),
(207, 171, 'M', 0, 0),
(208, 171, 'M', 0, 0),
(209, 172, 'M', 0, 0),
(210, 172, 'M', 0, 0),
(211, 172, 'M', 0, 0),
(212, 172, 'M', 0, 0),
(213, 201, 'M', 0, 0),
(214, 168, 'M', 0, 0),
(215, 201, 'M', 0, 0),
(227, 170, 'M', 0, 0),
(217, 168, 'M', 0, 0),
(218, 168, 'M', 0, 0),
(219, 169, 'M', 0, 0),
(220, 169, 'M', 0, 0),
(221, 169, 'M', 0, 0),
(222, 169, 'M', 0, 0),
(223, 165, 'M', 0, 0),
(224, 165, 'M', 0, 0),
(225, 165, 'M', 0, 0),
(226, 201, 'M', 0, 0),
(228, 170, 'M', 0, 0),
(229, 170, 'M', 0, 0),
(230, 216, 'M', 0, 0),
(231, 216, 'M', 0, 0),
(232, 216, 'M', 0, 0),
(233, 217, 'M', 0, 0),
(234, 217, 'M', 0, 0),
(235, 217, 'M', 0, 0),
(236, 218, 'M', 0, 0),
(237, 218, 'M', 0, 0),
(238, 235, 'M', 0, 0),
(239, 235, 'M', 0, 0),
(240, 165, 'M', 0, 0),
(241, 165, 'M', 0, 0),
(242, 178, 'M', 0, 0),
(243, 178, 'M', 0, 0),
(244, 168, 'M', 0, 0),
(245, 235, 'M', 0, 0),
(246, 199, 'M', 0, 0),
(247, 165, 'M', 0, 0),
(248, 248, 'M', 0, 0),
(248, 255, 'A', 0, 0),
(278, 224, 'M', 0, 0),
(279, 224, 'M', 0, 0),
(280, 224, 'M', 0, 0),
(281, 224, 'M', 0, 0),
(282, 224, 'M', 0, 0),
(283, 224, 'M', 0, 0),
(284, 224, 'M', 0, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_bundles`
--

CREATE TABLE `[[dbprefix]]product_bundles` (
  `bundle_id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` int(11) unsigned NOT NULL,
  `products` text,
  `date_from` int(11) unsigned NOT NULL DEFAULT '0',
  `date_to` int(11) unsigned NOT NULL DEFAULT '0',
  `display_in_promotions` char(1) NOT NULL DEFAULT 'Y',
  `status` char(1) NOT NULL DEFAULT 'D',
  `linked_promotion_id` mediumint(8) unsigned NOT NULL,
  PRIMARY KEY (`bundle_id`),
  KEY `company_id` (`company_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=4 ;

--
-- Dumping data for table `[[dbprefix]]product_bundles`
--

INSERT INTO `[[dbprefix]]product_bundles` VALUES
(1, 1, 'a:1:{i:0;a:6:{s:10:"product_id";i:12;s:6:"amount";i:3;s:13:"modifier_type";s:13:"by_percentage";s:8:"modifier";d:33.3299999999999982946974341757595539093017578125;s:20:"show_on_product_page";s:1:"Y";s:3:"aoc";s:1:"Y";}}', 0, 0, 'Y', 'A', 25),
(2, 1, 'a:3:{i:0;a:5:{s:10:"product_id";i:39;s:6:"amount";i:1;s:13:"modifier_type";s:13:"by_percentage";s:8:"modifier";i:50;s:20:"show_on_product_page";s:1:"Y";}i:1;a:5:{s:10:"product_id";i:51;s:6:"amount";i:1;s:13:"modifier_type";s:13:"by_percentage";s:8:"modifier";i:50;s:20:"show_on_product_page";s:1:"Y";}i:2;a:5:{s:10:"product_id";i:52;s:6:"amount";i:1;s:13:"modifier_type";s:13:"by_percentage";s:8:"modifier";i:50;s:20:"show_on_product_page";s:1:"Y";}}', 0, 0, 'Y', 'A', 26),
(3, 1, 'a:3:{i:0;a:5:{s:10:"product_id";i:237;s:6:"amount";i:1;s:13:"modifier_type";s:13:"by_percentage";s:8:"modifier";i:33;s:20:"show_on_product_page";s:1:"Y";}i:1;a:5:{s:10:"product_id";i:230;s:6:"amount";i:1;s:13:"modifier_type";s:13:"by_percentage";s:8:"modifier";i:33;s:20:"show_on_product_page";s:1:"Y";}i:2;a:5:{s:10:"product_id";i:234;s:6:"amount";i:1;s:13:"modifier_type";s:13:"by_percentage";s:8:"modifier";i:33;s:20:"show_on_product_page";s:1:"Y";}}', 0, 0, 'Y', 'A', 27);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_bundle_descriptions`
--

CREATE TABLE `[[dbprefix]]product_bundle_descriptions` (
  `bundle_id` int(10) unsigned NOT NULL,
  `name` varchar(50) NOT NULL DEFAULT '',
  `storefront_name` varchar(50) NOT NULL DEFAULT '',
  `description` mediumtext,
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`bundle_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_bundle_descriptions`
--

INSERT INTO `[[dbprefix]]product_bundle_descriptions` VALUES
(1, 'Sports pants bundle', 'Sports pants bundle', 'Get 3 pairs of pants at the price of 2', 'en'),
(2, 'Car audio bundle', 'Car audio bundle', 'Get everything you need for your car in one package, with 50% off', 'en'),
(3, 'Camping bundle', 'Camping bundle', '33% off everything a traveler needs', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_bundle_images`
--

CREATE TABLE `[[dbprefix]]product_bundle_images` (
  `bundle_image_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `bundle_id` int(10) unsigned NOT NULL,
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`bundle_image_id`),
  KEY `bundle_id` (`bundle_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=4 ;

--
-- Dumping data for table `[[dbprefix]]product_bundle_images`
--

INSERT INTO `[[dbprefix]]product_bundle_images` VALUES
(1, 1, 'en'),
(2, 2, 'en'),
(3, 3, 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_bundle_product_links`
--

CREATE TABLE `[[dbprefix]]product_bundle_product_links` (
  `bundle_id` int(10) unsigned NOT NULL,
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `amount` mediumint(8) NOT NULL DEFAULT '0',
  `show_on_product_page` char(1) NOT NULL DEFAULT 'Y',
  `all_variants` char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (`product_id`,`bundle_id`,`all_variants`),
  KEY `bundle_id` (`bundle_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_bundle_product_links`
--

INSERT INTO `[[dbprefix]]product_bundle_product_links` VALUES
(1, 12, 3, 'Y', 'N'),
(2, 39, 1, 'Y', 'N'),
(2, 51, 1, 'Y', 'N'),
(2, 52, 1, 'Y', 'N'),
(3, 237, 1, 'Y', 'N'),
(3, 230, 1, 'Y', 'N'),
(3, 234, 1, 'Y', 'N');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_descriptions`
--

CREATE TABLE `[[dbprefix]]product_descriptions` (
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `product` varchar(255) NOT NULL DEFAULT '',
  `shortname` varchar(255) NOT NULL DEFAULT '',
  `short_description` mediumtext,
  `full_description` mediumtext,
  `meta_keywords` varchar(255) NOT NULL DEFAULT '',
  `meta_description` varchar(255) NOT NULL DEFAULT '',
  `search_words` text,
  `page_title` varchar(255) NOT NULL DEFAULT '',
  `age_warning_message` text,
  `promo_text` mediumtext,
  `unit_name` varchar(255) DEFAULT '',
  PRIMARY KEY (`product_id`,`lang_code`),
  KEY `product_id` (`product_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_descriptions`
--

INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(1, 'en', '65" Class (64.5" Diag.) LED 8000 Series Smart TV', '', '', '<p>\r\n	     For the ultimate TV enthusiasts, incredible picture quality and advanced connectivity are just the first step; the Samsung UN65D8000 LED TV goes a step beyond, adding elegant design to the formula. On the commanding 65-inch screen you can enjoy Samsung'' Smart TV, which puts the web, a wide range of apps, Skype video calling, and plenty more at your fingertips. Or connect a Blu-ray 3D player to get immersed in cinema-quality 3D programming--two pairs of active glasses are included.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(4, 'en', '40" Class (40.0" Diag.) LED 5003 Series TV', '', '', '<p>\r\n	Clear Motion Rate (CMR) is Samsung''s more comprehensive and accurate measure for how well an LCD or LED TV can display fast-moving images. Previously, motion clarity was expressed simply by the refresh rate, measured in Hz. CMR, however, takes into account all three factors that contribute to motion clarity: panel refresh rate, image processor speed and backlight technology.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text">\r\n	<span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span>\r\n</p>', ''),
(5, 'en', '46" Class (45.9" Diag.) LCD 610 Series TV', '', '', '<p>\r\n	      ConnectShare™ Movie lets you watch videos, play music or view photos from a USB drive. Simply plug your USB directly into your Samsung TV’s USB port and watch on the big screen with friends and family.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(6, 'en', 'Toshiba 32C120U 32" Class 720P HD LCD TV', '', '', '<p>Think you need to break your budget to enjoy blockbuster HD entertainment? Not with Toshiba''s 32" class C110U LCD HDTV. Featuring all-new design, this value-packed television looks great and works well in a living room, kitchen or bedroom. Increase detail and depth of the images on your screen with our impressive Dynalight technology.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(7, 'en', 'Trefoil Hoodie', '', '', '<p>The adidas Originals Trefoil Hoodie has been a streetwear essential for  decades, with its characteristic big hood, kangaroo pocket and large  Trefoil. Now it''s your turn to join the Trefoil men''s hoodie crew and  carry the legend forward.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(8, 'en', 'Toshiba 32TL515U 32" Class 1080P 3D LED HD TV', '', '', '<p>\r\n	 Although its attractive features, design, and passive 3D have merit, the picture quality issues of the Toshiba TL515U LED-based LCD TV lessen its appeal in the face of the stiff competition.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(9, 'en', 'Toshiba 42TL515U 42" Class 1080P 3D LED HD TV', '', '', '<p>Although its attractive features, design, and passive 3D have merit, the picture quality issues of the Toshiba TL515U LED-based LCD TV lessen its appeal in the face of the stiff competition.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(10, 'en', 'Toshiba 47TL515U 47" Class 1080P 3D LED HD TV', '', '', '<p>Although its attractive features, design, and passive 3D have merit, the picture quality issues of the Toshiba TL515U LED-based LCD TV lessen its appeal in the face of the stiff competition.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(11, 'en', 'Collegiate 72 Tee', '', '', '<p>It''s not how old you are, it''s how stylish, and this men''s adidas  Originals Collegiate 72 Tee shirt feels just as fresh as it was the day  the Trefoil was born in 1972. That''s why this t-shirt features a  collegiate "72" on the front.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(12, 'en', '100g Pants', '', '', '<p>\r\n	When coach calls you off the bench, you need warm-up pants that come off  in three seconds or less. That’s why these men''s adidas 100g basketball  pants have tear-away snaps down the sides, so you''re ready for action  as fast as a superhero.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(13, 'en', 'Your Idea, Inc. 12 Steps to Building a Million Dollar Business -- Starting Today!', '', '', '<p style="text-align: left; color: #000000; font-size: 12px; background-color: #ffffff;">\r\n	Every time a new story about how some nobody from nowhere got rich producing some clever new product in his garage, you may think, "Why can''t I do that?" Well, anyone can--the trick is to take those good ideas and build them into great products that can succeed in the marketplace. In this book, you will get the 12-step plan you need to make your new product or service a profitable reality. You will learn important skills for success, including how to:\r\n</p>\r\n<ul style="text-align: left; color: #000000; font-size: 12px; background-color: #ffffff;">\r\n	<li style="text-align: left;">Refine their idea to attract a target audience</li>\r\n	<li style="text-align: left;">Research the competition</li>\r\n	<li style="text-align: left;">Find the right manufacturer</li>\r\n	<li style="text-align: left;">Create appropriate brand messaging</li>\r\n	<li style="text-align: left;">Build buzz online and beyond</li>\r\n	<li style="text-align: left;">Work trade shows and conventions</li>\r\n</ul>\r\n<p>\r\n	<span style="color: #000000; font-family: Arial, sans-serif; font-size: 12px; background-color: #ffffff;">Written by a woman with no formal business experience who turned her own idea into a million-dollar company, this book is the pragmatic yet inspiring guide every aspiring entrepreneur is looking for.</span>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(14, 'en', 'Toshiba 40E220U 40" Class 1080P HD LCD TV', '', '', '<p>Enjoy a stunning picture bursting with color and clarity with the 40-inch Toshiba 40E200U LCD HDTV (40-inch diagonal screen size), featuring a 1080p Full HD resolution that provides twice the pixel resolution of 720p HD models. It provides a number of convenient home entertainment options and key picture quality features, including DynaLight dynamic backlight control for deeper black levels and four HDMI digital inputs for simple high quality connection to cable/satellite boxes, DVD players and more. Plus, the HDMI ports feature fast InstaPort switching for quick changes from one source to another.&nbsp;<br /><br />DynaLight automatically adjusts the backlight intensity based on the image content.<br /><br /> With the Gaming Mode function, you''ll experience reduced game control delay and improved reaction time--perfect for PC gaming--and the Photo Frame capability with Auto Slide Show enables you to display slideshows of your favorite images when not watching TV programming. <br /><br /> Boasting a slimming tapered bezel and attractive front panel gradation, the new Horizon design creates a more modern, elegant appearance that also adds a subtle luminance to the logo to further its stylish appeal. Other features include MP3 playback via the integrated USB port, a PC input, and a removable stand.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(15, 'en', 'Nike Chambray Super Runner Men''s Jacket', '', '<p>The  timeless Windrunner design gets a premium upgrade in the Nike Chambray  Super Runner Men''s Jacket. Created with tough, water-resistant fabric  and a mesh lining, this jacket combines breathability and protection  from the elements.</p>', '<div class="text description black-white">\r\n<div class="product-description-component">\r\n<p><strong>The Nike Chambray Super Runner Jacket: A durable, updated classic </strong></p>\r\n<br />\r\n<p>The  timeless Windrunner design gets a premium upgrade in the Nike Chambray  Super Runner Men''s Jacket. Created with tough, water-resistant fabric  and a mesh lining, this jacket combines breathability and protection  from the elements.</p>\r\n<br />\r\n<p><strong>Benefits</strong></p>\r\n<li>Hood with drawcord for an adjustable fit</li>\r\n<li>Overlay at yoke and raglan sleeves for style and enhanced protection</li>\r\n<li>Rib cuffs and hem for a fit that stays in place</li>\r\n<li>Mesh lining for enhanced ventilation</li>\r\n<li>Durable, wind-resistant fabric to protect against the elements</li>\r\n<br />\r\n<p><strong>Additional Details</strong></p>\r\n<li>Side zip pockets for secure storage</li>\r\n<li>Fabric: Body: 100% cotton. Lining and overlay: 100% polyester.</li>\r\n<li>Machine wash</li>\r\n<li>Imported</li>\r\n</div>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(16, 'en', '3D Blu-ray Disc™ Player (BD-D7500)', '', '', '<p>Whether you are viewing a premium-quality 2D picture or seeing incredible 3D depth, images are breathtakingly real in Samsung Full HD. Combine with a 3D TV and 3D active shutter glasses to view the latest Hollywood 3D titles or amplify your viewing experience by upconverting 2D content to immersive 3D.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(17, 'en', '101 Things Everyone Should Know About Economics A Down and Dirty Guide to Everything from Securities and Derivatives to Interest Rates and Hedge Funds—And What They Mean For You', '', '', '<p><span style="color: #000000; font-family: Arial, sans-serif; font-size: 12px; background-color: #ffffff;">What you don''t know about economics can hurt you&mdash;now more than ever. This easy-to-understand guide answers all the questions you need to know to secure your financial future, such as:</span></p>\r\n<ul style="text-align: left; color: #000000; font-size: 12px; background-color: #ffffff;">\r\n<li style="text-align: left;">What does it mean to my paycheck when the Fed lowers or raises interest rates?</li>\r\n<li style="text-align: left;">What''s the difference between bonds, securities, and derivatives&mdash;and which should I invest in now?</li>\r\n<li style="text-align: left;">What does Keynesian economics have to do with my savings?</li>\r\n</ul>\r\n<p><span style="color: #000000; font-family: Arial, sans-serif; font-size: 12px; background-color: #ffffff;">For those people whose heads spin when reading the business pages of the newspaper, here''s a roadmap through the economic jungle. In simple, plain language, Peter Sander explains how economies work, why they grow, how they contract, and what the government can and can''t do to help them. Most important, he tells you how all this affects&nbsp;</span><em style="color: #000000; font-family: Arial, sans-serif; font-size: 12px; background-color: #ffffff;">you</em><span style="color: #000000; font-family: Arial, sans-serif; font-size: 12px; background-color: #ffffff;">&mdash;and what kind of changes you''re going to see in your finances as a result.</span></p>\r\n<p style="text-align: left; color: #000000; font-size: 12px; background-color: #ffffff;">Economics has been called the "dismal" science. But it doesn''t need to be gloomy or impenetrable. This book is an essential guide for anyone who wants to understand where the economy is today, where it''s going, and what it means for the rest of us.</p>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(18, 'en', '3D Blu-ray Disc™ Player (BD-D7000)', '', '', '<p>Whether you are viewing a premium-quality 2D picture or seeing incredible 3D depth, images are breathtakingly real in Samsung Full HD. Combine with a 3D TV and 3D active shutter glasses to view the latest Hollywood 3D titles or amplify your viewing experience by upconverting 2D content to immersive 3D.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(19, 'en', 'Toshiba BDX2150 Blu-ray Player', '', '', '<p>Enjoy the clarity of Blu-ray and the convenience of streaming media with the Toshiba BDX2150 Blu-ray Disc player. Wi-Fi ready for clutter-free in-home connectivity (Wi-Fi adapter required, sold separately), this player lets you enjoy your favorite movies with stunning native 1080p Full HD output plus surround sound with Dolby audio enhancements. Internet connectivity enables you to take advantage of popular streaming services such as Blockbuster, Netflix*, CinemaNow, Pandora, Vudu and YouTube. In addition, BD-Live 2.0 technology allows you to access internet-only bonus material available on many Blu-ray titles. Offering both USB and HDMI with CEC ports, this player is equipped with the latest command and control functionality.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(20, 'en', 'The ABCs of Gold Investing. How to Protect and Build Your Wealth with Gold', '', '', '<p><em style="color: #000000; font-family: Verdana; background-color: #ffffff; font-size: small;"><strong>The ABCs of Gold Investing</strong></em><span style="color: #000000; font-family: Verdana; background-color: #ffffff; font-size: small;">&nbsp;(Second Edition) is a solid resource for investors wishing to understand the benefits of private gold ownership. In this reader-friendly book, author Michael J. Kosares addresses the rapid changes in both the American and world economies and explains why gold is important to you as an investor. And, with thirty years experience in the gold business, he can tell you how to add gold to your portfolio in a safe and economical manner.</span></p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(21, 'en', 'Toshiba SD3300 DVD Player', '', '', '<p>Toshiba SD3300 DVD Player''s narrower width gives this unit a smaller footprint and will help to conserve entertainment center shelf space.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(22, 'en', '7.1 Channel Blu-ray 3D Home Theater System', '', '', '<p>Whether you are viewing a premium-quality 2D picture or seeing incredible 3D depth, images are breathtakingly real in Samsung Full HD. Combine with a 3D TV and 3D active shutter glasses to view the latest Hollywood 3D titles or amplify your viewing experience by upconverting 2D content to immersive 3D.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(23, 'en', '5.1 Channel Blu-ray 3D Home Theater System', '', '', '<p>\r\n	  Whether you are viewing a premium-quality 2D picture or seeing incredible 3D depth, images are breathtakingly real in Samsung Full HD. Combine with a 3D TV and 3D active shutter glasses to view the latest Hollywood 3D titles or amplify your viewing experience by upconverting 2D content to immersive 3D.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(24, 'en', '5.1 Channel Blu-ray 3D Home Theater System', '', '', '<p>Whether you are viewing a premium-quality 2D picture or seeing incredible 3D depth, images are breathtakingly real in Samsung Full HD. Combine with a 3D TV and 3D active shutter glasses to view the latest Hollywood 3D titles or amplify your viewing experience by upconverting 2D content to immersive 3D.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(25, 'en', 'HW-D7000 AV Receiver with built-in Blu-ray Disc® Player', '', '', '<p>Replicate the theater experience in your own home by immersing yourself in 7.2 channel surround sound. You can position the speakers throughout your space to bring your favorite music and movies to life with cinematic sound, transforming your living room into the ultimate home theater.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(26, 'en', 'Mac OS X Lion: The Missing Manual', '', '', '<table style="color: #333333; font-family: Arial, Verdana, Geneva, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;" cellspacing="0" cellpadding="0" width="100%">\r\n<tbody>\r\n<tr>\r\n<td style="font-size: 12px; font-family: Arial, Verdana, Geneva, Helvetica, sans-serif; color: #333333;">\r\n<div>\r\n<div>\r\n<p>For a company that promised to "put a pause on new features," Apple sure has been busy-there''s barely a feature left untouched in Mac OS X 10.6 "Snow Leopard." There''s more speed, more polish, more refinement-but still no manual. Fortunately, David Pogue is back, with the humor and expertise that have made this the #1 bestselling Mac book for eight years straight. You get all the answers with jargon-free introductions to:</p>\r\n<p>&nbsp;</p>\r\n<ul>\r\n<li><strong>Big-ticket changes.</strong>&nbsp;A 64-bit overhaul. Faster everything. A rewritten Finder. Microsoft Exchange compatibility. All-new QuickTime Player. If Apple wrote it, this book covers it.</li>\r\n<li><strong>Snow Leopard Spots.</strong>&nbsp;This book demystifies the hundreds of smaller enhancements, too, in all 50 programs that come with the Mac: Safari, Mail, iChat, Preview, Time Machine.</li>\r\n<li><strong>Shortcuts.</strong>&nbsp;This must be the tippiest, trickiest Mac book ever written. Undocumented surprises await on every page.</li>\r\n<li><strong>Power usage.</strong>&nbsp;Security, networking, build-your-own Services, file sharing with Windows, even Mac OS X''s Unix chassis-this one witty, expert guide makes it all crystal clear.</li>\r\n</ul>\r\n</div>\r\n</div>\r\n</td>\r\n</tr>\r\n</tbody>\r\n</table>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(27, 'en', 'Trefoil Logo Hoodie', '', '<p>This classic women''s adidas Originals Trefoil Logo Hoodie is made of  comfortable fleece with a drawcord hood, a kangaroo pocket and an  outsize logo. The pullover hoodie also features extra-long cuffs and hem  for feminine style.</p>', '<div class="productText" style="display: block;">\r\n<div class="prodDesc">This classic women''s adidas Originals Trefoil Logo Hoodie is made of  comfortable fleece with a drawcord hood, a kangaroo pocket and an  outsize logo. The pullover hoodie also features extra-long cuffs and hem  for feminine style.</div>\r\n<div class="prodDetail">\r\n<h3>Details</h3>\r\n<ul>\r\n<li>Kangaroo pocket</li>\r\n<li>Drawcord-adjustable hood</li>\r\n<li>Ribbed long cuffs and wider hem</li>\r\n<li>Large Trefoil on front</li>\r\n<li>70% cotton / 30% polyester fleece</li>\r\n<li>Imported</li>\r\n</ul>\r\n</div>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(28, 'en', 'Run Perf 7/8 Ti', '', '', '<p>adidas Run Perf 7/8 Ti , new to site, more details coming soon.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(29, 'en', 'TomTom GO LIVE Top Gear edition', '', '', '<p>The TomTom GO LIVE Top Gear edition satnav! Featuring the voice of Jeremy Clarkson, plus a heap of Top Gear bonus goodies, this special edition satnav is the ultimate traffic- vanquishing weapon for the discerning driverist. With speed camera warnings, information via Local Search with Google&trade;, weather reports and more, it&rsquo;ll spirit you onto gloriously empty roads when all about you are stuck in jams. With the calming presence of Jeremy Clarkson himself by your side, what could possibly go wrong?</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(30, 'en', 'GO 2535 TM WTE', '', '', '<p>The TomTom GO series is the ultimate in driving intelligence. The new, super-slim TomTom GO series holds the latest navigation technology, in a fresh, sleek design and includes a magnetic, click &amp; lock mount for maximum mounting security. Travel confidently with superior routing and the most accurate, dependable maps in the GPS industry.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(31, 'en', 'Nike Classic Solid Women''s Jersey Shorts', '', '', '<div class="text dark-grey-heather-white description">\r\n<div class="product-description-component">\r\n<p><strong>The Nike Classic Women''s Shorts: Versatile comfort</strong></p>\r\n<br />\r\n<p>With a simple and sporty design, the comfortable Nike Classic Solid Women''s Jersey Shorts are a must-have for every gym bag.</p>\r\n<br />\r\n<p><strong>Benefits</strong></p>\r\n<li>Elastic waist with drawcord for an athletic fit</li>\r\n<li>Vented hem for a full range of motion</li>\r\n<br />\r\n<p><strong>Additional Details</strong></p>\r\n<li>Fabric: 61% cotton/33% polyester/6% spandex</li>\r\n<li>Machine wash</li>\r\n<li>Imported</li>\r\n</div>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(32, 'en', 'nüvi® 3450', '', '', '<p>Garmin Guidance 3.0 allows you to quickly look up addresses and services and be guided to your destination with voice-prompted, turn-by-turn directions that speak street names. It comes preloaded with maps that feature 3-D landmarks and terrain for North America. It also comes preloaded with more than 8 million points of interest and offers the ability to add your own.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(33, 'en', 'nüvi® 2455LT', '', '', '<p>Whether you&rsquo;re driving through an unfamiliar city or on your daily commute, n&uuml;vi 2455LT makes your trip easier than ever before. It includes FREE lifetime traffic updates, advanced lane guidance and more.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(34, 'en', 'Nike "Untouchable" Women''s Tank Top', '', '', '<div class="text description dark-grey-heather-dark-grey-heather-red">\r\n<div class="product-description-component">\r\n<p><strong>The Nike "Untouchable" Tank Top: Sleeveless tribute to ''72</strong></p>\r\nCelebrating  a banner year in sports with vibrant print detail, the Nike  "Untouchable" Women''s Tank Top offers a motion-friendly racerback  silhouette in a body-hugging fit.<br />\r\n<p><strong>Benefits</strong></p>\r\n<li>Slim fit contours to your body</li>\r\n<li>Rib scoop-neck and armholes for durability and comfort</li>\r\n<li>Racerback for enhanced range of movement</li>\r\n<li>Screen-print at front</li>\r\n<br />\r\n<p><strong>Additional Details</strong></p>\r\n<li>Fabric: 100% cotton</li>\r\n<li>Machine wash</li>\r\n<li>Imported</li>\r\n</div>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(35, 'en', 'Managing Enterprise Content: A Unified Content Strategy, 2nd Edition', '', '', '<p>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 1em; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; line-height: 1.5em; color: #000000; font-family: ''Lucida Grande'', Arial, Helvetica, Verdana, sans-serif; background-color: #ffffff;">We can''t just design content for one channel, device or medium anymore; we need to design responsive structured content to reach customers anytime, anywhere, and on any device. And we can''t do that until we can define how each element associated with a content object should be effectively written to respond to different customer needs and context of the content as well as changes in display and different capabilities of devices. This book presents a unified content strategy model.<br /><br />A unified content strategy:</p>\r\n<ul style="margin-top: 0px; margin-bottom: 1em; margin-left: 1.5em; color: #000000; font-family: ''Lucida Grande'', Arial, Helvetica, Verdana, sans-serif; background-color: #ffffff; padding: 0px;">\r\n<li style="margin-top: 0px; margin-right: 0px; margin-bottom: 1em; margin-left: 0px; line-height: 1.5em;">Identifies customer requirements</li>\r\n</ul>\r\n<ul style="margin-top: 0px; margin-bottom: 1em; margin-left: 1.5em; color: #000000; font-family: ''Lucida Grande'', Arial, Helvetica, Verdana, sans-serif; background-color: #ffffff; padding: 0px;">\r\n<li style="margin-top: 0px; margin-right: 0px; margin-bottom: 1em; margin-left: 0px; line-height: 1.5em;">Defines structured content models for responsive content</li>\r\n</ul>\r\n<ul style="margin-top: 0px; margin-bottom: 1em; margin-left: 1.5em; color: #000000; font-family: ''Lucida Grande'', Arial, Helvetica, Verdana, sans-serif; background-color: #ffffff; padding: 0px;">\r\n<li style="margin-top: 0px; margin-right: 0px; margin-bottom: 1em; margin-left: 0px; line-height: 1.5em;">Determines how content will be reused and repurposed across media and devices and how it will adapt to changing customer needs</li>\r\n</ul>\r\n<ul style="margin-top: 0px; margin-bottom: 1em; margin-left: 1.5em; color: #000000; font-family: ''Lucida Grande'', Arial, Helvetica, Verdana, sans-serif; background-color: #ffffff; padding: 0px;">\r\n<li style="margin-top: 0px; margin-right: 0px; margin-bottom: 1em; margin-left: 0px; line-height: 1.5em;">Identifies the tags (metadata) for retrieval and dynamic delivery</li>\r\n</ul>\r\n<ul style="margin-top: 0px; margin-bottom: 1em; margin-left: 1.5em; color: #000000; font-family: ''Lucida Grande'', Arial, Helvetica, Verdana, sans-serif; background-color: #ffffff; padding: 0px;">\r\n<li style="margin-top: 0px; margin-right: 0px; margin-bottom: 1em; margin-left: 0px; line-height: 1.5em;">Determines how content should be managed throughout the entire content lifecycle</li>\r\n</ul>\r\n<ul style="margin-top: 0px; margin-bottom: 1em; margin-left: 1.5em; color: #000000; font-family: ''Lucida Grande'', Arial, Helvetica, Verdana, sans-serif; background-color: #ffffff; padding: 0px;">\r\n<li style="margin-top: 0px; margin-right: 0px; margin-bottom: 1em; margin-left: 0px; line-height: 1.5em;">Defines the governance policies to manage the content from creation to retirement</li>\r\n</ul>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(36, 'en', 'Routing Protocols and Concepts: CCNA Exploration Companion Guide', '', '', '<p>&nbsp;</p>\r\n<p style="font-family: Arial, Helvetica, sans-serif; font-size: 12px; color: #000000; text-align: left; margin: 0px;"><em>Routing Protocols and Concepts</em>, CCNA Exploration Companion Guide is the official supplemental textbook for the Routing Protocols and Concepts course in the Cisco Networking Academy&reg; CCNA&reg; Exploration curriculum version 4. This course describes the architecture, components, and operation of routers, and explains the principles of routing and the primary routing protocols. The Companion Guide, written and edited by Networking Academy instructors, is designed as a portable desk reference to use anytime, anywhere. The book&rsquo;s features reinforce the material in the course to help you focus on important concepts and organize your study time for exams.</p>\r\n<p style="font-family: Arial, Helvetica, sans-serif; font-size: 12px; color: #000000; text-align: left; margin: 0px;">&nbsp;</p>\r\n<p style="font-family: Arial, Helvetica, sans-serif; font-size: 12px; color: #000000; text-align: left; margin: 0px;">New and improved features help you study and succeed in this course:</p>\r\n<ul style="font-family: Arial, Helvetica, sans-serif; font-size: 12px; color: #000000; text-align: left;">\r\n<li style="font-size: 1em;">Chapter objectives&mdash;Review core concepts by answering the focus questions listed at the beginning of each chapter.</li>\r\n<li style="font-size: 1em;">Key terms&mdash;Refer to the updated lists of networking vocabulary introduced and turn to the highlighted terms in context in each chapter.</li>\r\n<li style="font-size: 1em;">Glossary&mdash;Consult the comprehensive glossary with more than 150 terms.</li>\r\n<li style="font-size: 1em;">Check Your Understanding questions and answer key&mdash;Evaluate your readiness with the updated end-of-chapter questions that match the style of questions you see on the online course quizzes. The answer key explains each answer.</li>\r\n<li style="font-size: 1em;">Challenge questions and activities&mdash;Strive to ace more challenging review questions and activities designed to prepare you for the complex styles of questions you might see on the CCNA exam. The answer key explains each answer.&nbsp;</li>\r\n</ul>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(37, 'en', 'DPX308U', '', '', '<p>Many cars come with a 2DIN opening so swap that basic factory radio out for a DPX308U! This full featured CD-receiver comes with front USB input which provides a simple connection for your iPod/iPhone, allowing you to listen to your favorite music while controlling it easily from you your car stereo. When connecting an iPod or iPhone to the USB port you get the added benefit of advanced search features designed to let you spend more time listening to your favorite songs instead of hunting for them.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(38, 'en', 'Nike Futura Unravel Women''s T-Shirt', '', '', '<div class="text black-gold description">\r\n<div class="product-description-component">\r\n<p><strong>The Nike Futura Shirt: A flattering fit with bold pops of color</strong></p>\r\n<br />\r\n<p>It''s  a style explosion in the Nike Futura Unravel Women''s T-Shirt, a  high-energy essential with a flattering design and playful bursts of  color.</p>\r\n<br />\r\n<p><strong>Benefits</strong></p>\r\n<li>Extended rib V-neck for a flattering, comfortable fit</li>\r\n<li>Reflective screen-print at front for a pop of color</li>\r\n<li>A slim fit that''s contoured to your body</li>\r\n<br />\r\n<p><strong>Additional Details</strong></p>\r\n<li>Fabric: 100% cotton</li>\r\n<li>Machine wash</li>\r\n<li>Imported</li>\r\n</div>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(39, 'en', 'DEH-80PRS', '', '', '<p>The DEH-80PRS CD receiver features audiophile grade internal components and materials that are carefully selected to achieve Pioneer''s highest standards for the ultimate in sound quality. Pioneer&rsquo;s exclusive sound field technologies including Auto EQ and Auto Time Alignment help optimize audio in ways that perfectly suit particular listening spaces and allow subtle manual control of settings. Versatile connectivity helps deliver exceptional sound quality from various digital devices.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(40, 'en', 'DEH-P8400BH', '', '', '<p>The DEH-P8400BH CD receiver features a full-dot LCD display with Pioneer''s new MIXTRAX technology, built-in Bluetooth&reg; for hands-free calling and audio streaming, and an HD Radio&trade; tuner. A variety of multimedia options ensures that you will be properly entertained. Customizable audio functions make it easy to suit your listening taste.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(41, 'en', 'Gift Set (Onesie Plus Socks)', '', '', '<p>Welcome the new addition with this adidas  Originals Gift Set, featuring a one-piece romper and matching socks. The  romper has a sleepy-time Trefoil character on the back, while the front  bristles with fun in vibrant stripes.</p>\r\n<div class="prodDetail">\r\n<h3>Details</h3>\r\n<ul>\r\n<li>Crewneck</li>\r\n<li>Full snap-button front for easy on and off</li>\r\n<li>Allover yarn-dyed stripe pattern on front</li>\r\n<li>Solid-color back with Trefoil-inspired graphic</li>\r\n<li>Matching socks included</li>\r\n<li>95% cotton / 5% elastane single jersey</li>\r\n<li>Imported</li>\r\n</ul>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(42, 'en', 'DEH-1300MP', '', '', '<p>With music in so many different formats, it only makes sense to have a CD receiver that can play them all. Take your digital songs on the go by copying them directly onto a CD-R or CD-RW disc in either MP3 or WMA formats. Since these files are digitally encoded, you will be able to see detailed track information such as artist, song title, and album.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(43, 'en', 'FH-P8000BT', '', '', '<p>The FH-P8000BT is smartly designed to expand your system, customize your experience, provide superior sound quality and easy operation.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(44, 'en', 'U.S. History and Government, Second Edition', '', '', '<p>\r\n<p style="color: #333333; font-family: Verdana, Geneva, sans-serif; font-size: 14px; line-height: 17px;"><span style="color: #996633; font-family: Georgia, ''Times New Roman'', Times, serif; font-size: x-small;"><strong>Purpose:</strong></span></p>\r\n<p style="color: #333333; font-family: Verdana, Geneva, sans-serif; font-size: 14px; line-height: 17px;"><span style="color: #996633; font-family: Georgia, ''Times New Roman'', Times, serif; font-size: x-small;">To provide students taking the 11th-grade New York State course in U.S. history and government and the Regents examination, as well as others taking a similar course, with a concise and comprehensive text.&nbsp;<br /></span></p>\r\n<ul style="color: #333333; font-family: Verdana, Geneva, sans-serif; font-size: 14px; line-height: 17px;" type="square">\r\n<span style="color: #996633; font-family: Georgia, ''Times New Roman'', Times, serif; font-size: x-small;"><strong>Text features include:</strong>\r\n<li>introduction to U.S. geography with an emphasis on how geography has shaped the American experience</li>\r\n<li>summary of the founding, principles, and operations of the U.S. government . lucid historical narrative</li>\r\n<li>emphasis on the modern period</li>\r\n<li>primary source readings in every chapter</li>\r\n<li>emphasis on the experiences and contributions of women and minorities</li>\r\n<li>mid-chapter &ldquo;in Review&rdquo; features</li>\r\n<li>end-of-chapter exercises: multiple-choice, thematic-essay, and document-based questions</li>\r\n<li>more maps, charts, and tables</li>\r\n<li>expanded coverage of U.S. Supreme Court landmark cases</li>\r\n<li>&ldquo;The American People: Changes at the Millennium&rdquo; - a demographic feature in the last chapter</li>\r\n<li>appendix: annotated Declaration of Independence and U.S. Constitution.</li>\r\n<li>Teacher&rsquo;s Manual With Answers has guidelines for class presentation of each chapter, answer key, Student&rsquo;s Study Guide.</li>\r\n<li>Hardbound</li>\r\n</span>\r\n</ul>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(45, 'en', 'The Process of Research in Psychology', '', '', '<p><strong style="color: #000000; font-family: Arial, Verdana, ''Sans Serif''; line-height: 15px; text-align: justify;">A student friendly, thoughtfully organized introduction to research in psychology&nbsp;</strong><br style="color: #000000; font-family: Arial, Verdana, ''Sans Serif''; line-height: 15px; text-align: justify;" /><br style="color: #000000; font-family: Arial, Verdana, ''Sans Serif''; line-height: 15px; text-align: justify;" /><span style="color: #000000; font-family: Arial, Verdana, ''Sans Serif''; line-height: 15px; text-align: justify;">Employing numerous examples and the pedagogical approach of spaced repetition, this introductory text provides a step-by-step explanation of how to design, conduct, and present a research study in psychology. Chronologically organized and chock-full of pedagogy, this book creates logical scaffolding upon which students can build their knowledge.</span><br style="color: #000000; font-family: Arial, Verdana, ''Sans Serif''; line-height: 15px; text-align: justify;" /></p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(46, 'en', 'The Official SAT Study Guide: Second Edition(TM)', '', '', '<p>&nbsp;</p>\r\n<p class="dtm" style="margin-top: 10px !important; margin-right: 0px; margin-bottom: 10px; margin-left: 0px; color: #000000; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 11px; text-align: left; background-color: #ffffff;">When it comes to getting answers, go to the source!&nbsp;<em>The Official SAT Study Guide: Second Edition&trade;</em>&nbsp;features 10 SAT&reg; practice tests created by the test maker. With over 1,000 pages and more than 20 chapters, it''s packed with the most up-to-date information students need to get ready for the test.</p>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px; color: #000000; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 11px; text-align: left; background-color: #ffffff;">Students will gain valuable experience and raise their confidence by taking practice tests, by reviewing critical concepts, test-taking approaches, and focused sets of practice questions just like those on the actual SAT.</p>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px; color: #000000; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 11px; text-align: left; background-color: #ffffff;"><em>The Official SAT Study Guide: Second Edition&trade;</em>&nbsp;will help students get ready for the SAT with:</p>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 16px; color: #000000; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 11px; text-align: left; background-color: #ffffff; padding: 0px;">\r\n<li style="list-style-image: url(http://store.collegeboard.com/common/shared/images/bullet.gif); list-style-type: square; margin-bottom: 10px;">10 official SAT practice tests, including 3 new recent exams</li>\r\n<li style="list-style-image: url(http://store.collegeboard.com/common/shared/images/bullet.gif); list-style-type: square; margin-bottom: 10px;">detailed descriptions of math, critical reading, and writing sections of the SAT</li>\r\n<li style="list-style-image: url(http://store.collegeboard.com/common/shared/images/bullet.gif); list-style-type: square; margin-bottom: 10px;">targeted practice questions for each SAT question type</li>\r\n<li style="list-style-image: url(http://store.collegeboard.com/common/shared/images/bullet.gif); list-style-type: square; margin-bottom: 10px;">practice essay questions, along with sample essays and annotations</li>\r\n<li style="list-style-image: url(http://store.collegeboard.com/common/shared/images/bullet.gif); list-style-type: square; margin-bottom: 10px;">a review of math concepts tested in the exam</li>\r\n<li style="list-style-image: url(http://store.collegeboard.com/common/shared/images/bullet.gif); list-style-type: square; margin-bottom: 10px;">test-taking approaches and suggestions that underscore important points</li>\r\n<li style="list-style-image: url(http://store.collegeboard.com/common/shared/images/bullet.gif); list-style-type: square; margin-bottom: 10px;">free online score reports</li>\r\n<li style="list-style-image: url(http://store.collegeboard.com/common/shared/images/bullet.gif); list-style-type: square; margin-bottom: 10px;">exclusive access to online answers and explanations at collegeboard.org</li>\r\n<li style="list-style-image: url(http://store.collegeboard.com/common/shared/images/bullet.gif); list-style-type: square; margin-bottom: 10px;">$10 discount on&nbsp;<em>The Official SAT Online Course</em>&nbsp;to all book owners</li>\r\n</ul>\r\n<p><span style="color: #000000; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 11px; text-align: left; background-color: #ffffff;">There''s also a complete chapter on the PSAT/NMSQT&reg;</span></p>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', '');
INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(47, 'en', 'MARVEL® VS. CAPCOM® 3: FATE OF TWO WORLDS SPECIAL EDITION (PS3)', '', '', '<p><span style="color: #242424; font-family: Arial, Verdana, Helvetica, sans-serif; text-align: left; background-color: #ffffff; font-size: xx-small; padding: 0px; margin: 0px;">The ultimate "VS." Series was born here!</span></p>\r\n<ul style="padding-top: 0px; padding-right: 20px; padding-bottom: 0px; padding-left: 20px; margin-top: 10px; margin-bottom: 20px; margin-left: 0px; list-style-position: initial; list-style-image: initial; color: #242424; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">\r\n<li style="padding-top: 2px; padding-bottom: 8px; padding-left: 20px; background-image: url(http://drh.img.digitalriver.com/DRHM/Storefront/Site/capcomus/cm/images/site/bg_bullet.jpg); background-attachment: scroll; background-origin: initial; background-clip: initial; background-color: transparent; background-position: 0% 5px; background-repeat: no-repeat no-repeat; margin: 0px;"><strong style="padding: 0px; margin: 0px;">Innovative graphics and gameplay bring the Marvel&reg; and Capcom universes to life:</strong>Powered by an advanced version of MT Framework, the engine used in Resident Evil&reg; 5 and Lost Planet&reg; 2, Marvel&reg; vs. Capcom&reg; 3 brings beautiful backgrounds and character animations to the forefront</li>\r\n<li style="padding-top: 2px; padding-bottom: 8px; padding-left: 20px; background-image: url(http://drh.img.digitalriver.com/DRHM/Storefront/Site/capcomus/cm/images/site/bg_bullet.jpg); background-attachment: scroll; background-origin: initial; background-clip: initial; background-color: transparent; background-position: 0% 5px; background-repeat: no-repeat no-repeat; margin: 0px;"><strong style="padding: 0px; margin: 0px;">Evolved VS. Fighting System:</strong>&nbsp;Wild over-the-top gameplay complete with signature aerial combos, hyper combos and more. The evolved new battle system, the &ldquo;Team Aerial Combo,&rdquo; takes the exciting mind-reading game to a whole new level!</li>\r\n<li style="padding-top: 2px; padding-bottom: 8px; padding-left: 20px; background-image: url(http://drh.img.digitalriver.com/DRHM/Storefront/Site/capcomus/cm/images/site/bg_bullet.jpg); background-attachment: scroll; background-origin: initial; background-clip: initial; background-color: transparent; background-position: 0% 5px; background-repeat: no-repeat no-repeat; margin: 0px;"><strong style="padding: 0px; margin: 0px;">3-on-3 Tag Team Fighting:</strong>&nbsp;Players build their own perfect team by assigning unique &ldquo;Assist Attacks&rdquo; for each character and utilize each character&rsquo;s special moves to create their own unique fighting style</li>\r\n<li style="padding-top: 2px; padding-bottom: 8px; padding-left: 20px; background-image: url(http://drh.img.digitalriver.com/DRHM/Storefront/Site/capcomus/cm/images/site/bg_bullet.jpg); background-attachment: scroll; background-origin: initial; background-clip: initial; background-color: transparent; background-position: 0% 5px; background-repeat: no-repeat no-repeat; margin: 0px;"><strong style="padding: 0px; margin: 0px;">Simple Mode:</strong>&nbsp;Streamlined button mapping option allows novice players to perform moves like a pro</li>\r\n<li style="padding-top: 2px; padding-bottom: 8px; padding-left: 20px; background-image: url(http://drh.img.digitalriver.com/DRHM/Storefront/Site/capcomus/cm/images/site/bg_bullet.jpg); background-attachment: scroll; background-origin: initial; background-clip: initial; background-color: transparent; background-position: 0% 5px; background-repeat: no-repeat no-repeat; margin: 0px;"><strong style="padding: 0px; margin: 0px;">Living Comic Book Art Style:</strong>&nbsp;See the most adored characters from the Capcom and Marvel&reg; universes brought to life in a &ldquo;moving comic&rdquo; style, blurring the boundaries between 2D and 3D graphics</li>\r\n<li style="padding-top: 2px; padding-bottom: 8px; padding-left: 20px; background-image: url(http://drh.img.digitalriver.com/DRHM/Storefront/Site/capcomus/cm/images/site/bg_bullet.jpg); background-attachment: scroll; background-origin: initial; background-clip: initial; background-color: transparent; background-position: 0% 5px; background-repeat: no-repeat no-repeat; margin: 0px;"><strong style="padding: 0px; margin: 0px;">New Characters:</strong>&nbsp;Popular returning characters include Spider-Man, Ryu, Wolverine, Morrigan, Iron Man, Hulk, Captain America, Felicia, Chun-Li, Tron Bonne, Magneto and Doctor Doom. Viewtiful Joe will make his debut in the Marvel vs. Capcom franchise.&nbsp;<strong style="padding: 0px; margin: 0px;">New characters joining the playable cast for the first time in fighting game history include Chris Redfield, Thor, Trish, Super-Skrull, Amaterasu, Dormammu, Wesker, X-23, Arthur, Deadpool, Nathan Spencer, M.O.D.O.K. and Dante!</strong></li>\r\n</ul>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(48, 'en', 'TS-MR2040', '', '', '<p>This is marine audio at its best. This 8" two-way speaker is built specifically for marine use, with heavy-duty construction that strenuously resists water, corrosion, heat&mdash;and boring music. Pioneer research showed that more bass is required for boating applications, and this 8" size delivers.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(49, 'en', 'TS-MR1640', '', '', '<p>Whether you''re out on the water or at the dock, this 6-1/2&rdquo; two-way speaker adds a new dimension to your boat. It''s built specifically for marine use, with heavy-duty construction inside and out that strenuously resists water, corrosion, heat, and sunlight.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(50, 'en', 'TS-D1720C', '', '', '<p>Absolute fidelity to musical sources takes form from speakers that reproduce the ambience in which sounds originate. Stage size, musicians&rsquo; movement, aural reflection and other distinctive details all bring these sounds to life. Pioneer D-Series speakers are available in 2-way component packages or 2-way coaxial designs in multiple sizes that fit most vehicles.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(51, 'en', 'TS-D6902R', '', '', '<p>Absolute fidelity to musical sources takes form from speakers that reproduce the ambience in which sounds originate. Stage size, musicians&rsquo; movement, aural reflection and other distinctive details all bring these sounds to life. Pioneer D-Series speakers are available in 2-way component packages or 2-way coaxial designs in multiple sizes that fit most vehicles.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(52, 'en', 'KFC-W3013PS', '', '', '<p>1200W Peak Power<br /> 400W RMS Power<br /> 4 ohms Impedance<br /> 34Hz - 300Hz Frequency Response<br /> 6" Mounting Depth<br /> PP Cone with Diamond Array Pattern<br /> Dual-Ventilation System<br /> Rubber Surround</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(53, 'en', 'KFC-W3012', '', '', '<p>Super-sturdy, super powerful, the KFC-W3012 is a 12-inch, 4-ohm sub that handles an impressive 1200W of power. A truly high-performance sub, the KFC-W3012 has a long stroke design and a silver textured pattern cone woofer that adds strength and rigidity to the cone for maximum bass performance.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(54, 'en', 'TS-W3002D2|D4', '', '', '<p>The TS-W3002D2/4 subwoofers are designed to produce enormously powerful music. Just take a look at its super-heavy-duty construction, all designed to handle up to 3,500 watts max. Double-stacked magnets for higher power, and a step-up radial surround for superior control and long excursions. We used a constructed cast-aluminum basket for this sub. Add in our patented IMPP cone and you''ve got a monster sub that can handle whatever you want to throw at it.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(55, 'en', 'PRS-D800', '', '', '<p>The PRS-D800 2-channel amplifier contains audiophile grade components that were carefully selected and design perfected to achieve highest audio quality.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(56, 'en', 'GM-6500F', '', '', '<p>From dramatic distinction to dramatic design, Pioneer''s new GM-Series amplifiers are thrillers in every sense, pushing the limits of flexibility and functionality.<br /><br />The 4-channel GM-6500F delivers a whopping 760 watts max - plenty of juice to power your speakers. It''s also got built-in low-pass/high-pass crossovers, speaker level inputs for easy connection to an OEM headunit and oversized power terminals.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(57, 'en', 'GM-D8500M', '', '', '<p>Class-D amplifiers overcome the inefficiencies of traditional Class-A or AB amplifiers. Pioneer&rsquo;s Class-D amps transform very little power into heat so a higher percentage of the power supply (67%) is transformed into the load. This results in a very compact amp which needs less input power to produce very high output power. The Class-D amplifier&rsquo;s PWM (Pulse Width Modulator) modulates the original audio input signal with a triangulated signal wave which has a much higher fixed frequency. The result is a digital signal which contains both the input signal and a band of frequency components around the modulation frequency. A LPF (Low Pass Filter) then filters out the high frequency pulses and the resulting amplified output signal is then sent to the subwoofer and/or speakers.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(58, 'en', 'AVH-P8400BH', '', '', '<p>The AVH-P8400BH is Pioneer''s top-of-the-line DVD multimedia receiver that features a beautiful 7" motorized touchscreen interface with our new Advanced Display Resolution technology, built-in Bluetooth&reg; for hands-free calling and audio streaming, an HD Radio&trade; tuner, and Advanced App Mode for iPhone&reg; 4/4S. The newly designed and innovative user interface makes direct operation of the unit stress-free by eliminating complicated layered selection displays, so access to desired functions is smoother and simpler than ever. A variety of multimedia options ensures that you will be properly entertained. Customizable audio and video functions make it easy to suit your mood.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(59, 'en', 'AVH-P4400BH', '', '', '<p>The AVH-P4400BH DVD multimedia receiver features a 7" motorized touchscreen display, built-in Bluetooth&reg; for hands-free calling and audio streaming, and an HD Radio&trade; tuner. The newly updated and innovative user interface makes direct operation of the unit stress-free by eliminating complicated layered selection displays, so access to desired functions is smoother and simpler than ever. A variety of multimedia options ensures that you will be properly entertained. Customizable audio and video functions make it easy to suit your mood.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(60, 'en', 'AVIC-Z130BT', '', '', '<p>Pioneer''s flagship navigation receiver, the double-DIN AVIC-Z130BT features built-in navigation with maps of the US, Alaska, Hawaii, Canada, and Puerto Rico. Get there fast with spoken street names, lane guidance, and a wealth of GPS features, and stay in touch on the way with built-in Bluetooth for hands-free calling. The motorized 7-inch WVGA touchscreen display is great for GPS and for navigating your entertainment, whether it''s DVDs or CDs, your digital media from USB drives or microSD cards, or content from your iPhone. Speaking of iPhones, the AVIC-Z130BT features enhanced integration with Pandora and Aha Radio apps, along with GPS features through the free AVIC FEEDS app.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(62, 'en', 'XRS 9945', '', '', '<p>The XRS 9945 provides total protection and peace of mind with Super-Xtreme Range Superheterodyne&trade; Technology, detecting all 15 radar/laser bands with its super-fast lock-on detection circuitry. The unit provides extra detection range and the best possible advance warning to even the fastest of POP mode radar guns. Other features include Cobra exclusive full-color ExtremeBright DataGrafix&reg; Display, an 8-point electronic compass, Voice Alert&trade;, car battery voltage display/low car battery warning and much more.<br /><br /> With the optional GPS Locator and AURA&trade; Database, upgrade your unit to alert you to verified Speed and Red Light Camera locations, dangerous intersections, and reported Speed Trap locations for entire United States and Canada (purchase and subscription necessary).</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(63, 'en', 'XRS 9770', '', '', '<p>The XRS 9770 provides total protection and peace of mind with Xtreme Range Superheterodyne Technology, detecting all 15 radar/laser bands with its completely new, super-fast lock-on detection circuitry. The unit provides extra detection range and the best possible advance warning to even the fastest of POP mode radar guns. Other features include DigiView&reg; Text Display, an 8-point electronic compass, Voice Alert, and much more.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(64, 'en', 'XRS 9745', '', '', '<p>The XRS 9745 provides total protection and peace of mind with Xtreme Range Superheterodyne&reg; Technology, detecting all 15 radar/laser bands with its super-fast lock-on detection circuitry. The unit provides extra detection range and the best possible advance warning to even the fastest of POP mode radar guns. Other features include DigiView&reg; Text Display, an 8-point electronic compass, Voice Alert&trade;, and much more.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(65, 'en', 'XRS 9370', '', '', '<p>The XRS 9370 provides total protection and peace of mind with the Xtreme Range Superheterodyne technology, detecting all 14 radar/laser bands at greater range than its predecessor. It comes in an industry-leading compact design with UltraBright&trade; Data Display, LaserEye&reg;, and much more.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(66, 'en', 'XRS 9970G', '', '', '<p>The XRS 9970G provides total protection and peace of mind with Super-Xtreme Range Superheterodyne Technology, detecting all 15 radar/laser bands with its super-fast lock-on detection circuitry. The unit provides extra detection range and the best possible advance warning to even the fastest of POP mode radar guns. . It comes with a GPS Locator and Lifetime updates to the AURA&trade; Database to alert you to verified Speed and Red Light Camera locations, dangerous intersections, and reported Speed Trap locations for entire United States and Canada.  Other features include Cobra exclusive Touchscreen, full-color ExtremeBright DataGrafix Display, an 8-point electronic compass, Voice Alert, car battery voltage display/low car battery warning and much more.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(67, 'en', 'HTC Wildfire S - White (T-Mobile)', '', '', '<p>The HTC Wildfire S for T-Mobile is a 3G capable smartphone that adds style to a practical device. This sleek device runs on the Android&trade; 2.3 platform, so you can have the latest Android&trade; technology and access to thousands of apps. It also features a 3.2 inch capacitive touchscreen, a 5 megapixel camera for capturing important moments and Wi-Fi calling/hotspot capabilities! Weighing only 3.7 ounces, the Wildfire S is extremely portable. If you are looking for a stylish and fun smartphone that is easy to use, the HTC Wildfire S could be the phone for you!</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(68, 'en', 'Titan', '', '', '<p>In the right hands, amazing things happen.<br /><br />Put emails in their place<br /> Combine your personal inboxes while keeping your work account separate.<br /><br />Plenty of room in the office<br /> Microsoft&reg; Office Mobile and multitasking on a huge <br /> 4.7" screen makes plenty of room for work, wherever you go.<br /><br />Focus on thoughts, not thumbs<br /> With such a spacious keypad, you can stop focusing on your fingers and start focusing on ideas.<br /><br />Expansive display, infinite possibility<br /> Whether you&rsquo;re taking care of business or taking a break from it all, you can see the big picture on the 4.7" LCD screen.<br /><br />Pocket-sized profile<br /> At 9.9mm, it&rsquo;s slim enough to fit comfortably in your pocket. But considering everything the HTC TITAN with Windows Phone is capable of, it won&rsquo;t be spending much time there.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(69, 'en', 'Rhyme', '', '', '<p>HTC Rhyme&trade; and its suite of innovative accessories<br /> deliver seamless experiences.<br /><br />Docking Station<br />Effortlessly slide the HTC Rhyme into the Docking Station to charge it and automatically activate Dock Mode, turning your phone into an all-in-one alarm clock, music player, and picture frame.<br /><br /> Charm<br /> Attached to your bag, the Charm alerts you of calls, missed calls, and messages. It also keeps your phone within easy reach and goes with anything.<br /><br /> Tangle&ndash;free Headphones<br /> These headphones don&rsquo;t just sound amazing&mdash;they&rsquo;re virtually tangle-free, thanks to flat wires.<br /><br />Exclusive HTC Sense&trade; experience<br /> The HTC Rhyme delivers a visually refined and intuitive <br /> HTC Sense experience. Find what you want faster with streamlined menus across HTC Sense apps and get the live info you care about on the home screen with the Quick Launch widget. Stay on top of all your to-dos by creating tasks from emails and messages, then sync those tasks with your Microsoft&reg; Exchange account for one to-do list on phone and PC.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(70, 'en', 'EVO Design 4G', '', '', '<p>The HTC EVO Design 4G is a high-end smartphone that is packed full of the latest features! Powered by Android 2.3, this device comes pre-loaded with the newest Android Platform for smartphones. You can choose from thousands of apps and games at the Android Marketplace. The HTC EVO Design 4G also comes loaded with a 4.0&rdquo; qHD capacitive touch display, with the latest version of HTC Sense, and international phone capabilities. With a 5 megapixel main camera, you will have the ability to capture, record and playback in HD. This smartphone also features a 1.3 megapixel front-facing camera for video chats! Quickly download movies and create user generated content with a flash-enabled web browsing experience running on Sprint''s 4G network and the power of a 1.2 GHz processor.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(71, 'en', 'DROID INCREDIBLE 2', '', '', '<p>Socialize with a sense of style<br /> The Droid Incredible 2 by HTC is ready to party. Its sleek, all-black design will get looks, and front and back cameras can help capture a scene, start a conversation, or snap a self-portrait. You can record the night''s most memorable moments in 720p HD video for sharing later.<br /><br />A phone that''s designed around you<br /> HTC Sense&trade; lets you do more in fewer steps with a friendly experience that brings everything you care about right to the surface. You can easily make your phone your own and put everything exactly where you want it. FriendStream&trade; pulls together all your friends'' Twitter,&trade; Facebook,&reg; and Flickr&reg; updates in one place. Here''s an idea: Choose a People widget that lets you see everybody''s latest updates and messages right on the home screen. You can also select a compact People widget that just shows their profile pictures.<br /><br />Worth watching &mdash; and listening to<br /> Your music and movies look and sound great on a 4-inch super LCD screen with SRS WOW&trade; HD surround sound. Get access to unlimited songs through V CAST&trade; Music with Rhapsody or tune in to the expert DJs on Slacker&reg; Internet Radio. V CAST Video on Demand gives you on-the-go access to more shows and movies, including those available from BLOCKBUSTER On Demand.&reg;<br /><br />Invite friends to your own private Hotspot<br /> Your phone turns into a 3G Mobile Hotspot, for up to five other Wi-Fi&reg;&ndash;enabled devices. That just might make you more popular than ever.<br /><br />Call anyone, anywhere &mdash; no matter where you travel<br /> The global-ready Droid Incredible 2 by HTC will keep you connected from Lima to London.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(72, 'en', 'DROID RAZR', '', '', '<p>DESIGN: THINNEST 4G LTE SMARTPHONE<br />DROID RAZR is so thin, it makes microchips feel flabby. The thinnest 4G LTE smartphone, it can get you out of the tightest of situations while letting you keep your cool.<br /><br />CONSTRUCTION: DROID STRONG, RAZR SHARP<br />DROID RAZR proves that thin no longer equals frail. It''''s made strong with KEVLAR&reg; fiber, while Corning&reg; Gorilla&reg; Glass defends the screen against scrapes and scratches. A force field of water-repellent nanoparticles shields the phone against water attacks - even the electrical boards inside.<br /><br />NETWORK SPEED: DOMINATE AT WARP SPEED<br />Unleash the fierce power of Verizon''s 4G LTE network, piloted by a dual-core 1.2 GHz processor. Blast your music and check the score, while email reloads - all at the same time, without delay. The 1 GB of RAM keeps you rocketing through.<br /><br />DUAL CAMERAS: LIFE HAS NEVER LOOKED BETTER<br />Create some cinematic awesomeness of your own with an 8MP rear camera and 1080p HD video recording. Ready for all conditions, DROID RAZR has image stabilization technology for less blurry video.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(73, 'en', 'DROID BIONIC', '', '', '<p>With a ferociously fast Verizon Wireless 4G LTE network and dual-core 1 GHz processor, DROID BIONIC is the master of all Droids. And with ZumoCast&trade; by Motorola, nothing is beyond your digital reach. The free app lets you pull your music, movies, pictures and documents from your computer like a digital telepath - instantly and wirelessly. That''s right, DROID BIONIC is so powerful, it can control your connected devices and extract their precious content, remotely, at 4G LTE speed. That makes it not only the master of all Droids, but the master of machines.<br /><br />Key Features:<br /> Our free Zumocast&trade; app lets you stream content 24/7 and in real time from your computer <br /> 4G LTE speeds up to 10x faster than 3G to stream movies, watch TV and video chat <br /> Crisp text, vivid imagery and brilliant color delivered in 4.3-inch high res qHD <br /> Doubles as a 4G LTE mobile hotspot for up to 5 Wi-Fi enabled devices <br /> Dual-core 1GHz processor and 1GB RAM <br /> Webtop app transforms your phone; surf the web, run apps and take calls - all at the same time <br />In The Box:<br /> DROID BIONIC phone<br />HW4X Standard Battery<br /> Standard Battery Door<br />Travel Charger<br />Micro USB Data cable<br /> User Guide</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(74, 'en', 'Droid 3', '', '', '<p>You''re going places, and DROID 3 by Motorola can take you there. With incredible dual-core speed and brilliant qHD display. You''re making a big Android smartphone statement. DROID 3 offers more power and greater responsiveness, and the efficient handling of a five-row keyboard. The thinnest full QWERTY smartphone. Ever.<br /><br />Key Features: <br />Adobe&reg; Flash&reg; Player for stellar video and gaming<br />Scratch-resistant Corning&reg; Gorilla&reg; Glass with glare reducing coating<br />View, capture and share on the large 4-inch qHD display<br />An 8MP camera with 1080p HD video and front-facing web cam to see and be seen<br />Video capture in 1080p HD; output to compatible device via HDMI&reg; micro connector cable<br />Thinnest Full QWERTY smartphone ever.<br /> Super-charged dual-core 1GHz processor makes multi-tasking a snap<br /> What you get in the box: <br />DROID 3 phone <br />Battery Door <br />Battery <br />Charger <br />User Guide</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(75, 'en', 'DROID PRO', '', '', '<p>Access your work directory, email or calendar with Droid Pro by Motorola, an Android-for-business smartphone with corporate-level-security. It features both a QWERTY keyboard and touchscreen, a speedy 1 GHZ processor and Adobe&reg; Flash&reg; Player 10.<br /><br /> Key Features: <br /> Up to 2GB memory on board, 2GB microSD pre-installed, expandable up to 34GB <br /> 5MP camera with auto focus and dual-LED flash <br /> Touchscreen navigation, pinch to zoom and customized home screens <br /> CDMA plus quad-band GSM and tri-band UTMS <br /> Ultra-fast 1 GHz processor for better web browsing and speedy UI and downloads <br /> Android 2.2 (Froyo) Platform <br /> Mobile Email: IMAP and POP, Microsoft Exchange, Gmail&trade;, MSN Hotmail&reg;, Yahoo!&reg; and AOL&reg; <br /> Quickoffice&reg;, Skype mobile&trade;, YouTube, AuthenTec VPN client, Mediashare, File Manager <br /> Be a mobile hot spot for up to 5 other devices <br /> Adobe&reg; Flash&reg; Player 10 <br />What you get: <br /> DROID PRO by Motorola phone <br /> Battery <br /> Battery Door <br /> Travel Charger <br /> User Guide</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(76, 'en', 'FLIPSIDE with MOTOBLUR', '', '', '<p>MOTOROLA FLIPSIDE&trade; is a powerhouse at work or play, with enhanced MOTOBLUR to not only sync social media, but now to help prioritize - with content filters and resizable widgets to keep you on track.<br /><br /> Key Features: <br />Use Global Address Lookup to access corporate directions and easily schedule meetings on the go <br /> Touchscreen supports pinch-to-zoom or slide open for QWERTY keyboard and laptop-like nav pad <br /> Extend time between charges as MOTOBLUR battery manager monitors power consumption <br />Prioritize home screen messages using MOTOBLUR filters and resizable widgets <br />CrystalTalk&trade; PLUS technology amplifies your voice and filters out background noise <br />Facebook&trade;, MySpace and Twitter Direct Messaging <br />What you get in the box:: <br />FLIPSIDE&trade; with MOTOBLUR&trade; for AT&amp;T phone <br /> Battery BT61 <br /> Battery Door <br />Travel Charger <br /> User Guide</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(117, 'en', 'SCH-I515', '', '', '<p>Galaxy Nexus is the world''s first phone with a 4.65" high-definition  Super AMOLED display, making text, photos, videos and games look crisp,  vibrant and rich. With 1280x720 HD resolution, videos look amazing and  the unique Contour Display curves nicely to the shape of your face and  makes it easier to hold.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(118, 'en', 'Smallville: The Complete Tenth Season', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Screen Aspect: 16 X 9 FULL FRAME</p>\r\n<p>Run Time: 1012 minutes</p>\r\n<p>Episodes Info :</p>\r\n<p>Lazarus</p>\r\n<p>Shield</p>\r\n<p>Supergirl</p>\r\n<p>Homecoming</p>\r\n<p>Isis</p>\r\n<p>Harvest</p>\r\n<p>Ambush</p>\r\n<p>Abandoned</p>\r\n<p>Patriot</p>\r\n<p>Luthor</p>\r\n<p>Icarus</p>\r\n<p>Collateral</p>\r\n<p>Beacon</p>\r\n<p>Masquerade</p>\r\n<p>Fortune</p>\r\n<p>Scion</p>\r\n<p>Kent</p>\r\n<p>Booster</p>\r\n<p>Dominion</p>\r\n<p>Prophecy</p>\r\n<p>Finale Part 1</p>\r\n<p>Finale Part 2</p>\r\n<p>Special Features:</p>\r\n<p>Commentaries on 2 Key Episodes</p>\r\n<p>Unaired Scenes</p>\r\n<p>Smallville: Coming Home: Cast and Creators Reflect on the Landmark 200th Episode Homecoming, in Which Clark Kent Experiences</p>\r\n<p>Transformative Events on the Way to His Final Destiny</p>\r\n<p>My Fathers, My Son: How Clark Kent&rsquo;s Fathers/Son Relationships Evolved over the Series&rsquo; 10 Years</p>\r\n<p>How Do We Do Music Video</p>\r\n<p>Media Quantity: Multi D</p>\r\n<p>Packaging Type: VIVA 6 Disc 25mm Case</p>\r\n<p>Subtitle Languages:</p>\r\n<p>Chinese</p>\r\n<p>French</p>\r\n<p>Portuguese</p>\r\n<p>Spanish</p>\r\n<p>Copyright:</p>\r\n<p>SMALLVILLE and all related characters and elements are trademarks of and &copy; DC Comics.</p>\r\n<p>Genre: Drama, Television</p>\r\n<p>Synopsis:</p>\r\n<p>The series that redefines the origins of the world&rsquo;s greatest hero reaches its powerful conclusion with more revelations, more fascinating characters from DC Comics lore and a mind-blowing, spirit-lifting finale that is everything fans could want. In this 22-Episode Season 10, super heroes emerge from the shadows, only to be driven underground by a public that labels them vigilantes. At the same time, otherworld forces of darkness gather, presenting Clark Kent with the greatest challenge of his young life. The world he calls home and the people he loves &ndash; including Lois Lane, who now shares his secret and his life &ndash; need a champion. They shall have one. Don&rsquo;t miss all the hopes, heartaches and heroics of a final season to remember. They will lift you up, up and away.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(78, 'en', 'adizero Rush Shoes', '', '', '<p>Get moving in the lightweight adizero&trade; Rush shoes by adidas. These  featherweight, dynamic men''s running shoes are just 7.5 ounces of  high-mileage style, with adiPRENE&reg;+ support in the forefoot, a light  synthetic upper and a thin rubber outsole for a close</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(79, 'en', 'adiZero Tempaia Shoes', '', '', '<p>\r\n	The adiZero™ Tempaia shoes by adidas are lightweight, breathable tennis  shoes designed for multi-court use. They feature a breathable upper,  adiPRENE®+ in the forefoot for propulsion, adiPRENE® heel cushioning and  EXTENDED TORSION® for support.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(80, 'en', 'Nike Tenkay Slip TXTL Women''s Shoe', '', '', '<div class="black-white-black-white text description">\r\n<div class="product-description-component">\r\n<p><strong>The Nike Tenkay Slip TXTL: Casual-cool with a sporty side</strong></p>\r\nVersatile  and super comfortable, the Nike Tenkay Slip TXTL Women''s Shoe looks as  good as it feels. With a soft textile upper and a durable rubber  outsole, this shoe provides excellent traction on a variety of surfaces.<br />\r\n<p><strong>Benefits</strong></p>\r\n<li>Textile upper with suede overlays for a comfortable fit</li>\r\n<li>Elastic slip-on entry for easy on and off</li>\r\n<li>Flex grooves at outsole for enhanced flexibility</li>\r\n<br />\r\n<p><strong>Additional Details</strong></p>\r\n<li>Removable ankle strap for a versatile fit</li>\r\n<li>Rubber outsole for durability</li>\r\n</div>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(81, 'en', 'Minnetonka Original Cowhide Driving Moc', '', '', '<div class="linePadding leadingEquity">Authentic designs. Free-spirited heritage. Shaping the moccasin''s place in history since 1946.</div>\r\n<div class="linePadding">Leather</div>\r\n<ul class="equityBullets firstSet">\r\n<li>&bull; Genuine leather construction </li>\r\n<li>&bull; Lace-up front </li>\r\n<li>&bull; Long-wearing nub bottom </li>\r\n<li>&bull; Cushioned leather insole </li>\r\n<li>&bull; Contrast stitching </li>\r\n</ul>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(82, 'en', 'Legend of the Guardians: the Owls of Ga''hoole(VG)', '', '', '<ul class="desc_details" style="margin-top: 0px; margin-bottom: 0px; margin-left: 0px; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; font-size: 11px; font-family: Verdana, Helvetica, Arial, sans-serif; vertical-align: baseline; list-style-position: initial; list-style-image: initial; color: #ffffff; line-height: 11px; padding: 0px; border: 0px initial initial;"><li style="padding-bottom: 5px; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; font-style: inherit; font-family: inherit; vertical-align: baseline; line-height: 15px; clear: left; margin: 0px; border: 0px initial initial;"><span style="color: #000000;"><strong>Studio:</strong> Warner Home Video</span></li>\r\n<li style="padding-bottom: 5px; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; font-style: inherit; font-family: inherit; vertical-align: baseline; line-height: 15px; clear: left; margin: 0px; border: 0px initial initial;"><span style="color: #000000;"><strong>Theatrical Release Date: </strong>09/23/2010</span></li>\r\n<li style="padding-bottom: 5px; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; font-style: inherit; font-family: inherit; vertical-align: baseline; line-height: 15px; clear: left; margin: 0px; border: 0px initial initial;"><span style="color: #000000;"><strong>Packaging Type:</strong> Wii</span></li>\r\n<li style="padding-bottom: 5px; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; font-style: inherit; font-family: inherit; vertical-align: baseline; line-height: 15px; clear: left; margin: 0px; border: 0px initial initial;"><span style="color: #000000;"><strong>Genre:</strong> Action/Adventure</span></li>\r\n<li style="padding-bottom: 5px; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; font-style: inherit; font-family: inherit; vertical-align: baseline; line-height: 15px; clear: left; margin: 0px; border: 0px initial initial;"> \r\n<ul class="desc_details" style="margin-top: 0px; margin-bottom: 0px; margin-left: 0px; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; font-size: 11px; font-family: Verdana, Helvetica, Arial, sans-serif; vertical-align: baseline; list-style-position: initial; list-style-image: initial; color: #ffffff; line-height: 11px; padding: 0px; border: 0px initial initial;">\r\n<li style="padding-bottom: 5px; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; font-style: inherit; font-family: inherit; vertical-align: baseline; line-height: 15px; clear: left; margin: 0px; border: 0px initial initial;"><span style="color: #000000; background-color: #ffffff;"><strong style="border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; font-style: inherit; font-family: inherit; vertical-align: baseline; padding: 0px; margin: 0px; border: 0px initial initial;">Theatrical Release Date:</strong>&nbsp;09/23/2010</span></li>\r\n<li style="padding-bottom: 5px; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; font-style: inherit; font-family: inherit; vertical-align: baseline; line-height: 15px; clear: left; margin: 0px; border: 0px initial initial;"><span style="color: #000000; background-color: #ffffff;">Ships to U.S. Destinations Only</span></li>\r\n</ul>\r\n</li>\r\n</ul>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(83, 'en', 'Speed Racer: The Videogame (Wii)', '', '', '<p>&nbsp;</p>\r\n<p>Studio: Warner Home Video</p>\r\n<p>Packaging Type: Wii</p>\r\n<p>Genre: Action/Adventure, Racing</p>\r\n<p>Synopsis:</p>\r\n<p>Fantasy Violence, Mild Language</p>\r\n<p>&nbsp;</p>\r\n<p>After uncovering the corrupt influence of Royalton Industries and smashing all his opponents in The Crucible, Speed Racer returns for his 2nd year of racing and this time the illustrious World Racing League Cup is up for grabs. Who will be the fastest, most cunning racer to win is unknown. Watch out for Cannonball Taylor who has revenge on his mind, while choosing allies like Racer X, to overcome the challenges that this years circuit has to offer.</p>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(84, 'en', 'Lego Batman (Wii)', '', '', '<p>&nbsp;</p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Packaging Type: Wii</p>\r\n<p>Copyright:</p>\r\n<p>BATMAN and all related characters and elements are trademarks of and &copy; DC Comics. WBIE LOGO, WB SHIELD: &trade; &amp; &copy; Warner Bros. Entertainment Inc. (s08) LEGO, the LEGO logo and the Minifigure are trademarks of the LEGO Group. &copy; 2008 The LEGO Group. All Rights Reserved. LEGO BATMAN: THE VIDEOGAME Software &copy; 2008 TT Games Publishing Ltd. All other trademarks and copyrights are the property of their respective owners. All rights reserved.</p>\r\n<p>Genre: Action/Adventure, GAME</p>\r\n<p>Synopsis:</p>\r\n<p>Cartoon Violence</p>\r\n<p>&nbsp;</p>\r\n<p>When all the villains in Arkham Asylum team up and break loose, only the dynamic duo is bold enough to take them on to save Gotham City. The fun of LEGO, the drama of Batman and the uniqueness of the combination makes for a comical and exciting adventure in LEGO Batman: The Videogame. Play as Batman and his sidekick Robin as you build, drive, swing and fight your way through Gotham City capturing escaped villains including The Joker, Penguin, Scarecrow and more. Then, jump into the story from the other side and play as Batmans foes! Enjoy the power you wield and battle Batman while spreading chaos throughout the city. There is no rest for the good (or evil!).</p>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(85, 'en', 'Looney Tunes: Acme Arsenal (Wii)', '', '', '<p>&nbsp;</p>\r\n<p>Official Website: <a title="http://looneytunes.warnerbros.com/acmearsenal/" href="http://looneytunes.warnerbros.com/acmearsenal/">http://looneytunes.warnerbros.com/acmearsenal/</a></p>\r\n<p>Studio: Warner Home Video</p>\r\n<p>Packaging Type: Wii</p>\r\n<p>Genre: Action/Adventure</p>\r\n<p>Synopsis:</p>\r\n<p>Cartoon Violence</p>\r\n<p>&nbsp;</p>\r\n<p>Tag-team with the Tunes in the fight for their lives! Wield a major arsenal of ACME weapons as the tunes team-up to hunt down the mad scientist, chasing him through exotic locals from the past, present and future. Unite Bugs, Taz, Daffy, Marvin and more in a co-operative "whack-and-smash" romp through time - including online play! Melee and projectile weapons: Each character''s weapon/melee skills can power up three times on the fly as you go. Vehicle Based Action: Race a jet scooter across an alien environment or wage battle on top of a giant flying Pterodactyl...the possibilities are endless! Travel to various locations such as Camelot, Ancient Egypt, Mars, the Wild West and more! Top-notch voice talent provides the characters with their classic voices and an authentic Looney Tunes slapstick adventure, while giving their look an updated, next-generation, modern edge.</p>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(86, 'en', 'Nokia 700', '', '', '<p>Nokia 700 - Experience the thinnest and most compact Nokia touch Smartphone (L=4.33", W=1.97", Thickness=.38", Weight=.21 lbs.). Stay connected with friends and family with a compact and elegant device. Slim and sustainable elegance fits perfectly in your hand. Fresh and fast new Nokia UI delivers what you need when you need it. Personalize your multiple home screens with different sized widgets. Browsing experience like on your desktop PC. Choose from thousands of apps. Sharing pictures and pairing accessories has never been so easy. You can effortlessly share your photos and videos with NFC. Tap and access information and benefits from NFC tags placed in stores and public places. Crisp and Clear display makes it look almost as if the icons are painted on the surface of the handset with Vibrant colors and sharp contrasts indoors and outdoors, day or night. Extensive use of recycled metals, bio plastics and bio paint makes this the most Nokia Smartphone ever.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(87, 'en', 'Sesame Street:Cookie''s Counting Carnival (Wii)', '', '', '<p>\r\n<p>Studio: Warner Home Video</p>\r\n<p>Packaging Type: Wii</p>\r\n<p>Synopsis:</p>\r\n<p>Cookie Monster and Big Bird will guide you through festive numbers games and teach you all about counting at the greatest Carnival of Numbers! Play fun games in the many areas of the carnival such as the Grandstand, Rides, Petting Zoo, Concession Stand, Theater, and the Arcade.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(88, 'en', 'Lord of the Rings: War in the North(PS3)', '', '', '<p>&nbsp;</p>\r\n<p>Studio: Warner Home Video</p>\r\n<p>Packaging Type: PS3</p>\r\n<p>Genre: Action/Adventure, Racing</p>\r\n<p>Synopsis:</p>\r\n<p>In The Lord of the Rings: War in the North, players will experience an unrivaled Co-Op based Action/RPG gameplay experience &ndash; banding together on an untold journey to defeat the Dark Lord Sauron&rsquo;s forces and turn the tide in the War of the Ring.</p>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(89, 'en', 'Green Lantern: Rise of the Manhunters (PS3)', '', '', '<p>\r\n<p>Studio: Warner Home Video</p>\r\n<p>Packaging Type: PS3</p>\r\n<p>Genre: Action/Adventure</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(90, 'en', 'F.E.A.R. 3 (PS3) MX', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Packaging Type: PS3</p>\r\n<p>Genre: GAME</p>\r\n<p>Synopsis:</p>\r\n<p>As a specialized soldier in the elite squad, First Encounter Assault Recon (F.E.A.R.), you must uncover the mystery of Armacham&rsquo;s current operations, reassemble the lost F.E.A.R. and Delta teams, and stop the powerful paranormal entity, Alma, before she releases the most unimaginable horror into this world.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(91, 'en', 'Montblanc Nicolas Rieussec Chronograph Automatic', '', '', '<p>43 mm watch with stainless steel case, Montblanc Calibre MB R200,  monopusher chronograph with automatic winding, anthracite-coloured dial  with applique hour circle, date display, second time zone with day/night  display, chronograph counters with rotating discs.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', '');
INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(92, 'en', 'Montblanc TimeWalker Automatic', '', '', '<p>42 mm stainless steel watch with black dial, red-gold plated hands and  numerals, automatic movement, date display, black alligator-skin strap</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(93, 'en', 'Scene It? Bright Lights! Big Screen(X360)', '', '', '<p>\r\n<p>Studio: Warner Home Video</p>\r\n<p>Run Time: 1 minutes</p>\r\n<p>Packaging Type: XBOX 360 Amaray</p>\r\n<p>Genre: Party</p>\r\n<p>Synopsis:</p>\r\n<p>The popular movie trivia game franchise now launches its 3rd video game edition across all consoles with even more movie clips, feature-rich content, new mini-games, a dynamic visual package, DLC support, and four-player multiplayer.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(94, 'en', 'Batman: Arkham City (X360)', '', '', '<p>\r\n<p>Studio: Warner Home Video</p>\r\n<p>Packaging Type: XBOX 360 Amaray</p>\r\n<p>Genre: Action/Adventure</p>\r\n<p>Synopsis:</p>\r\n<p>The city''s greatest heroes and villains collide within the diseased heart of Gotham.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(95, 'en', 'Game Party: In Motion (X360)', '', '', '<p>\r\n<p>Studio: Warner Home Video</p>\r\n<p>Packaging Type: Wii</p>\r\n<p>Genre: Puzzle</p>\r\n<p>Synopsis:</p>\r\n<p>Get off the couch and get ready for the party as Game Party: In Motion turns your living room into the ultimate fun filled arcade. Grab your friends and family and jump right into the action as you use the motion of your entire body to play 16 exciting games. Throw a football at moving targets as you dodge an oncoming rusher or toss ringers in a game of horseshoes. Game Party: In Motion lets family and friends alike connect, play and get things moving!</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(96, 'en', 'Batman: Arkham City (X360) CE', '', '', '<p>\r\n<p>Studio: Warner Home Video</p>\r\n<p>Packaging Type: XBOX 360 Amaray</p>\r\n<p>Genre: Action/Adventure</p>\r\n<p>Synopsis:</p>\r\n<p>The city''s greatest heroes and villains collide within the diseased heart of Gotham.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(97, 'en', 'Harry Potter and the Deathly Hallows - Part 2 (Blu-ray+DVD+UltraViolet Digital Copy Combo Pack)', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Theatrical Release Date: 07/14/2011</p>\r\n<p>Special Features:</p>\r\n<p>- Disc 1 (Blu-ray): Feature Film and Maximum Movie Mode</p>\r\n<p>- Disc 2 (Blu-ray): Special Features</p>\r\n<p>- Disc 3: (DVD): Standard definition version of the film Also includes an UltraViolet Digital Copy for Instant Streaming (redeemed</p>\r\n<p>via in-packed insert)</p>\r\n<p>&nbsp;</p>\r\n<p>&bull; Maximum Movie Mode hosted by Matthew Lewis (Neville Longbottom) and other cast members - As the epic showdown between Harry</p>\r\n<p>Potter and Lord Voldemort approaches, don&rsquo;t miss a single detail as the forces of Good and Evil clash one final time throughout the</p>\r\n<p>grounds of Hogwarts.</p>\r\n<p>&bull; A Conversation with JK Rowling and Daniel Radcliffe - Join J.K. Rowling and Daniel Radcliffe for an exclusive conversation</p>\r\n<p>about bringing the character of Harry Potter to life, the last decade of films and how their lives have changed by the fame that</p>\r\n<p>they&rsquo;ve both experienced.</p>\r\n<p>&bull; The Goblins of Gringotts - Hosted by Warwick Davis, you&rsquo;ll see the entire process of becoming a goblin&rdquo; on a Harry Potter</p>\r\n<p>film, from auditions and casting to makeup and prosthetic tests as well as filming the final scenes.</p>\r\n<p>&bull; The Women of Harry Potter &ndash; A look at the remarkable women in Harry Potter&rsquo;s life and the critical role they play in the</p>\r\n<p>films.</p>\r\n<p>&bull; Warner Bros. Leavesden Studios Sneak Peek</p>\r\n<p>&bull; Deleted Scenes&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>Packaging Type: O-Sleeve 3-disc Elite BD Case</p>\r\n<p>Copyright:</p>\r\n<p>&copy; 2011 Warner Bros. Ent. Harry Potter Publishing Rights &copy; J.K.R. Harry Potter characters, names and related indicia are trademarks of and &copy; Warner Bros. Ent. All Rights Reserved.</p>\r\n<p>Genre: Drama, Fantasy Adventure, Mystery</p>\r\n<p>Synopsis:</p>\r\n<p>In the epic finale, the battle between the good and evil forces of the wizarding world escalates into an all-out war. The stakes have never been higher and no one is safe. But it is Harry who may be called upon to make the ultimate sacrifice as he draws closer to the climactic showdown with Lord Voldemort. It all ends here.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(112, 'en', 'Gone with The Wind: 2-Disc Special Edition', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Theatrical Release Date: 12/14/1939</p>\r\n<p>Run Time: 238 minutes</p>\r\n<p>Special Features:</p>\r\n<p>Commentary by Historian Rudy Behlmer</p>\r\n<p>&nbsp;</p>\r\n<p>Mail-in poster offer</p>\r\n<p>Media Quantity: Multi D</p>\r\n<p>Packaging Type: Double Eco Amaray Case</p>\r\n<p>Copyright:</p>\r\n<p>GONE WITH THE WIND, its characters and elements are trademarks of Turner Entertainment Co. &amp; The Stephens Mitchell Trusts. &copy; Turner Entertainment Co.</p>\r\n<p>Genre: Classic, Drama, Romance</p>\r\n<p>Synopsis:</p>\r\n<p>Period romance. War epic. Family saga. Popular fiction adapted with crowd-pleasing brilliance. Star acting aglow with charisma and passion. Moviemaking craft at its height. These are sublimely joined in the words Gone with the Wind. This dynamic and durable screen entertainment of the Civil War-era South comes home with the renewed splendor of a New 70th-Anniversary Digital Transfer capturing a higher-resolution image from Restored Picture Elements than ever before possible. David O. Selznick&rsquo;s monumental production of Margaret Mitchell&rsquo;s Pulitzer Prize-winning book can now enthrall new generations of home viewers with a majestic vibrance that befits one of Hollywood&rsquo;s greatest achievements.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(113, 'en', 'SGH-I677', '', '', '<p>The Samsung Focus Flash 4G mobile phone features Windows Phone 7.5 OS (Mango) and 4G speed for faster downloads and streaming. This 4G smartphone also includes a Super AMOLED touch screen for simple navigation of features, a rear-facing 5.0MP camera for still photos, a secondary front-facing camera for video chatting, and Bluetooth-compatibility for use with your favorite Bluetooth-enabled device. Plus, the Samsung Focus Flash 4G doubles as a mobile hotspot for up to 4 additional Wi-Fi enabled devices.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(114, 'en', 'Birds of Prey: The Complete Series (DVD)', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Screen Aspect: 4 X 3 FULL FRAME</p>\r\n<p>Episodes Info :</p>\r\n<p>13 One-Hour Episodes</p>\r\n<p>&nbsp;</p>\r\n<p>Pilot</p>\r\n<p>Slick</p>\r\n<p>Prey for the Hunter</p>\r\n<p>Three Birds and a Baby</p>\r\n<p>Sins of the Mother</p>\r\n<p>Primal Scream</p>\r\n<p>Split</p>\r\n<p>Lady Shiva</p>\r\n<p>Nature of the Beast</p>\r\n<p>Gladiatrix</p>\r\n<p>Reunion</p>\r\n<p>Feat of Clay</p>\r\n<p>Devil''s Eye</p>\r\n<p>Special Features:</p>\r\n<p>GOTHAM GIRLS SEASONS 1-3 - The animated web-based series featuring the</p>\r\n<p>female heroes and rogues from Gotham City.</p>\r\n<p>Media Quantity: Multi D</p>\r\n<p>Packaging Type: VIVA 4 Disc 15mm Case</p>\r\n<p>Genre: Drama, Television</p>\r\n<p>Synopsis:</p>\r\n<p>Who will stand up to villains now that a heartbroken Dark Knight has mysteriously vanished? Never fear, New Gothamites, a trio of champions is ready to take wing &ndash; and Helena, the daughter of Batman and Catwoman, is among them. She calls herself Huntress and crime is her prey. Teenaged Dinah is the youngest of the group, learning as she goes and gifted in clairvoyance. And overseeing the awesome threesome&rsquo;s high-tech nerve center is Batgirl. Left wheelchair-bound by The Joker, she has reinvented herself as Oracle, the team&rsquo;s cyber expert. Huntress, Dinah, Oracle: They are the Birds of Prey. Fighting together. Living together. And soaring into adventure together in 13 breathtaking live-action episodes.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(100, 'en', 'The Hangover Part II (Blu-ray)', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Theatrical Release Date: 05/25/2011</p>\r\n<p>Special Features:</p>\r\n<p>- Now includes Instant Streaming with UltraViolet Digital Copy</p>\r\n<p>MUST REDEEM DIGITAL COPY OFFER BY 12/06/2013</p>\r\n<p>- "Comedy Rhythm of Todd Phillips"</p>\r\n<p>- "Not Your Everyday Monkey"</p>\r\n<p>- "Bangkok Tour with Mr. Chow"</p>\r\n<p>- Action Mash-Up</p>\r\n<p>- Gag Reel</p>\r\n<p>Packaging Type: O-Sleeve BD Case</p>\r\n<p>Copyright:</p>\r\n<p>&copy; 2011 Warner Bros. Entertainment Inc. and Legendary Pictures. All Rights Reserved.</p>\r\n<p>Genre: Comedy</p>\r\n<p>Synopsis:</p>\r\n<p>Phil (Bradley Cooper), Stu (Ed Helms), Alan (Zach Galifianakis) and Doug (Justin Bartha) travel to exotic Thailand for Stu''s wedding. What could go wrong? Director Todd Phillips'' explosively funny follow-up to his award-winning smash hit demonstrates that though what happens in Vegas may stay in Vegas, what happens in Bangkok can hardly be imagined!</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(101, 'en', 'Nokia X3-02', '', '', '<p>Stay connected and keep yourself entertained wherever you roam with the sleek Nokia X3-02 unlocked GSM mobile phone. This stunning, touch-and-type phone features a keypad for easy messaging and a touch display for one-handed navigation. Touch and type is ideal for SMS and social networking where fast and frequent input is needed, while touch is ideal for functions such as setting alarms, smooth browsing and controlling applications like music and games.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(102, 'en', 'PR 100 Women''s White Quartz Watch', '', '', '<p>Unrivaled best seller that is true to its name, the PR 100 is certainly precise and hugely popular.<br /> <br /> A combination of tradition with up-to-the-minute looks using quality  materials on the outside and Swiss reliability on the inside.  This  ironic watch family offers lady and gent sizes to prevent any rivalry,  although as far as style is concerned, the race is on!  The Swiss made  quartz ETA movement has battery end-of-life indicator, a scratch  resistant sapphire crystal and date indicator.  Features include a  stainless steel bracelet, a magnificent white dial, and water resistance  up to 100 meters.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(103, 'en', 'Fringe: The Complete Third Season (Blu-Ray)', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Screen Aspect: 16 X 9 FULL FRAME</p>\r\n<p>Run Time: 1012 minutes</p>\r\n<p>Episodes Info :</p>\r\n<p>Olivia</p>\r\n<p>The Box</p>\r\n<p>The Plateau</p>\r\n<p>Do Shapeshifters Dream of Electric Sheep?</p>\r\n<p>Amber 31422</p>\r\n<p>6955 kHz</p>\r\n<p>The Abducted&hellip;</p>\r\n<p>Entrada</p>\r\n<p>Marionette</p>\r\n<p>The Firefly</p>\r\n<p>Reciprocity</p>\r\n<p>Concentrate and Ask Again</p>\r\n<p>Immortality</p>\r\n<p>6 B</p>\r\n<p>Subject 13</p>\r\n<p>Os</p>\r\n<p>Stowaway</p>\r\n<p>Bloodline</p>\r\n<p>Lysergic Acid Diethylamide</p>\r\n<p>6:02 AM EST</p>\r\n<p>The Last Sam Weiss</p>\r\n<p>The Day We Died</p>\r\n<p>Special Features:</p>\r\n<p>Duality of Worlds: Four featurettes exploring The Other You, Visualizing an Alternate World, A Machine of Destiny and The Psychology</p>\r\n<p>of Duality</p>\r\n<p>Animating the &ldquo;Lysergic Acid Diethylamide&rdquo; Episode</p>\r\n<p>Constructing an Extrasensory Soundscape</p>\r\n<p>BLU-RAY EXCLUSIVE &ndash; Glimmer to the Other Side</p>\r\n<p>Experience &ldquo;Os&rdquo; (Episode 316) in Selectable Maximum Episode Mode with Pop-Up Experience-Enhancing Commentaries and Featurettes</p>\r\n<p>Commentary on &ldquo;The Plateau&rdquo; with Monica Owusu-Breen, Jeff Pinkner and Timothy Good</p>\r\n<p>Commentary on &ldquo;Lysergic Acid Diethylamide&rdquo; with Jay Worth, Luyen Vu, and Tanya Swerling</p>\r\n<p>Unusual Side Effects: Gag Reel</p>\r\n<p>Trailers</p>\r\n<p>Packaging Type: O-Sleeve BD Case</p>\r\n<p>Subtitle Languages:</p>\r\n<p>Danish</p>\r\n<p>English SDH</p>\r\n<p>Finnish</p>\r\n<p>French</p>\r\n<p>Norwegian</p>\r\n<p>Portuguese</p>\r\n<p>Spanish</p>\r\n<p>Swedish</p>\r\n<p>Copyright:</p>\r\n<p>FRINGE and all related characters and elements are trademarks of and &copy; Warner Bros. Entertainment Inc.</p>\r\n<p>Genre: Drama, Television</p>\r\n<p>Synopsis:</p>\r\n<p>Immersive. Compelling. Hypnotic. Brilliantly imaginative. Endlessly thrilling. Pick your term. The mystery of the universes deepens in the critically acclaimed 22-episode third season of television&rsquo;s most exciting sci-fi. The Fringe team escapes from the parallel universe &ndash; except for Olivia, trapped in the other world and replaced in ours by her double, who turns Peter and Olivia&rsquo;s tentative relationship into a love affair. Then Olivia returns, bonds of trust fray, ever more bizarre and terrifying phenomena occur and secrets that stretch back to 1985 threaten to destroy our universe. Or theirs. &ldquo;Fringe continues its hot streak known as Season 3. It&rsquo;s been firing on all cylinders all season&rdquo; (Andrew Hanson, LATimes.com).</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(104, 'en', 'Final Destination 5 (Blu-ray)', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Theatrical Release Date: 08/11/2011</p>\r\n<p>Special Features:</p>\r\n<p>- Now includes Instant Streaming with UltraViolet Digital Copy</p>\r\n<p>MUST REDEEM DIGITAL COPY OFFER BY 12/27/2013</p>\r\n<p>- Circle of Death</p>\r\n<p>- Alternate Death Scenes</p>\r\n<p>- Visual Effects of Death: Collapsing Bridge</p>\r\n<p>- Visual Effects of Death: Airplane Crash</p>\r\n<p>Packaging Type: O-Sleeve BD Case</p>\r\n<p>Copyright:</p>\r\n<p>&copy; 2011 New Line Productions, Inc.</p>\r\n<p>Genre: Horror</p>\r\n<p>Synopsis:</p>\r\n<p>Death is just as omnipresent as ever, and in Final Destination 5 it strikes again. During the bus ride to a corporate retreat, Sam (Nicholas D&rsquo;Agosto) has a premonition in which he and most of his friends &mdash; as well as numerous others &mdash; die in a horrific bridge collapse. When his vision ends, events begin to mirror what he had seen, and he frantically ushers as many of his colleagues &mdash; including his friend, Peter (Miles Fisher), and girlfriend, Molly (Emma Bell) &mdash; away from the disaster before Death can claim them. But these unsuspecting souls were never supposed to survive, and in a terrifying race against time, the ill-fated group tries to discover a way to escape Death&rsquo;s sinister agenda.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(105, 'en', 'Nokia Lumia 800', '', '', '<p>EASIER, FASTER, FUNNER<br /><br />The Nokia Lumia 800. One glance to see what everyone''s up to.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(106, 'en', 'Nokia E5-00', '', '', '<p>Discover more ways to stay connected with friends, family, business contacts and everyone important to you with the Nokia E5-00. It has everything you need to stay in touch with a variety of email and messaging options, while also helping you to take and share pics and videos, explore the web, connect through social networking, access work and personal email, navigate your day and more. The affordable Nokia E5 even manages to fit a full QWERTY keyboard into its compact, eye-catching design for quick and easy messaging on the go. Plus, there are plenty of features to make it the perfect business-focused device. Stay productive and stay in the loop with work no matter where you are with simple setup and access for your corporate email account. The Nokia E5 makes communicating with work a breeze with Mail for Exchange, the free, direct and secure corporate email solution that offers a robust desktop-like email experience right on your phone, with email, calendar, contacts and more. Plus, your work email shows up on your phone instantly, so you don&rsquo;t have to wait for important emails. The Nokia E5 also features a fully integrated Microsoft Communicator Mobile client, to provide your mobile device the same great IM, contacts and usability that you enjoy on your computer. Keep in touch however you like with a variety of ways to connect to others with the Nokia E5. The home screen offers an easy visual way to view your contacts and makes it easy to organize the people you talk to most. The Nokia E5 also features one-click access to messaging as well as easy email setup and support for plenty of popular personal email services. The leading IM services have also been seamlessly integrated onto the phone. The Nokia E5 also offers free voice-guided navigation from Ovi Maps so you always know where you&rsquo;re going. Plus customize your phone with thousands of available apps from Ovi Store. Connect with everyone and everything you want with the Nokia E5.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(107, 'en', 'Montblanc Classic Collection Money Clip', '', '', '<p>Platinum-plated money clip with black onyx inlay</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(108, 'en', 'Due Date (Blu-ray)', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Theatrical Release Date: 11/04/2010</p>\r\n<p>Special Features:</p>\r\n<p>- Deleted Scenes</p>\r\n<p>- Action Mashup</p>\r\n<p>- Too Many Questions Mashup</p>\r\n<p>- Gag Reel</p>\r\n<p>- "Two and a Half Men" Sequence featuring Ethan Tremblay</p>\r\n<p>MUST REDEEM DIGITAL COPY OFFER BY 2/20/12</p>\r\n<p>Packaging Type: Blue BD Case</p>\r\n<p>Copyright:</p>\r\n<p>&copy; 2010 Warner Bros. Entertainment. All Rights Reserved.</p>\r\n<p>Genre: Comedy</p>\r\n<p>Synopsis:</p>\r\n<p>From The Hangover director Todd Phillips, Due Date throws two unlikely companions together on a road trip that turns out to be as life-changing as it is outrageous. Expectant first-time father Peter Highman (Robert Downey Jr.) looks forward to his new child&rsquo;s due date five days away. As Peter hurries to catch a flight home from Atlanta to be at his wife&rsquo;s side for the birth, his best intentions go completely awry when an encounter with aspiring actor Ethan Tremblay (Zach Galifianakis) forces Peter to hitch a ride with Ethan on a cross-country trip that will ultimately destroy several cars, many friendships and Peter&rsquo;s last nerve.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(109, 'en', 'Montblanc Contemporary Collection Key Ring with Montblanc emblem', '', '', '<p>Stainless steel key ring with brown calf leather</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(111, 'en', 'Last Samurai, The (DVD) (WS)', '', '', '<p>\r\n<p>Official Website: http://lastsamurai.warnerbros.com/</p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Theatrical Release Date: 12/04/2003</p>\r\n<p>Screen Aspect: 16 X 9 LETTERBOX</p>\r\n<p>Run Time: 154 minutes</p>\r\n<p>Special Features:</p>\r\n<p>Audio Commentary: Commentary by Edward Zwick</p>\r\n<p>Deleted Scenes: The Beheading (Behind the Beheading)</p>\r\n<p>&nbsp;</p>\r\n<p>Algren and Katsumoto</p>\r\n<p>&nbsp;</p>\r\n<p>Documentaries: History vs. Hollywood: The Last Samurai {History Channel Documentary)</p>\r\n<p>Featurette: Tom Cruise: A Warrior''s Journey</p>\r\n<p>&nbsp;</p>\r\n<p>Edward Zwick: Director''s Video Journal {Behind-the-scenes production journal - narrated by Ed Zwick and Tom Cruise</p>\r\n<p>&nbsp;</p>\r\n<p>A World of Detail: Production Design with Lilly Kilvert</p>\r\n<p>&nbsp;</p>\r\n<p>Silk and Armor: Costume Design with Ngila Dickson</p>\r\n<p>&nbsp;</p>\r\n<p>Imperial Army Basic Training: From Soldier to Samurai: The Weapons</p>\r\n<p>&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>Interviews: Making an Epic: A Conversation with Edward Zwick</p>\r\n<p>Other: Japan Premieres {Tokyo &amp; Kyoto red carpet)</p>\r\n<p>Packaging Type: Eco Amaray Case</p>\r\n<p>Subtitle Languages:</p>\r\n<p>English</p>\r\n<p>French</p>\r\n<p>Spanish</p>\r\n<p>Copyright:</p>\r\n<p>&copy; 2003 Warner Bros. Entertainment Inc. All Rights Reserved.</p>\r\n<p>Genre: Action/Adventure, Drama, Period, War, WESTERN</p>\r\n<p>Synopsis:</p>\r\n<p>Epic Action Drama. Set in Japan during the 1870s, The Last Samurai tells the story of Capt. Nathan Algren (Tom Cruise), a respected American military officer hired by the Emperor of Japan to train the country''s first army in the art of modern warfare. As the Emperor attempts to eradicate the ancient Imperial Samurai warriors in preparation for more Westernized and trade-friendly government policies, Algren finds himself unexpectedly impressed and influenced by his encounters with the Samurai, which places him at the center of a struggle between two eras and two worlds, with only his own sense of honor to guide him.</p>\r\n<p>"Two Thumbs Up" - EBERT &amp; ROEPER&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>"A stunning beautiful epic adventure" - ROGER EBERT / EBERT &amp; ROEPER&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>"It''s a spectacular epic. Tom Cruise is truly magnificent. - PAUL CLINTON / CNN&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>"Ken Watanabe is magnetic and majestic." - LISA SCHWARZBAUM / ENTERTAINMENT WEEKLY&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>"The Last Samurai is a movie that demands our surrender" - RICHARD SCHICKEL / TIME&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>"Bold and daring. The battle scenes are astonishing!" - JEFFREY LYONS / NBC&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>"The Last Samurai'' is a transfixing, majestic experience." - GENE SHAL</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(110, 'en', 'Roots 30th Anniversary Special Edition (DVD)', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Screen Aspect: 4 X 3 FULL FRAME</p>\r\n<p>Media Quantity: Multi D</p>\r\n<p>Packaging Type: Slipcase - Super Slim</p>\r\n<p>Copyright:</p>\r\n<p>TM &amp; (c) Warner Bros. Entertainment Inc.</p>\r\n<p>Genre: Black Theme or Star</p>\r\n<p>Synopsis:</p>\r\n<p>Based on Alex Haley''s best-selling novel about his African ancestors, Roots followed several generations in the lives of a slave family. The saga began with Kunta Kinte (LeVar Burton), a West African youth captured by slave raiders and shipped to America in the 1700s. The family''s saga is depicted up until the Civil War where Kunte Kinte''s grandson gained emancipation. Roots made its greatest impression on the ratings and widespread popularity it garnered. On average, 130 million - almost half the country at the time - saw all or part of the series.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(115, 'en', 'Evolve SST.2 X9 Complete Bike 10SPD ''12', '', '', '<p><span class="content">The all new 100mm travel Evolve sst.2 with ICT  Technology is dialed in to maintain the legendary efficiency, handling  and ride of a nimble full suspension cross country bike while harnessing  the rolling efficiency and feel of the 29" wheel.  The NEW super formed  pivot integrated seat tube is lighter and stronger while the NEW  semi-integrated tapered head tube is stiffer and more responsive. </span></p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(116, 'en', 'I Am Legend (DVD) (WS)', '', '', '<p>\r\n<p>fficial Website: <a title="http://iamlegend.warnerbros.com/" href="http://iamlegend.warnerbros.com/">http://iamlegend.warnerbros.com/</a></p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Theatrical Release Date: 12/13/2007</p>\r\n<p>Screen Aspect: 16 X 9 LETTERBOX</p>\r\n<p>Special Features:</p>\r\n<p>4 awesome animated comics: Death as a gift, Isolation, Sacrificing the Few for the Many and Shelter</p>\r\n<p>DVD-ROM PC weblink to intense bonus material databanki chronicling the movie''s creation and exploring the history and current status</p>\r\n<p>of life-threatening viral infections</p>\r\n<p>Packaging Type: Amaray Case</p>\r\n<p>Copyright:</p>\r\n<p>(c) 2007 A Warner Bros. Entertainment Inc. All Rights Reserved</p>\r\n<p>Genre: Action/Adventure, Drama, Horror, Sci-Fi/Fantasy</p>\r\n<p>Synopsis:</p>\r\n<p>Robert Neville is a brilliant scientist, but even he could not contain the terrible virus that was unstoppable, incurable, and man-made. Somehow immune, Neville is now the last human survivor in what is left of New York City and maybe the world. For three years, Neville has faithfully sent out daily radio messages, desperate to find any other survivors who might be out there. But he is not alone. Mutant victims of the plague -- The Infected -- lurk in the shadows... watching Neville''s every move... waiting for him to make a fatal mistake. Perhaps mankind''s last, best hope, Neville is driven by only one remaining mission: to find a way to reverse the effects of the virus using his own immune blood. But he knows he is outnumbered... and quickly running out of time.</p>\r\n<p>"I Am Legend is mind-blowing excitement..." Pete Hammond / Maxim</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(119, 'en', 'The Big Bang Theory: The Complete Fourth Season', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Screen Aspect: 16 X 9 LETTERBOX</p>\r\n<p>Run Time: 529 minutes</p>\r\n<p>Episodes Info :</p>\r\n<p>The Robotic Manipulation</p>\r\n<p>The Cruciferous Vegetable Amplification</p>\r\n<p>The Zazzy Substitution</p>\r\n<p>The Hot Troll Deviation</p>\r\n<p>The Desperation Emanation</p>\r\n<p>The Irish Pub Formulation</p>\r\n<p>The Apology Insufficiency</p>\r\n<p>The 21-Second Excitation</p>\r\n<p>The Boyfriend Complexity</p>\r\n<p>The Alien Parasite Hypothesis</p>\r\n<p>The Justice League Recombination</p>\r\n<p>The Bus Pants Utilization</p>\r\n<p>The Love Car Displacement</p>\r\n<p>The Thespian Catalyst</p>\r\n<p>The Benefactor Factor</p>\r\n<p>The Cohabitation Formulation</p>\r\n<p>The Toast Derivation</p>\r\n<p>The Prestidigitation Approximation</p>\r\n<p>The Zarnecki Incursion</p>\r\n<p>The Herb Garden Germination</p>\r\n<p>The Agreement Dissection</p>\r\n<p>The Wildebeest Implementation</p>\r\n<p>The Engagement Reaction</p>\r\n<p>The Roommate Transmogrification</p>\r\n<p>Special Features:</p>\r\n<p>Actor on Actor: The Big Bang''s Theory of Relativity Featurette -This fun and light-hearted piece features the stars of the show</p>\r\n<p>conducting interviews with each other detailing their experiences working on one of the hottest comedies on television.</p>\r\n<p>The Barenaked Ladies on Big Bang Theory Featurette - Having created one of the greatest theme songs in recent history, the Barenaked</p>\r\n<p>Ladies bring it home when they come to the set of the Big Bang Theory to record a music video for the song. Featuring an interview</p>\r\n<p>with the band, behind the scenes footage of the filming of an episode, and clips from the new video itself, this piece carries with</p>\r\n<p>it all of the fun and energy you could expect from both the band and the show.</p>\r\n<p>The History of Everything Music Video</p>\r\n<p>Gag Reel</p>\r\n<p>Media Quantity: Multi D</p>\r\n<p>Packaging Type: VIVA 4 Disc 15mm Case</p>\r\n<p>Subtitle Languages:</p>\r\n<p>Chinese</p>\r\n<p>English SDH</p>\r\n<p>French</p>\r\n<p>Portuguese</p>\r\n<p>Spanish</p>\r\n<p>Thai</p>\r\n<p>Copyright:</p>\r\n<p>BIG BANG THEORY and all related characters and elements are trademarks of and &copy; Warner Bros. Entertainment Inc.</p>\r\n<p>Genre: Comedy, Television</p>\r\n<p>Synopsis:</p>\r\n<p>&ldquo;Four seasons in, it is still laugh-out-loud funny. Every episode, every week,&rdquo; USA Today&rsquo;s Robert Bianco says about the hit series The Big Bang Theory. Here&rsquo;s your chance to subject his conclusion to empirical analysis by watching all 24 Season 4 Episodes! This season the Big Bang gang&rsquo;s romantic universe expands. On the rebound from Penny, Leonard falls into the arms of Raj&rsquo;s sister Priya. Sheldon gets a girlfriend, or rather a friend who is a girl: Amy, a dour neurobiologist who declares herself besties with Penny. Howard and Bernadette heat up. And so do Raj and Bernadette (at least in Raj&rsquo;s Bollywood daydream). All in the furtherance of award-winning genius comedy.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(120, 'en', 'Samsung Galaxy S II, Epic 4G Touch (Black)', '', '', '<p>The fastest, state-of-the-art networks are 4G, so naturally, the Epic&trade;  4G Touch is designed for speed. With 4G, every download, upload, app,  game, connection and feature runs almost as fast as you can push the  button.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(121, 'en', 'Fringe: The Complete Third Season', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Screen Aspect: 16 X 9 FULL FRAME</p>\r\n<p>Run Time: 1012 minutes</p>\r\n<p>Episodes Info :</p>\r\n<p>Olivia</p>\r\n<p>The Box</p>\r\n<p>The Plateau</p>\r\n<p>Do Shapeshifters Dream of Electric Sheep?</p>\r\n<p>Amber 31422</p>\r\n<p>6955 kHz</p>\r\n<p>The Abducted&hellip;</p>\r\n<p>Entrada</p>\r\n<p>Marionette</p>\r\n<p>The Firefly</p>\r\n<p>Reciprocity</p>\r\n<p>Concentrate and Ask Again</p>\r\n<p>Immortality</p>\r\n<p>6 B</p>\r\n<p>Subject 13</p>\r\n<p>Os</p>\r\n<p>Stowaway</p>\r\n<p>Bloodline</p>\r\n<p>Lysergic Acid Diethylamide</p>\r\n<p>6:02 AM EST</p>\r\n<p>The Last Sam Weiss</p>\r\n<p>The Day We Died</p>\r\n<p>Special Features:</p>\r\n<p>Duality of Worlds: Four featurettes exploring The Other You, Visualizing an Alternate World, A Machine of Destiny and The Psychology</p>\r\n<p>of Duality</p>\r\n<p>Animating the &ldquo;Lysergic Acid Diethylamide&rdquo; Episode</p>\r\n<p>Constructing an Extrasensory Soundscape</p>\r\n<p>Experience &ldquo;Os&rdquo; (Episode 316) in Selectable Maximum Episode Mode with Pop-Up Experience-Enhancing Commentaries and Featurettes</p>\r\n<p>Commentary on &ldquo;The Plateau&rdquo; with Monica Owusu-Breen, Jeff Pinkner and Timothy Good</p>\r\n<p>Commentary on &ldquo;Lysergic Acid Diethylamide&rdquo; with Jay Worth, Luyen Vu, and Tanya Swerling</p>\r\n<p>Unusual Side Effects: Gag Reel</p>\r\n<p>Trailers</p>\r\n<p>Media Quantity: Multi D</p>\r\n<p>Packaging Type: Viva Multi-Disc (6-10)</p>\r\n<p>Subtitle Languages:</p>\r\n<p>Chinese Traditional</p>\r\n<p>English SDH</p>\r\n<p>French</p>\r\n<p>Portuguese</p>\r\n<p>Spanish</p>\r\n<p>Thai</p>\r\n<p>Copyright:</p>\r\n<p>FRINGE and all related characters and elements are trademarks of and &copy; Warner Bros. Entertainment Inc.</p>\r\n<p>Genre: Drama, Television</p>\r\n<p>Synopsis:</p>\r\n<p>Immersive. Compelling. Hypnotic. Brilliantly imaginative. Endlessly thrilling. Pick your term. The mystery of the universes deepens in the critically acclaimed 22-episode third season of television&rsquo;s most exciting sci-fi. The Fringe team escapes from the parallel universe &ndash; except for Olivia, trapped in the other world and replaced in ours by her double, who turns Peter and Olivia&rsquo;s tentative relationship into a love affair. Then Olivia returns, bonds of trust fray, ever more bizarre and terrifying phenomena occur and secrets that stretch back to 1985 threaten to destroy our universe. Or theirs. &ldquo;Fringe continues its hot streak known as Season 3. It&rsquo;s been firing on all cylinders all season&rdquo; (Andrew Hanson, LATimes.com).</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(122, 'en', 'Evolution SST.2 XO Complete Bike 10SPD12', '', '', '<p><span class="content">The all new ICT bred Evolution 29er boasts 120mm  of fully active travel. Combine the Evolution sst.2 120 frame with a set  of fast rolling 29" wheels and you have a machine that can take you  further than you ever thought possible.</span></p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(123, 'en', 'Supernatural: The Complete Sixth Season', '', '', '<p>\r\n<p>Studio: Warner Bros.</p>\r\n<p>Screen Aspect: 16 X 9 FULL FRAME</p>\r\n<p>Run Time: 924 minutes</p>\r\n<p>Episodes Info :</p>\r\n<p>Exile on Main St.</p>\r\n<p>Two and a Half Men</p>\r\n<p>The Third Man</p>\r\n<p>Weekend at Bobby''s</p>\r\n<p>Live Free or Twihard</p>\r\n<p>You Can''t Handle the Truth</p>\r\n<p>Family Matters</p>\r\n<p>All Dogs Go to Heaven</p>\r\n<p>Clap Your Hands if You Believe</p>\r\n<p>Caged Heat</p>\r\n<p>Appointment in Samarra</p>\r\n<p>Like a Virgin</p>\r\n<p>Unforgiven</p>\r\n<p>Mannequin 3: The Reckoning</p>\r\n<p>The French Mistake</p>\r\n<p>...And Then There Were None</p>\r\n<p>My Heart Will Go On</p>\r\n<p>Frontierland</p>\r\n<p>Mommy Dearest</p>\r\n<p>The Man Who Would Be King</p>\r\n<p>Let It Bleed</p>\r\n<p>The Man Who Knew Too Much</p>\r\n<p>Special Features:</p>\r\n<p>Jensen Ackles: A Director&rsquo;s Journey featurette</p>\r\n<p>Supernatural and the Quest for the Soul featurette</p>\r\n<p>Audio Commentary on &ldquo;Clap Your Hands if you Believe&rdquo; with EPs Robert Singer, Sera Gamble, and Ben Edlund</p>\r\n<p>Audio Commentary on &ldquo;The French Mistake&rdquo; with EP''s Robert Singer, Sera Gamble and Ben Edlund.</p>\r\n<p>&ldquo;The French Mistake&rdquo; Alternate Takes and Outtakes</p>\r\n<p>Gag Reel</p>\r\n<p>Easter Egg</p>\r\n<p>Two bonus episodes from Supernatural: The Anime Series - &ldquo;All Hell Breaks Loose&rdquo; Parts 1 &amp; 2</p>\r\n<p>Media Quantity: Multi D</p>\r\n<p>Packaging Type: VIVA 6 Disc 25mm Case</p>\r\n<p>Subtitle Languages:</p>\r\n<p>Chinese</p>\r\n<p>French</p>\r\n<p>Portuguese</p>\r\n<p>Spanish</p>\r\n<p>Thai</p>\r\n<p>Genre: Drama, Television</p>\r\n<p>Synopsis:</p>\r\n<p>The prize: ending the Apocalypse. The price: Sam&rsquo;s life. Season 5&rsquo;s horrific finale left Dean alone, as Sam descended into Hell. Now a different man, Dean vows to stop hunting and devote himself to building a family with Lisa and her son Ben. Then, mysteriously, Sam reappears, drawing Dean back into the old life. But Sam&rsquo;s a different man too. He&rsquo;s returned without his soul. How the Winchesters confront this greatest challenge yet to their powerful bond is the troubled heart &ndash; and soul &ndash; of the profound and thrilling 5-Disc, 22-Episode Season 6. As the brothers struggle to reunite, they must also battle deadly supernatural forces. Demons. Angels. Vampires. Shapeshifters. And a terrifying new foe called the Mother of All.</p>\r\n<div></div>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(124, 'en', 'Truth SST.2 X9 Complete Bike 10SPD ''12', '', '', '<p><span class="content">The legendary performance of the 100mm travel  Truth sst.2 has been enhanced through fine tuning and tweaking over  countless seasons of XC and endurance racing in every condition  imaginable. With Ellsworth''s proprietary ICT suspension, SST tubing,a  lighter and stronger pivot integrated seat tube and a semi-integrated  tapered head tube - this is the fastest Truth ever created. </span></p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(125, 'en', 'Samsung Galaxy S II', '', '', '<dl><dt>The Galaxy S II has an amazing 4.27" Super  AMOLED Plus screen. This superb display has razor sharp clarity and  breathtaking color. See every detail of videos and pictures. See the  full range of hues in all their subtlety and brilliance. And with its  superior wide viewing angle, you don''t have to be directly in front of  the screen to see a perfect image. Truth is, you really have to see it  to believe it.</dt></dl>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(126, 'en', 'Casio PRIZM fx-CG10', '', '', '<p><br /><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/pressreleases/fx-CG10_Prizm_press_2.jpg" alt="PRIZM fx-CG10" align="right" /><strong style="word-wrap: break-word;">High-resolution color LCD with full textbook-style display</strong><br style="word-wrap: break-word;" /><br style="word-wrap: break-word;" />The color LCD offers full textbook-style display with the highest pixel resolution* (82,944 dots) and widest color reproduction* (65,536 colors) of any calculator. PRIZM&trade; comes with high-resolution fonts up to 18x24 dots (including blank dots), to enable equations and text to be displayed just like they appear in textbooks. The Blanview LCD delivers superior visibility and low power consumption, enabling color display with an estimated run time of 140 hours on four AAA-size alkaline batteries.**<strong style="word-wrap: break-word;"><br style="word-wrap: break-word;" /></strong>*As of October 7, 2010, for the pixel resolution and color reproduction of calculators. According to a survey by Casio Computer Co., Ltd.<br style="word-wrap: break-word;" />**Using repetition of the following one-hour sequence: Menu display for 5 minutes, Run-Matrix mode calculation for 5 minutes, flashing cursor in Run-Matrix mode for 50 minutes. Based on default settings for display brightness and auto power off. (Refer to the Specifications for exact settings)&nbsp;&nbsp;<strong style="word-wrap: break-word;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/pressreleases/fx-CG10_Prizm_press_3.jpg" alt="PRIZM fx-CG10" align="right" /></strong><strong style="word-wrap: break-word;">Picture Plot enables learning from real-life pictures</strong><strong style="word-wrap: break-word;">&nbsp;</strong><br style="word-wrap: break-word;" /><br style="word-wrap: break-word;" />Picture Plot enables users to create their own graphs over pictures displayed on the color LCD. PRIZM&trade; comes with 55 types of color pictures that users can create graphs over, such as a picture of the parabola of jets from a water fountain and an image sequence of a clock&rsquo;s pendulum movement. Users can perform regression calculations from the completed graphs to enhance their understanding of math functions.&nbsp;&nbsp;&nbsp;<strong style="word-wrap: break-word;">Multitude of functions that leverage the color LCD</strong><br style="word-wrap: break-word;" /><br style="word-wrap: break-word;" />Colors can be added to a multitude of graphing objects including dotted lines, circles, and bars, as well as grid lines on graphs, labels of coordinate axes, and coordinate values displayed during tracing. The Color Link function links the colors used in graphs to the designated values in the spreadsheet screen, to aid the visual comprehension of trends and changes in values. PRIZM&trade; automatically color-codes brackets when entering equations with multiple brackets, as a visual aid to facilitate the entry of complex equations.&nbsp;</p>\r\n<table style="word-wrap: break-word;" align="center">\r\n<tbody style="word-wrap: break-word;">\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/pressreleases/fx-CG10_Prizm_press_3.jpg" alt="PRIZM fx-CG10" align="left" /></strong></td>\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/pressreleases/fx-CG10_Prizm_press_4.jpg" alt="PRIZM fx-CG10" align="left" /></strong></td>\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/pressreleases/fx-CG10_Prizm_press_5.jpg" alt="PRIZM fx-CG10" align="left" /></strong></td>\r\n</tr>\r\n</tbody>\r\n</table>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(127, 'en', 'Fore CR5 SRAM Red', '', '', '<p>An all new frame and new graphics package make the Fore CR5 look as  fast as it really is. Now available with SRAM Red componants.</p>\r\n<p>What do you get when you interview hundreds of riders, questioning them  about their desires for the ultimate road bike and then, spend  thousands of hours translating those ideas into reality? A dream come  true. We call it the Fezzari For&eacute; CR5. It is the pinnacle of road bike  performance. From its all new state of the art, proprietary Fezzari  Racing Design Xr7 3K monocoque carbon frame to its best-of-market  components, the For&eacute; CR5 is THE ultimate road bike. Our designers and  engineers didn''t cut corners.<br /> <br /> Take, for instance, the state of the art proprietary Fezzari Racing  Design Xr7 3K monocoque carbon fiber frame. We used the highest grade of  carbon fiber available on the market. We made it even stiffer laterally  by enlarging the bottom bracket shell and adding the BB30 bottom  bracket/crank design, strengthening the headtube and making it more  laterally stiff by enlarging the diameter to a 1.5" tapered design.  We''ve also enlarged the seatstays near the rear axle for more lateral  rigidity. We made the Xr7 frame even more vertically compliant for those  rides on the cobblestones. We''ve done this by using an oval design in  our top tube and down tube.&nbsp; The new Xr7 frame is even more aerodynamic  than before with the new F4 ultralight bladed carbon fork and internal  cable routing on the top tube.&nbsp; The Xr7 frame was recently tested to be  one of the most durable frames on the market, and it weighs a mere 900  grams. Strength, lightweight, rigidity where you need it most, and  flexible enough to take the edge off of rough roads -- it''s the perfect  frame for anyone who wants to get the most out of their riding  experience.<br /> <br /> Next, take a look at the perfect blend of components. The Fore CR5  includes SRAM Red components shifters, brakes and derraileurs, FSA  K-Force Light BB30 Carbon Crankset, Fezzari F4 XrT 3K carbon ultralite  bladed carbon fork with carbon steerer tube, FSA K-Force compact carbon  bars, FSA K- Force carbon seat post, and even carbon spacers on the  headset.<br /> <br /> Finally, add the new sleek graphics and logos and you have--the ultimate road ride.<br /> <br /> You get the following upgrades over the CR3:</p>\r\n<ol>\r\n<li> <strong>Upgraded Frameset</strong> &ndash; from the Xr5 to the new Xr7  frame,&nbsp; more lateral stiffness with a BB30 crank system, enlarged  headtube for better cornering, and sprinting, added rigidity in the rear  triangle, increased aerodynamics with the new F4 bladed fork design and  internal cable routing.</li>\r\n<li> <strong>Upgraded Shifters</strong> &ndash; from Shimano Ultegra to the flagship SRAM Red, for smoother, more precise shifting</li>\r\n<li> <strong>Upgraded Front Derailleur</strong> &ndash; from Shimano Ultegra to SRAM Red, which is lighter and smoother</li>\r\n<li> <strong>Upgraded Cassette</strong> &ndash; from Shimano Ultegra to SRAM Red</li>\r\n<li> <strong>Upgraded Crankset</strong> &ndash; from FSA SLK Light to FSA K-Force Light, which is lighter</li>\r\n<li> <strong>Upgraded Chain</strong> &ndash; from Shimano Ultegra to SRAM Red</li>\r\n<li> <strong>Upgraded Wheelset</strong> &ndash; Mavic Ksyrium SL, which are lighter,stiffer, faster, and perform better</li>\r\n<li> <strong>Upgraded Brakes</strong> &ndash; from Shimano Ultegra to SRAM Red, which are lighter and smoother</li>\r\n<li> <strong>Upgraded Seatpost-&nbsp; </strong>The&nbsp; FSA K-force light seatpost  is one of the lightest on the market.&nbsp; It also completes the graphics  package complimenting the crank and handle bar.</li>\r\n</ol>\r\n<p>When you get a For&eacute; CR5, we custom fit it for you through our 23-Point  Custom Setup program. We&rsquo;ll get your specific&nbsp; body measurements so we  can outfit your bike to fit you perfectly.&nbsp; You''ll have the rest of the  peloton envious of your ride.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', '');
INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(128, 'en', 'Casio FX-115ES', '', '', '<table class="defTBL" style="word-wrap: break-word; color: #555555; font-family: Helvetica, sans-serif; font-size: 12px; line-height: 18px; text-align: left; background-color: #ffffff;" border="0" width="95%">\r\n<tbody style="word-wrap: break-word;">\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;">Number of Functions</strong></td>\r\n<td style="word-wrap: break-word;">279</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;">Display</strong></td>\r\n<td style="word-wrap: break-word;">&nbsp;</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">2-Line Digit</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Natural Textbook</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Digits</td>\r\n<td style="word-wrap: break-word;">10 + 2</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;">Memory</strong></td>\r\n<td style="word-wrap: break-word;">&nbsp;</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Store/Recall</td>\r\n<td style="word-wrap: break-word;">Yes/Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Recall &amp; Edit values</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Number of independent memories</td>\r\n<td style="word-wrap: break-word;">1</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Number of constant memories</td>\r\n<td style="word-wrap: break-word;">6</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;">Features</strong></td>\r\n<td style="word-wrap: break-word;">&nbsp;</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Operating system</td>\r\n<td style="word-wrap: break-word;">S - V.P.A.M</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Protective hard case</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Clear last entry and clear all</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Review &amp; edit preview entries</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Overhead Model Available</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Fixed decemial capabilities</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Multi-replay</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Plastic Keys</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;">Mathematics</strong></td>\r\n<td style="word-wrap: break-word;">&nbsp;</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Metric conversions</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Scientific notation</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Parenthesis/Constant</td>\r\n<td style="word-wrap: break-word;">Yes/-</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Pi</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Xth root</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Fraction calculations</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Complex numbers</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">DMS &lt;&gt; DD / P &lt;&gt; R Conversions</td>\r\n<td style="word-wrap: break-word;">Yes/Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;">Trigonometry</strong></td>\r\n<td style="word-wrap: break-word;">&nbsp;</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Sin, Cos, Tan, &amp; Inverses</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Hyperbolic Functions</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Converts between DEG, RAD, GRAD</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;">Statistics</strong></td>\r\n<td style="word-wrap: break-word;">&nbsp;</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">One/two variable</td>\r\n<td style="word-wrap: break-word;">Yes/Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Mean, sum, # elements</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Standard Deviation</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Linear Regression</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Log, In, Inverse Log, Exponential</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Store and edit data in memory</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Quadratic, log, exp, power, inverse regression</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">nPr, cPr, x!</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Random number generator</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;">Calculus</strong></td>\r\n<td style="word-wrap: break-word;">&nbsp;</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Complex number calculations</td>\r\n<td style="word-wrap: break-word;">No</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Numeric integration</td>\r\n<td style="word-wrap: break-word;">No</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Numeric differential calculations</td>\r\n<td style="word-wrap: break-word;">No</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;"><strong style="word-wrap: break-word;">Power/Unit Dimensions</strong></td>\r\n<td style="word-wrap: break-word;">&nbsp;</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Power</td>\r\n<td style="word-wrap: break-word;">Solar Plus w/Battery back-up</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Auto Power Off</td>\r\n<td style="word-wrap: break-word;">Yes</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Battery</td>\r\n<td style="word-wrap: break-word;">-</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Size (H x W x L) Inches</td>\r\n<td style="word-wrap: break-word;">Not available</td>\r\n</tr>\r\n<tr class="contentTextGray" style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Weight (ounces)</td>\r\n<td style="word-wrap: break-word;">Not available</td>\r\n</tr>\r\n</tbody>\r\n</table>\r\n<p>&nbsp;</p>\r\n<p class="contentTextGray" style="word-wrap: break-word; margin-top: 10px; margin-right: 0px; margin-bottom: 15px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; line-height: 1.25em; color: #555555; font-family: Helvetica, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">Technical Specifications subject to change</p>\r\n<p class="contentTextGray" style="word-wrap: break-word; margin-top: 10px; margin-right: 0px; margin-bottom: 15px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; line-height: 1.25em; color: #555555; font-family: Helvetica, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">The FX-115ES is permitted on AP, SAT and PSAT/NMSQT. Policies are subject to change. Visit<a style="word-wrap: break-word; color: #00349a; text-decoration: underline;" href="http://www.collegeboard.com/" target="_blank">www.collegeboard.com</a>for more information.</p>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(129, 'en', 'Fore CR1', '', '', '<p>Take your riding to the next level with the For&eacute; CR1 full carbon road  bike, built to be extremely durable and responsive. Feel the adrenalin  rush as it accelerates smoothly and corners aggressively. Great for  cross-country riding, a triathlon, and even a race.&nbsp; The new Fezzari  Fore CR1 is the newest bike to the Fezzari carbon road bike family.&nbsp; It  has the same tried and true monocoque carbon frame as the&nbsp; Fore CR2, but  is built with a Shimano 105/Ultegra groupo to help save a little on the  price.</p>\r\n<p>Start with a proprietary Fezzari Racing Design Xr4 monocoque carbon  frame that was recently tested as one of the most durable frames on the  market.</p>\r\n<p>All this translates into exhilaration when you&rsquo;re climbing &ndash; knowing  that you&rsquo;re ascending more efficiently &ndash; and confidence on the downhill  when you take that corner at high speeds. Our proprietrary frame  painting process give one of the best looking finishes available.</p>\r\n<p>You get e&nbsp; upgrades over the Catania:</p>\r\n<ol>\r\n<li> <strong>Upgraded Frame</strong> &ndash; the CR1 has a full monocoque carbon  frame vs the Catania&rsquo;s aluminum alloy frame. The carbon frame is lighter  and will absorb more of the road chatter when riding.</li>\r\n<li> <strong>Upgraded Seatpost</strong> &ndash; the larger diameter 31.6mm seatpost is stiffer and lighter.</li>\r\n<li> <strong>Upgraded Wheels</strong> &ndash; The CR1 gets a lighter and more aero dynamic wheel whith looks to go with it.</li>\r\n</ol>\r\n<p>Who will want this bike? If you&rsquo;ve been biking and plan to get into it  more, and you want to get something that will grow with you as you grow  in the sport (but you&rsquo;re not willing to pay the price of a CR3 or CR5),  then this is the bike for you. It gets you on a full monocoque carbon  fiber frame and still gives you the confidence you won''t miss a shift  with the Shimano 105/Ultegra drivetrain. You&rsquo;ll have the confidence that  you can ride with anyone, anytime.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(130, 'en', 'Casio DR-210TM', '', '', '<table class="defTBL" style="word-wrap: break-word; color: #555555; font-family: Helvetica, sans-serif; font-size: 12px; line-height: 18px; text-align: left; background-color: #ffffff;" width="79%">\r\n<thead style="word-wrap: break-word;">\r\n<tr style="word-wrap: break-word;">\r\n<th style="word-wrap: break-word;" colspan="2">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><strong style="word-wrap: break-word;">DR-210TM Technical Specifications</strong></div>\r\n</th>\r\n</tr>\r\n</thead>\r\n<tbody style="word-wrap: break-word;">\r\n<tr style="word-wrap: break-word;">\r\n<th style="word-wrap: break-word;" colspan="2">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><strong style="word-wrap: break-word;">Display</strong></div>\r\n</th>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Digits</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;">12</div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Type</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;">Digitron</div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Special</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;">Large Display</div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<th style="word-wrap: break-word;" colspan="2">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><strong style="word-wrap: break-word;">Printer</strong></div>\r\n</th>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Speed - lines/second</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;">4.4</div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Print Color</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;">2 Color-Black/Red</div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Type</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;">Ribbon</div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Ink Ribbon</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;">RB-02</div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<th style="word-wrap: break-word;" colspan="2">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><strong style="word-wrap: break-word;">Features</strong></div>\r\n</th>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Decimal Selector</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;">Floating or fixed decimal 0,1,2,3,4,6</div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Item Counter</td>\r\n<td style="word-wrap: break-word;">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Independent Memory</td>\r\n<td style="word-wrap: break-word;">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Printing Reference Numbers</td>\r\n<td style="word-wrap: break-word;">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Tax Calculation</td>\r\n<td style="word-wrap: break-word;">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Automatic Constants</td>\r\n<td style="word-wrap: break-word;">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Independent Add Register</td>\r\n<td style="word-wrap: break-word;">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Grand Total</td>\r\n<td style="word-wrap: break-word;">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">MU/MD</td>\r\n<td style="word-wrap: break-word;">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Feed</td>\r\n<td style="word-wrap: break-word;">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Right Shift Key</td>\r\n<td style="word-wrap: break-word;">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;">Round Off</td>\r\n<td style="word-wrap: break-word;">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Round Up</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Cut Off</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">ADD Mode</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Cost/Sell/Margin</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<th style="word-wrap: break-word;" colspan="2">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><strong style="word-wrap: break-word;">Paper</strong></div>\r\n</th>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">2-1/4 inch plain</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><img style="word-wrap: break-word; border-style: initial; border-color: initial;" src="http://www.casio.com/resource/images/catalog/calculator/black_bullet.gif" border="0" alt="" /></div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<th style="word-wrap: break-word;" colspan="2">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><strong style="word-wrap: break-word;">Power</strong></div>\r\n</th>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Type</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;">AC</div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<th style="word-wrap: break-word;" colspan="2">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;"><strong style="word-wrap: break-word;">Unit Dimensions</strong></div>\r\n</th>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Size (inches)&nbsp; H x W x L</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;">4-3/10" x 8-2/5" x 15"</div>\r\n</td>\r\n</tr>\r\n<tr style="word-wrap: break-word;">\r\n<td style="word-wrap: break-word;" width="61%">Weight oz/lbs</td>\r\n<td style="word-wrap: break-word;" width="39%">\r\n<div style="word-wrap: break-word; padding: 0px; margin: 0px;">3.7 lbs</div>\r\n</td>\r\n</tr>\r\n</tbody>\r\n</table>\r\n<p>\r\n<p style="word-wrap: break-word; margin-top: 10px; margin-right: 0px; margin-bottom: 15px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; line-height: 1.25em; color: #555555; font-family: Helvetica, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">Technical Specifications Subject to Change</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(131, 'en', 'Catania', '', '', '<p class="MsoPlainText">The new Catania features carbon fork, carbon seatpost, Ultegra  derailleur, and the new Fezzari Racing Design R3A frame with increased  aerodynamic properties and a sleeker look.</p>\r\n<p class="MsoPlainText">The Catania road bike is a great all-around bike. If you want to get  into road biking or want a bike that is durable, high-performing, and as  comfortable as a road bike can get, the Catania is for you.</p>\r\n<p class="MsoPlainText">The Catania features the R3A frame with compact geometry. Compact  geometry means that we shorten the seat tube slightly, which makes the  bike a little lighter and reduces lateral flex (you don&rsquo;t want your bike  flexing side to side when you&rsquo;re pedaling). It also allows your riding  position to be a little more upright.</p>\r\n<p class="MsoPlainText">Add to that a great set of components, including: Shimano Ultegra  derailleur and Shimano 105 shifters for smooth shifting Fezzari Carbon  II fork to minimize the road chatter; FSA Gossamer crank with external  oversized bearings that make it pedal smoother and more efficiently;  Alex double-wall rims that are extremely durable; Maxxis performance  tires; and a Fezzari Racing Design Ultra XR saddle that is one of the  most comfortable road saddles you&rsquo;ll ride.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(132, 'en', 'Samsung Galaxy Player 5.0', '', '', '<p>Easily connect via Wi-Fi without any monthly service fees. The Samsung Galaxy Player can access the internet and apps anywhere there is an available hotspot. The sleek, lightweight 6.42 oz. design fits in any pocket and the brilliant 5&rdquo; LCD delivers incredible viewing quality.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(133, 'en', 'Samsung Galaxy Player 4.0', '', '', '<p>Easily connect via Wi-Fi without any monthly service fees. The Samsung Galaxy Player can access the internet and apps anywhere there is an available hotspot. The sleek, lightweight 4.27 oz. design fits in any pocket and the brilliant 4&rdquo; Super Clear LCD delivers incredible viewing quality.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(134, 'en', 'Creative ZEN Style M300 MP3 Player 16GB (Black)', '', '', '<p>Don''t let the compact appearance of the Creative ZEN Style M300 MP3 player fool you. For a media player this tiny, you&rsquo;d be amazed at the array of features it can offer for a remarkably affordable price.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(135, 'en', 'Creative ZEN Touch 2 MP3 Player 8GB (Black)', '', '', '<p>The ZEN line of portable media players has long been associated with the highest quality in audio playback, and the Creative ZEN Touch 2 continues to uphold this standard. But that''s not all it offers. What makes this player truly stand out from the rest is that you can stream music wirelessly to compatible Bluetooth&reg; headphones or speakers such as Creative''s ZiiSound D5 and WP-300, and surf the Internet too.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(136, 'en', 'BlazBlue: Continuum Shift EXTEND', '', '', '<p>\r\n<p>The Time of the AZURE is Here!</p>\r\n<p>&nbsp;</p>\r\n<p>Aksys Games, a publisher of interactive entertainment software, is proud to announce that the next installment in the hit fighting game series BlazBlue, BlazBlue: Continuum Shift EXTEND, will be coming to North America as a PlayStation&reg;Vita launch title! With the devious, all new playable character Relius Clover, new story scenarios, new gameplay modes, and competitively balanced action, BlazBlue: Continuum Shift EXTEND makes a grand return to home consoles and the new frontier!</p>\r\n<p>BlazBlue: Continuum Shift EXTEND Key Features:</p>\r\n<p>&nbsp;</p>\r\n<p>Enhanced Story Mode: Relive and rediscover the events that took place in BlazBlue: Calamity Trigger or venture forth into one of four all new story scenarios!</p>\r\n<p>New and Revised Game Modes to Explore: Take on the strongest of foes in Unlimited Mars Mode, dungeoneer your way to the bottom of Abyss Mode, or lead an army to victory in Legion Mode!</p>\r\n<p>Fully Revised Combat System: All characters, new and old, have been thoroughly rebalanced and armed with all new strategies and combos to take your game to the top!</p>\r\n<p>Improved Online Multiplayer: Battle it out in BlazBlue&rsquo;s acclaimed online mode with all new multiplayer features, such as online team battles!</p>\r\n<p>SHIP DATE: February 14, 2012</p>\r\n<p>GENRE: Fighting</p>\r\n<p>PLAYER(S): 1 Local, 2-6 Online</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(137, 'en', 'Ultimate Marvel VS. Capcom® 3', '', '', '<p>\r\n<p>he ULTIMATE heroes from Marvel and Capcom collide again in Ultimate Marvel vs. Capcom 3. Every epic character from the original blockbuster returns to the fray alongside 12 new fighters,&nbsp;</p>\r\n<p>8 over-the-top new stages and enhanced gameplay.</p>\r\n<p>COMING SOON: Ultimate Marvel Vs. Capcom 3 for PlayStation&reg;Vita system! It''s the full console experience packed with 50 legendary characters*, local and Wi-Fi multiplayer, touch panel controls, and exclusive new features.</p>\r\n<p>UNLEASH YOUR ULTIMATE</p>\r\n<p>ANYTIME, ANYWHERE</p>\r\n<p>LAUNCHING with the PlayStation&reg;Vita system on 2/22/12&nbsp;</p>\r\n<p>OUT NOW on Xbox 360 and PlayStation&reg;3 system</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(138, 'en', 'Ridge Racer', '', '', '<p>\r\n<p>BEAUTY &amp; HIGH SPEED DRIFTING AROUND THE WORLD!</p>\r\n<p>The high-octane racing franchise drifts onto the PlayStation&reg;Vita delivering stunning graphics and heart-pounding action that players can truly feel. Ridge Racer&reg; features high-speed action, high-performance racing machines, and all-new gameplay additions creating an edge-of-your-seat experience only possible on the PlayStation&reg;Vita. Racing fans can also take the action online and tear up the track against players from around the globe using the PlayStation&reg;Vita &ldquo;near&rdquo; and Wi-Fi functionality and race against other players&rsquo; ghosts anywhere at anytime.</p>\r\n<p>\r\n<p>Vivid, next generation high-contrast graphics and advanced lighting effects powered by the PlayStation&reg;Vita painting processor</p>\r\n<p>An immersive audio experience with a dynamic soundscape that changes and evolves with each race according to the movement of your machine.</p>\r\n<p>All-new custom drift system enables players to tune the action to suit their style of driving. All new "Machine Upgrade Map" customization allows players to upgrade functional parts and create their own original machines</p>\r\n<p>New introduction of the Planetary League allows players to join in one of four racing teams and race against other players from around the world both at real-time and "anywhere at any time" by exchanging ghosts via "near" functionality.</p>\r\n<p>Compete against up to 7 other players from around the world with online (ad-hoc, Wi-Fi) multiplayer.</p>\r\n</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(139, 'en', 'Shinobido 2: Revenge of Zen', '', '', '<p>\r\n<p>Shinobido 2: Revenge of Zen is the sequel to Shinobido: Way of the Ninja, featuring the series&rsquo; trademark stealth action gameplay with the addition of new stylish assassin moves and a dynamic storyline. Developed by Acquire, the story is set six months after the events of the previous opus, with the Utakata region once again at the center of the storm and embroiled in a civil war involving the mysterious Magic Mirror. Players will take the role of Zen, a man who has suffered betrayal at the hands of his companions and the loss of his home. Saved by the Asuka clan of Utakata, Zen makes up his mind to live as an assassin and begins a perilous journey in search of revenge.</p>\r\n<p>Dynamic Storyline: Interact with three factions with different choices affecting the power balance between the factions and resulting in diverging storylines.</p>\r\n<p>Stealth action gameplay for a master assassin: Employ a variety of deadly finishing moves which vary according to the location. Activate the Zankoku for bullet-time action and use the Ninja Flying ability to freely explore environments.</p>\r\n<p>New &lsquo;near&rsquo; network features: Boost your inventory by receiving gift items from other players using the PlayStation&reg;Vita near feature.</p>\r\n<p>Original PS Vita rear touch panel gameplay features: &nbsp;Use the rear touch panel to change to a first person view and launch long range weapons at enemies.</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(140, 'en', 'Yamaha PDX-11 DB', '', '', '<p>This easy-to-carry, powerful speaker system frees your iPod/iPhone music for your active lifestyle. Enjoy your entire content library whenever you want, wherever you go.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(141, 'en', 'Yamaha PDX-11 GR', '', '', '<p>This easy-to-carry, powerful speaker system frees your iPod/iPhone music for your active lifestyle. Enjoy your entire content library whenever you want, wherever you go.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(142, 'en', 'Yamaha TSX-130WH', '', '', '<p>Enjoy music from all your favorite sources with this attractive all-in-one audio system.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(143, 'en', 'Yamaha PDX-30PI', '', '', '<p>A certified "works with iPhone" Desktop Audio product that every iPhone or iPod fan who wants to enjoy a higher sound quality with a powerful output needs to have! The PDX-30 includes a card-type remote control for additional convenience.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(144, 'en', 'Yamaha PDX-30BU', '', '', '<p>A certified "works with iPhone" Desktop Audio product that every iPhone or iPod fan who wants to enjoy a higher sound quality with a powerful output needs to have! The PDX-30 includes a card-type remote control for additional convenience.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(145, 'en', 'Sansa Fuze+ MP3 Player (Red) - 4GB', '', '', '<p>With the versatile SanDisk Sansa Fuze+ MP3 player, you''ll get more features for less money. You''ll be able to watch video on the 2.4-inch screen, share photos, listen to FM radio, record voice memos, and more--all in a device that is just 0.43-inches thin. Internal memory and a microSDHC expansion slot give you plenty of storage options for your digital media, and you can expand your enjoyment even further by adding an optional slotRadio card for an instant library of songs.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(146, 'en', 'Sansa Clip+ MP3 Player (Blue) - 4GB', '', '', '<p>Small but powerful, the Sansa Clip+ is a tiny MP3 player that boasts an array of cool features, as well as distinctively big sound for its small size. Rock out with up to 1,000 songs on this blue player. &dagger; Enjoy even more play when you use the expandable memory slot to play preloaded microSDHC&trade; cards**. slotRadio&trade; and slotMusic cards** are preloaded with tunes ready to pop into the player&rsquo;s memory card slot. Rock on with a 15-hour battery life. &dagger; &dagger;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(147, 'en', 'Sansa Clip+ MP3 Player (Red) - 4GB', '', '', '<p>Small but powerful, the Sansa Clip+ is a tiny MP3 player that boasts an array of cool features, as well as distinctively big sound for its small size. Rock out with up to 1,000 songs on this red player. Enjoy even more play when you use the expandable memory slot to play preloaded microSDHC cards. slotRadio and slotMusic cards are preloaded with tunes ready to pop into the player&rsquo;s memory card slot. Rock on with a 15-hour battery life.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(148, 'en', '16GB A Series Walkman Video MP3', '', '', '<p>With an A Series by your side, there''s never a dull moment. The dazzling 2.8" (400x240) touch screen delivers incredible color and quickly serves up photos, videos, album artwork and more. Easily navigate your media library with the tap of a finger or via traditional button controls if you prefer. Experience your music wirelessly and stream audio to other compatible devices with integrated Bluetooth&reg;. Sony Clear Audio technologies work as a team to make your music sound the best it can &ndash; Digital Sound Enhancement Engine, Clear Stereo and Clear Bass Audio Technologies offer deeper, richer sound plus S-Master&trade; MX amplification makes for higher signal to noise ratios and less distortion. Upload the matching lyric file and learn the words to your favorite song as your A Series scrolls them along the screen in sync with the music. Premium EX earbuds and USB cable included.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(149, 'en', '8GB E Series Walkman Video MP3', '', '', '<p>Long lasting battery offering up to 50 hours of music or up to 10 hours of video playback, FM tuner, Karaoke mode, Clear Audio technologies, EX headphones, integrated mic and 2.0" LCD.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(150, 'en', 'Wildwood city classic', '', '', '<div id="overview-bullets">\r\n<ul class="bullet-points">\r\n<li>Hi-Ten Remington Steel Wildwood Citi Comfort Frame</li>\r\n<li>45mm Travel Comfort Suspension Fork</li>\r\n<li>Compact Crankset w/ Integrated Chainguard</li>\r\n<li>SSW26 Double Tunnel Alloy Rims<span> </span></li>\r\n<li>Avenir Comfort Saddle w/ Supersoft Foam, Coil Springs</li>\r\n</ul>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(151, 'en', 'Wildwood classic', '', '', '<div id="overview-bullets">\r\n<ul class="bullet-points">\r\n<li>6061-T6 Aluminum Wildwood Comfort Frame</li>\r\n<li>50mm Travel Comfort Suspension Fork</li>\r\n<li>Compact Crankset w/ Integrated Chainguard</li>\r\n<li>SSW26 Double Tunnel Alloy Rims<span> </span></li>\r\n<li>Puncture-Resistant Kenda Comfort Tires</li>\r\n</ul>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(152, 'en', 'Drifter 2', '', '', '<div id="overview-bullets">\r\n<ul class="bullet-points">\r\n<li>Sun-Hot Heat-Treated Aluminum Beach Cruiser Frame</li>\r\n<li>Hi-Ten Remington Steel Curvaceous Beach Cruiser Fork</li>\r\n<li>Shimano 7-Spd Megarange Freewheel &amp; Twist Shifter</li>\r\n<li>Rust-Proof Alloy Rims &amp; Stainless Steel Spokes</li>\r\n<li>Color-Matched Custom Beach Cruiser Fenders</li>\r\n</ul>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(153, 'en', 'UR55 Full Size Headphones', '', '', '<p>Slipping into a set of lightweight, professional headphones like the Koss UR55 studio headphones is like listening to a live musical performance at a spacious outdoor venue. These high velocity headphones feature open-screen ear cups that deliver great sound, lasting comfort, and impressive air circulation. <br /><br />Designed to deliver equal parts sound quality and comfort, Koss UR55s bump with massive bass while their lightweight foam ear cushions are enough to convince you it&rsquo;s just you and the music. A padded sling with a sturdy metal headband reinforcement provides extreme durability, while the swivel ear cups encourage maximum flexibility, single-ear listening and convenient storage.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(154, 'en', 'JR900 Wireless Headphones', '', '', '<p>Koss JR900s are the music lover&rsquo;s answer to true stereo and cordless freedom. Operating on one of the highest power bands available on the market, the Koss JR900 headphone system (consisting of a high quality, battery operated RF transmitter with AC adapter) offers the best in wireless audio technology, allowing you to roam freely over a 70,000-square-foot area. From room to room, inside to outside, even in bright sunlight, you can move to your heart&rsquo;s content without the need for additional transmitters or worry of signal breakup.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(155, 'en', 'Porta Pro KTC On-Ear Headphone', '', '', '<p>Koss Porta Pro KTC, the most sophisticated version of the Porta Pro, features a new technological upgrade which brings listeners closer to the music they love. Koss Touch Control (KTC) remote and microphone technology, made for iPhone&reg;, iPad&reg; and iPod&reg;, gives listeners more control in fewer steps. Listeners are now able to stay connected, shuffle song and adjust volume with the flick of a switch.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(156, 'en', 'Extra Bass Headphones – 70mm', '', '', '<p>Get that super bass. A tightly sealed acoustic design combines mega 70mm XB driver units &ndash; the world''s largest1 &ndash; and king-sized cushion earpads to deliver ultra-deep bass.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(157, 'en', 'Studio Monitor Headphones', '', '', '<p>Love at first listen. Striking yet comfortable studio monitor headphones with neodymium magnets deliver sounds even the most discerning of audiophiles will flip for.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', '');
INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(158, 'en', 'AIKO SAFE Model Economy (AS 30) Home Safe, with single key', '', '', '<table>\r\n<tbody>\r\n<tr>\r\n<td>AIKO safes are designed to provide maximum protection against fire and foil any tampering and break-ins. The anti-burglary \r\n\r\nConstruction: \r\nBody &amp; Door: Tough steel plates precisely engineered using industry leading manufacturing techniques. Inserted with Premium formulated Ultra Fine Bubble Concrete provides the most effective insulation against intense heat to ensure valuables are protected from burglary &amp; fire.\r\n\r\nAutomatic Stopper: The automatic stopper feature allows users to close the door with slightest of push.\r\n\r\nLocking System: Fitted with  Solid Steel bolt locking system to lock horizontally. Fitted with Single Key lock system, with ultra secure cylinder Key.\r\n\r\nTest &amp; Approvals: Achieved the following international test certificates.\r\n      1.  JIS - Japan Standard\r\n      2.  KS - Korea Standard\r\n      3.  SINTEF - Norway Standard\r\n      4.  CNAL - China Standard \r\n\r\nBuilt in Alarm: (Optional) To set off anti burglary alarm \r\n\r\nTerms and Conditions\r\n\r\n   1. Only loca</td>\r\n</tr>\r\n</tbody>\r\n</table>\r\n<table width="100%" style="margin-top: 20px;">\r\n<tbody>\r\n<tr>\r\n<td colspan="8">\r\n<h4>SIZE (APPROX.) &amp; BRIEF SPECIFICATION</h4>\r\n</td>\r\n</tr>\r\n<tr>\r\n<td colspan="8">\r\n<table width="100%">\r\n<tbody>\r\n<tr bgcolor="#660000">\r\n<td class="arial_11pt_white" style="font-family: Arial, Helvetica, sans-serif; font-size: 11px; color: #ffffff; padding-top: 0px; padding-right: 0px; padding-bottom: 0px; padding-left: 6px; text-decoration: none;" width="45%" height="35"><strong>Model</strong></td>\r\n<td class="arial_11pt_white" style="font-family: Arial, Helvetica, sans-serif; font-size: 11px; color: #ffffff; padding-top: 0px; padding-right: 0px; padding-bottom: 0px; padding-left: 6px; text-decoration: none;" width="55%"><strong>AS 30 - Single Key</strong></td>\r\n</tr>\r\n<tr>\r\n<td width="45%">Outside</td>\r\n<td width="55%">320 H x 400 W x 330 D MM</td>\r\n</tr>\r\n<tr>\r\n<td>Inside</td>\r\n<td>220 H x 320 W x 210 D MM</td>\r\n</tr>\r\n<tr>\r\n<td>Weight</td>\r\n<td>30 KGS</td>\r\n</tr>\r\n<tr>\r\n<td>Accessory</td>\r\n<td>NIL</td>\r\n</tr>\r\n<tr>\r\n<td>Capacity</td>\r\n<td>14 LTR</td>\r\n</tr>\r\n</tbody>\r\n</table>\r\n</td>\r\n</tr>\r\n</tbody>\r\n</table>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(159, 'en', 'AIKO SAFE Model AS 53 Home Safe, Horizontal Model with one tray', '', '', '<p>All AIKO safes are designed to provide maximum protection against fire and foil any tampering and break-ins. The anti-burglary</p>\r\n<p>Construction: Body &amp; Door: Tough steel plates precisely engineered using industry leading manufacturing techniques. Inserted with Premium formulated Ultra Fine Bubble Concrete provides the most effective insulation against intense heat to ensure valuables are protected from burglary &amp; fire.</p>\r\n<p>Automatic Stopper: The automatic stopper feature allows users to close the door with slightest of push.</p>\r\n<p>Locking System: Fitted with 4 directional Solid Steel bolt locking system to lock horizontally &amp; Vertically. Fitted with Dual Key lock system, with ultra secure cylinder Keys, Key &amp; Dial or Key &amp; Digital lock system.</p>\r\n<p>Automatic Re-locking: Fitted with Automatic Re-locking device.</p>\r\n<p>Test &amp; Approvals: Achieved the following international test certificates. 1.  JIS - Japan Standard 2.  KS - Korea Standard 3.  SINTEF - Norway Standard</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(160, 'en', 'Drifter 3', '', '', '<div id="overview-bullets">\r\n<ul class="bullet-points">\r\n<li>Sun-Hot Heat-Treated Aluminum Stretch Beach Cruiser Frame</li>\r\n<li>Hi-Ten Remington Steel Curvaceous Beach Cruiser Fork</li>\r\n<li>Shimano Nexus Internal 3-Spd Hub / Twist Shifter</li>\r\n<li>Rust-Proof Alloy Rims &amp; Stainless Steel Spokes</li>\r\n<li>Color-Matched Custom Beach Cruiser Fenders</li>\r\n</ul>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(161, 'en', 'MV800 16.1 Megapixel MultiView Compact Digital Camera', '', '', '<p>The 3.0" Flip-Out Display lets you take and view great pictures from multiple angles. Easily adjust the LCD from 0 to 180 degrees and make any shot possible. Snap a picture over a crowd or get waist-level candids of kids and pets, or spin the display for perfectly framed self-portraits. Choose from 3 shutter options to comfortably snap pics from any position.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(162, 'en', 'AIKO SAFE Model AS 180 Office Safe with one shelve & one drawer', '', '', '<table>\r\n<tbody>\r\n<tr>\r\n<td>All AIKO safes are designed to provide maximum protection against fire and foil any tampering and break-ins. The anti-burglary\r\n\r\nConstruction:\r\nBody &amp; Door: Tough steel plates precisely engineered using industry leading manufacturing techniques. Inserted with Premium formulated Ultra Fine Bubble Concrete provides the most effective insulation against intense heat to ensure valuables are protected from burglary &amp; fire.\r\n\r\nAutomatic Stopper: The automatic stopper feature allows users to close the door with slightest of push.\r\n\r\nLocking System: Fitted with 4 directional Solid Steel bolt locking system to lock horizontally &amp; Vertically. Fitted with Dual Key lock system, with ultra secure cylinder Keys, Key &amp; Dial or Key &amp; Digital lock system.\r\n\r\nAutomatic Re-locking: Fitted with Automatic Re-locking device.\r\n\r\nTest &amp; Approvals: Achieved the following international test certificates.\r\n1. JIS - Japan Standard\r\n2. KS - Korea Standard\r\n3. SINTEF - Norway Standard\r\n4. CNAL - China Standard\r\n\r\nBuilt in Alarm: (Optional) To set off anti burglary alarm</td>\r\n</tr>\r\n</tbody>\r\n</table>\r\n<table width="100%" style="margin-top: 20px;">\r\n<tbody>\r\n<tr>\r\n<td colspan="8">\r\n<h4>SIZE (APPROX.) &amp; BRIEF SPECIFICATION</h4>\r\n</td>\r\n</tr>\r\n<tr>\r\n<td colspan="8">\r\n<table width="100%">\r\n<tbody>\r\n<tr bgcolor="#660000">\r\n<td class="arial_11pt_white" style="font-family: Arial, Helvetica, sans-serif; font-size: 11px; color: #ffffff; padding-top: 0px; padding-right: 0px; padding-bottom: 0px; padding-left: 6px; text-decoration: none;" width="45%" height="35"><strong>Model</strong></td>\r\n<td class="arial_11pt_white" style="font-family: Arial, Helvetica, sans-serif; font-size: 11px; color: #ffffff; padding-top: 0px; padding-right: 0px; padding-bottom: 0px; padding-left: 6px; text-decoration: none;" width="55%"><strong>AS-180</strong></td>\r\n</tr>\r\n<tr>\r\n<td width="45%">Outside</td>\r\n<td width="55%">H900 X W600 X D570 mm</td>\r\n</tr>\r\n<tr>\r\n<td>Inside</td>\r\n<td>H693 X W462 X D360 mm</td>\r\n</tr>\r\n<tr>\r\n<td>Weight</td>\r\n<td>180 Kgs</td>\r\n</tr>\r\n<tr>\r\n<td>Accessory</td>\r\n<td>1 Shelf, 1 Drawer</td>\r\n</tr>\r\n<tr>\r\n<td>Capacity</td>\r\n<td>116L</td>\r\n</tr>\r\n</tbody>\r\n</table>\r\n</td>\r\n</tr>\r\n</tbody>\r\n</table>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(163, 'en', 'NX200 20.3 Megapixel Compact System Camera', '', '', '<p>Capture every moment in true-to-life quality. With the best-in-class resolution of the extra large 20.3 MP APS-C CMOS sensor, shots are rich, deep and exquisitely detailed. For active subjects, stills can be captured beautifully with 7fps Continuous Shot/100ms AF Speed. Then review your shot on the large 3.0&rdquo; AMOLED display&mdash;made for sharper images and glare reduction.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(164, 'en', 'WB210 10MB 14 Megapixel Slim Digital Camera (Red)', '', '', '<p>When shooting in low light, zooming in on a shot, or when your camera is unsteady, Optical Image Stabilization helps eliminate blurry results. This feature stabilizes your photos by changing their path to the image sensor before they are recorded digitally. Your photos come out sharp and ideally focused.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(165, 'en', 'Nikon 1 J1 One-Lens Kit White', '', '', '<p>For your very mobile lifestyle comes a completely new imaging system with freedom to create and express as never before. Highly compact and portable, the Nikon 1 J1 goes everywhere you go. Moments from your amazing world are captured using a highly responsive autofocus and super fast shooting speed. In one touch you can work in Full HD (1080p) movie record mode. A camera so versatile you can even snap photos while recording movies. Unleash your creativity with Nikon 1&mdash;offering a balance of high performance, advanced features, portability and a newly designed interchangeable lens system. Infuse your world with photos from every moment and connect as never before.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(166, 'en', 'Nikon 1 J1 Two-Lens Wide Angle Kit  Red', '', '', '<p>For your very mobile lifestyle comes a completely new imaging system with freedom to create and express as never before. Highly compact and portable, the Nikon 1 J1 goes everywhere you go. Moments from your amazing world are captured using a highly responsive autofocus and super fast shooting speed. In one touch you can work in Full HD (1080p) movie record mode. A camera so versatile you can even snap photos while recording movies. Unleash your creativity with Nikon 1&mdash;offering a balance of high performance, advanced features, portability and a newly designed interchangeable lens system. Infuse your world with photos from every moment and connect as never before.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(167, 'en', 'D3100 + 18-55 VR Lens Kit', '', '', '<p>\r\n	Beautiful pictures–Amazing movies–Incredibly Easy with the 14 Megapixel DX sensor and learn-as-you-grow Guide Mode.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(168, 'en', 'D300S (Body Only)', '', '', '<p>Extraordinary still and HD video imaging performance converge in the fast and agile 12.3-megapixel, DX-format D300S, delivering D-SLR versatility.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(169, 'en', 'D5100 + AF-S DX NIKKOR 18-55mm f/3.5-5.6G VR Lens Kit', '', '', '<p>Creativity from any point of view. <br />Pictures that amaze. Movies that inspire.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(170, 'en', '588 Chrome Wedge', '', '', '<p>The 588 Forged wedge maintains the popular, tour-proven shape of its  predecessor with a series of technological breakthroughs to provide even  more performance. Every wedge is Precision Forged from 1025 carbon  steel for incredibly soft, solid feel and the highest level of  manufacturing consistency for supreme confidence and trust over every  shot. Tour Zip Grooves&trade; and Laser Milled&trade; technology maximize spin in  accordance with USGA regulations. Exclusive to the 588 Forged wedge is  the Tour Concept Wedge steel shaft, co-developed and engineered by  Cleveland Golf and industry leader True Temper. With a unique stiffness  profile that features a less active tip, this shaft promotes a more  penetrating ball flight, increased spin and optimal distance control  along with superior feel. Choose from two different finishes &ndash; Satin and  Chrome &ndash; as well as low, standard and high bounce options.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(171, 'en', 'Swingline™ Stack-and-Shred™ 100X Hands Free Shredder', '', '', '<p>\r\n<p style="padding-top: 0px; padding-bottom: 10px; color: #424242; font-family: arial, verdana, sans-serif; font-size: 11px; margin: 0px;">\r\n<h2 style="font-size: 13px; padding: 0px; margin: 0px;"><span id="_ctl0_MainContent__ctl0_lblProdName" style="padding: 0px; margin: 0px;">Swingline&trade; Stack-and-Shred&trade; 100X Hands Free Shredder</span></h2>\r\n<p style="padding-top: 0px; padding-bottom: 10px; color: #424242; margin: 0px;"><span id="_ctl0_MainContent__ctl0_lblWebCopy" style="padding: 0px; margin: 0px;">Experience the productivity of hands free shredding. The Swingline&trade; Stack-and-Shred&trade; shredder works without your supervision; just stack, shut and you''re done. Stack up to 100 sheets for automatic shredding at home or in the office. Manual bypass handles 6 sheets of glossy, folded or crumpled paper.</span></p>\r\n<ul style="margin-top: 0px; margin-bottom: 0px; margin-left: 0px; padding-top: 0px; padding-right: 0px; padding-bottom: 0px; padding-left: 15px;">\r\n<span id="_ctl0_MainContent__ctl0_lblFeatBenefits" style="padding: 0px; margin: 0px;">\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">Hands free shredding-just stack, shut and you''re done</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">Auto+ jam clearance automatically reverses and re-feeds stuck papers to clear any jam. LED light indicates rare jams that require user action.</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">Cross-cut shredder meets moderate security needs (Level 3)</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">Shreds credit cards, paper clips, staples, documents into 7-gallon waste bin with view window</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">100 sheet shred capacity on automatic operation, 6 sheet shred capacity on manual</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">Self Clean feature extends cutter life</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">2-year warranty on machine, 2-year on cutters</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">Dimensions: 17&rdquo;H x 12&rdquo;W x 14&rdquo;D, fits under a desk</li>\r\n</span>\r\n</ul>\r\n</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(172, 'en', 'Compact Full HD Camcorder', '', '', '<p>\r\n	            The T10 camcorder was designed to capture memories in comfort and in style. It boasts an ultra compact size, alightweight body and a brushed metal finish creating a subtle but sophisticated look and feel. In fact, its smooth curves fit so comfortably in your hand, it makes shooting video for longer periods of time more enjoyable\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(173, 'en', 'H300 Long Zoom Compact Full HD Camcorder (Black)', '', '', '<p>3.0" LCD Touch Panel display gives you a clearer picture of what you are shooting. By leveraging the latest in LCD display technology, the Touch Panel delivers clean, crisp images that are saturated with natural color and deep, dynamic detail, enabling you to shoot with enhanced comfort and confidence in any external light condition. With the large 3.0" display, it&rsquo;s much easier to browse through content and find the exact features you&rsquo;re looking for. Most useful, the extra large LCD screen makes it easier to select the features you need.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(174, 'en', 'Swingline® Optima® 20 Electric Stapler', '', '', '<p>&nbsp;</p>\r\n<h2 style="color: #424242; font-size: 13px; font-family: arial, verdana, sans-serif; padding: 0px; margin: 0px;"><span id="_ctl0_MainContent__ctl0_lblProdName" style="padding: 0px; margin: 0px;">Swingline&reg; Optima&reg; 20 Electric Stapler</span></h2>\r\n<p style="padding-top: 0px; padding-bottom: 10px; color: #424242; font-family: arial, verdana, sans-serif; font-size: 11px; margin: 0px;"><span id="_ctl0_MainContent__ctl0_lblWebCopy" style="padding: 0px; margin: 0px;">Quiet, space-saving desktop electric stapler is packed with user-friendly features including intuitive user control that helps provide accurate staple placement.</span></p>\r\n<ul style="margin-top: 0px; margin-bottom: 0px; margin-left: 0px; padding-top: 0px; padding-right: 0px; padding-bottom: 0px; padding-left: 15px; color: #424242; font-family: arial, verdana, sans-serif; font-size: 11px;">\r\n<span id="_ctl0_MainContent__ctl0_lblFeatBenefits" style="padding: 0px; margin: 0px;">\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">Jam free stapling guaranteed when using S.F.&reg; 4&reg; or Optima&trade; Premium Staples</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">Durable construction to withstand everyday use</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">Convenient, built-in detachable staple remover &amp; LED light to indicates low staple count</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">Manual or automatic operation, with both plug-in and battery power options</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">20 sheet stapling capacity</li>\r\n<li style="list-style-image: url(http://www.acco.com/swingline/assets/images/li_plus.gif); margin: 0px;">Limited 5-year warranty &amp; 100% Performance Guarantee</li>\r\n</span> \r\n</ul>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(175, 'en', 'F50 Flash Memory 52x Zoom Camcorder (Silver)', '', '', '<p>2.7&rdquo; LCD Touch Panel display gives you a clearer picture of what you are shooting. By leveraging the latest in LCD display technology, the Touch Panel delivers clean, crisp images that are saturated with natural color and deep, dynamic detail, enabling you to shoot with enhanced comfort and confidence in any external light condition.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(176, 'en', 'Quartet® Euro™ Magnetic Porcelain Total Erase® Mobile Easel', '', '', '<p>\r\n<p class="prod16bold" style="margin-top: 0px; margin-right: 0px; margin-bottom: 15px; margin-left: 0px; color: #333333; font-weight: bold; font-size: 16px; text-align: left; text-decoration: none; font-family: Verdana, Arial, Helvetica, sans-serif; background-color: #ffffff;"><span id="_ctl0_MainContent_lblTitle">Quartet&reg; Euro&trade; Magnetic Porcelain Total Erase&reg; Mobile Easel</span></p>\r\n<p class="body12" style="margin-top: 0px; margin-right: 0px; margin-bottom: 15px; margin-left: 0px; color: #333333; font-size: 12px; text-align: left; text-decoration: none; font-family: Verdana, Arial, Helvetica, sans-serif; background-color: #ffffff;"><span id="_ctl0_MainContent_lblDescription">Ultra-durable, ultra-smooth 27" x 41" mobile presentation easel with DuraMax&reg; porcelain surface that will not scratch, dent, stain or ghost. Delivers superior performance when collaboration is needed in high-profile, heavy-use office environments. Magnetic surface doubles as bulletin board. Easy-to-clean writing surface requires minimal use of Quartet&reg; cleaning solutions. Adjustable hooks and clamp hold standard-sized flipcharts for easy sheet tear-away meeting notes. Smooth-rolling 5-caster star-base wheels lock firmly in place for total control and mobility. Flexible spring-loaded height adjuster moves from 67" to 77" for optimal height. Includes spacious folding accessory tray and 4 assorted Quartet&reg; whiteboard markers. Sleek Euro&trade; design with matte aluminum finish for maximum style and durability. 100% Satisfaction Guaranteed.</span></p>\r\n<p class="body12" style="margin-top: 0px; margin-right: 0px; margin-bottom: 15px; margin-left: 0px; color: #333333; font-size: 12px; text-align: left; text-decoration: none; font-family: Verdana, Arial, Helvetica, sans-serif; background-color: #ffffff;"><span id="_ctl0_MainContent_lblFeatures">&nbsp;</span></p>\r\n<ul style="color: #000000; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 11px; text-align: left; background-color: #ffffff;">\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Ultra-durable, ultra-smooth 27" W x 41" H mobile presentation easel with DuraMax&reg; porcelain surface that will not scratch, dent, stain or ghost</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Delivers superior performance when collaboration is needed in high-profile, heavy-use office environments</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Magnetic surface doubles as bulletin board</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Adjustable hooks and clamp hold standard-sized flipcharts for easy sheet tear-away</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Easy-to-clean writing surface requires minimal use of Quartet&reg; cleaning solutions</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Smooth-rolling 5-caster star-base wheels lock firmly in place for total control and mobility</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Flexible spring-loaded height adjuster moves from 67" to 77" for optimal height</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Includes spacious folding accessory tray and 4 assorted Quartet&reg; whiteboard markers</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Sleek Euro&trade; design with matte aluminum finish for maximum style and durability</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">100% Satisfaction Guaranteed</li>\r\n</ul>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(177, 'en', 'CG BLACK DRIVER', '', '', '<p>With a sleek and striking look, the CG Black driver weighs only 265  grams, making it the lightest driver on the market to help players  generate measurable increases in swing speed and distance with the same  swing effort. The advanced aerodynamics found in the driver&rsquo;s Speed  Crown Design &ndash; an innovative, teardrop-inspired crown profile &ndash; maximize  distance by reducing drag at all angles of airflow during the swing.  MaxCOR2 Variable Face Thickness Technology reduces face weight and  increases trampoline effect on off-center hits, meaning higher ball  speed and more distance on off-center hits. Plus, a high-density weight  screw at the rear of the sole plate positions the center of gravity  lower and deeper to promote a high, draw-biased trajectory with optimal  launch conditions for effortless distance. The CG Black driver features a  Miyazaki C. Kua 39 Limited Edition graphite shaft and a Golf Pride  Ultralite grip, a combination that decreases overall club weight for  faster swing speed.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(178, 'en', 'Wilson Jones® 364 Heavy Duty Round Ring Binder with Label Holder, 1", Black', '', '', '<p>\r\n<p class="body12" style="margin-top: 0px; margin-right: 0px; margin-bottom: 15px; margin-left: 0px; color: #333333; font-size: 12px; text-align: left; text-decoration: none; font-family: Verdana, Arial, Helvetica, sans-serif; background-color: #ffffff;"><span id="_ctl0_MainContent_lblDescription">Built to last, this heavy duty binder with standard round rings is made of flexible polypropylene allowing it to fully protect your documents from the elements. The label holder on the binder spine is perfect for titling your projects.</span></p>\r\n<p class="body12" style="margin-top: 0px; margin-right: 0px; margin-bottom: 15px; margin-left: 0px; color: #333333; font-size: 12px; text-align: left; text-decoration: none; font-family: Verdana, Arial, Helvetica, sans-serif; background-color: #ffffff;"><span id="_ctl0_MainContent_lblFeatures">&nbsp;</span></p>\r\n<ul style="color: #000000; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 11px; text-align: left; background-color: #ffffff;">\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">220 sheet capacity in 1 inch binder size</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">No-Gap round rings close tightly</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Eco-friendly, PVC Free polypropylene material is virtually impossible to tear</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">100% recycled chipboard and 45% post consumer waste minimum recycled content</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">CleanView&trade; protection prevents ink from transferring off papers onto binder</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Two clear interior pockets and label holder on spine</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Available in black, blue and dark red, multiple sizes</li>\r\n</ul>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(179, 'en', 'CG16 Black Pearl Wedge', '', '', '<div class="overviewbody">\r\n<p>Based on the shape of the tour proven CG14<span style="font-size: 8pt;">&trade;</span> wedge, the CG16<span style="font-size: 8pt;">&trade;</span> has a hint of offset and is slightly larger for added forgiveness.&nbsp; The  face features the same spin maximizing technology featured on the CG15<span style="font-size: 8pt;">&trade;</span> wedge &ndash; Tour Zip Grooves<span style="font-size: 8pt;">&trade;</span> in combination with Cleveland<span style="font-size: 8pt;">&reg;</span> Golf&rsquo;s breakthrough Laser Milled<span style="font-size: 8pt;">&trade; </span>surface  roughness technology.&nbsp; Using the precision accuracy of a laser, each  face features four perfectly calibrated texture lines milled between  each groove exactly to the conforming roughness limit.&nbsp; This surface  roughness application optimizes ball-to-face friction and maximizes spin  within the Rules of Golf.</p>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(180, 'en', '18-55mm Portrait Lens', '', '', '<p>Certain photos vividly remind you of memorable moments even at a quick glance. You can treasure such everlasting, memories with the 18-55mm lens. This lens enables you to create diverse images from any scene, including wide-angle and portrait shots, making your precious moments last forever.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(181, 'en', 'Women''s Bloom Complete Set', '', '', '<p>Created for women golfers looking to improve their game, the Bloom 14 Piece set covers all of her equipment needs. Designed specifically for her swing, the 100% titanium Driver and Stainless Steel Fairway woods are designed with today&rsquo;s modern lightweight and oversized technology to drastically increase distance and consistency-particularly on mishits. The hybrid long irons are hollow and extremely forgiving and are packaged together with the short game simplifying NIBLICK &ndash; to make the game even easier to learn. If that isn&rsquo;t enough, the classically designed mini boot bag has retro details yet modern convenience with ample pocket space and detachable wristlet.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(182, 'en', 'GBC® Smart-View® 3-Ring Report Cover', '', '', '<p>\r\n<p class="body12" style="margin-top: 0px; margin-right: 0px; margin-bottom: 15px; margin-left: 0px; color: #333333; font-size: 12px; text-align: left; text-decoration: none; font-family: Verdana, Arial, Helvetica, sans-serif; background-color: #ffffff;"><span id="_ctl0_MainContent_lblDescription">Clear front cover folds back and keeps title sheet intact by securing it inside cover edge. Interior 3-ring design holds 3-hole punched report pages.</span></p>\r\n<p class="body12" style="margin-top: 0px; margin-right: 0px; margin-bottom: 15px; margin-left: 0px; color: #333333; font-size: 12px; text-align: left; text-decoration: none; font-family: Verdana, Arial, Helvetica, sans-serif; background-color: #ffffff;"><span id="_ctl0_MainContent_lblFeatures">&nbsp;</span></p>\r\n<ul style="color: #000000; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 11px; text-align: left; background-color: #ffffff;">\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Durable polypropylene material</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Rings hold up to 40 3-hole punched sheets</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Soft, rounded spine and textured cover</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Large back pocket with business card holder</li>\r\n<li class="body12" style="color: #333333; font-size: 12px; text-align: left; text-decoration: none;">Black</li>\r\n</ul>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(183, 'en', 'Samsung 50-200mm NX Telephoto OIS Lens', '', '', '<p>The Samsung T50200SB 50-200mm Telephoto OIS Lens is a long telephoto zoom lens compatible with our NX Series of digital cameras.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(184, 'en', 'Samsung 30mm NX Pancake Lens', '', '', '<p>Samsung&rsquo;s compact 30mm pancake lens is the brightest in its class. With its 30mm fixed focal length and maximum aperture of F/2, you can capture exceptionally bright images &mdash; even in low-light situations such as shady forest paths and indoor weddings. You can also create striking, images with shallow depth of field in a variety of settings. And since it&rsquo;s incredibly slim and lightweight, you can take it with you everywhere.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(185, 'en', 'CG Lightweight Cart Bag', '', '', '<p>CG Lightweight Cart bags are perfect for push and power carts</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(186, 'en', 'CG Black Staff Bag', '', '', '<h3 class="product_availability">Item is not available at this time.<br />Can be Preordered.</h3>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(187, 'en', '2010 TOUR STAFF Bag 10"', '', '', '<p>Used by Cleveland Golf tour staff players worldwide</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(188, 'en', 'NEW Wilson Staff Fifty Elite Yellow Golf Ball', '', '', '<p>An aggressive core is offset by a responsive cover; Explosive distance is coupled with soft feel; Low driver spin is offset by high greenside spin; Long carry, quick stop</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(189, 'en', 'AF-S NIKKOR 14-24mm f/2.8G ED', '', '', '<p>Fast aperture, high-performance, ultra-wide-angle zoom optimized for FX- and DX-format sensors featuring Nikon&rsquo;s exclusive ED Glass and Nano Crystal Coat.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(190, 'en', 'AF-S DX NIKKOR 10-24mm f/3.5-4.5G ED', '', '', '<p>This ultra wide-angle lens, designed exclusively for use with Nikon&rsquo;s DX-format, provides a versatile wide-angle zoom perspective.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(191, 'en', 'Esperanza Spalding - Radio Music Society', '', '', '<p>\r\n<p>THIS IS A PRE ORDER ITEM.</p>\r\n<p>IF PURCHASED, YOUR ITEM(S) WILL SHIP ON OR FOR DELIVERY ON MARCH 20, 2012</p>\r\n<p>&nbsp;</p>\r\n<p>ESPERANZA SPALDING RELEASES RADIO MUSIC SOCIETY,</p>\r\n<p>A KALEIDOSCOPIC COLLECTION CELEBRATING THE POWER OF SONG</p>\r\n<p>&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>CD With ADDED Value Download Card Card To Download 11 Music Videos</p>\r\n<p>&nbsp;</p>\r\n<p>&ldquo;Radio Song,&rdquo; the new disc&rsquo;s opening track, both sets the tone and confirms the aptness of Spalding&rsquo;s &ldquo;radio music&rdquo; metaphor. &ldquo;Everyone has the experience of turning on a car radio,&rdquo; she explains,&rdquo; mindlessly flipping through the dial and suddenly a fragment grabs you and you&rsquo;re totally digging it. I wanted to capture that moment when the music just sinks in. It&rsquo;s about the power of song, and how at the least it can save the day.&rdquo;</p>\r\n<p>&nbsp;</p>\r\n<p>Fleshing out the concept with original music was second nature to Spalding. &ldquo;I have this book of music that I&rsquo;ve written, and so much of it fit either the Chamber Music or Radio Music concept. Songs develop for me in fragments, so for these projects, I took my notes and organized them into coherent works of music.&rdquo;</p>\r\n<p>&nbsp;</p>\r\n<p>In the process, Spalding added her original, affirmative perspective to classic radio music themes. Songs about love run a full gamut. &ldquo;Hold On Me&rdquo; is a narrative of unrequited love, inspired by people who cling to dreams of relationships that can never be realized. &ldquo;Let Her,&rdquo; one of Spalding&rsquo;s older compositions, was inspired by &ldquo;different people I&rsquo;ve known who are in miserable situations, then complain when they end.&rdquo; &ldquo;Cinnamon Tree,&rdquo; written to cheer up a friend, celebrates platonic love, and Spalding&rsquo;s belief that &ldquo;the love between friends is just as important as romantic love.&rdquo;</p>\r\n<p>&nbsp;</p>\r\n<p>&ldquo;Crowned and Kissed,&rdquo; with references to King Arthur and Midas, is about &ldquo;the unsung royalty in your life, men and women who quietly, every day do the most honorable things, and who deserve to be honored even if they don&rsquo;t end up with castles and thrones.&rdquo; The edgy &ldquo;Smile Like That&rdquo; marks the moment a person realizes that his or her partner has developed other interests. &ldquo;I&rsquo;m saying, `Okay, I get it, let&rsquo;s not beat around the bush,&rdquo;&rsquo; Spalding explains.</p>\r\n<p>&nbsp;</p>\r\n<p>Her takes on the state of our country and our culture are equally fresh and insightful. &ldquo;Vague Suspicions&rdquo; confronts society&rsquo;s short attention span and our habit of absorbing horrific events and celebrity gossip as part of the same media overload. The brief &ldquo;Land Of The Free&rdquo; speaks to the sinister system of false imprisonment by outlining the case of one innocent victim who spent 30 years in jail for a crime he did not commit.</p>\r\n<p>&nbsp;</p>\r\n<p>&ldquo;Black Gold&rdquo; is specifically addressed to young boys of color. &ldquo;So much of our strength is drawn from resistance and endurance,&rdquo; she explains, &ldquo;but black pride didn&rsquo;t just start with the slave trade. I wanted to address our nobility, going back to our incredible ancestors in pre-colonial Africa. I remember meetings when I was in elementary school about being strong as young black women, and I don&rsquo;t think the boys had those meetings. This song is meant to speak to those young men, and I imagined it might one day be something that a parent could sing to his or her son.&rdquo;</p>\r\n<p>&nbsp;</p>\r\n<p>Radio Music Society also features &ldquo;City of Roses,&rdquo; a celebration of her native Portland, Oregon that Spalding was commissioned to write by Banana Republic, and two cover tunes. Taking the advice of one of her mentors, tenor saxophone giant Joe Lovano: &ldquo;When you do a classic, you have to find your own reason for doing it.&rdquo; Spalding charges Stevie Wonder&rsquo;s &ldquo;I Can&rsquo;t Help It&rdquo; with the energy of apprehensive new love and adds original lyrics to Wayne Shorter&rsquo;s &ldquo;Endangered Species&rdquo;.</p>\r\n<p>&nbsp;</p>\r\n<p>The music is realized by many of the brilliant musicians who are part of Spalding&rsquo;s ever-expanding universe. In addition to longtime partners Lovano, keyboard player Leo Genovese and drummer Terri Lyne Carrington, the ranks contain jazz legends Jack DeJohnette and Billy Hart; guitar heroes Jef Lee Johnson and Lionel Loueke; an array of master vocalists including Algebra Blessett, Lalah Hathaway, Gretchen Parlato, Leni Stern and Becca Stevens; hip-hop giant Q-Tip (who performs on and co-produced two tracks); and two Portland-based musicians, Janice Scroggins and Dr. Thara Memory, who provided essential mentorship in Spalding&rsquo;s youth.</p>\r\n<p>&nbsp;</p>\r\n<p>Four tracks feature the horn section of the American Music Program, a youth big band of musicians age 12 to 18 directed by her longtime mentor and teacher Dr. Memory, who conducts and provides horn arrangements; while the soulful pianist on &ldquo;Hold on Me&rdquo; is Ms. Scroggins, who Spalding studied with as a child. &ldquo;Both of them are phenomenal artists who aren&rsquo;t well known outside of the Northwest,&rdquo; Spalding emphasizes. &ldquo;Janice Scroggins was, quite honestly, too deep for me when I was eight years old. She unifies completely the sounds of gospel, blues and jazz, our American roots music. And Dr. Thara Memory, the teacher I came up through, has dedicated his life to spreading the message of this music. I had to have his youth band on the record, because they&rsquo;re part of my Music Society, too.&rdquo;</p>\r\n<p>&nbsp;</p>\r\n<p>Among its many strengths, Radio Music Society is a celebration of the men and women who have helped cultivate Spalding&rsquo;s talent, as well as those who have nurtured her vision and inspired her along the way. &ldquo;I&rsquo;ve had the honor and blessing of working with so many phenomenal jazz musicians over the years,&rdquo; she says. &ldquo;As I&rsquo;ve gotten to know them and their music, I&rsquo;ve grown to love them as family and colleagues. I wished for an opportunity for us all to interpret songs together, so that they can be heard and received by a larger audience. All my personal heroes who are revered in the jazz world &ndash; like Joe Lovano and Terri Lyne Carrington &ndash; should be heard by a mainstream audience, because what they manifest in their music is so beautiful, sincere and uplifting. I think they literally bring good into the lives of the people who hear them. So I&rsquo;ve tried to put together a program of music that speaks to the non-jazz listener, but can still provide a viable foundation for my jazz heroes to express themselves. Hopefully, people can enjoy all the elements of my music without being told which genres it is &lsquo;supposedly&rsquo; a blend of. Everyone is invited to listen with no pre-conceived notions. It&rsquo;s a journey. Think and feel for yourself. But, most importantly, ENJOY!&rdquo;</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', '');
INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(192, 'en', 'Black and White America (CD Pack)', '', '', '<p><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">Tracklisting:</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">1. Black And White America</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">2. Come On Get It</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">3. In The Black</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">4. Liquid Jesus</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">5. Rock Star City Life</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">6. Boongie Drop</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">7. Stand</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">8. Superlove</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">9. Everything</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">10. I Can''t Be Without You</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">11. Looking Back On Love</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">12. Life Ain''t Ever Been Better Than It Is Now</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">13. The Faith Of A Child</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">14. Sunflower</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">15. Dream</span><br style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #cac5c5; padding: 0px; margin: 0px;" /><span style="color: #000000; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 16px; text-align: left; background-color: #ffffff;">16. Push</span></p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(205, 'en', 'DIR-657 HD Media Router 1000', '', '', '<p>&nbsp;</p>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; vertical-align: baseline; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; line-height: 16px; font-family: myriad-pro-1, myriad-pro-2; visibility: visible; color: #555555; border: 0px initial initial;">Up to 300 Mbps speed, 4 Gigabit Ethernet ports and HD Fuel bandwidth prioritization combine to optimize your online entertainment for seamless HD video streams, high-performance gaming, and VOIP calls without annoying glitches or lags. There&rsquo;s a Shareport USB to allow for device printing, an SD Card slot for accessing HD media files and with DLNA, the HD Media Router can connect to virtually any device. The HD Media Router 1000 has been designed to keep up with your connected lifestyle and deliver the uninterrupted connectivity you need to power multiple devices, simultaneously, and keep you in command of your digital universe.<em style="vertical-align: baseline; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; padding: 0px; margin: 0px; border: 0px initial initial;"><br /></em></p>\r\n<h3 style="margin-top: 10px; margin-right: 0px; margin-bottom: 6px; margin-left: 0px; font-size: 14px; font-weight: 400; vertical-align: baseline; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; line-height: 14px; font-family: myriad-pro-1, myriad-pro-2; visibility: visible; color: #e22736; padding: 0px; border: 0px initial initial;">Features:</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 20px; margin-left: 0px; vertical-align: baseline; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; list-style-position: initial; list-style-image: initial; color: #555555; font-family: myriad-pro-1, myriad-pro-2, arial; padding: 0px; border: 0px initial initial;">\r\n<li style="margin-top: 0px; margin-right: 0px; margin-bottom: 4px; margin-left: 0px; padding-left: 20px; vertical-align: baseline; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; background-image: url(http://amplifi.dlink.com/resource/1325889383000/LumSitesCSS/lumSitesCSS/images/LumSitesGlobalSprite.png); background-attachment: scroll; background-origin: initial; background-clip: initial; background-position: 0px -297px; background-repeat: no-repeat no-repeat; border: 0px initial initial;">Up to 300 Mbps data transfer rates</li>\r\n<li style="margin-top: 0px; margin-right: 0px; margin-bottom: 4px; margin-left: 0px; padding-left: 20px; vertical-align: baseline; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; background-image: url(http://amplifi.dlink.com/resource/1325889383000/LumSitesCSS/lumSitesCSS/images/LumSitesGlobalSprite.png); background-attachment: scroll; background-origin: initial; background-clip: initial; background-position: 0px -297px; background-repeat: no-repeat no-repeat; border: 0px initial initial;">HD Fuel&trade; QoS to prioritize high-bandwidth applications</li>\r\n<li style="margin-top: 0px; margin-right: 0px; margin-bottom: 4px; margin-left: 0px; padding-left: 20px; vertical-align: baseline; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; background-image: url(http://amplifi.dlink.com/resource/1325889383000/LumSitesCSS/lumSitesCSS/images/LumSitesGlobalSprite.png); background-attachment: scroll; background-origin: initial; background-clip: initial; background-position: 0px -297px; background-repeat: no-repeat no-repeat; border: 0px initial initial;">High bandwidth Gigabit ports for performance devices</li>\r\n<li style="margin-top: 0px; margin-right: 0px; margin-bottom: 4px; margin-left: 0px; padding-left: 20px; vertical-align: baseline; border-image: initial; outline-width: 0px; outline-style: initial; outline-color: initial; background-image: url(http://amplifi.dlink.com/resource/1325889383000/LumSitesCSS/lumSitesCSS/images/LumSitesGlobalSprite.png); background-attachment: scroll; background-origin: initial; background-clip: initial; background-position: 0px -297px; background-repeat: no-repeat no-repeat; border: 0px initial initial;">SharePort&trade; Plus Technology for sharing USB 2.0 devices</li>\r\n</ul>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(194, 'en', 'U218 Singles (U2TCD020)', '', '', '<p><span style="color: #000000; font-family: Arial, Geneva, ''sans serif''; text-align: left; background-color: #ffffff;">U218 Singles is the first single-disc collection - including 16 of their best-known songs. Also included are two brand-new tracks recorded with producer Rick Rubin at Abbey Road Studios in London: "The Saints Are Coming" (with Green Day) and "Window in the Skies."</span></p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(195, 'en', 'Crossroads Guitar Festival 2010 (2DVD)', '', '', '<p>\r\n<p>2DVD edition of the 2010 Crossroads Guitar Festival. Featuring: Eric Clapton, Jeff Beck,Sheryl Crow,Vince Gill, Buddy Guy, B.B. King,John Mayer, Bill Murray,Steve Winwood,Ronnie Wood, ZZ Top,and more PLUS behind-the-scenes footage and interviews.</p>\r\n<p>&nbsp;</p>\r\n<p>DVD 1</p>\r\n<p>&nbsp;</p>\r\n<p>01 Promise Land - By Sonny Landreth with Eric Clapton</p>\r\n<p>02 Z. Rider - By Sonny Landreth with Eric Clapton</p>\r\n<p>03 Traveling Shoes - By Robert Randolph &amp; The Family Band</p>\r\n<p>04 Going Down - By Pino Daniele, Joe Bonamassa, Robert Randolph &amp; The Family Band</p>\r\n<p>05 Killing Floor - By Robert Cray with Jimmie Vaughan &amp; Hubert Sumlin</p>\r\n<p>06 Six Strings Down - By Jimmie Vaughan with Robert Cray &amp; Hubert Sumlin</p>\r\n<p>07 Waiting For The Bus - By ZZ Top</p>\r\n<p>08 Jesus Just Left Chicago - By ZZ Top</p>\r\n<p>09 Gypsy Blood - By Doyle Bramhall II</p>\r\n<p>10 In My Time Of Dying (Jesus Make Up My Dying Bed) - By Doyle Bramhall II</p>\r\n<p>11 Bright Lights - By Gary Clark Jr.</p>\r\n<p>12 Long Road Home - By Sheryl Crow with Derek Trucks, Susan Tedeschi, Doyle Bramhall II &amp; Gary Clark Jr.</p>\r\n<p>13 Our Love Is Fading - By Sheryl Crow with Eric Clapton, Doyle Bramhall II &amp; Gary Clark Jr.</p>\r\n<p>14 Blackwaterside - By Bert Jansch</p>\r\n<p>15 Mississippi Blues - By Stefan Grossman &amp; Keb'' Mo''</p>\r\n<p>16 Roll And Tumble Blues - By Stefan Grossman</p>\r\n<p>17 One More Last Chance - By Vince Gill with Keb'' Mo'', James Burton, Earl Klugh &amp; Albert Lee</p>\r\n<p>18 Mystery Train - By Vince Gill with James Burton, Albert Lee, Keb'' Mo'' &amp; Earl Klugh</p>\r\n<p>19 Lay Down Sally - By Vince Gill with Sheryl Crow, Keb'' Mo'', Albert Lee, James Burton &amp; Earl Klugh</p>\r\n<p>20 Angelina - By Earl Klugh</p>\r\n<p>21 Vonetta - By Earl Klugh</p>\r\n<p>22 Who Did You Think I Was - By John Mayer Trio</p>\r\n<p>23 Ain''t No Sunshine - By John Mayer Trio</p>\r\n<p>&nbsp;</p>\r\n<p>DVD 2</p>\r\n<p>&nbsp;</p>\r\n<p>01 Midnight In Harlem - By Derek Trucks &amp; Susan Tedeschi Band</p>\r\n<p>02 Coming Home - By Derek Trucks &amp; Susan Tedeschi Band with Warren Haynes</p>\r\n<p>03 Soulshine - By Warren Haynes</p>\r\n<p>04 Don''t Keep Me Wondering - By David Hidalgo &amp; Cesar Rosas with Derek Trucks</p>\r\n<p>05 Space Captain - By Derek Trucks &amp; Susan Tedeschi Band with Warren Haynes, David Hidalgo, Cesar Rosas &amp; Chris Stainton</p>\r\n<p>06 Five Long Years - By Buddy Guy with Jonny Lang &amp; Ronnie Wood</p>\r\n<p>07 Miss You - By Buddy Guy with Jonny Lang &amp; Ronnie Wood</p>\r\n<p>08 Hammerhead - By Jeff Beck</p>\r\n<p>09 Nessun Dorma - By Jeff Beck</p>\r\n<p>10 Crossroads</p>\r\n<p>11 Hands Of The Saints - By Citizen Cope &amp; Eric Clapton</p>\r\n<p>12 I Shot The Sheriff</p>\r\n<p>13 Shake Your Money Maker - By Eric Clapton &amp; Jeff Beck</p>\r\n<p>14 Had To Cry Today - By Steve Winwood &amp; Eric Clapton</p>\r\n<p>15 Voodoo Chile - By Eric Clapton &amp; Steve Winwood</p>\r\n<p>16 Dear Mr. Fantasy - By Steve Winwood &amp; Eric Clapton</p>\r\n<p>17 The Thrill Is Gone - By B.B. King &amp; Ensemble</p>\r\n<div></div>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(196, 'en', 'Feeding the Monkies At Ma Maison (Zappa)', '', '', '<p>&nbsp;</p>\r\n<p>Official Release #90&nbsp;</p>\r\n<p>Released: 22 September 2011</p>\r\n<p>Label: Zappa Records&nbsp;</p>\r\n<p>Catalog Number: ZR 20012</p>\r\n<p>Produced/Composed/Arranged by Frank Zappa</p>\r\n<p>CD Compilation by Gail Zappa &amp; Joe Travers</p>\r\n<p>Tracklisting:</p>\r\n<p>&nbsp;</p>\r\n<p>01. Feeding The Monkies at Ma Maison 20:12</p>\r\n<p>02. Buffalo Voice 11:34</p>\r\n<p>03. Secular Humaism 6:37</p>\r\n<p>04. Worms From Hell 5:31</p>\r\n<p>05. Samba Funk 11:29</p>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(197, 'en', 'Guitar Man Album Artwork', '', '', '<p>\r\n<p>Guitar Man CD</p>\r\n<p>George Benson - Guitar Man</p>\r\n<p>AUDIO TRACKS:</p>\r\n<p>- Tenderly</p>\r\n<p>- I Want To Hold Your Hand</p>\r\n<p>- My Cherie Amour</p>\r\n<p>- Naima</p>\r\n<p>- Tequila</p>\r\n<p>- Don''t Know Why</p>\r\n<p>- Lady In My Life</p>\r\n<p>- My One And Only Love</p>\r\n<p>- Paper Moon</p>\r\n<p>- Danny Boy</p>\r\n<p>- Since I Fell For You</p>\r\n<p>- Fingerlero</p>\r\n<p>FILE:</p>\r\n<p>- George Benson - Guitar Man Digital Album Booklet</p>\r\n<p>George Benson - Guitar Man (Exclusive Bonus Tracks)</p>\r\n<p>AUDIO TRACKS:</p>\r\n<p>- Somewhere</p>\r\n<p>- Maria</p>\r\n<p>MERCHANDISE:</p>\r\n<p>- Guitar Man CD</p>\r\n<p>Type: CD</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(198, 'en', 'B.B. King One Kind Favor CD Grammy Award Winning CD Manufacturer: Geffen Records Sku: BBK-11ONEKINDFAVORCD  Reviewed 2 times', '', '', '<p>\r\n<div class="wiki_section" style="margin-bottom: 15px; line-height: 18px; color: #3b3b3b; font-family: ''Gill Sans MT'', tahoma, arial, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">\r\n<h3 style="font-size: 11pt; color: #666666; margin-top: 2px; margin-right: 0px; margin-bottom: 1px; margin-left: 0px; font-family: ''Gill Sans MT Pro Medium'', tahoma, arial, sans-serif;">GRAMMY AWARD WINNING CD: BEST TRADITIONAL BLUES ALBUM</h3>\r\n</div>\r\n<div class="wiki_section" style="margin-bottom: 15px; line-height: 18px; color: #3b3b3b; font-family: ''Gill Sans MT'', tahoma, arial, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">Product Details&nbsp;</div>\r\n<div class="wiki_section" style="margin-bottom: 15px; line-height: 18px; color: #3b3b3b; font-family: ''Gill Sans MT'', tahoma, arial, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">\r\n<ul class="wiki_list">\r\n<li class="wiki_listitem">Audio CD (August 26, 2008)</li>\r\n<li class="wiki_listitem">Original Release Date: August 26, 2008</li>\r\n<li class="wiki_listitem">Number of Discs: 1</li>\r\n<li class="wiki_listitem">Label: Geffen Records</li>\r\n</ul>\r\n</div>\r\n<div class="wiki_section" style="margin-bottom: 15px; line-height: 18px; color: #3b3b3b; font-family: ''Gill Sans MT'', tahoma, arial, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">Listen to samples&nbsp;</div>\r\n<div class="wiki_section" style="margin-bottom: 15px; line-height: 18px; color: #3b3b3b; font-family: ''Gill Sans MT'', tahoma, arial, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">The full track listing for One Kind Favor (original artist in parenthesis):&nbsp;</div>\r\n<div class="wiki_section" style="margin-bottom: 15px; line-height: 18px; color: #3b3b3b; font-family: ''Gill Sans MT'', tahoma, arial, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">\r\n<ul class="wiki_list">\r\n<li class="wiki_listitem">1.See That My Grave Is Kept Clean (Lemon Jefferson)</li>\r\n<li class="wiki_listitem">2.I Get So Weary (T-Bone Walker)</li>\r\n<li class="wiki_listitem">3.Get These Blues Off Me (Lee Vida Walker)</li>\r\n<li class="wiki_listitem">4.How Many More Years (Chester Burnett)</li>\r\n<li class="wiki_listitem">5.Waiting For Your Call (Oscar Lollie)</li>\r\n<li class="wiki_listitem">6.My Love Is Down (Lonnie Johnson)</li>\r\n<li class="wiki_listitem">7.The World Is Gone Wrong (Walter Vinson, also known as Walter Jacobs, and Lonnie Chatmon, core members of the Mississippi Sheiks)</li>\r\n<li class="wiki_listitem">8.Blues Before Sunrise (John Lee Hooker)</li>\r\n<li class="wiki_listitem">9.Midnight Blues (John Willie "Shifty" Henry)</li>\r\n<li class="wiki_listitem">10.Backwater Blues (Big Bill Broonzy)</li>\r\n<li class="wiki_listitem">11.Sitting On Top Of The World (Walter Vinson and Lonnie Chatmon)</li>\r\n<li class="wiki_listitem">12.Tomorrow Night (Lonnie Johnson)</li>\r\n</ul>\r\n</div>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(199, 'en', 'B.B. King - Original Greatest Hits CD', '', '', '<p>\r\n<div class="wiki_section" style="margin-bottom: 15px; line-height: 18px; color: #3b3b3b; font-family: ''Gill Sans MT'', tahoma, arial, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">Product Details&nbsp;<br />\r\n<ul class="wiki_list">\r\n<li class="wiki_listitem">Audio CD (September 13, 2005)</li>\r\n<li class="wiki_listitem">Original Release Date: September 13, 2005</li>\r\n<li class="wiki_listitem">Number of Discs: 2</li>\r\n<li class="wiki_listitem">Label: Virgin Records Us</li>\r\n</ul>\r\n</div>\r\n<div class="wiki_section" style="margin-bottom: 15px; line-height: 18px; color: #3b3b3b; font-family: ''Gill Sans MT'', tahoma, arial, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff;">Disc: 1\r\n<ul class="wiki_list">\r\n<li class="wiki_listitem">1. 3 O''Clock Blues</li>\r\n<li class="wiki_listitem">2. Blind Love</li>\r\n<li class="wiki_listitem">3. She''s Dynamite</li>\r\n<li class="wiki_listitem">4. You Know I Love You</li>\r\n<li class="wiki_listitem">5. Please Love Me</li>\r\n<li class="wiki_listitem">6. Story Fom My Heart And Soul</li>\r\n<li class="wiki_listitem">7. The Woman I Love</li>\r\n<li class="wiki_listitem">8. Neighborhood Affair</li>\r\n<li class="wiki_listitem">9. When My Heart Beats Like A Hammer</li>\r\n<li class="wiki_listitem">10. Every Day I Have The Blues</li>\r\n<li class="wiki_listitem">11. Love You Baby (Take A Swing With Me)</li>\r\n<li class="wiki_listitem">12. Ten Long Years</li>\r\n<li class="wiki_listitem">13. You Upset Me, Baby</li>\r\n<li class="wiki_listitem">14. Boogie Rock (House Rocker)</li>\r\n<li class="wiki_listitem">15. Crying Won''t Help You</li>\r\n<li class="wiki_listitem">16. Bad Luck</li>\r\n<li class="wiki_listitem">17. Did You Ever Love A Woman</li>\r\n<li class="wiki_listitem">18. You Don''t Know</li>\r\n<li class="wiki_listitem">19. Sweet Little Angel</li>\r\n<li class="wiki_listitem">20. On My Word Of Honor</li>\r\n</ul>\r\n<br />Disc: 2\r\n<ul class="wiki_list">\r\n<li class="wiki_listitem">1. Be Careful With A Fool</li>\r\n<li class="wiki_listitem">2. Please Accept My Love</li>\r\n<li class="wiki_listitem">3. Days Of Old</li>\r\n<li class="wiki_listitem">4. Worry, Worry</li>\r\n<li class="wiki_listitem">5. Confessin'' The Blues</li>\r\n<li class="wiki_listitem">6. Sweet Sixteen Parts 1 &amp; 2</li>\r\n<li class="wiki_listitem">7. Ain''t Nobody''s Business</li>\r\n<li class="wiki_listitem">8. Walkin'' Dr. Bill</li>\r\n<li class="wiki_listitem">9. My Own Fault</li>\r\n<li class="wiki_listitem">10. You Done Lost Your Good Thing Now</li>\r\n<li class="wiki_listitem">11. Downhearted (How Blue Can You Get?)</li>\r\n<li class="wiki_listitem">12. I''ll Survive</li>\r\n<li class="wiki_listitem">13. Mashed Potato Twist</li>\r\n<li class="wiki_listitem">14. Down Now</li>\r\n<li class="wiki_listitem">15. Peace Of Mind</li>\r\n<li class="wiki_listitem">16. That Evil Child</li>\r\n<li class="wiki_listitem">17. Blues Stay Away From Me</li>\r\n<li class="wiki_listitem">18. Rock Me Baby</li>\r\n<li class="wiki_listitem">19. Miss Martha King</li>\r\n<li class="wiki_listitem">20. When Your Baby Packs Up And Goes</li>\r\n</ul>\r\n</div>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(200, 'en', 'John Rutter - The Colours of Christmas', '', '', '<p>\r\n<p>The Colours of Christmas is a collection of the greatest Christmas carols by the composer/conductor whose music has, for many, been so associated with Christmas. Featuring the Royal Philharmonic Orchestra and The Bach Choir, with guest artists Over the Bridge and conducted by Rutter himself.&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>The Colours of Christmas (track 2 from the album) is a newly composed carol by Rutter for this new album, and is testament to the very best of Rutter&rsquo;s music. Newly orchestrated for this album are the carols Ding Dong! Merrily On High and Hark! The Herald Angels Sing. All recordings on this album are brand new.</p>\r\n<p>TRACKLISTING</p>\r\n<p>1. Ding Dong! Merrily on High&nbsp;</p>\r\n<p>2. The Colours of Christmas&nbsp;</p>\r\n<p>3. In Dulci Jubilo&nbsp;</p>\r\n<p>4. What is this lovely fragrance?&nbsp;</p>\r\n<p>5. Away in a Manger&nbsp;</p>\r\n<p>6. Hodie Christus natus est&nbsp;</p>\r\n<p>7. Riu riu chiu&nbsp;</p>\r\n<p>8. I wonder as I wander&nbsp;</p>\r\n<p>9. Star Carol&nbsp;</p>\r\n<p>10. Once in Royal David''s City&nbsp;</p>\r\n<p>11. Silent Night&nbsp;</p>\r\n<p>12. In the bleak midwinter&nbsp;</p>\r\n<p>13. Gabriel''s Message&nbsp;</p>\r\n<p>14. Fanfare - O come, all ye faithful&nbsp;</p>\r\n<p>15. O Holy Night&nbsp;</p>\r\n<p>16. A New Year Carol&nbsp;</p>\r\n<p>17. Joy to the World&nbsp;</p>\r\n<p>18. Sleigh Ride&nbsp;</p>\r\n<p>19. Deck the Hall&nbsp;</p>\r\n<p>20. The Christmas Song&nbsp;</p>\r\n<p>21. The Twelve Days Of Christmas&nbsp;</p>\r\n<p>22. Have yourself a merry little Christmas&nbsp;</p>\r\n<p>23. Fanfare - Hark! the herald angels sing</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(201, 'en', 'Beethoven Piano Concertos Nos. 1 & 2', '', '', '<p>\r\n<p>ROYAL PHILHARMONIC ORCHESTRA&nbsp;</p>\r\n<p>PIANO: MARIO GALEANI&nbsp;</p>\r\n<p>CONDUCTOR: GRZEGORZ NOWAK</p>\r\n<p>&nbsp;</p>\r\n<p>Mario Galeani and Grzegorz Nowak partner once more in a new disc of Beethoven piano concertos.</p>\r\n<p>TRACKLISTING</p>\r\n<p>Piano Concerto No.1 in C Major, Op.15&nbsp;</p>\r\n<p>1. Allegro con brio&nbsp;</p>\r\n<p>2. Largo&nbsp;</p>\r\n<p>3. Rondo: Allegro scherzando&nbsp;</p>\r\n<p>&nbsp;</p>\r\n<p>Piano Concerto No.2 in B Flat Major, Op.19&nbsp;</p>\r\n<p>4. Allegro con brio&nbsp;</p>\r\n<p>5. Adagio&nbsp;</p>\r\n<p>6. Rondo: Molto allegro&nbsp;</p>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(202, 'en', 'New Year''s Concert 2011 Diverse Klassik Welser-moest / Wiener Philharmoniker', '', '', '<p><strong style="color: #333333; font-family: ''Trebuchet MS'', serif, Times, ''Times New Roman''; font-size: 12px; line-height: 18px; background-color: #ffffff;">New Year''s Concert 2011</strong><br style="color: #333333; font-family: ''Trebuchet MS'', serif, Times, ''Times New Roman''; font-size: 12px; line-height: 18px; background-color: #ffffff;" /><span style="color: #333333; font-family: ''Trebuchet MS'', serif, Times, ''Times New Roman''; font-size: 12px; line-height: 18px; background-color: #ffffff;">Diverse Klassik</span><br style="color: #333333; font-family: ''Trebuchet MS'', serif, Times, ''Times New Roman''; font-size: 12px; line-height: 18px; background-color: #ffffff;" /><span style="color: #333333; font-family: ''Trebuchet MS'', serif, Times, ''Times New Roman''; font-size: 12px; line-height: 18px; background-color: #ffffff;">Welser-moest / Wiener Philharmoniker</span></p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(203, 'en', 'New Year''s Concert 2012 Diverse Wr.Philharmoniker / Jansons,M. / Wr.Sän', '', '', '<p><span style="color: #333333; font-family: ''Trebuchet MS'', serif, Times, ''Times New Roman''; font-size: 12px; line-height: 18px; background-color: #ffffff;">The traditional Vienna Philharmonic New Year''s Concert on January 1, 2012, will be conducted for the second time by the Latvian conductor Mariss Jansons. Ever since the first concert together in April 1992, Mariss Jansons has belonged to the circle of conductors with whom the Vienna Philharmonic feels a special bond. His first New Year''s Concert in 2006 was widely acclaimed by both audiences and the media. The New Year''s Concert 2012 will once again be broadcast by the ORF to over 70 television networks and 300 radio stations worldwide.&nbsp;</span></p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(204, 'en', 'The Police - The Stewart Copeland Anthology', '', '', '<p><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">Collecting The Police''s drummer''s solo work on one CD.&nbsp;</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">Track Listing:</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">1. Too Kool To Kalypso&nbsp;</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">2. Don''t Box Me In</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">3. Tulsa Tango</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">4. Koteja&nbsp;</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">5. Serengeti Long Walk</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">6. Equalizer Main Title</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">7. Anacott Steel</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">8. Slither</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">9. Night Drive&nbsp;</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">10. Taxi Ride Home</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">11. Bill Is Dead</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">12. Wield the Spade&nbsp;</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">13. Look Up&nbsp;</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">14. Rain</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">15. Childhood Friends</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">16. Mud Lions&nbsp;</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">17. Pizica Degli Ucci</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">18. Chrystal/Drive Daisy/End Title</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">19. George Trip/End Montage/End Title</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">20. Big Drum Tribe&nbsp;</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">21. Regret</span><br style="color: #ffffff; font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #000000;" /><span style="font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10px; text-align: left; background-color: #ffffff; color: #000000;">(5OCD09)</span></p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', '');
INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(206, 'en', 'RT-N66U Dual-Band Wireless-N900 Gigabit Router', '', '', '<div style="font-size: 12px; font-family: Arial, Helvetica, sans-serif; background-color: #ffffff; position: relative; z-index: 1; color: #222222; line-height: 18px;">\r\n<div class="clearfix" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;"><span style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;"><span style="border-image: initial; font-weight: bold; font-style: inherit; font-size: 25px; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">Incredible Performance with Incredible Control</span>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">The ASUS RT-N66U dual-band wireless-N900 gigabit router delivers incredible performance and coverage range. With new ASUSWRT UI, quickly setup your network, customize user access, and monitor signal strength. Following the award-winning RT-N56U, the RT-N66U increases Wi-Fi speed for both 5 GHz and 2.4 GHz transmission by 50% up to 900Mbps that makes it ideal for bandwidth demanding tasks such as 3D HD video steaming, multiplayer gaming, USB hard drive file sharing, and USB connected printer sharing. Built-in Wi-Fi amplifiers make the RT-N66U the perfect wireless router for larger, multi-level homes and buildings with signal range that reaches virtually any area.<br style="padding: 0px; margin: 0px;" /><br style="padding: 0px; margin: 0px;" />Whether you&rsquo;re a tech-savvy enthusiast or a first-time user, the RT-N66U is exceptional easy to use with CD-free, Quick Installation Setup (QIS) that lets you plug-n-surf right out of the box and connect PCs, smartphones, tablets, and other wireless devices quickly. Thanks to its refined interface tools, you get control like never before, letting you monitor signal strength, setup parental settings, and other useful functions in a robust yet intuitive way.</p>\r\n</div>\r\n<div style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Designed for Class-Leading Speed and Range</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">Designed with the latest in networking technology, the RT-N66U delivers exceptionally fast wired and wireless connectivity. What&rsquo;s more, it comes with a powerful detachable Wi-Fi antenna to further extend wireless range.</p>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;"></p>\r\n</div>\r\n<br style="padding: 0px; margin: 0px;" />\r\n<div class="columns_ab" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="column">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Dual-Band Connectivity for Lag-Free Entertainment</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">Delivering both 2.4 GHz and 5 GHz concurrent bands up to 450Mbps and 450Mbps respectively, the RT-N66U has a total speed of up to 900Mbps connectivity to provide speed with stability. Perform basic internet tasks like Web browsing and file downloading under the 2.4 GHz band, while also simultaneously streaming 3D HD content and other demanding applications smoothly on the 5 GHz band.</p>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;"></p>\r\n</div>\r\n<div class="column last">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Optimized and Reliable Wireless Coverage via Ai Radar</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">ASUS Ai Radar intelligently strengthens connections to wireless devices. With high-powered amplification and beam package, it provides optimized signals in any direction with better coverage to improve data throughput.</p>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;"></p>\r\n</div>\r\n</div>\r\n<br style="padding: 0px; margin: 0px;" />\r\n<div class="columns_ab" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="column" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Easy Setup Through Your Tablet, Smartphone, or PC</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">With the RT-N66U, setup is simple. Simply power and connect the router and then open a bowser on a Wi-Fi-enabled device like a laptop or tablet. You will be taken to a setup page with a prompt to enter the ID/password from your Internet provider and that&rsquo;s it! Now setting up your network is easier than ever.</p>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;"></p>\r\n</div>\r\n<div class="column last" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Powerful functions, easiest management</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">With the ASUSWRT Dashboard UI, setup, monitor, and control network applications all in one intuitive area. The whole new dashboard interface lets you manage all clients and settings on a single graphical interface and provides 1-click updates.</p>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;"></p>\r\n</div>\r\n</div>\r\n<br style="padding: 0px; margin: 0px;" />\r\n<div class="columns_ab" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="column" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Optimize Your Network for You</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">Do you game a lot, or spend most of your time streaming videos? Whatever your planned use is, the RT-N66U has a Quality of Service (QoS) that lets you select how much bandwidth is prioritized for virtually any task. Plus, the traffic monitor allows you to check your Web usage in a clear and graphical interface.</p>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;"></p>\r\n</div>\r\n<div class="column last" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Two Multi-Functional Built-in USB ports</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">Featuring connectivity to devices, FTPs, SAMBA, UPnP AV servers, and DLNA support, the RT-N66U makes sharing and networking easier with two built-in USB ports. Download HTTP, FTP, and P2P files to a router-connected USB storage device all day without the need of PC. Additionally, the twin USB ports allow network printer and file server connections, so you perform multiple tasks at once.</p>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;"></p>\r\n</div>\r\n</div>\r\n<br style="padding: 0px; margin: 0px;" />\r\n<div class="columns_ab" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="column" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Download and Stream From Anywhere</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">Download Master and DLNA server lets you download and play multimedia files stored on a router-attached USB storage device on DLNA-compatible devices such as PC, tablet, PS3, XBOX, and Internet TV. Download Master can also download files while a PC is turned off, and allows you to manage and monitor download status remotely.</p></div>\r\n<div class="column last" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Powerful Online Multitasking up to 300,000 Data Sessions</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">Support f or a massive data pipeline of up to 300,000 data sessions means the RT-N66U has around 20 times the networking capacity of other conventional routers for exceptionally smooth performance.</p>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;"></p>\r\n</div>\r\n</div>\r\n<br style="padding: 0px; margin: 0px;" />\r\n<div class="columns_ab" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="column" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Separate and Secure Wi-Fi Network via Guest Network Access</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">The RT-N66U supports up to three wireless networks over the 2.4 GHz band and three over the 5 GHz band, so it can protect computers from any unauthorized access, hacking and virus attacks. The parental control allows you to set up your kids'' computer access times.</p>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;"></p>\r\n</div>\r\n<div class="column last" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">VPN Server Enabled</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">Easily set up a VPN server to surf the Web and access data&mdash;no matter where you are. Featuring MPPE encryption, your data transmission will be secure and confidential.</p>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;"></p>\r\n</div>\r\n</div>\r\n<br style="padding: 0px; margin: 0px;" />\r\n<div class="columns_ab" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="column" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Flexible Installation with Versatile Design</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">Wall-mountable, the RT-N66U fits nearly any space in the home or office.</p>\r\n</div></div>\r\n</span></div>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(207, 'en', 'Asus USB-N53', '', '', '<p>&nbsp;</p>\r\n<div id="product_content_area" class="component_style" style="font-size: 12px; font-family: Arial, Helvetica, sans-serif; background-color: #ffffff; position: relative; z-index: 1; color: #222222; line-height: 18px;">\r\n<div id="overview" class="clearfix" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;"><span id="ctl00_ContentPlaceHolder1_ctl00_overview1_span_overview" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">The ASUS USB-N53 is a dual-band USB adapter that provides flexible dual-band connection for lag-free streaming and high performance networking. It also has a superior antenna design for extensive wireless coverage. With the bundled USB cable, you can flexibly adjust the antenna to receive the strongest signal. A friendly user interface utility allows you to install and use the application easily, making the USB-N53 a fantastic router both at home and on the road.</p>\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Flexible Dual-band Connection</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">Wireless-N dual-band internet application for lag-free, high defination streaming.</p>\r\n<div class="columns_ab" style="border-image: initial; font-style: inherit; font-family: inherit; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="column first">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Power Signal Transmission</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">Superior antenna design for extensive wireless coverage- an increase of more than 150%.</p>\r\n</div>\r\n<div class="column last">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.4em; margin-left: 0px; border-image: initial; font-weight: normal; font-style: inherit; font-size: 21px; font-family: inherit; color: #0090ff; line-height: 1; background-image: none; height: auto; padding: 0px; border: 0px initial initial;">Enhanced Reception</h3>\r\n<p style="padding-top: 0px; padding-bottom: 0px; margin-top: 0px; margin-right: 0px; margin-bottom: 4em; margin-left: 0px; border-image: initial; font-style: inherit; font-family: inherit; border: 0px initial initial;">With the USB cable accessory, you can flexibly adjust the antenna to receive the strongest signal.</p>\r\n</div>\r\n</div>\r\n</span></div>\r\n</div>\r\n<p><span style="color: #666666; font-family: Arial, Helvetica, sans-serif; font-size: xx-small;"><br /></span></p>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(208, 'en', 'H.264 Megapixel Surveillance Camera TL-SC3430', '', '', '<p>&nbsp;</p>\r\n<h3 style="padding-top: 14px; padding-right: 0px; padding-bottom: 14px; padding-left: 0px; font-size: 20px; font-weight: normal; font: normal normal normal 20px/1 ''Trebuchet MS'', Arial, Helvetica, sans-serif; color: #333333; text-align: left; background-color: #ffffff; margin: 0px;">What This Product Does</h3>\r\n<p class="MsoNormal" style="margin-top: 0px; margin-right: 0px; margin-bottom: 1em; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; color: #333333; font-family: Arial, Helvetica, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff; line-height: 18pt;"><span style="font-family: Arial, sans-serif;" lang="EN-US">With its built-in high performance 1.3Mega-Pixel sensor, the TL-SC3430 is excellent for homes, shops, banks, offices and other building surveillance where clearer video and more image detail are required. What is more exciting is that wherever users are, high definition video can be delivered to them with the most fluidity, through a standard web browser or 3G device so that users will be to stay close to what they care for most.<br />With simple installation, event alerts, 2-way audio and other practical functions, the TL-SC3430 is a perfect solution for the advanced viewer with attention to detail.</span></p>\r\n<h3 style="padding-top: 14px; padding-right: 0px; padding-bottom: 14px; padding-left: 0px; font-size: 20px; font-weight: normal; font: normal normal normal 20px/1 ''Trebuchet MS'', Arial, Helvetica, sans-serif; color: #333333; text-align: left; background-color: #ffffff; margin: 0px;">1.3 Megapixel HD Video for Identification Surveillance</h3>\r\n<div style="font-family: Arial, Helvetica, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff; line-height: 18pt; padding: 0px; margin: 0px;">Equipped with high performance 1.3Mega-Pixel sensor, it can provide HD images that are more useful, with more image detail and with wider scope for identification, such as faces of people or a car&rsquo;s license plate.</div>\r\n<h3 style="padding-top: 14px; padding-right: 0px; padding-bottom: 14px; padding-left: 0px; font-size: 20px; font-weight: normal; font: normal normal normal 20px/1 ''Trebuchet MS'', Arial, Helvetica, sans-serif; color: #333333; text-align: left; background-color: #ffffff; margin: 0px;">Advanced H.264 Codec Delivers Beautifully Smooth Video</h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 1em; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; color: #333333; font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 19px; text-align: left; background-color: #ffffff;">&nbsp;H.264 is an advanced video compression technology that greatly reduces the size of a digital video file (up to 80%) without compromising video quality compared with video quantity. Using H.264 provides savings in network bandwidth and storage costs, as well as achieves much higher video quality for a given bit rate.&nbsp;</p>\r\n<h3 style="padding-top: 14px; padding-right: 0px; padding-bottom: 14px; padding-left: 0px; font-size: 20px; font-weight: normal; font: normal normal normal 20px/1 ''Trebuchet MS'', Arial, Helvetica, sans-serif; color: #333333; text-align: left; background-color: #ffffff; margin: 0px;">Intelligent Surveillance Functionality</h3>\r\n<p class="MsoNormal" style="margin-top: 0px; margin-right: 0px; margin-bottom: 1em; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; color: #333333; font-family: Arial, Helvetica, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff; line-height: 18pt;"><span style="font-family: Arial, sans-serif;" lang="EN-US">Motion detection settings make the camera record automatically and alert you via an e-mail when motion is detected.&nbsp;</span></p>\r\n<h3 style="padding-top: 14px; padding-right: 0px; padding-bottom: 14px; padding-left: 0px; font-size: 20px; font-weight: normal; font: normal normal normal 20px/1 ''Trebuchet MS'', Arial, Helvetica, sans-serif; color: #333333; text-align: left; background-color: #ffffff; margin: 0px;">Multiple Easy Remote Viewing Options</h3>\r\n<div style="font-family: Arial, Helvetica, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff; line-height: 18pt; padding: 0px; margin: 0px;">TP-LINK''s TL-SC3430 is compliant with 3GPP protocols, so users can look in on their cameras from 3G mobile Phones, laptops or tablets, such as Android&nbsp;<span style="font-size: 9pt;">&trade;</span>&nbsp;phones or 3G enabled iPads&nbsp;<span style="font-size: 9pt;">&trade;</span>.</div>\r\n<h3 style="padding-top: 14px; padding-right: 0px; padding-bottom: 14px; padding-left: 0px; font-size: 20px; font-weight: normal; font: normal normal normal 20px/1 ''Trebuchet MS'', Arial, Helvetica, sans-serif; color: #333333; text-align: left; background-color: #ffffff; margin: 0px;">16-channel Management Software</h3>\r\n<div style="font-family: Arial, Helvetica, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff; line-height: 18pt; padding: 0px; margin: 0px;">The TL-SC3430&rsquo;s bundled surveillance software assists users with managing multiple cameras at the same time. With it, video from 16 cameras can be displayed on one screen. Users can archive streamed video and audio straight to their hard drives, playback video, and monitor up to 16 cameras on a single screen.</div>\r\n<h3 style="padding-top: 14px; padding-right: 0px; padding-bottom: 14px; padding-left: 0px; font-size: 20px; font-weight: normal; font: normal normal normal 20px/1 ''Trebuchet MS'', Arial, Helvetica, sans-serif; color: #333333; text-align: left; background-color: #ffffff; margin: 0px;">2-Way Audio Communication</h3>\r\n<div style="font-family: Arial, Helvetica, sans-serif; font-size: 12px; text-align: left; background-color: #ffffff; line-height: 18pt; padding: 0px; margin: 0px;">With the TL-SC3430&rsquo;s built-in microphone or one purchased separately, users can hear what&rsquo;s happening within range of their cameras remotely. What&rsquo;s more , by connecting an external speaker to the TL-SC3430, users may also speak to someone near the camera or give a public address depending on the speaker&rsquo;s strength. This brings users more convenience allowing for better communication when monitoring their cameras from a remote location.</div>\r\n<h3 style="padding-top: 14px; padding-right: 0px; padding-bottom: 14px; padding-left: 0px; font-size: 20px; font-weight: normal; font: normal normal normal 20px/1 ''Trebuchet MS'', Arial, Helvetica, sans-serif; color: #333333; text-align: left; background-color: #ffffff; margin: 0px;">Easy Remote Access-DDNS &amp; UPnP</h3>\r\n<div style="font-family: Arial, Helvetica, sans-serif; font-size: 12px; line-height: 19px; text-align: left; background-color: #ffffff; padding: 0px; margin: 0px;">Eliminating the need for users to remember a numeric IP address, the TL-SC3430&rsquo;s DDNS feature enables users to remotely access the camera by typing an easy-to-remember domain name (e.g. www.mycamera.com) into their browser. This feature comes in handy, especially when the camera&rsquo;s IP address is always changed by users&rsquo; Internet Service Providers. Even more convenient is if the camera is connected with a router and set up in a local area network, the router&rsquo;s UPnP function can facilitate access to the camera without any complicated configuration of the router or camera.<br /><br /></div>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(209, 'en', 'HP Scanjet G3110 Scanner', '', '', '<p>&nbsp;</p>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px; padding-bottom: 10px;">Make your photos, documents, slides, and negatives all look great by scanning them at 4800 x 9600<a class="dotline" style="color: #003366; border-bottom-width: 1px; border-bottom-style: dashed; border-bottom-color: #003366; cursor: default;">dpi</a>resolution<sup style="font-size: 0.8em;">1</sup>. Our Scanjet G3110 Photo Scanner comes with software that removes red eye, removes dust and scratches, and restores vibrant color to your old, faded images.</div>\r\n<div class="fl" style="float: left; color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff;">\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px;"><img style="border-style: initial; border-color: initial; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/overview/l2698a_open_left.jpg" alt="Top surface with slides" /></p>\r\n</div>\r\n<div class="col59pctL" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-bottom: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Excellent quality, affordable price</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Get great scans</strong>of black-and-white and color photos with the 4800 x 9600<a class="dotline" style="color: #003366; border-bottom-width: 1px; border-bottom-style: dashed; border-bottom-color: #003366; cursor: default;">dpi</a>and 48-bit color</li>\r\n<li><strong>Remove red eye</strong>from scanned photos</li>\r\n<li><strong>Bring out the detail</strong>in dark photos, plus restore faded colors</li>\r\n<li><strong>Correct most flaws</strong>and scratches from damaged photos</li>\r\n</ul>\r\n</div>\r\n<div class="fl" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-bottom: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Versatile flatbed design</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Scan four 35 mm slides,</strong>five negatives, or three 4 x 6" photos at once, then save to separate files</li>\r\n<li><strong>Archive important records</strong>and documents: the G3110 scans sizes up to 8.5 x 11"</li>\r\n<li><strong>Get realistic</strong>scans of 3-D items, capturing more detail and depth (ideal for photos for on-line auctions)</li>\r\n<li><strong>Create word-processing files</strong>and PDFs from scanned documents with the included optical character recognition software</li>\r\n<li><strong>Scan directly to e-mail</strong>for quick and easy sharing</li>\r\n<li><strong>Print copies</strong>of scanned documents using a one-touch button and default printer</li>\r\n</ul>\r\n</div>\r\n<div class="fr" style="float: right; color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-bottom: 10px;">\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px;"><img style="border-style: initial; border-color: initial; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/overview/l2698a_portsview_right.jpg" alt="View of side ports" /></p>\r\n</div>\r\n<div class="fl" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-bottom: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Fast and easy</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Save time</strong>on common jobs with scan shortcuts</li>\r\n<li><strong>Use four one-touch buttons</strong>for common tasks: scan, copy, scan to e-mail, scan to PDF</li>\r\n<li><strong>Organize, edit,</strong>print, share, and save scanned photos with the included HP Photosmart Essential Software</li>\r\n<li><strong>Connect to a PC</strong>for optimal scan transfer speeds with Hi-Speed USB 2.0</li>\r\n</ul>\r\n</div>\r\n<div class="fr" style="float: right; color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-bottom: 10px;">\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px;"><img style="border-style: initial; border-color: initial; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/overview/l2698a_top_right.jpg" alt="View of top buttons" /></p>\r\n</div>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">First-class warranty and support</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Get peace of mind</strong>with the 90-day limited warranty and toll-free phone support</li>\r\n<li><strong>Find answers</strong>to your product questions online, 24 x 7, at our Consumer Support Forum, HP.com/support/consumer-forum</li>\r\n</ul>\r\n</div>\r\n<div class="p10" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding: 10px;">\r\n<h2 class="theme_ruled" style="font-size: small; margin-bottom: 0px; margin-top: 1px; border-bottom-width: 4px; border-bottom-style: solid; padding-bottom: 1px; border-color: #000000;">What''s in the box?</h2>\r\n<p class="fl mt10 mr10" style="margin-top: 10px; margin-right: 10px; margin-bottom: 10px; margin-left: 0px; float: left;"><img style="border-style: initial; border-color: initial; display: inline; padding: 0px; margin: 0px;" longdesc="http://www.shopping.hp.com/product/scanner/photo/1/storefronts/L2698A%2523B1H" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/products/l2698a_150.gif" border="0" alt="HP Scanjet G3110 Scanner" width="150" height="100" /></p>\r\n</div>\r\n<p>&nbsp;</p>\r\n<table border="0" cellspacing="0" cellpadding="0" width="100%">\r\n<tbody>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Scanner</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>USB cable</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Power cord and supply</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>CDs with software and instructions</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Set-up poster</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>IRIS registration flyer</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Warranty statement</td>\r\n</tr>\r\n</tbody>\r\n</table>\r\n<p>&nbsp;</p>\r\n<div class="p10" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; margin-top: 10px; padding: 10px;">\r\n<h2 class="theme_ruled" style="font-size: small; margin-bottom: 0px; margin-top: 1px; border-bottom-width: 4px; border-bottom-style: solid; padding-bottom: 1px; border-color: #000000;">Compatible with</h2>\r\n<p class="fl mt10 mr10" style="margin-top: 10px; margin-right: 10px; margin-bottom: 10px; margin-left: 0px; float: left;"><img style="border-style: initial; border-color: initial; display: inline; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/logos/icon_windows_compatible.gif" alt="Windows compatible" width="20" height="15" /><img style="border-style: initial; border-color: initial; display: inline; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/logos/icon_compatible_mac.gif" alt="Mac compatible" width="20" height="15" /></p>\r\n</div>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(210, 'en', 'HP Photosmart Plus e-All-in-One Printer - B210a', '', '', '<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px; padding-bottom: 10px;">Touch your way to easy, affordable printing with our Photosmart Plus e-All-in-One &ndash; B210a. You''ll get affordable lab-quality photos, everyday documents, creative projects, and Web pages. Plus, HP<a class="udrline" style="color: #003366; text-decoration: underline;" href="http://www.hp.com/go/eprintbanner" target="_blank">ePrint</a><sup style="font-size: 0.8em;">1</sup>and<a class="dotline" style="color: #003366; border-bottom-width: 1px; border-bottom-style: dashed; border-bottom-color: #003366; cursor: default;">integrated wireless</a>will keep you connected on the go.<sup style="font-size: 0.8em;">1, 2</sup></div>\r\n<div class="fl" style="float: left; color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff;">\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px;"><img style="border-style: initial; border-color: initial; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/overview/cn216a_right_facing.jpg" alt="HP Photosmart Plus e-All-in-One - B210a, right facing image" /></p>\r\n</div>\r\n<div class="col59pctL" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-bottom: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Easy and affordable</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Print photos and documents,</strong>make copies, and scan&mdash;all without turning on your PC</li>\r\n<li><strong>Get lab-quality,</strong>smudge-resistant photos that last<sup style="font-size: 0.8em;">3</sup></li>\r\n<li><strong>Use the automatic photo tray</strong>tray for easy picture printing</li>\r\n<li>Share photos with friends<sup style="font-size: 0.8em;">4</sup>via Snapfish</li>\r\n<li><strong>Have fun</strong>with photos using the included software</li>\r\n<li><strong>Print affordably</strong>with individual HP inks; save money with our high-capacity XL cartridges (sold separately) for frequent printing</li>\r\n<li><strong>Get templates</strong>for calendars and games with HP<a class="udrline" style="color: #003366; text-decoration: underline;" href="http://h71036.www7.hp.com/hho/us/en/ep/articles/quick-forms.html" target="_blank">Quick Forms</a><sup style="font-size: 0.8em;">4</sup></li>\r\n</ul>\r\n</div>\r\n<div class="fl" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-bottom: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Quick Web printing, no PC</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Print from the Web without a PC</strong>&mdash;photos, coupons, recipes, greeting cards and more with customizable<a class="udrline" style="color: #003366; text-decoration: underline;" href="http://www.hp.com/go/eprintcenter" target="_blank">print apps</a><sup style="font-size: 0.8em;">4</sup></li>\r\n<li><strong>Use the intuitive</strong>TouchSmart screen to make copies, photo reprints, and scans</li>\r\n<li><strong>Print and share</strong>from multiple PCs via the<a class="dotline" style="color: #003366; border-bottom-width: 1px; border-bottom-style: dashed; border-bottom-color: #003366; cursor: default;">integrated wireless</a><sup style="font-size: 0.8em;">2</sup></li>\r\n<li><strong>Just touch a button</strong>to print wirelessly<sup style="font-size: 0.8em;">5</sup></li>\r\n<li><strong>Print wirelessly</strong>from a smartphone with our<a class="udrline" style="color: #003366; text-decoration: underline;" href="http://www.hp.com/go/mobile-printing-solutions" target="_blank">mobile printing apps</a><sup style="font-size: 0.8em;">6</sup></li>\r\n</ul>\r\n</div>\r\n<div class="fr" style="float: right; color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-bottom: 10px;">\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px;"><img style="border-style: initial; border-color: initial; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/overview/cn216a_top_view.jpg" alt="HP Photosmart Plus e-All-in-One - B210a, top view image" /></p>\r\n</div>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">If you can e-mail it, you can print it</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Print directly</strong>to your HP printer using a smartphone, laptop, or other mobile device with HP ePrint</li>\r\n<li><strong>Print from your iPad, iPhone, or iPod touch</strong><sup style="font-size: 0.8em;">7</sup>wirelessly with<a class="udrline" style="color: #003366; text-decoration: underline;" href="http://www.hp.com/go/airprint" target="_blank">AirPrint</a></li>\r\n</ul>\r\n</div>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Helping conserve resources</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Save energy</strong>with this efficient, ENERGY STAR<sup style="font-size: 0.8em;">&reg;</sup>qualified machine</li>\r\n<li><strong>Recycle:</strong>return your cartridges via our Planet Partners program<sup style="font-size: 0.8em;">8</sup></li>\r\n</ul>\r\n</div>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Peace of mind</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Protect your investment</strong>with the one-year limited warranty plus and one year of toll-free tech support</li>\r\n<li><strong>Get product questions answered</strong>toll-free, 24 x 7, or via e-mail in as little time as an hour</li>\r\n<li><strong>Get exclusive offers</strong>and discounts on supplies, shop from your own supplies list, and get free next-day shipping with "My Print Rewards"</li>\r\n</ul>\r\n</div>\r\n<div class="p10" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding: 10px;">\r\n<h2 class="theme_ruled" style="font-size: small; margin-bottom: 0px; margin-top: 1px; border-bottom-width: 4px; border-bottom-style: solid; padding-bottom: 1px; border-color: #000000;">What''s in the box?</h2>\r\n<p class="fl mt10 mr10" style="margin-top: 10px; margin-right: 10px; margin-bottom: 10px; margin-left: 0px; float: left;"><img style="border-style: initial; border-color: initial; display: inline; padding: 0px; margin: 0px;" longdesc="http://www.shopping.hp.com/product/printer/Photosmart/1/storefronts/CN216A%2523B1H" src="http://hpshopping.speedera.net/s7d2.scene7.com/is/image/HPShopping/full3_fmt/cn216a_main.jpg" border="0" alt="HP Photosmart Plus e-All-in-One Printer - B210a" width="150" height="100" /></p>\r\n</div>\r\n<p>&nbsp;</p>\r\n<table border="0" cellspacing="0" cellpadding="0" width="100%">\r\n<tbody>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Printer</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Power supply</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Power cord</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Accessory bag</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>HP 564 black cartridge (approx. 250 pages)</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>HP 564 cyan, magenta, yellow cartridge (approx. 300 pages each)</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>CD with software</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Reference guide</td>\r\n</tr>\r\n</tbody>\r\n</table>\r\n<p>&nbsp;</p>\r\n<div class="p10" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; margin-top: 10px; padding: 10px;">\r\n<h2 class="theme_ruled" style="font-size: small; margin-bottom: 0px; margin-top: 1px; border-bottom-width: 4px; border-bottom-style: solid; padding-bottom: 1px; border-color: #000000;">Compatible with</h2>\r\n<p class="fl mt10 mr10" style="margin-top: 10px; margin-right: 10px; margin-bottom: 10px; margin-left: 0px; float: left;"><img style="border-style: initial; border-color: initial; display: inline; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/logos/icon_windows_compatible.gif" alt="Windows compatible" width="20" height="15" /><img style="border-style: initial; border-color: initial; display: inline; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/logos/icon_compatible_mac.gif" alt="Mac compatible" width="20" height="15" /></p>\r\n</div>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', '');
INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(211, 'en', 'HP Officejet Pro 8600 Premium e-All-in-One Printer', '', '', '<p>&nbsp;</p>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px; padding-bottom: 10px;">View apps on our Officejet Pro 8600A Premium e-All-in-One''s large touchscreen. Get networking and versatile performance; get professional-color documents for a cost per page of up to 50% lower than with laser printers.<sup style="font-size: 0.8em;">1</sup>You can even print from a mobile device via HP<a class="udrline" style="color: #003366; text-decoration: underline;" href="http://www.hp.com/go/eprintbanner" target="_blank">ePrint</a>.<sup style="font-size: 0.8em;">2</sup></div>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Professional color, economical price</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Get great-looking color</strong>for a cost per page of up to 50% lower than with lasers, and get better value with frequent printing<sup style="font-size: 0.8em;">3</sup></li>\r\n<li><strong>Resist fading,</strong>water and highlighter-pen smears when using HP Officejet inks<sup style="font-size: 0.8em;">4, 5</sup></li>\r\n<li><strong>Print at ISO speeds up to 20 ppm black</strong>and 16 color when using our affordable individual inks<sup style="font-size: 0.8em;">6</sup></li>\r\n<li><strong>Rely on the 25,000-page</strong>monthly<a class="dotline" style="color: #003366; border-bottom-width: 1px; border-bottom-style: dashed; border-bottom-color: #003366; cursor: default;">duty cycle</a></li>\r\n</ul>\r\n</div>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Web connectivity and mobile printing</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Print from virtually anywhere,</strong>and from a variety of mobile devices, using HP ePrint</li>\r\n<li><strong>Use the large touchscreen</strong>with gesturing to access business apps, plus print and store files</li>\r\n<li><strong>View and print photos</strong>from a USB drive and<a class="dotline" style="color: #003366; border-bottom-width: 1px; border-bottom-style: dashed; border-bottom-color: #003366; cursor: default;">memory cards</a></li>\r\n<li><strong>Stay connected</strong>&mdash;share on a wireless or wired network<sup style="font-size: 0.8em;">7</sup></li>\r\n</ul>\r\n</div>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Versatile for copying and scanning</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Make flawless copies</strong>with the CopySmart feature</li>\r\n<li><strong>Print a one-sided copy</strong>of a two-sided ID card</li>\r\n<li><strong>Automatically print, copy, and scan</strong>on both sides of the page</li>\r\n<li><strong>Get more done</strong>with the 50-page<a class="dotline" style="color: #003366; border-bottom-width: 1px; border-bottom-style: dashed; border-bottom-color: #003366; cursor: default;">automatic document feeder</a></li>\r\n<li><strong>Improve workflow</strong>&mdash;send faxes, scan documents to a PC or e-mail, and more</li>\r\n<li><strong>Create borderless, double-sided flyers</strong>and brochures, plus print impressive business photos</li>\r\n<li><strong>Use original HP ink</strong>for quality, reliability and rewards<sup style="font-size: 0.8em;">8</sup></li>\r\n</ul>\r\n</div>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Energy and resource saver</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Reduce energy use</strong>by up to 50% compared with laser printers with this ENERGY STAR<sup style="font-size: 0.8em;">&reg;</sup>qualified printer<sup style="font-size: 0.8em;">9</sup>and preset on/off times</li>\r\n<li><strong>Use up to 70% less in supplies</strong>and packaging by weight, compared with laser printers<sup style="font-size: 0.8em;">10</sup></li>\r\n<li><strong>Automatically print two-sided</strong>with the<a class="dotline" style="color: #003366; border-bottom-width: 1px; border-bottom-style: dashed; border-bottom-color: #003366; cursor: default;">automatic document feeder</a>; cut your paper use in half</li>\r\n<li><strong>Recycle</strong>your cartridges&mdash;it''s free and easy<sup style="font-size: 0.8em;">11</sup></li>\r\n</ul>\r\n</div>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Peace of mind</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Protect your investment</strong>with World-class service and support. One-year limited hardware warranty, 24-hour, 7 days a week Web support, business hour phone support within warranty period.</li>\r\n</ul>\r\n</div>\r\n<div class="p10" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding: 10px;">\r\n<p class="tinygray" style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px; color: #666666; font-size: 10px;"><span style="font-size: small; color: #000000;">What''s in the box?</span></p>\r\n</div>\r\n<div class="p10" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding: 10px;">\r\n<p class="fl mt10 mr10" style="margin-top: 10px; margin-right: 10px; margin-bottom: 10px; margin-left: 0px; float: left;"><img style="border-style: initial; border-color: initial; display: inline; padding: 0px; margin: 0px;" longdesc="http://www.shopping.hp.com/product/printer/Officejet+Pro/1/storefronts/CN577A%2523B1H" src="http://hpshopping.speedera.net/s7d2.scene7.com/is/image/HPShopping/full3_fmt/cn577a_main.jpg" border="0" alt="HP Officejet Pro 8600 Premium e-All-in-One Printer" width="150" height="100" /></p>\r\n</div>\r\n<p>&nbsp;</p>\r\n<table border="0" cellspacing="0" cellpadding="0" width="100%">\r\n<tbody>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Printer</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Automatic two-sided printing accessory</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Second 250 sheet input tray</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>HP 950 Setup Black Officejet Ink Cartridge (~ 1,000 pages)</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>HP 951 Setup Cyan Officejet Ink Cartridge</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>HP 951 Setup Magenta Officejet Ink Cartridge</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>HP 951 Setup Yellow Officejet Ink Cartridge: composite yield (~ 700 pages),</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Second set of color cartridges</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Power cord</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Phone cord</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Set-up poster</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Getting started guide</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>In-house marketing kit</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>CDs with software, Windows and Mac printer drivers, user guide</td>\r\n</tr>\r\n</tbody>\r\n</table>\r\n<p>&nbsp;</p>\r\n<div class="p10" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; margin-top: 10px; padding: 10px;">\r\n<h2 class="theme_ruled" style="font-size: small; margin-bottom: 0px; margin-top: 1px; border-bottom-width: 4px; border-bottom-style: solid; padding-bottom: 1px; border-color: #000000;">Compatible with</h2>\r\n<p class="fl mt10 mr10" style="margin-top: 10px; margin-right: 10px; margin-bottom: 10px; margin-left: 0px; float: left;"><img style="border-style: initial; border-color: initial; display: inline; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/logos/icon_windows_compatible.gif" alt="Windows compatible" width="20" height="15" /><img style="border-style: initial; border-color: initial; display: inline; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/logos/icon_compatible_mac.gif" alt="Mac compatible" width="20" height="15" /></p>\r\n</div>\r\n<p>&nbsp;</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(212, 'en', 'Panasonic KX-MB2000 24PPM 3-in-1 Monochrome Laser MFP', '', '', '<p>&nbsp;</p>\r\n<h3 style="border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; color: #000000; line-height: 12px; padding: 0px; margin: 0px; border: 0px initial initial;">Robust Feature Set &amp; Superior Ease of Use.</h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; line-height: 16px; color: #40474b; border: 0px initial initial;">The KX-MB2000 includes standard printing, color scanning, and copying capabilities to meet the demands of todays businesses. The KX-MB2000 boasts a highly reliable print engine with an easy open clam shell design which makes consumable replacement and the removal of the occasional paper jam extremely easy. In addition, the KX-MB2000 includes a 10/100 Base-TX Ethernet interface for convenient device sharing in multi-user office environments, not to mention the ability to remotely manage and configure the device using a standard internet browser.</p>\r\n<h3 style="border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; color: #000000; line-height: 12px; padding: 0px; margin: 0px; border: 0px initial initial;">High Speed, Professional-Quality Laser Printing</h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; line-height: 16px; color: #40474b; border: 0px initial initial;">The KX-MB2000 is capable of outputting up to 24 professional quality documents per minute<sup style="border-image: initial; font-size: 7px; font: inherit; display: inline; line-height: 7px; padding: 0px; margin: 0px; border: 0px initial initial;">1</sup>&nbsp;at 600 x 600 DPI. The KX-MB2000 includes a Host Based GDI printer driver which has been optimized for maximum printing productivity. The advanced printing features of the GDI printer driver include the ability to add watermarks to printed documents, print or create document Overlays, merge up to 16 documents on a single sheet of paper, or enlarge your document to a wall size poster.</p>\r\n<h3 style="border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; color: #000000; line-height: 12px; padding: 0px; margin: 0px; border: 0px initial initial;">PC &amp; Network Document Scanner</h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; line-height: 16px; color: #40474b; border: 0px initial initial;">The built in document flatbed on the KX-MB2000, is able to scan documents directly to a PC, E-mail, shared network folder or FTP server. Scanned documents can be saved as a PDF, JPG, TIFF or BMP file. The KX-MB2000 is capable of scanning documents in full color with resolutions up to 19,200 x 19,200 dpi (Interpolated).</p>\r\n<h3 style="border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; color: #000000; line-height: 12px; padding: 0px; margin: 0px; border: 0px initial initial;">Convenient Desktop Copier</h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; line-height: 16px; color: #40474b; border: 0px initial initial;">The KX-MB2000 can also be used a desktop copy machine, utilizing the standard document flatbed. The KX-MB2000 offers many convenient copy features, such as Image Repeat, N in 1 Copy, Separate N in 1 Copy, Quick ID Copy and Proof Copy.</p>\r\n<h3 style="border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; color: #000000; line-height: 12px; padding: 0px; margin: 0px; border: 0px initial initial;">Panasonic Multifunction Station Suite Software</h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; line-height: 16px; color: #40474b; border: 0px initial initial;">The KX-MB2000 comes bundled with the Panasonic Multifunction Station Suite Software, which includes all the software and utilities for the device. The bundled software suite includes; Panasonic''s Multi-function viewer software which allows you to view scanned documents, remotely adjust the device configuration with the Remote control utility, and the Device Manager Application which provides a real time view of the devices current state.</p>\r\n<h3 style="border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; color: #000000; line-height: 12px; padding: 0px; margin: 0px; border: 0px initial initial;">Advanced Document Management</h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; font-family: Arial, Helvetica, sans-serif; line-height: 16px; color: #40474b; border: 0px initial initial;">The KX-MB2000 features Panasonic''s newest software application, the Panasonic Easy Print Utility. This intuitive application allows you to merge multiple documents into a single print job, which can then be previewed from your computers monitor before actual printing, to ensure the document layout is correct without wasting paper and toner. In addition, the KX-MB2000 includes a copy of Readiris Pro 7, which will allow you to convert your digital documents into text editable file formats.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(213, 'en', 'Intel® Boxed Intel® Core™ i7-2600', '', '', '<div class="proc-spec-title" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 0px; padding-right: 0px; padding-bottom: 8px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, Tahoma, Helvetica, sans-serif; font-size: 14px; color: #666666; background-color: #ffffff; margin: 0px; border: 0px initial initial;">Intel&reg; Boxed Intel&reg; Core&trade; i7-2600 Processor (8M Cache, 3.40 GHz) FC-LGA10 Desktop Processor Specification</div>\r\n<p>&nbsp;</p>\r\n<table style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; border-collapse: collapse; width: 100%; color: #666666; font-family: intel-neo-sans-1, intel-neo-sans-2, Tahoma, Helvetica, sans-serif; line-height: 16px; background-color: #ffffff; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<tbody style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Processor Model #</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">i7-2600</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Platform Technology</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Desktop</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Cores/Threads</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">4/8</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Clock Speed</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">3.40 GHz</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Socket</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">LGA1155</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Max Turbo Frequency</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">3.80GHz</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">L2 Cache</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">8M</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Front Side Bus</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">N/A</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Max TDP</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">95</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Silicon</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">32nm</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Intel Turbo Boost Technology</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Y</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Intel Hyper Threading Technology</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Y</td>\r\n</tr>\r\n</tbody>\r\n</table>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(226, 'en', 'Intel® Core™ i7 Processor i7-950', '', '', '<div class="prod-details-processor-information" style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, Tahoma, Helvetica, sans-serif; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="prod-details-processor-image" style="outline-style: none; outline-width: initial; outline-color: initial; margin-top: 0px; margin-right: 20px; margin-bottom: 20px; border-image: initial; font: inherit; vertical-align: baseline; color: #666666; float: left; font-size: 14px; width: 90px; padding: 0px; border: 0px initial initial;"><img style="outline-style: none; outline-width: initial; outline-color: initial; border-style: initial; border-color: initial; font: inherit; vertical-align: baseline; padding: 0px; margin: 0px;" src="http://www.intel.com/sites/sitewide/pix/badges/core/ci7_78x59.gif" alt="" /></div>\r\n<div class="prod-details-processor-details component" style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; color: #666666; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="proc-spec-intelinside" style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="proc-spec-title" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 0px; padding-right: 0px; padding-bottom: 8px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-size: 14px; color: #666666; background-color: #ffffff; margin: 0px; border: 0px initial initial;">Intel&reg; Core&trade; i7 Processor i7-950 Desktop Processor Specification</div>\r\n</div>\r\n</div>\r\n</div>\r\n<table style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; border-collapse: collapse; color: #666666; line-height: 16px; background-color: #ffffff; padding: 0px; margin: 0px; border: 0px initial initial; width: 100%">\r\n<tbody style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Processor Model #</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">i7-950</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Platform Technology</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Desktop</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Cores/Threads</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">4/8</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Clock Speed</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">3.06 GHz</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Socket</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">FCLGA1366</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Max Turbo Frequency</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">3.33GHz</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">L2 Cache</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">8M</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Front Side Bus</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">4.8 GT/s</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Max TDP</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">130</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Silicon</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">45nm</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Intel Turbo Boost Technology</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Y</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Intel Hyper Threading Technology</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Y</td>\r\n</tr>\r\n</tbody>\r\n</table>\r\n<div class="prod-details-processor-information" style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, Tahoma, Helvetica, sans-serif; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="prod-details-processor-details component" style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; color: #666666; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="proc-spec-intelinside" style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; padding: 0px; margin: 0px; border: 0px initial initial;"></div>\r\n</div>\r\n</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(214, 'en', 'ASUS CP6130', '', '', '<p>A glossy surface givess the CP6130 an air of elegance, while and an eye-catching power button inspired from the halo of a lunar eclipse seamlessly blends in to the front of the case.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', '');
INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(215, 'en', 'Intel® Core™ i7 processor Extreme Edition 980X – i7-980X', '', '', '<div class="prod-details-processor-information" style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, Tahoma, Helvetica, sans-serif; color: #555555; line-height: 16px; background-color: #ffffff; font-size: medium; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="prod-details-processor-image" style="outline-style: none; outline-width: initial; outline-color: initial; margin-top: 0px; margin-right: 20px; margin-bottom: 20px; border-image: initial; font: inherit; vertical-align: baseline; color: #666666; float: left; font-size: 14px; width: 90px; padding: 0px; border: 0px initial initial;"><img style="outline-style: none; outline-width: initial; outline-color: initial; border-style: initial; border-color: initial; font: inherit; vertical-align: baseline; padding: 0px; margin: 0px;" src="http://www.intel.com/sites/sitewide/pix/badges/core/ci7x_78x59.gif" alt="" /></div>\r\n<div class="prod-details-processor-details component" style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; color: #666666; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="proc-spec-intelinside" style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<div class="proc-spec-title" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 0px; padding-right: 0px; padding-bottom: 8px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-size: 14px; margin: 0px; border: 0px initial initial;">Intel&reg; Core&trade; i7 processor Extreme Edition 980X &ndash; i7-980X Desktop Processor Specification</div>\r\n</div>\r\n</div>\r\n</div>\r\n<p>&nbsp;</p>\r\n<table style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; border-collapse: collapse; padding: 0px; margin: 0px; border: 0px initial initial; width: 100%;">\r\n<tbody style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Processor Model #</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">i7-980X</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Platform Technology</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Desktop</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Cores/Threads</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">6/12</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Clock Speed</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">3.33 GHz</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Socket</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">FCLGA1366</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Max Turbo Frequency</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">3.60GHz</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">L2 Cache</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">12M</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Front Side Bus</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">6.4 GT/s</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Max TDP</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">130</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Silicon</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">32nm</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Intel Turbo Boost Technology</td>\r\n<td class="proc-spec-table-row-odd" style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; background-image: initial; background-attachment: initial; background-origin: initial; background-clip: initial; background-color: #f2f2f2; margin: 0px; border: 0px initial initial;">Y</td>\r\n</tr>\r\n<tr style="outline-style: none; outline-width: initial; outline-color: initial; border-image: initial; font: inherit; vertical-align: baseline; height: 21px; padding: 0px; margin: 0px; border: 0px initial initial;">\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Intel Hyper Threading Technology</td>\r\n<td style="outline-style: none; outline-width: initial; outline-color: initial; padding-top: 4px; padding-right: 0px; padding-bottom: 4px; padding-left: 0px; border-image: initial; font: inherit; vertical-align: baseline; font-family: intel-neo-sans-1, intel-neo-sans-2, tahoma, helvetica, sans-serif; font-size: 12px; margin: 0px; border: 0px initial initial;">Y</td>\r\n</tr>\r\n</tbody>\r\n</table>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(227, 'en', 'Acer 3D Series HN274H bmiiid', '', '', '<p><span style="font-family: Helvetica, Arial, Verdana; font-size: 12px; line-height: 20px; text-align: left; background-color: #ffffff; color: #000000;">27" Widescreen LCD display - 1920 x 1080 resolution - 100,000,000:1 contrast ratio - white LED backlight - 2ms response time - integrated speakers - HDMI&reg; - USB - DVI - VGA - adjustable display angle - 3D ready - 3-year limited warranty</span></p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(228, 'en', 'LG D2342P-PN', '', '', '<p>\r\n<div class="bottom-gradient" style="border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px; border-left-width: 0px; border-style: initial; border-color: initial; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; background-image: -webkit-linear-gradient(bottom, #f6f6f5, #ffffff 32px); background-attachment: initial; background-origin: initial; background-clip: initial; background-color: initial; border-bottom-style: solid; border-bottom-color: #cccccc; color: #222222; font-family: Arial, Helvetica, sans-serif; line-height: 14px; text-align: left; padding: 0px; margin: 0px;">\r\n<div class="text-col narrow" style="margin-top: 15px; margin-right: 10px; margin-bottom: 0px; margin-left: 0px; padding-top: 10px; padding-right: 0px; padding-bottom: 0px; padding-left: 40px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; height: auto; border: 0px initial initial;">\r\n<div class="feature-block feature-block2" style="margin-top: 16px; margin-right: 0px; margin-bottom: 0px; margin-left: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; padding: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.5em; margin-left: 0px; border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; font-weight: normal; font-family: BryantLGMedium; text-transform: uppercase; padding: 0px; border: 0px initial initial;">NEXT GENERATION&nbsp;<span style="border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; color: #d80546; padding: 0px; margin: 0px; border: 0px initial initial;">3D MONITOR</span></h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; border: 0px initial initial;">With lightweight, battery-free glasses, and 3D picture quality that is clearer and brighter, the LG D2342P Cinema 3D monitor brings movie theater 3D effects to your desktop. Experience a new dimension in 3D gaming and enjoy your favorite 2D content converted to NEXT GENERATION 3D MONITOR 3D right in the comfort of your own home. Welcome to the next generation of LG 3D.</p>\r\n</div>\r\n</div>\r\n</div>\r\n<div class="bottom-gradient" style="border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px; border-left-width: 0px; border-style: initial; border-color: initial; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; background-image: -webkit-linear-gradient(bottom, #f6f6f5, #ffffff 32px); background-attachment: initial; background-origin: initial; background-clip: initial; background-color: initial; border-bottom-style: solid; border-bottom-color: #cccccc; color: #222222; font-family: Arial, Helvetica, sans-serif; line-height: 14px; text-align: left; padding: 0px; margin: 0px;">\r\n<div class="text-col narrow" style="margin-top: 15px; margin-right: 10px; margin-bottom: 0px; margin-left: 0px; padding-top: 10px; padding-right: 0px; padding-bottom: 0px; padding-left: 40px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; height: auto; border: 0px initial initial;">\r\n<div class="feature-block feature-block2" style="margin-top: 16px; margin-right: 0px; margin-bottom: 0px; margin-left: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; padding: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.5em; margin-left: 0px; border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; font-weight: normal; font-family: BryantLGMedium; text-transform: uppercase; padding: 0px; border: 0px initial initial;">LESS COMPLICATED.&nbsp;<span style="border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; color: #d80546; padding: 0px; margin: 0px; border: 0px initial initial;">MORE COMFORTABLE</span></h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; border: 0px initial initial;">With lightweight, battery-free glasses, and 3D picture quality that is clearer and brighter, the LG D2342P Cinema 3D monitor brings movie theater 3D effects to your desktop. Experience a new dimension in 3D gaming and enjoy your favorite 2D content converted to 3D right in the comfort of your own home. Welcome to the next generation of LG 3D.</p>\r\n</div>\r\n</div>\r\n</div>\r\n<div class="bottom-gradient" style="border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px; border-left-width: 0px; border-style: initial; border-color: initial; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; background-image: -webkit-linear-gradient(bottom, #f6f6f5, #ffffff 32px); background-attachment: initial; background-origin: initial; background-clip: initial; background-color: initial; border-bottom-style: solid; border-bottom-color: #cccccc; color: #222222; font-family: Arial, Helvetica, sans-serif; line-height: 14px; text-align: left; padding: 0px; margin: 0px;">\r\n<div class="text-col narrow" style="margin-top: 15px; margin-right: 10px; margin-bottom: 0px; margin-left: 0px; padding-top: 10px; padding-right: 0px; padding-bottom: 0px; padding-left: 40px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; height: auto; border: 0px initial initial;">\r\n<div class="feature-block feature-block2" style="margin-top: 16px; margin-right: 0px; margin-bottom: 0px; margin-left: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; padding: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.5em; margin-left: 0px; border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; font-weight: normal; font-family: BryantLGMedium; text-transform: uppercase; padding: 0px; border: 0px initial initial;">CLEARER, BRIGHTER,&nbsp;<span style="border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; color: #d80546; padding: 0px; margin: 0px; border: 0px initial initial;">SHARPER 3D</span></h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; border: 0px initial initial;">With 3D Effect Mode, LG Cinema 3D technology creates an even brighter and clearer 3D picture with especially calibrated settings optimized for 3D viewing. LG''s 3D monitors also produce exceptionally clear and vivid images in 2D. Seeing really is believing.</p>\r\n</div>\r\n</div></div>\r\n<div class="bottom-gradient" style="border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px; border-left-width: 0px; border-style: initial; border-color: initial; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; background-image: -webkit-linear-gradient(bottom, #f6f6f5, #ffffff 32px); background-attachment: initial; background-origin: initial; background-clip: initial; background-color: initial; border-bottom-style: solid; border-bottom-color: #cccccc; color: #222222; font-family: Arial, Helvetica, sans-serif; line-height: 14px; text-align: left; padding: 0px; margin: 0px;"><div class="text-col narrow" style="margin-top: 15px; margin-right: 10px; margin-bottom: 0px; margin-left: 0px; padding-top: 10px; padding-right: 0px; padding-bottom: 0px; padding-left: 40px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; height: auto; border: 0px initial initial;">\r\n<div class="feature-block feature-block2" style="margin-top: 16px; margin-right: 0px; margin-bottom: 0px; margin-left: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; padding: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.5em; margin-left: 0px; border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; font-weight: normal; font-family: BryantLGMedium; text-transform: uppercase; padding: 0px; border: 0px initial initial;">BIG FUN.&nbsp;<span style="border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; color: #d80546; padding: 0px; margin: 0px; border: 0px initial initial;">BIG SAVINGS.</span></h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; border: 0px initial initial;">With 3D Effect Mode, LG Cinema 3D technology creates an even brighter and clearer 3D picture with especially calibrated settings optimized for 3D viewing. LG''s 3D monitors also produce exceptionally clear and vivid images in 2D. Seeing really is believing.</p>\r\n</div>\r\n</div>\r\n</div>\r\n<div class="bottom-gradient" style="border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px; border-left-width: 0px; border-style: initial; border-color: initial; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; background-image: -webkit-linear-gradient(bottom, #f6f6f5, #ffffff 32px); background-attachment: initial; background-origin: initial; background-clip: initial; background-color: initial; border-bottom-style: solid; border-bottom-color: #cccccc; color: #222222; font-family: Arial, Helvetica, sans-serif; line-height: 14px; text-align: left; padding: 0px; margin: 0px;">\r\n<div class="text-col narrow" style="margin-top: 15px; margin-right: 10px; margin-bottom: 0px; margin-left: 0px; padding-top: 10px; padding-right: 0px; padding-bottom: 0px; padding-left: 40px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; height: auto; border: 0px initial initial;">\r\n<div class="feature-block feature-block2" style="margin-top: 16px; margin-right: 0px; margin-bottom: 0px; margin-left: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; padding: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.5em; margin-left: 0px; border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; font-weight: normal; font-family: BryantLGMedium; text-transform: uppercase; padding: 0px; border: 0px initial initial;">MORE&nbsp;<span style="border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; color: #d80546; padding: 0px; margin: 0px; border: 0px initial initial;">IN 3D</span></h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; border: 0px initial initial;">Need even more 3D content? LG''s 2D to 3D conversion function enables the enjoyment of a 3D effect even without original 3D content. See your favorite standard 2D images, games or movies in 3D. Note: 2D to 3D conversion requires install of included software.</p>\r\n</div>\r\n</div></div>\r\n<div class="bottom-gradient" style="border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px; border-left-width: 0px; border-style: initial; border-color: initial; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; background-image: -webkit-linear-gradient(bottom, #f6f6f5, #ffffff 32px); background-attachment: initial; background-origin: initial; background-clip: initial; background-color: initial; border-bottom-style: solid; border-bottom-color: #cccccc; color: #222222; font-family: Arial, Helvetica, sans-serif; line-height: 14px; text-align: left; padding: 0px; margin: 0px;"><div class="text-col narrow" style="margin-top: 15px; margin-right: 10px; margin-bottom: 0px; margin-left: 0px; padding-top: 10px; padding-right: 0px; padding-bottom: 0px; padding-left: 40px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; height: auto; border: 0px initial initial;">\r\n<div class="feature-block feature-block2" style="margin-top: 16px; margin-right: 0px; margin-bottom: 0px; margin-left: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; padding: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.5em; margin-left: 0px; border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; font-weight: normal; font-family: BryantLGMedium; text-transform: uppercase; padding: 0px; border: 0px initial initial;">YOU WON''T BELIEVE&nbsp;<span style="border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; color: #d80546; padding: 0px; margin: 0px; border: 0px initial initial;">YOUR EYES</span></h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; border: 0px initial initial;">LG''s SUPER LED Backlighting technology provides a slim profile and delivers amazing brightness, clarity and color detail in both 2D and 3D, as well as greater energy efficiency compared to conventional monitors.</p>\r\n</div>\r\n</div>\r\n</div>\r\n<div class="bottom-gradient" style="border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px; border-left-width: 0px; border-style: initial; border-color: initial; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; background-image: -webkit-linear-gradient(bottom, #f6f6f5, #ffffff 32px); background-attachment: initial; background-origin: initial; background-clip: initial; background-color: initial; border-bottom-style: solid; border-bottom-color: #cccccc; color: #222222; font-family: Arial, Helvetica, sans-serif; line-height: 14px; text-align: left; padding: 0px; margin: 0px;">\r\n<div class="text-col narrow" style="margin-top: 15px; margin-right: 10px; margin-bottom: 0px; margin-left: 0px; padding-top: 10px; padding-right: 0px; padding-bottom: 0px; padding-left: 40px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; height: auto; border: 0px initial initial;">\r\n<div class="feature-block feature-block2" style="margin-top: 16px; margin-right: 0px; margin-bottom: 0px; margin-left: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; padding: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.5em; margin-left: 0px; border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; font-weight: normal; font-family: BryantLGMedium; text-transform: uppercase; padding: 0px; border: 0px initial initial;">PICTURE&nbsp;<span style="border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; color: #d80546; padding: 0px; margin: 0px; border: 0px initial initial;">QUALITY MATTERS</span></h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; border: 0px initial initial;">This stunning picture is the reason you wanted HD in the first place. With almost double the pixel resolution, Full HD 1080p gives it superior picture quality over standard HD resolution. You''ll see details and colors like never before.</p>\r\n</div>\r\n</div></div>\r\n<div class="bottom-gradient" style="border-top-width: 0px; border-right-width: 0px; border-bottom-width: 1px; border-left-width: 0px; border-style: initial; border-color: initial; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; background-image: -webkit-linear-gradient(bottom, #f6f6f5, #ffffff 32px); background-attachment: initial; background-origin: initial; background-clip: initial; background-color: initial; border-bottom-style: solid; border-bottom-color: #cccccc; color: #222222; font-family: Arial, Helvetica, sans-serif; line-height: 14px; text-align: left; padding: 0px; margin: 0px;"><div class="text-col narrow" style="margin-top: 15px; margin-right: 10px; margin-bottom: 0px; margin-left: 0px; padding-top: 10px; padding-right: 0px; padding-bottom: 0px; padding-left: 40px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; height: auto; border: 0px initial initial;">\r\n<div class="feature-block feature-block2" style="margin-top: 16px; margin-right: 0px; margin-bottom: 0px; margin-left: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; padding: 0px; border: 0px initial initial;">\r\n<h3 style="margin-top: 0px; margin-right: 0px; margin-bottom: 0.5em; margin-left: 0px; border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; font-weight: normal; font-family: BryantLGMedium; text-transform: uppercase; padding: 0px; border: 0px initial initial;">GET&nbsp;<span style="border-image: initial; font-size: 20px; font: inherit; vertical-align: baseline; color: #d80546; padding: 0px; margin: 0px; border: 0px initial initial;">CONNECTED</span></h3>\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 12px; margin-left: 0px; padding-top: 0px; padding-bottom: 0px; border-image: initial; font-size: 12px; font: inherit; vertical-align: baseline; border: 0px initial initial;">Get deeper colors, take advantage of full HD and connect 3D devices experience with HDMI connectivity even without a PC. LG CINEMA 3D monitor makes it possible to view 3D content, whether from a game console, blu-ray disc&trade; player, set-top box or another source. Prepare yourself for tomorrow''s technology today.</p>\r\n</div>\r\n</div>\r\n</div>\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(217, 'en', 'ASUS CP6230', '', '', '<p>The ASUS CP6230 features a space-saving design with a hexagonal pattern lid that easily fits anywhere in your home. It draws you in with its elegant aesthetics but holds your attention with its computer power to tackle any task.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(218, 'en', 'ASUS Essentio CP1130', '', '', '<p>The ASUS new Essentio CP1130 has sleek appearance and small size make it perfectly fit anywhere in your home. At the same time, it provides complete function and delivers ultimate performance for daily computing.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(219, 'en', 'Series 3 15.6" Laptop', '', '', '<p>Don''t be weighed down by wasted time, let your PC come alive when you need it. Your life happens on the go, you don''t have time to wait for PC to shut down and power up. With Samsung''s exclusive Fast Start technology, simply close the lid to enter a hybrid sleep mode. When you open the lid, you are up and running in less than 3 sec.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(220, 'en', 'Series 7 Chronos 14” Notebook', '', '', '<p>Cutting edge design: Sleek aluminum, a stunning screen, cutting edge performance, all seamlessly blended in one of the world&rsquo;s thinnest quad core PC.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(221, 'en', 'Series 9 13.3" Laptop', '', '', '<p>You no longer have to shut down your Samsung computer, just close its lid and it goes into a special powerless sleep mode. When you open the lid your computer comes back to life in 3 seconds and you are exactly at the same place as when you shut the lid. Fast Start saves your data and system configurations to your hard drive and PC memory. So, when you power it back on it is just like you left it.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(222, 'en', 'Series 3 15.6" Laptop', '', '', '<p>Don''t be weighed down by wasted time, let your PC come alive when you need it. Your life happens on the go, you don''t have time to wait for PC to shut down and power up. With Samsung''s exclusive Fast Start technology, simply close the lid to enter a hybrid sleep mode. When you open the lid, you are up and running in less than 3 sec.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(223, 'en', 'Samsung Galaxy Tab 8.9 (Wi-Fi Only) - 32GB Metallic Gray', '', '', '<p>If you buy the wrong tablet, you&rsquo;re at the mercy of the manufacturer regarding how much you can customize or personalize your screens. But the beauty of Android is that you have much greater flexibility to arrange things however you want. You&rsquo;ll have multiple home screens to compose and design, plus live wallpapers to express your mood and personality. The Tab also offers you the freedom of TouchWiz&reg;, the intuitive user interface that allows you to quickly drag and drop your icons, widgets and Live Panels with only the touch of a finger. Now, reorganizing your tablet&rsquo;s menus and navigational options will be simple and straightforward.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(224, 'en', 'Samsung Galaxy Tab™ 8.9 (AT&T)', '', '', '<p>Your eyes have never seen such rich, luscious color. And at 1280x800, the resolution is well above normal HD standards. Of course, everything about the Tab is above normal.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(225, 'en', 'Samsung Galaxy Tab™ 7.0" (Verizon)', '', '', '<p>The Samsung Galaxy Tab&trade; brings you the media you want and keeps you connected with anyone, anytime. Compact and light, you can keep in touch with people and content through 3G connectivity, Wi-Fi&reg; 802.11 b/g/n, Bluetooth&reg; Wireless Technology 3.0. With a battery life of up to seven hours* and a crisp TFT-LCD display, you&rsquo;re free to communicate, update, and enjoy.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', '');
INSERT INTO `[[dbprefix]]product_descriptions` VALUES
(229, 'en', 'HP 2711x 27" LED Monitor', '', '', '<p>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px; padding-bottom: 10px;">Maximize your home PC experience with our 2711x 27" LED Monitor. You''ll enjoy movies, photos, on-line<sup style="font-size: 0.8em;">1</sup>games, and streamed shows on your PC in brilliant color on this ultra-slim, energy-saving monitor.</div>\r\n<div class="fl" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff;">\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px;"><img style="border-style: initial; border-color: initial; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/overview/xp600aa_front_facing_left_cut.jpg" alt="HP 2711x 27" /></p>\r\n</div>\r\n<div class="col59pctL" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-bottom: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Superior technology</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Go ultra-slim:</strong>LED backlighting reduces the number and overall size of the components</li>\r\n<li><strong>See the detail:</strong>get deep blacks, brilliant color, and clarity with the ultra-high dynamic<a class="dotline" style="color: #003366; border-bottom-width: 1px; border-bottom-style: dashed; border-bottom-color: #003366; cursor: default;">contrast ratio</a></li>\r\n<li><strong>Switch on/off</strong>faster than with a CCFL (standard) monitor</li>\r\n</ul>\r\n</div>\r\n<div class="fl" style="float: left; color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-bottom: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Spacious and spectacular</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Expand your view</strong>of Web pages, videos, and documents; see two application Windows at once on the 27" LED screen</li>\r\n<li><strong>Immerse yourself</strong>in cinema-like movies and realistic on-line gaming with the Full HD<sup style="font-size: 0.8em;">2</sup>1920 x 1080 resolution</li>\r\n<li><strong>Minimize blur</strong>in sports broadcasts, action movies, and on-line games with the 5 ms on/off response time</li>\r\n<li><strong>Reduce glare</strong>and sharpen images with the BrightView technology</li>\r\n</ul>\r\n</div>\r\n<div class="fr" style="float: right; color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-bottom: 10px;">\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px;"><img style="border-style: initial; border-color: initial; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/overview/BrightView_1.jpg" alt="HP 2711x 27" /></p>\r\n</div>\r\n<div class="fl" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff;">\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px;"><img style="border-style: initial; border-color: initial; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/overview/xp600aa_side_view.jpg" alt="HP 2711x 27" /></p>\r\n</div>\r\n<div class="col59pctL" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-bottom: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Sleek design, enhanced features</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Save space</strong>and complement your HP desktop or laptop PC with the stylish, ultra-slim design (about 1" deep)</li>\r\n<li><strong>Connect</strong>to your HP desktop or laptop via VGA, HDCP-supported<a class="dotline" style="color: #003366; border-bottom-width: 1px; border-bottom-style: dashed; border-bottom-color: #003366; cursor: default;">HDMI</a>, or DVI-D input</li>\r\n<li><strong>Find the best</strong>viewing position with the tilt adjustment and ability to slide from left to right</li>\r\n</ul>\r\n</div>\r\n<div class="fl" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-bottom: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">Eco highlights</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Help protect the environment:</strong>this model is ENERGY STAR<sup style="font-size: 0.8em;">&reg;</sup>5.0 qualified and EPEAT Silver registered</li>\r\n<li><strong>Lower your impact</strong>on the environment with the mercury-free LED backlighting</li>\r\n<li><strong>Be eco-conscious</strong>with the arsenic-free display glass<sup style="font-size: 0.8em;">3</sup>, recyclable plastic parts, and recyclable packaging</li>\r\n</ul>\r\n</div>\r\n<div class="fr" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-bottom: 10px;">\r\n<p style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px;"><img style="border-style: initial; border-color: initial; padding: 0px; margin: 0px;" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/overview/xp600aa_right_facing.jpg" alt="HP 2711x 27" /></p>\r\n</div>\r\n<div style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding-left: 10px; padding-right: 10px;">\r\n<h3 class="cb large mb5" style="font-size: 14px; margin-bottom: 5px; margin-top: 1px; clear: both;">First-class warranty and support</h3>\r\n<ul style="margin-top: 0px; margin-bottom: 10px; margin-left: 20px; padding: 0px;">\r\n<li><strong>Get peace of mind</strong>with the one-year limited warranty plus real-time chat and e-mail response in about an hour</li>\r\n<li><strong>Find answers</strong>to product questions online, 24 x 7, at our Consumer Support Forum, hp.com/support/consumer-forum</li>\r\n</ul>\r\n</div>\r\n<div class="p10" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding: 10px;">\r\n<p class="tinygray" style="margin-top: 0px; margin-right: 0px; margin-bottom: 10px; margin-left: 0px; color: #666666; font-size: 10px;">1. Internet access required, sold separately.<br />2. HD content required to view HD images.<br />3. Arsenic and its compounds were not detected using US EPA Test Methods 3052 and 3052/6010b by ICP or ICP-AES.</p>\r\n</div>\r\n<div class="p10" style="color: #000000; font-family: Arial, Verdana, Helvetica, sans-serif; font-size: 12px; background-color: #ffffff; padding: 10px;">\r\n<h2 class="theme_ruled" style="font-size: small; margin-bottom: 0px; margin-top: 1px; border-bottom-width: 4px; border-bottom-style: solid; padding-bottom: 1px; border-color: #000000;">What''s in the box?</h2>\r\n<p class="fl mt10 mr10" style="margin-top: 10px; margin-right: 10px; margin-bottom: 10px; margin-left: 0px; float: left;"><img style="border-style: initial; border-color: initial; display: inline; padding: 0px; margin: 0px;" longdesc="http://www.shopping.hp.com/product/display/display/1/storefronts/XP600AA%2523ABA" src="http://hpshopping.speedera.net/www.shopping.hp.com/shopping/images/products/xp600aa_150.gif" border="0" alt="HP 2711x 27&quot; LED Monitor" width="150" height="100" /></p>\r\n</div>\r\n</p>\r\n<table border="0" cellspacing="0" cellpadding="0" width="100%">\r\n<tbody>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Monitor</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>External power supply</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Power cable</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>VGA cable</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>DVI-D cable</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Cable clip management</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>CD with instructions</td>\r\n</tr>\r\n<tr>\r\n<td width="10" valign="top">&bull;</td>\r\n<td>Warranty card</td>\r\n</tr>\r\n</tbody>\r\n</table>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(230, 'en', '2011 Pit Boss', '', '', '<p>Hydration Capacity: 100 oz (3 L)<br /><br />Total Capacity: 1800 cu in (29.50 L)<br /><br />CamelBak&reg; Got Your Bak&trade; Guarantee: If we built it, we''ll Bak it&trade; with our lifetime guarantee. <br /><br />Reservoir Features: Quick Link&trade; System, 1/4 turn - easy open/close cap, lightweight fillport, dryer arms, center baffling and low-profile design, patented Big Bite&trade; Valve, HydroGuard&trade; technology, insulated PureFlow&trade; tube, easy-to-clean wide-mouth opening<br /><br />BACK PANEL: Air Director&trade; Snowshed&trade;<br /><br />HARNESS: Therminator&trade; provides easy access for frequent sipping, insulated and fully enclosed to protect against freezing<br /><br />BELT: Load-bearing with cargo<br /><br />Additional Features: <br />Versatile Snowboard / Ski Carry (Diagonal, Vertical or Horizontal), tri-zip quick gear access, gear compression, goggle pocket, essentials pocket<br />Drop-out Probe Pocket for instant probe access -- locate survivors without unloading your pack<br /><br />Designed to carry: skis/snowboard, shovel, probe, skins, snowshoes, helmet, goggles, extra layers, lunch, tools, camera, phone, wallet, keys</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(231, 'en', '2011 Tycoon', '', '', '<p>Hydration Capacity: 100 oz (3 L)<br /><br />Total Capacity: 1125 cu in (18.44 L)<br /><br />CamelBak&reg; Got Your Bak&trade; Guarantee: If we built it, we''ll Bak it&trade; with our lifetime guarantee. <br /><br />Reservoir Features: Quick Link&trade; System, 1/4 turn - easy open/close cap, lightweight fillport, dryer arms, center baffling and low-profile design, patented Big Bite&trade; Valve, HydroGuard&trade; technology, insulated PureFlow&trade; tube, easy-to-clean wide-mouth opening<br /><br />BACK PANEL: Snowshed&trade;<br /><br />HARNESS: Therminator&trade; provides easy access for frequent sipping, insulated and fully enclosed to protect against freezing<br /><br />BELT: Load-bearing<br /><br />Additional Features: <br />Snowboard / Ski Carry (Diagonal, Vertical or Horizontal), pack compression, goggle pocket, essentials pocket<br />Drop-out Probe Pocket for instant probe access -- locate survivors without unloading your pack<br /><br />Designed to carry: skis/snowboard, shovel, probe, skins or snowshoes, goggles, extra layer, snack, phone, wallet, keys</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(232, 'en', '2011 Ice Queen', '', '', '<p>Hydration Capacity: 70 oz (2 L)<br /><br />Total Capacity: 1000 cu in (16.39 L)<br /><br />CamelBak&reg;Got Your Bak&trade; Guarantee: If we built it, we''ll Bak it&trade; with our lifetime guarantee. <br /><br />Reservoir Features: 1/4 turn - easy open/close cap, lightweight fillport, dryer arms, center baffling and low-profile design, patented Big Bite&trade; Valve, HydroGuard&trade; technology, insulated PureFlow&trade; tube, easy-to-clean wide-mouth opening<br /><br />BACK PANEL: Snowshed&trade;<br /><br />HARNESS: S-Curved Women''s Harness; Therminator&trade; provides easy access for frequent sipping, insulated and fully enclosed to protect against freezing<br /><br />BELT: Removable 1" (25 mm) stability<br /><br />Additional Features: <br />Tri-Zip design allows easy access to all your gear, compresion, goggle pocket, essentials pocket<br /><br />Designed to carry: Helmet, goggles, extra layers, lunch, phone, wallet, keys</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(233, 'en', 'Crystal Lake Warm Weather Sleeping Bag', '', '', '<p>&bull;  Coleman&reg; warm weather sleeping bags made for camping temperatures between 40 and 60 degrees<br />&bull;  Rectangle shape, 33&rdquo; x 75&rdquo;, fits up to 5&rsquo;11&rdquo; tall<br />&bull;  3 pounds of ThermoTech&reg; insulation<br />&bull;  Cotton cover with soft cotton liner<br />&bull;  Essential camping gear, sleeping bag for a better night outdoors<br />&bull;  Don&rsquo;t forget the Coleman&reg; camping tent to go with your sleeping bags<br />&bull;  ComfortSmart&trade; Technology includes:<br />&bull;  ZipPlow&trade; plows fabric away from zipper to prevent snags<br />&bull;  ComfortCuff&trade; surrounds your face with softness<br />&bull;  Roll Control&trade; locks bag in place for easier rolling<br />&bull;  FiberLock&trade; prevents insulation from shifting, increases durability<br />&bull;  ThermoLock&trade; construction reduces heat loss through the zipper, keeping you warmer<br />&bull;  ZipperGlide&trade; tailoring allows smooth zipper operation around the corners<br />&bull;  QuickCord&trade; for easy, no tie closure<br />&bull;  Commercial Machine washable<br />&bull;  Five year limited warranty<br />&bull;  Made in China</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(234, 'en', 'White Water™ Cool Weather Sleeping Bag', '', '', '<p>&bull;  Coleman&reg; cool weather sleeping bags made for camping temperatures between 30 and 50 degrees<br />&bull;  Rectangle shape, big &amp; tall 39&rdquo; x 84&rdquo;, fits up to 6&rsquo;4&rdquo; tall<br />&bull;  4 pounds of Coletherm&reg; insulation<br />&bull;  Polyester cover with cotton flannel liner<br />&bull;  Groundbreaking headrest shape makes keeping your head off the ground or floor easy<br />&bull;  Essential camping gear, sleeping bag for a better night outdoors<br />&bull;  Don&rsquo;t forget the Coleman&reg; camping tent to go with your sleeping bags<br />&bull;  ComfortSmart&trade; Technology includes:<br />&bull;  ZipPlow&trade; plows fabric away from zipper to prevent snags<br />&bull;  ComfortCuff&trade; surrounds your face with softness<br />&bull;  Roll Control&trade; locks bag in place for easier rolling<br />&bull;  FiberLock&trade; prevents insulation from shifting, increases durability<br />&bull;  ThermoLock&trade; construction reduces heat loss through the zipper, keeping you warmer<br />&bull;  ZipperGlide&trade; tailoring allows smooth zipper operation around the corners<br />&bull;  QuickCord&trade; for easy, no tie closure<br />&bull;  Commercial Machine washable<br />&bull;  Five year limited warranty<br />&bull;  Made in China</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(235, 'en', 'Everglades Cold Weather Sleeping Bag', '', '', '<p>&bull;  The perfect sleeping bag for extreme sleeping conditions between 10 and 30 degrees<br />&bull;  3 lbs Coletherm&reg; insulation<br />&bull;  33&rdquo; x 85&rdquo;, fits up to 5&rsquo;11&rdquo; tall<br />&bull;  Diamond ripstop cover to polyester liner<br />&bull;  Double-batt, offset quilt construction eliminates potential cold spots<br />&bull;  Essential camping gear, sleeping bag for a better night outdoors<br />&bull;  Semi-sculpted hood surrounds head with warmth, keeps head off the ground<br />&bull;  Fleece foot section provides extra warmth<br />&bull;  Two way zipper for maximum ventilation<br />&bull;  Stuff sack included<br />&bull;  Made in China<br />&bull;  Commercial Machine washable<br />&bull;  Five year limited warranty</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(236, 'en', 'WeatherMaster Screened 6 Tent With Hinged Door', '', '', '<p>&bull;  6 person tent/ 2 rooms<br />&bull;  17''x9'' footprint<br />&bull;  Cabin structure; heavier, stronger, better for extended stay camping<br />&bull;  6 ft. 10 in. center height<br />&bull;  2 Doors - Front Door is Hinged (Patent Pending)<br />&bull;  Strong steel and fiberglass frame<br />&bull;  Control airflow with Variflo&trade; adjustable ventilation<br />&bull;  Privacy vent window<br />&bull;  Interior gear pocket<br />&bull;  Electrical access port<br />&bull;  Reverse angle windows<br />&bull;  Easy set up with continuous, color coded pole sleeves and shock-corded poles<br />&bull;  Easy instructions sewn into durable carry bag<br />&bull;  Carry bag also includes separate sacks for poles and stakes<br />&bull;  Fly: Polyester taffeta 75D <br />&bull;  Mesh: Polyester 68D inner tent<br />&bull;  Floor: Polyethylene 1000D-140g/sqm floor<br />&bull;  Limited 1 year warranty<br />&bull;  Made in China</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(237, 'en', 'Elite Evanston 8 Tent', '', '', '<p>&bull;  8 person/1 room tent<br />&bull;  12''x12'' footprint<br />&bull;  Exclusive WeatherTec&trade; System<br />Keeps you dry -- Guaranteed&trade;<br />&bull;  Modified dome structure, easy to transport and simple to set up<br />&bull;  6 ft. 2 in. center height<br />&bull;  Hinged door (patent pending)<br />&bull;  Great for family camping, scout leaders, extended camping trips<br />&bull;  Self-rolling windows (patent pending)<br />&bull;  Tent includes remote controlled light<br />&bull;  Light is 100 lumens<br />&bull;  Control airflow with Variflo&trade; adjustable ventilation<br />&bull;  Privacy vent window<br />&bull;  Interior gear pocket<br />&bull;  Electrical access port<br />&bull;  Front Porch and Wings provide great outdoor living space<br />&bull;  Easy set up with continuous, color coded pole sleeves and shock-corded poles<br />&bull;  Easy instructions sewn into durable carry bag<br />&bull;  Carry bag also includes separate sacks for poles and stakes<br />&bull;  Fly: Polyester taffeta 75D <br />&bull;  Mesh: Polyester 68D inner tent<br />&bull;  Floor: Polyethylene 1000D-140g/sqm floor<br />&bull;  Poles: 11 mm, 7.9 mm and 6.3 mm fiberglass<br />&bull;  Limited 1 year warranty<br />&bull;  Made in China</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(238, 'en', 'Apple iPhone 4S Black', '', '', '<p>\r\n	16GB iPhone 4S locked AT&amp;T model. Will work on AT&amp;T. Now you can use your voice to use your iPhone. Just talk to Siri as you would to a person: "Do I need an umbrella?" or "Any great burgers around here?" or "Where''s the closest ATM?" Siri not only understands what you say, it knows what you mean.1 It figures out the right apps to use to find the right answer. Then, just like a personal assistant, it answers you. Siri makes phone calls, sends messages, schedules meetings, sets reminders, and more. How much more? Just ask, and Siri tells you that, too. Two cores in the A5 chip deliver up to two times more power and up to seven times faster graphics.2 And you''ll feel the effects. Fast. iPhone 4S is quick and responsive, which makes all the difference when you''re launching apps, browsing the web, gaming, and doing just about everything. And no matter what you''re doing, you can keep on doing it. Because the A5 chip is so power-efficient, iPhone 4S has outstanding battery life. This just might be the best camera ever on a phone. And with all-new optics, it just might be the only camera you need. Because behind every shot, you''ve got 8-megapixel resolution and a custom lens with a larger f/2.4 aperture. Not to mention an improved backside illumination sensor, excellent auto white balance, advanced color accuracy, face detection, and reduced motion blur. It all means that no matter how many people, how much light, and how much action you capture, everything looks exactly as it should. And just wait until you see the photos. Shoot stunning 1080p HD video everywhere you go. With all-new optics, the light is always right, the color is always vivid, and everything will look even better than you remember. Video stabilization steadies shaky shots. And you can edit video right on iPhone and share your lush life as fast as you shoot.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(239, 'en', 'Apple iPhone 4S White', '', '', '<p>\r\n	 16GB iPhone 4S locked AT&amp;T model. Will work on AT&amp;T. Now you can use your voice to use your iPhone. Just talk to Siri as you would to a person: "Do I need an umbrella?" or "Any great burgers around here?" or "Where''s the closest ATM?" Siri not only understands what you say, it knows what you mean.1 It figures out the right apps to use to find the right answer. Then, just like a personal assistant, it answers you. Siri makes phone calls, sends messages, schedules meetings, sets reminders, and more. How much more? Just ask, and Siri tells you that, too. Two cores in the A5 chip deliver up to two times more power and up to seven times faster graphics.2 And you''ll feel the effects. Fast. iPhone 4S is quick and responsive, which makes all the difference when you''re launching apps, browsing the web, gaming, and doing just about everything. And no matter what you''re doing, you can keep on doing it. Because the A5 chip is so power-efficient, iPhone 4S has outstanding battery life. This just might be the best camera ever on a phone. And with all-new optics, it just might be the only camera you need. Because behind every shot, you''ve got 8-megapixel resolution and a custom lens with a larger f/2.4 aperture. Not to mention an improved backside illumination sensor, excellent auto white balance, advanced color accuracy, face detection, and reduced motion blur. It all means that no matter how many people, how much light, and how much action you capture, everything looks exactly as it should. And just wait until you see the photos. Shoot stunning 1080p HD video everywhere you go. With all-new optics, the light is always right, the color is always vivid, and everything will look even better than you remember. Video stabilization steadies shaky shots. And you can edit video right on iPhone and share your lush life as fast as you shoot.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(240, 'en', 'Apple® - iPad® with Retina® display Wi-Fi - 64GB - Black', '', '', '<p>\r\n	iPad features a stunning Retina display, iSight® and FaceTime cameras, the all new A6X chip and ultrafast wireless. And with access to over 275,000 apps1 on the App Store, you can do more than ever.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text">\r\n	<span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span>\r\n</p>', ''),
(241, 'en', 'Apple® - iPad® with Retina® display Wi-Fi - 32GB - White', '', '', '<p>\r\n	  iPad features a stunning Retina display, iSight® and FaceTime cameras, the all new A6X chip and ultrafast wireless. And with access to over 275,000 apps1 on the App Store, you can do more than ever.\r\n</p>', '', '', '', '', '', '<p class="product-promo-text">\r\n	 <span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span>\r\n</p>', ''),
(244, 'en', 'Packard Bell OneTwo', '', '', '<p>\r\n	      Great Packard Bell all in one PC with 23" HD  LCD Multi Touchscreen and Windows 7. The PC is in perfect working order. The LCD screen is very crisp and bright and the touchscreen is responsive and easy to use  The casing is in good but used condition, there is hardly a  mark on it and only noticeable very close up.  Comes with an Intel i3 CPU and a dedicated nVidia Geforce 315 video card for superb performance. Also has a Freeview TV card so you can watch and record TV.It  has an HDMI out port making it simple to connect to a larger TV if required.  It has had a fresh install of Windows 7 including the full Packard Bell software suite. Windows has been fully updated and you are ready to go straight out of the box.  Has an active recovery partition enabling you to perform a full reset to factory defaults straight from the hard drive and also create a spare set of recovery discs.\r\n</p>', '', '', '', '', '', '', ''),
(242, 'en', 'Apple iPod Classic Black', '', '', '<p>With 160GB of storage, iPod classic can hold up to 40,000 songs, 200 hours of video, or 25,000 photos.** That&rsquo;s more than enough room for a day&rsquo;s &mdash; or a lifetime&rsquo;s &mdash; worth of entertainment.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(243, 'en', 'Apple iPod Classic White', '', '', '<p>With 160GB of storage, iPod classic can hold up to 40,000 songs, 200 hours of video, or 25,000 photos.** That&rsquo;s more than enough room for a day&rsquo;s &mdash; or a lifetime&rsquo;s &mdash; worth of entertainment.</p>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">FREE US shipping over $100!</span><span class="product-promo-body">Orders within next 2 days will be shipped on Monday</span></p>', ''),
(245, 'en', 'Apple - iPhone 5c 32GB Cell Phone - Green', '', '', '<p>\r\n	  A6 chip. 8MP iSight camera. 4-inch Retina display. Ultrafast LTE wireless. iPhone 5c has the things that made iPhone 5 an amazing phone — and more, including iOS 7. All in a completely new design that feels great in your hand.\r\n</p>', '', '', '', '', '', '', ''),
(246, 'en', 'GoPro - Hero3+ Black Edition Camera', '', '', '<p>\r\n	 Take smooth video with up to 4K resolution with this GoPro Hero3+ Black Edition CHDHX-302 camera that features a waterproof housing and a wearable, mountable design that lets you easily film yourself engaging in your favorite activities.\r\n</p>', '', '', '', '', '', '', ''),
(247, 'en', 'Nokia N1 Pad 7.9" Quad-Core 64bit 2.3GHz 2GB 32GB Android 5.0', '', '', '<p>Nokia N1 smartphone with 7.90-inch 2048x1536 display powered by 2.3GHz processor alongside 2GB RAM and 8-megapixel rear camera.</p>', '', '', '', '', NULL, '', ''),
(248, 'en', 'X-Box One', '', '', '<p>Xbox One''s exterior casing consists of a two-tone "liquid black" finish; with half finished in a matte grey, and the other in a glossier black. The design was intended to evoke a more entertainment-oriented and simplified look than previous iterations of the console; among other changes.</p><div>It is powered by an AMD "Jaguar" Accelerated Processing Unit (APU) with two quad-core modules totaling eight x86-64 cores clocked at 1.75 GHz, and 8 GB of DDR3 RAM with a memory bandwidth of 68.3 GB/s. The memory subsystem also features an additional 32 MB of "embedded static" RAM, or ESRAM, with a memory bandwidth of 109 GB/s.</div>', '', '', '', '', '', '<p class="product-promo-text"><span class="product-promo-header">Just before the end of the week!</span><span class="product-promo-body">Select the drive with the game as a gift!</span></p>', ''),
(278, 'en', 'T-shirt, Color: White', '', NULL, NULL, '', '', NULL, '', NULL, NULL, ''),
(279, 'en', 'T-shirt, Color: White', '', NULL, NULL, '', '', NULL, '', NULL, NULL, ''),
(280, 'en', 'T-shirt, Color: Black', '', NULL, NULL, '', '', NULL, '', NULL, NULL, ''),
(281, 'en', 'T-shirt, Color: Black', '', NULL, NULL, '', '', NULL, '', NULL, NULL, ''),
(282, 'en', 'T-shirt, Color: Blue', '', NULL, NULL, '', '', NULL, '', NULL, NULL, ''),
(283, 'en', 'T-shirt, Color: Blue', '', NULL, NULL, '', '', NULL, '', NULL, NULL, ''),
(284, 'en', 'T-shirt, Color: Blue', '', NULL, NULL, '', '', NULL, '', NULL, NULL, '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_features`
--

CREATE TABLE `[[dbprefix]]product_features` (
  `feature_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `feature_code` varchar(32) NOT NULL DEFAULT '',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `purpose` varchar(32) NOT NULL DEFAULT '',
  `feature_style` varchar(32) NOT NULL DEFAULT '',
  `filter_style` varchar(32) NOT NULL DEFAULT '',
  `feature_type` char(1) NOT NULL DEFAULT 'T',
  `categories_path` text,
  `parent_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `display_on_product` char(1) NOT NULL DEFAULT 'Y',
  `display_on_catalog` char(1) NOT NULL DEFAULT 'Y',
  `display_on_header` char(1) NOT NULL DEFAULT 'N',
  `status` char(1) NOT NULL DEFAULT 'A',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `comparison` char(1) NOT NULL DEFAULT 'N',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `updated_timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`feature_id`),
  KEY `status` (`status`),
  KEY `company_id` (`company_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=550 ;

--
-- Dumping data for table `[[dbprefix]]product_features`
--

INSERT INTO `[[dbprefix]]product_features` VALUES
(17, '', 1, 'find_products', 'text', 'checkbox', 'S', '165,166,167,168,169,170,174,182,190,191,193,234,235,236,237,238,240', 14, 'Y', 'Y', 'N', 'A', 30, 'N', 0, 0),
(16, '', 1, 'find_products', 'text', 'checkbox', 'S', '165,166,167,168,169,170,174,182,190,191,193,234,235,236,237,238,240', 14, 'Y', 'Y', 'N', 'A', 20, 'N', 0, 0),
(15, '', 1, 'find_products', 'text', 'checkbox', 'S', '165,166,167,168,169,170,174,182,190,191,193,234,235,236,237,238,240', 14, 'Y', 'Y', 'N', 'A', 10, 'N', 0, 0),
(14, '', 1, '', '', '', 'G', '165,166,167,168,169,170,174,182,190,191,193,234,235,236,237,238,240', 0, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(18, '', 1, 'organize_catalog', 'brand', 'checkbox', 'E', '', 0, 'N', 'N', 'Y', 'A', 0, 'N', 0, 0),
(20, '', 1, '', '', '', 'G', '248', 0, 'Y', 'Y', 'N', 'A', 10, 'N', 0, 0),
(21, '', 1, 'find_products', 'text', 'checkbox', 'S', '248', 20, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(22, '', 1, 'find_products', 'checkbox', 'checkbox', 'C', '248', 20, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(23, '', 1, 'find_products', 'text', 'checkbox', 'S', '248', 20, 'Y', 'Y', 'Y', 'A', 0, 'N', 0, 0),
(24, '', 1, '', '', '', 'G', '248', 0, 'Y', 'Y', 'N', 'A', 20, 'N', 0, 0),
(25, '', 1, 'find_products', 'text', 'checkbox', 'S', '248', 24, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(26, '', 1, 'find_products', 'text', 'checkbox', 'S', '248', 24, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(27, '', 1, 'find_products', 'text', 'checkbox', 'S', '248', 24, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(28, '', 1, 'find_products', 'text', 'checkbox', 'S', '248', 24, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(29, '', 1, 'find_products', 'text', 'checkbox', 'S', '248', 24, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(30, '', 1, '', '', '', 'G', '248', 0, 'Y', 'Y', 'N', 'A', 40, 'N', 0, 0),
(31, '', 1, 'find_products', 'multiple_checkbox', 'checkbox', 'M', '248', 30, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(32, '', 1, 'find_products', 'multiple_checkbox', 'checkbox', 'M', '248', 30, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(33, '', 1, '', '', '', 'G', '248', 0, 'Y', 'Y', 'N', 'A', 30, 'N', 0, 0),
(34, '', 1, 'find_products', 'checkbox', 'checkbox', 'C', '248', 33, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(35, '', 1, 'find_products', 'multiple_checkbox', 'checkbox', 'M', '248', 33, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(36, '', 1, 'find_products', 'multiple_checkbox', 'checkbox', 'M', '248', 33, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(37, '', 1, '', '', '', 'G', '248', 0, 'Y', 'Y', 'N', 'A', 100, 'N', 0, 0),
(38, '', 1, 'describe_product', '', '', 'T', '248', 37, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(39, '', 1, 'describe_product', '', '', 'T', '248', 37, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(40, '', 1, '', '', '', 'G', '248', 0, 'Y', 'Y', 'N', 'A', 50, 'N', 0, 0),
(41, '', 1, 'describe_product', '', '', 'T', '248', 40, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(42, '', 1, 'find_products', 'multiple_checkbox', 'checkbox', 'M', '248', 40, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(43, '', 1, 'find_products', 'text', 'checkbox', 'S', '248', 40, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(44, '', 1, 'find_products', 'multiple_checkbox', 'checkbox', 'M', '248', 40, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(45, '', 1, 'find_products', 'text', 'checkbox', 'S', '248', 40, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(46, '', 1, 'describe_product', '', '', 'T', '248', 40, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(47, '', 1, 'find_products', 'checkbox', 'checkbox', 'C', '248', 20, 'Y', 'Y', 'N', 'A', 0, 'N', 0, 0),
(549, '', 1, 'group_catalog_item', 'dropdown_images', 'checkbox', 'S', '', 0, 'Y', 'Y', 'N', 'A', 10, 'Y', 0, 0),
(548, '', 1, 'group_variation_catalog_item', 'dropdown_labels', 'checkbox', 'S', '', 0, 'Y', 'Y', 'N', 'A', 20, 'Y', 0, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_features_descriptions`
--

CREATE TABLE `[[dbprefix]]product_features_descriptions` (
  `feature_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `description` varchar(255) NOT NULL DEFAULT '',
  `internal_name` varchar(255) NOT NULL DEFAULT '',
  `full_description` mediumtext,
  `prefix` varchar(128) NOT NULL DEFAULT '',
  `suffix` varchar(128) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`feature_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_features_descriptions`
--

INSERT INTO `[[dbprefix]]product_features_descriptions` VALUES
(16, 'Display', 'Display', '', '', '', 'en'),
(17, 'Storage Capacity', 'Storage Capacity', '', '', '', 'en'),
(15, 'Operating System', 'Operating System', '', '', '', 'en'),
(14, 'Electronics', 'Electronics', '', '', '', 'en'),
(18, 'Brand', 'Brand', '', '', '', 'en'),
(20, 'Main features', 'Main features', '', '', '', 'en'),
(21, 'Type', 'Type', '', '', '', 'en'),
(22, 'HD support', 'HD support', '', '', '', 'en'),
(23, 'Hard drive', 'Hard drive', '', '', '', 'en'),
(24, 'Specifications', 'Specifications', '', '', '', 'en'),
(25, 'RAM', 'RAM', '', '', '', 'en'),
(26, 'Graphics processor', 'Graphics processor', '', '', '', 'en'),
(27, 'System performance for floating point computation', 'System performance for floating point computation', '', '', '', 'en'),
(28, 'CPU speed', 'CPU speed', '', '', '', 'en'),
(29, 'CPU', 'CPU', '', '', '', 'en'),
(30, 'Interfaces', 'Interfaces', '', '', '', 'en'),
(31, 'Ports', 'Ports', '', '', '', 'en'),
(32, 'Communications', 'Communications', '', '', '', 'en'),
(33, 'Multimedia', 'Multimedia', '', '', '', 'en'),
(34, 'Video playback', 'Video playback', '', '', '', 'en'),
(35, 'Supported storage devices', 'Supported storage devices', '', '', '', 'en'),
(36, 'Supported formats', 'Supported formats', '', '', '', 'en'),
(37, 'Dimensions', 'Dimensions', '', '', '', 'en'),
(38, 'Dimensions (W x H x D)', 'Dimensions (W x H x D)', '', '', '', 'en'),
(39, 'Weight', 'Weight', '', '', '', 'en'),
(40, 'Additional info', 'Additional info', '', '', '', 'en'),
(41, 'Controller included', 'Controller included', '', '', '', 'en'),
(42, 'Accessories included', 'Accessories included', '', '', '', 'en'),
(43, 'Videogames storage', 'Videogames storage', '', '', '', 'en'),
(44, 'Compatibility with console videogames', 'Compatibility with console videogames', '', '', '', 'en'),
(45, 'Colors', 'Colors', '', '', '', 'en'),
(46, 'Features', 'Features', '', '', '', 'en'),
(47, '3D support', '3D support', '', '', '', 'en'),
(549, 'Color', 'Color', '', '', '', 'en'),
(548, 'Size', 'Size', '', '', '', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_features_values`
--

CREATE TABLE `[[dbprefix]]product_features_values` (
  `feature_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `variant_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `value` varchar(255) NOT NULL DEFAULT '',
  `value_int` double(12,2) DEFAULT NULL,
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`feature_id`,`product_id`,`variant_id`,`lang_code`),
  KEY `fl` (`feature_id`,`lang_code`,`variant_id`,`value`,`value_int`),
  KEY `variant_id` (`variant_id`),
  KEY `lang_code` (`lang_code`),
  KEY `product_id` (`product_id`),
  KEY `fpl` (`feature_id`,`product_id`,`lang_code`),
  KEY `idx_product_feature_variant_id` (`product_id`,`feature_id`,`lang_code`,`variant_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_features_values`
--

INSERT INTO `[[dbprefix]]product_features_values` VALUES
(15, 240, 39, '', NULL, 'en'),
(16, 227, 41, '', NULL, 'en'),
(16, 240, 44, '', NULL, 'en'),
(15, 241, 39, '', NULL, 'en'),
(16, 241, 44, '', NULL, 'en'),
(15, 214, 46, '', NULL, 'en'),
(17, 214, 47, '', NULL, 'en'),
(15, 217, 46, '', NULL, 'en'),
(17, 217, 48, '', NULL, 'en'),
(15, 218, 49, '', NULL, 'en'),
(17, 218, 50, '', NULL, 'en'),
(16, 229, 41, '', NULL, 'en'),
(16, 228, 51, '', NULL, 'en'),
(15, 223, 52, '', NULL, 'en'),
(16, 223, 53, '', NULL, 'en'),
(17, 223, 54, '', NULL, 'en'),
(15, 225, 55, '', NULL, 'en'),
(16, 225, 56, '', NULL, 'en'),
(17, 225, 45, '', NULL, 'en'),
(15, 224, 58, '', NULL, 'en'),
(16, 224, 53, '', NULL, 'en'),
(17, 224, 45, '', NULL, 'en'),
(15, 219, 46, '', NULL, 'en'),
(16, 219, 59, '', NULL, 'en'),
(17, 219, 60, '', NULL, 'en'),
(15, 222, 46, '', NULL, 'en'),
(16, 222, 59, '', NULL, 'en'),
(17, 222, 60, '', NULL, 'en'),
(15, 220, 46, '', NULL, 'en'),
(16, 220, 61, '', NULL, 'en'),
(17, 220, 62, '', NULL, 'en'),
(15, 221, 46, '', NULL, 'en'),
(16, 221, 63, '', NULL, 'en'),
(17, 221, 64, '', NULL, 'en'),
(15, 238, 39, '', NULL, 'en'),
(16, 238, 65, '', NULL, 'en'),
(17, 238, 45, '', NULL, 'en'),
(15, 239, 39, '', NULL, 'en'),
(16, 239, 65, '', NULL, 'en'),
(17, 239, 45, '', NULL, 'en'),
(15, 74, 66, '', NULL, 'en'),
(16, 74, 67, '', NULL, 'en'),
(17, 74, 45, '', NULL, 'en'),
(15, 73, 66, '', NULL, 'en'),
(16, 73, 68, '', NULL, 'en'),
(17, 73, 45, '', NULL, 'en'),
(15, 71, 66, '', NULL, 'en'),
(16, 71, 67, '', NULL, 'en'),
(17, 71, 45, '', NULL, 'en'),
(15, 68, 69, '', NULL, 'en'),
(16, 68, 70, '', NULL, 'en'),
(17, 68, 45, '', NULL, 'en'),
(15, 113, 69, '', NULL, 'en'),
(16, 113, 71, '', NULL, 'en'),
(17, 113, 72, '', NULL, 'en'),
(15, 117, 73, '', NULL, 'en'),
(16, 117, 70, '', NULL, 'en'),
(17, 117, 54, '', NULL, 'en'),
(15, 120, 66, '', NULL, 'en'),
(16, 120, 74, '', NULL, 'en'),
(17, 120, 45, '', NULL, 'en'),
(15, 125, 66, '', NULL, 'en'),
(16, 125, 68, '', NULL, 'en'),
(17, 125, 45, '', NULL, 'en'),
(15, 69, 66, '', NULL, 'en'),
(16, 69, 71, '', NULL, 'en'),
(17, 69, 75, '', NULL, 'en'),
(15, 101, 76, '', NULL, 'en'),
(16, 101, 77, '', NULL, 'en'),
(17, 101, 45, '', NULL, 'en'),
(15, 105, 69, '', NULL, 'en'),
(16, 105, 71, '', NULL, 'en'),
(17, 105, 45, '', NULL, 'en'),
(15, 106, 78, '', NULL, 'en'),
(16, 106, 77, '', NULL, 'en'),
(17, 106, 79, '', NULL, 'en'),
(15, 86, 78, '', NULL, 'en'),
(16, 86, 80, '', NULL, 'en'),
(17, 86, 81, '', NULL, 'en'),
(15, 67, 66, '', NULL, 'en'),
(16, 67, 80, '', NULL, 'en'),
(17, 67, 82, '', NULL, 'en'),
(15, 70, 66, '', NULL, 'en'),
(16, 70, 67, '', NULL, 'en'),
(17, 70, 75, '', NULL, 'en'),
(15, 72, 66, '', NULL, 'en'),
(16, 72, 68, '', NULL, 'en'),
(17, 72, 45, '', NULL, 'en'),
(15, 75, 55, '', NULL, 'en'),
(16, 75, 83, '', NULL, 'en'),
(17, 75, 75, '', NULL, 'en'),
(15, 76, 84, '', NULL, 'en'),
(16, 76, 83, '', NULL, 'en'),
(17, 76, 81, '', NULL, 'en'),
(18, 227, 92, '', NULL, 'en'),
(18, 194, 116, '', NULL, 'en'),
(18, 204, 113, '', NULL, 'en'),
(18, 195, 107, '', NULL, 'en'),
(18, 192, 105, '', NULL, 'en'),
(18, 200, 90, '', NULL, 'en'),
(18, 12, 86, '', NULL, 'en'),
(18, 11, 86, '', NULL, 'en'),
(18, 7, 86, '', NULL, 'en'),
(18, 15, 87, '', NULL, 'en'),
(18, 199, 90, '', NULL, 'en'),
(18, 197, 96, '', NULL, 'en'),
(18, 214, 88, '', NULL, 'en'),
(18, 217, 88, '', NULL, 'en'),
(18, 218, 88, '', NULL, 'en'),
(18, 219, 89, '', NULL, 'en'),
(18, 222, 89, '', NULL, 'en'),
(18, 220, 89, '', NULL, 'en'),
(18, 221, 89, '', NULL, 'en'),
(18, 240, 91, '', NULL, 'en'),
(18, 241, 91, '', NULL, 'en'),
(18, 223, 89, '', NULL, 'en'),
(18, 225, 89, '', NULL, 'en'),
(18, 224, 89, '', NULL, 'en'),
(18, 108, 119, '', NULL, 'en'),
(18, 104, 118, '', NULL, 'en'),
(18, 103, 119, '', NULL, 'en'),
(18, 97, 118, '', NULL, 'en'),
(18, 100, 118, '', NULL, 'en'),
(18, 229, 93, '', NULL, 'en'),
(18, 228, 94, '', NULL, 'en'),
(18, 207, 88, '', NULL, 'en'),
(18, 205, 95, '', NULL, 'en'),
(18, 208, 97, '', NULL, 'en'),
(18, 206, 88, '', NULL, 'en'),
(18, 114, 119, '', NULL, 'en'),
(18, 112, 119, '', NULL, 'en'),
(18, 116, 119, '', NULL, 'en'),
(18, 110, 119, '', NULL, 'en'),
(18, 211, 93, '', NULL, 'en'),
(18, 210, 93, '', NULL, 'en'),
(18, 209, 93, '', NULL, 'en'),
(18, 212, 98, '', NULL, 'en'),
(18, 213, 99, '', NULL, 'en'),
(18, 215, 99, '', NULL, 'en'),
(18, 226, 99, '', NULL, 'en'),
(18, 60, 100, '', NULL, 'en'),
(18, 30, 101, '', NULL, 'en'),
(18, 121, 119, '', NULL, 'en'),
(18, 118, 119, '', NULL, 'en'),
(18, 123, 119, '', NULL, 'en'),
(18, 119, 119, '', NULL, 'en'),
(18, 33, 102, '', NULL, 'en'),
(18, 32, 102, '', NULL, 'en'),
(18, 29, 101, '', NULL, 'en'),
(18, 42, 100, '', NULL, 'en'),
(18, 39, 100, '', NULL, 'en'),
(18, 40, 100, '', NULL, 'en'),
(18, 37, 103, '', NULL, 'en'),
(18, 43, 100, '', NULL, 'en'),
(18, 50, 100, '', NULL, 'en'),
(18, 51, 100, '', NULL, 'en'),
(18, 49, 100, '', NULL, 'en'),
(18, 48, 100, '', NULL, 'en'),
(18, 53, 103, '', NULL, 'en'),
(18, 52, 103, '', NULL, 'en'),
(18, 54, 100, '', NULL, 'en'),
(18, 56, 100, '', NULL, 'en'),
(18, 57, 100, '', NULL, 'en'),
(18, 55, 100, '', NULL, 'en'),
(18, 59, 100, '', NULL, 'en'),
(18, 58, 100, '', NULL, 'en'),
(18, 65, 104, '', NULL, 'en'),
(18, 64, 104, '', NULL, 'en'),
(18, 63, 104, '', NULL, 'en'),
(18, 62, 104, '', NULL, 'en'),
(18, 66, 104, '', NULL, 'en'),
(18, 4, 89, '', NULL, 'en'),
(18, 1, 89, '', NULL, 'en'),
(18, 8, 106, '', NULL, 'en'),
(18, 9, 106, '', NULL, 'en'),
(18, 10, 106, '', NULL, 'en'),
(18, 5, 89, '', NULL, 'en'),
(18, 6, 106, '', NULL, 'en'),
(18, 14, 106, '', NULL, 'en'),
(18, 18, 89, '', NULL, 'en'),
(18, 16, 89, '', NULL, 'en'),
(18, 19, 106, '', NULL, 'en'),
(18, 21, 106, '', NULL, 'en'),
(18, 23, 89, '', NULL, 'en'),
(18, 24, 89, '', NULL, 'en'),
(18, 22, 89, '', NULL, 'en'),
(18, 25, 89, '', NULL, 'en'),
(18, 238, 91, '', NULL, 'en'),
(18, 239, 91, '', NULL, 'en'),
(18, 71, 108, '', NULL, 'en'),
(18, 70, 108, '', NULL, 'en'),
(18, 67, 108, '', NULL, 'en'),
(18, 69, 108, '', NULL, 'en'),
(18, 68, 108, '', NULL, 'en'),
(18, 74, 109, '', NULL, 'en'),
(18, 73, 109, '', NULL, 'en'),
(18, 75, 109, '', NULL, 'en'),
(18, 72, 109, '', NULL, 'en'),
(18, 76, 109, '', NULL, 'en'),
(18, 82, 119, '', NULL, 'en'),
(18, 84, 118, '', NULL, 'en'),
(18, 85, 119, '', NULL, 'en'),
(18, 87, 119, '', NULL, 'en'),
(18, 83, 119, '', NULL, 'en'),
(18, 86, 110, '', NULL, 'en'),
(18, 106, 110, '', NULL, 'en'),
(18, 105, 110, '', NULL, 'en'),
(18, 101, 110, '', NULL, 'en'),
(18, 125, 89, '', NULL, 'en'),
(18, 120, 89, '', NULL, 'en'),
(18, 117, 89, '', NULL, 'en'),
(18, 113, 89, '', NULL, 'en'),
(18, 242, 91, '', NULL, 'en'),
(18, 243, 91, '', NULL, 'en'),
(18, 90, 118, '', NULL, 'en'),
(18, 89, 119, '', NULL, 'en'),
(18, 88, 119, '', NULL, 'en'),
(18, 134, 111, '', NULL, 'en'),
(18, 135, 111, '', NULL, 'en'),
(18, 133, 89, '', NULL, 'en'),
(18, 132, 89, '', NULL, 'en'),
(18, 148, 114, '', NULL, 'en'),
(18, 149, 114, '', NULL, 'en'),
(18, 146, 121, '', NULL, 'en'),
(18, 147, 121, '', NULL, 'en'),
(18, 145, 121, '', NULL, 'en'),
(18, 136, 120, '', NULL, 'en'),
(18, 140, 112, '', NULL, 'en'),
(18, 141, 112, '', NULL, 'en'),
(18, 144, 112, '', NULL, 'en'),
(18, 143, 112, '', NULL, 'en'),
(18, 142, 112, '', NULL, 'en'),
(18, 156, 114, '', NULL, 'en'),
(18, 138, 122, '', NULL, 'en'),
(18, 154, 115, '', NULL, 'en'),
(18, 155, 115, '', NULL, 'en'),
(18, 157, 114, '', NULL, 'en'),
(18, 153, 115, '', NULL, 'en'),
(18, 139, 123, '', NULL, 'en'),
(18, 168, 117, '', NULL, 'en'),
(18, 167, 117, '', NULL, 'en'),
(18, 169, 117, '', NULL, 'en'),
(18, 161, 89, '', NULL, 'en'),
(18, 165, 117, '', NULL, 'en'),
(18, 166, 117, '', NULL, 'en'),
(18, 163, 89, '', NULL, 'en'),
(18, 164, 89, '', NULL, 'en'),
(18, 137, 124, '', NULL, 'en'),
(18, 94, 119, '', NULL, 'en'),
(18, 96, 119, '', NULL, 'en'),
(18, 95, 119, '', NULL, 'en'),
(18, 93, 119, '', NULL, 'en'),
(18, 172, 89, '', NULL, 'en'),
(18, 130, 125, '', NULL, 'en'),
(18, 128, 125, '', NULL, 'en'),
(18, 126, 125, '', NULL, 'en'),
(18, 175, 89, '', NULL, 'en'),
(18, 173, 89, '', NULL, 'en'),
(18, 190, 117, '', NULL, 'en'),
(18, 189, 117, '', NULL, 'en'),
(18, 184, 117, '', NULL, 'en'),
(18, 183, 117, '', NULL, 'en'),
(18, 176, 126, '', NULL, 'en'),
(18, 174, 127, '', NULL, 'en'),
(18, 171, 127, '', NULL, 'en'),
(18, 178, 128, '', NULL, 'en'),
(18, 162, 129, '', NULL, 'en'),
(18, 159, 129, '', NULL, 'en'),
(18, 158, 129, '', NULL, 'en'),
(18, 34, 87, '', NULL, 'en'),
(18, 31, 87, '', NULL, 'en'),
(18, 38, 87, '', NULL, 'en'),
(18, 80, 87, '', NULL, 'en'),
(18, 187, 130, '', NULL, 'en'),
(18, 170, 130, '', NULL, 'en'),
(18, 177, 130, '', NULL, 'en'),
(18, 186, 130, '', NULL, 'en'),
(18, 185, 130, '', NULL, 'en'),
(18, 179, 130, '', NULL, 'en'),
(18, 188, 132, '', NULL, 'en'),
(18, 181, 130, '', NULL, 'en'),
(18, 78, 86, '', NULL, 'en'),
(18, 79, 86, '', NULL, 'en'),
(18, 41, 86, '', NULL, 'en'),
(18, 107, 133, '', NULL, 'en'),
(18, 109, 133, '', NULL, 'en'),
(18, 91, 133, '', NULL, 'en'),
(18, 92, 133, '', NULL, 'en'),
(18, 102, 134, '', NULL, 'en'),
(18, 28, 86, '', NULL, 'en'),
(18, 27, 86, '', NULL, 'en'),
(18, 230, 131, '', NULL, 'en'),
(18, 231, 131, '', NULL, 'en'),
(18, 232, 131, '', NULL, 'en'),
(18, 244, 92, '', NULL, 'en'),
(18, 245, 91, '', NULL, 'en'),
(18, 246, 135, '', NULL, 'en'),
(25, 248, 140, '', NULL, 'en'),
(27, 248, 142, '', NULL, 'en'),
(29, 248, 144, '', NULL, 'en'),
(28, 248, 143, '', NULL, 'en'),
(35, 248, 150, '', NULL, 'en'),
(18, 248, 136, '', NULL, 'en'),
(23, 248, 139, '', NULL, 'en'),
(22, 248, 0, 'Y', NULL, 'en'),
(21, 248, 137, '', NULL, 'en'),
(26, 248, 141, '', NULL, 'en'),
(35, 248, 151, '', NULL, 'en'),
(34, 248, 0, 'Y', NULL, 'en'),
(35, 248, 152, '', NULL, 'en'),
(36, 248, 155, '', NULL, 'en'),
(35, 248, 153, '', NULL, 'en'),
(31, 248, 145, '', NULL, 'en'),
(31, 248, 146, '', NULL, 'en'),
(32, 248, 149, '', NULL, 'en'),
(42, 248, 157, '', NULL, 'en'),
(42, 248, 158, '', NULL, 'en'),
(43, 248, 159, '', NULL, 'en'),
(32, 248, 148, '', NULL, 'en'),
(31, 248, 147, '', NULL, 'en'),
(45, 248, 161, '', NULL, 'en'),
(44, 248, 160, '', NULL, 'en'),
(42, 248, 156, '', NULL, 'en'),
(35, 248, 154, '', NULL, 'en'),
(47, 248, 0, 'N', NULL, 'en'),
(38, 248, 0, '343x81x264 mm', NULL, 'en'),
(39, 248, 0, '3.62 kg', NULL, 'en'),
(41, 248, 0, 'yes, wireless', NULL, 'en'),
(46, 248, 0, 'HDMI; complectation Kinect 2.0', NULL, 'en'),
(549, 278, 1201, '', NULL, 'en'),
(549, 279, 1201, '', NULL, 'en'),
(549, 280, 1200, '', NULL, 'en'),
(549, 281, 1200, '', NULL, 'en'),
(549, 282, 1199, '', NULL, 'en'),
(549, 283, 1199, '', NULL, 'en'),
(549, 284, 1199, '', NULL, 'en'),
(548, 278, 1195, '', NULL, 'en'),
(548, 279, 1194, '', NULL, 'en'),
(548, 280, 1195, '', NULL, 'en'),
(548, 281, 1194, '', NULL, 'en'),
(548, 282, 1195, '', NULL, 'en'),
(548, 283, 1194, '', NULL, 'en'),
(548, 284, 1193, '', NULL, 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_feature_variants`
--

CREATE TABLE `[[dbprefix]]product_feature_variants` (
  `variant_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `feature_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `url` varchar(255) NOT NULL DEFAULT '',
  `color` varchar(128) DEFAULT NULL,
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`variant_id`),
  KEY `feature_id` (`feature_id`),
  KEY `position` (`position`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1202 ;

--
-- Dumping data for table `[[dbprefix]]product_feature_variants`
--

INSERT INTO `[[dbprefix]]product_feature_variants` VALUES
(54, 17, '', NULL, 0),
(53, 16, '', NULL, 0),
(63, 16, '', NULL, 0),
(62, 17, '', NULL, 0),
(61, 16, '', NULL, 0),
(65, 16, '', NULL, 0),
(64, 17, '', NULL, 0),
(60, 17, '', NULL, 0),
(59, 16, '', NULL, 0),
(58, 15, '', NULL, 0),
(56, 16, '', NULL, 0),
(55, 15, '', NULL, 0),
(52, 15, '', NULL, 0),
(51, 16, '', NULL, 0),
(50, 17, '', NULL, 0),
(49, 15, '', NULL, 0),
(48, 17, '', NULL, 0),
(47, 17, '', NULL, 0),
(45, 17, '', NULL, 0),
(44, 16, '', NULL, 0),
(46, 15, '', NULL, 0),
(41, 16, '', NULL, 0),
(68, 16, '', NULL, 0),
(39, 15, '', NULL, 40),
(69, 15, '', NULL, 0),
(70, 16, '', NULL, 0),
(66, 15, '', NULL, 0),
(67, 16, '', NULL, 0),
(71, 16, '', NULL, 0),
(72, 17, '', NULL, 0),
(73, 15, '', NULL, 0),
(74, 16, '', NULL, 0),
(75, 17, '', NULL, 0),
(76, 15, '', NULL, 0),
(77, 16, '', NULL, 0),
(78, 15, '', NULL, 0),
(79, 17, '', NULL, 0),
(80, 16, '', NULL, 0),
(81, 17, '', NULL, 0),
(82, 17, '', NULL, 0),
(83, 16, '', NULL, 0),
(84, 15, '', NULL, 0),
(98, 18, '', NULL, 0),
(86, 18, '', NULL, 0),
(87, 18, '', NULL, 0),
(88, 18, '', NULL, 0),
(89, 18, '', NULL, 0),
(90, 18, '', NULL, 0),
(91, 18, '', NULL, 0),
(92, 18, '', NULL, 0),
(93, 18, '', NULL, 0),
(94, 18, '', NULL, 0),
(95, 18, '', NULL, 0),
(96, 18, '', NULL, 0),
(97, 18, '', NULL, 0),
(99, 18, '', NULL, 0),
(100, 18, '', NULL, 0),
(101, 18, '', NULL, 0),
(102, 18, '', NULL, 0),
(103, 18, '', NULL, 0),
(104, 18, '', NULL, 0),
(105, 18, '', NULL, 0),
(106, 18, '', NULL, 0),
(107, 18, '', NULL, 0),
(108, 18, '', NULL, 0),
(109, 18, '', NULL, 0),
(110, 18, '', NULL, 0),
(111, 18, '', NULL, 0),
(112, 18, '', NULL, 0),
(113, 18, '', NULL, 0),
(114, 18, '', NULL, 0),
(115, 18, '', NULL, 0),
(116, 18, '', NULL, 0),
(117, 18, '', NULL, 0),
(118, 18, '', NULL, 0),
(119, 18, '', NULL, 0),
(120, 18, '', NULL, 0),
(121, 18, '', NULL, 0),
(122, 18, '', NULL, 0),
(123, 18, '', NULL, 0),
(124, 18, '', NULL, 0),
(125, 18, '', NULL, 0),
(126, 18, '', NULL, 0),
(127, 18, '', NULL, 0),
(128, 18, '', NULL, 0),
(129, 18, '', NULL, 0),
(130, 18, '', NULL, 0),
(131, 18, '', NULL, 0),
(132, 18, '', NULL, 0),
(133, 18, '', NULL, 0),
(134, 18, '', NULL, 0),
(135, 18, '', NULL, 0),
(137, 21, '', NULL, 0),
(138, 23, '', NULL, 0),
(139, 23, '', NULL, 0),
(140, 25, '', NULL, 0),
(141, 26, '', NULL, 0),
(142, 27, '', NULL, 0),
(143, 28, '', NULL, 0),
(144, 29, '', NULL, 0),
(145, 31, '', NULL, 0),
(146, 31, '', NULL, 0),
(147, 31, '', NULL, 0),
(148, 32, '', NULL, 0),
(149, 32, '', NULL, 0),
(150, 35, '', NULL, 0),
(151, 35, '', NULL, 0),
(152, 35, '', NULL, 0),
(153, 35, '', NULL, 0),
(154, 35, '', NULL, 0),
(155, 36, '', NULL, 0),
(156, 42, '', NULL, 0),
(157, 42, '', NULL, 0),
(158, 42, '', NULL, 0),
(159, 43, '', NULL, 0),
(160, 44, '', NULL, 0),
(161, 45, '', NULL, 0),
(162, 26, '', NULL, 0),
(163, 25, '', NULL, 0),
(164, 27, '', NULL, 0),
(165, 29, '', NULL, 0),
(166, 28, '', NULL, 0),
(167, 35, '', NULL, 0),
(168, 35, '', NULL, 0),
(169, 36, '', NULL, 0),
(170, 36, '', NULL, 0),
(171, 31, '', NULL, 0),
(172, 31, '', NULL, 0),
(173, 42, '', NULL, 0),
(174, 44, '', NULL, 0),
(175, 43, '', NULL, 0),
(176, 44, '', NULL, 0),
(178, 26, '', NULL, 0),
(179, 25, '', NULL, 0),
(180, 29, '', NULL, 0),
(181, 28, '', NULL, 0),
(182, 31, '', NULL, 0),
(183, 44, '', NULL, 0),
(184, 43, '', NULL, 0),
(185, 25, '', NULL, 0),
(186, 27, '', NULL, 0),
(187, 32, '', NULL, 0),
(188, 44, '', NULL, 0),
(189, 23, '', NULL, 0),
(136, 18, '', NULL, 0),
(177, 18, '', NULL, 0),
(190, 18, '', NULL, 0),
(191, 18, '', NULL, 0),
(192, 18, '', NULL, 0),
(1193, 548, '', NULL, 1),
(1194, 548, '', NULL, 2),
(1195, 548, '', NULL, 3),
(1196, 548, '', NULL, 6),
(1197, 548, '', NULL, 5),
(1198, 549, '', NULL, 1),
(1199, 549, '', NULL, 2),
(1200, 549, '', NULL, 3),
(1201, 549, '', NULL, 4);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_feature_variant_descriptions`
--

CREATE TABLE `[[dbprefix]]product_feature_variant_descriptions` (
  `variant_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `variant` varchar(255) NOT NULL DEFAULT '',
  `description` mediumtext,
  `page_title` varchar(255) NOT NULL DEFAULT '',
  `meta_keywords` varchar(255) NOT NULL DEFAULT '',
  `meta_description` varchar(255) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`variant_id`,`lang_code`),
  KEY `variant` (`variant`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_feature_variant_descriptions`
--

INSERT INTO `[[dbprefix]]product_feature_variant_descriptions` VALUES
(51, '23"', '', '', '', '', 'en'),
(50, '320GB', '', '', '', '', 'en'),
(58, 'Android 3.2, Honeycomb', '', '', '', '', 'en'),
(56, '7.0"', '', '', '', '', 'en'),
(55, 'Android 2.2, Froyo', '', '', '', '', 'en'),
(54, '32GB', '', '', '', '', 'en'),
(53, '8.9"', '', '', '', '', 'en'),
(52, 'Android 3.1, Honeycomb', '', '', '', '', 'en'),
(49, 'Windows 7 Home Basic', '', '', '', '', 'en'),
(48, '500GB', '', '', '', '', 'en'),
(47, '1TB', '', '', '', '', 'en'),
(45, '16GB', '', '', '', '', 'en'),
(44, '9.7"', '', '', '', '', 'en'),
(46, 'Windows 7 Home Premium', '', '', '', '', 'en'),
(41, '27"', '', '', '', '', 'en'),
(68, '4.3"', '', '', '', '', 'en'),
(39, 'iOS 5', '', '', '', '', 'en'),
(69, 'Windows Phone 7.5, Mango', '', '', '', '', 'en'),
(70, '4.7"', '', '', '', '', 'en'),
(71, '3.7"', '', '', '', '', 'en'),
(59, '15.6"', '', '', '', '', 'en'),
(60, '640GB', '', '', '', '', 'en'),
(61, '14.0"', '', '', '', '', 'en'),
(62, '750GB', '', '', '', '', 'en'),
(63, '13.3"', '', '', '', '', 'en'),
(64, '256GB', '', '', '', '', 'en'),
(65, '3.5"', '', '', '', '', 'en'),
(66, 'Android 2.3, Gingerbread', '', '', '', '', 'en'),
(67, '4.0"', '', '', '', '', 'en'),
(72, '8GB', '', '', '', '', 'en'),
(73, 'Android 4.0, Ice Cream Sandwich', '', '', '', '', 'en'),
(74, '4.5"', '', '', '', '', 'en'),
(75, '4GB', '', '', '', '', 'en'),
(76, 'Nokia OS', '', '', '', '', 'en'),
(77, '2.4"', '', '', '', '', 'en'),
(78, 'Symbian OS', '', '', '', '', 'en'),
(79, '256MB', '', '', '', '', 'en'),
(80, '3.2"', '', '', '', '', 'en'),
(81, '2GB', '', '', '', '', 'en'),
(82, '512MB', '', '', '', '', 'en'),
(83, '3.1"', '', '', '', '', 'en'),
(84, 'Android 2.1', '', '', '', '', 'en'),
(98, 'Panasonic', '<p><p><b>Panasonic Corporation</b>, formerly known as <b>Matsushita Electric Industrial Co., Ltd.</b>, is a Japanese multinational electronics corporation headquartered in Kadoma, Osaka, Japan.</p>\r\n<p>The company was founded in 1918, and has grown to become one of the largest Japanese electronics producers alongside Sony, Toshiba, Sharp Corporation, and Canon. In addition to electronics, it offers non-electronic products and services such as home renovation services. Panasonic is the world''s fourth-largest television manufacturer and is among the world''s 20 largest semiconductor vendors.</p>\r\n<p>Panasonic has a primary listing on the Tokyo Stock Exchange and is a constituent of the Nikkei 225 and TOPIX indices. It has secondary listings on the Nagoya Stock Exchange, Osaka Securities Exchange and New York Stock Exchange.</p><br></p>', '', '', '', 'en'),
(86, 'Adidas', '<p></p><p><b>Adidas AG</b>&nbsp; is a German multinational corporation that designs and manufactures sports clothing and accessories based in Herzogenaurah, Bavaria, Germany. It is the holding company for the Adidas Group, which consists of the Reebok sportswear company, TaylorMade-Adidas golf company (including Asworth), and Rockport.\r\n Besides sports footwear, Adidas also produces other products such as \r\nbags, shirts, watches, eyewear, and other sports- and clothing-related \r\ngoods. Adidas is the largest sportwear manufacturer in Germany and Europe and the second biggest sportswear manufacturer in the world.</p><br><p></p>\r\n', '', '', '', 'en'),
(87, 'Nike', '<p><p><b>Nike, Inc. </b>is an American multinational corporation that is engaged in the design, development and worldwide marketing and \r\nselling of footwear, apparel, equipment, accessories and services. The \r\ncompany is headquartered near Beaverton, Oregon, in the Portland metropolitan area, and is one of only two Fortune 500 companies headquartered in Oregon. It is one of the world''s largest suppliers of athletic shoes and apparel and a major manufacturer of sports equipment,\r\n with revenue in excess of US$24.1&nbsp;billion in its fiscal year 2012 \r\n(ending May 31, 2012). As of 2012, it employed more than 44,000 people \r\nworldwide. The brand alone is valued at $10.7 billion making it the most\r\n valuable brand among sports businesses.</p><br></p>', '', '', '', 'en'),
(88, 'ASUS', '<p></p><p><b>ASUSTeK Computer Inc.</b>, trading as <b>Asus</b><span><span></span></span><span></span><span></span><span></span><span></span>, is a Taiwanese multinational computer hardware and electronics company headquartered in Taipei, Taiwan. Its products include desktops, laptops, mobile phones, monitors, motherboards, servers, tablet PCs and video cards. The company''s slogan is: "Inspiring Innovation. Persistent Perfection."</p>\r\n<p>Asus is the world''s fifth-largest PC vendor by 2012 unit sales (after HP, Lenovo, Dell and Acer). Asus appears in <i>BusinessWeek</i>’s\r\n "InfoTech 100" and "Asia’s Top 10 IT Companies" rankings, and it ranked\r\n first in the IT Hardware category of the 2008 Taiwan Top 10 Global \r\nBrands survey with a total brand value of US$1.3 billion.</p>\r\n<p>Asus has a primary listing on the Taiwan Stock Exchange and a secondary listing on the London Stock Exchange.</p><br><p></p>\r\n', '', '', '', 'en'),
(89, 'Samsung', '<p><p><b>Samsung Group</b><span></span><span></span> is a South Korean multinational conglomerate company headquartered in Samsung Town, Seoul. It comprises numerous subsidiaries and affiliated businesses, most of them united under the <i>Samsung</i> brand, and is the largest South Korean <i>chaebol</i>.</p>\r\n<p>Samsung was founded by Lee Byung-chull\r\n in 1938 as a trading company. Over the next three decades the group \r\ndiversified into areas including food processing, textiles, insurance, \r\nsecurities and retail. Samsung entered the electronics industry in the \r\nlate 1960s and the construction and shipbuilding industries in the \r\nmid-1970s; these areas would drive its subsequent growth. Following \r\nLee''s death in 1987, Samsung was separated into four business groups – \r\nSamsung Group, Shinsegae Group, CJ Group\r\n and Hansol Group. Since the 1990s Samsung has increasingly globalised \r\nits activities, and electronics, particularly mobile phones and \r\nsemiconductors, has become its most important source of income.</p>\r\n<p>Notable Samsung industrial subsidiaries include Samsung Electronics (the world''s largest information technology company measured by 2012 revenues), Samsung Heavy Industries (the world''s second-largest shipbuilder measured by 2010 revenues), and Samsung Engineering and Samsung C&amp;T (respectively the world''s 15th- and 63nd-largest construction companies). Other notable subsidiaries include Samsung Life Insurance (the world''s 14th-largest life insurance company), Samsung Everland (operator of Everland Resort, the oldest theme park in South Korea), Samsung Techwin (an aerospace, surveillance and defence company) and Cheil Worldwide (the world''s 16th-largest advertising agency measured by 2011 revenues).</p>\r\n<p>Samsung has a powerful influence on South Korea''s economic \r\ndevelopment, politics, media and culture, and has been a major driving \r\nforce behind the "Miracle on the Han River". Its affiliate companies produce around a fifth of South Korea''s total exports. Samsung''s revenue was equal to 17% of the South Korea''s $1082 billion GDP.</p><br></p>', '', '', '', 'en'),
(90, 'Universal Music Group', '<p><b>Universal Music Group</b> (UMG) is the largest American music \r\ncorporation in the world. It currently operates as a subsidiary of \r\nParis-based media conglomerate Vivendi. UMG also owns Universal Music Publishing Group,\r\n which is the second largest music publishing company in the world. \r\nUniversal Music Group''s global corporate headquarters are located in Sants Monica, California.<br></p>', '', '', '', 'en'),
(91, 'Apple', '<p><b>Apple Inc.,</b> formerly <b>Apple Computer, Inc.,</b> is an American multinational corporation headquartered in Cupertino, California that designs, develops, and sells consumer electronics, computer software and personal computers. Its best-known hardware products are the Mac line of computers, the iPod music player, the iPhone smartphone, and the iPad tablet computer. Its software includes the OS X and iOS operating systems, the iTunes media browser, the Safari web browser, and the iLife and iWork\r\n creativity and production suites. The company was founded on April 1, \r\n1976, and incorporated as Apple Computer, Inc. on January 3, 1977. The word "Computer" was removed from its name on January 9, 2007, reflecting its shifted focus towards consumer electronics after the introduction of the iPhone.</p>\r\n<p>Apple is the world''s second-largest information technology company by revenue after Samsung Electronics, and the world''s third-largest mobile phone maker after Samsung and Nokia. <i>Fortune</i> magazine named Apple the most admired company in the United States in 2008, and in the world from 2008 to 2012. However, the company has received criticism for its contractors'' labor practices, and for Apple''s own environmental and business practices.</p>\r\n<p>As of November 2012, Apple maintains 394 retail stores in fourteen countries as well as the online Apple Store and iTunes Store. It is the second-largest publicly traded corporation in the world by market capitalization, with an estimated value of US$414 billion as of January 2013. As of September&nbsp;29,&nbsp;2012, the company had 72,800 permanent full-time employees and 3,300 temporary full-time employees worldwide. Its worldwide annual revenue in 2012 totalled $156 billion. In May 2013, Apple had made it to the top ten of the Fortune 500 list of companies for the first time, taking the 6 position, 11 places up from the previous year.</p><p><br></p>', '', '', '', 'en'),
(92, 'Acer', '<p><p><b>Acer Inc.</b> <span><span></span></span><span></span><span></span><span></span><em></em> is a Taiwanese multinational hardware and electronics corporation headquartered in Xizhi, New Taipei City, Taiwan. Acer''s products include inexpensively-targeted desktop and laptop PCs, tablet computers, servers, storage devices, displays, smartphones and peripherals. It also provides e-business services to businesses, governments and consumers. Acer is the fourth largest PC maker in the world.</p>\r\n<p>In the early 2000s, Acer implemented a new business model, shifting \r\nfrom a manufacturer to a designer, marketer and distributor of products,\r\n while performing production processes via contract manufacturers.</p>\r\n<p>In addition to its core business, Acer also owns the largest franchised computer retail chain in Taipei, Taiwan.</p><br></p>', '', '', '', 'en'),
(93, 'Hewlett-Packard', '<p><p><b>Hewlett-Packard Company</b> or <b>HP</b> is an American multinational information technology corporation headquartered in Palo Alto, California, United States. It provides products, technologies, software, solutions and services to consumers, small- and medium-sized businesses (SMBs) and large enterprises, including customers in the government, health and education sectors.</p>\r\n<p>The company was founded in a one-car garage in Palo Alto by William "Bill" Redington Hewlett and Dave Packard. HP is the world''s leading PC manufacturer and has been since 2007, fending off a challenge by Chinese manufacture Lenovo, according to Gartner.\r\n It specializes in developing and manufacturing computing, data storage,\r\n and networking hardware, designing software and delivering services. \r\nMajor product lines include personal computing devices, enterprise, and \r\nindustry standard servers, related storage devices, networking products,\r\n software and a diverse range of printers, and other imaging products. \r\nHP markets its products to households, small- to medium-sized businesses\r\n and enterprises directly as well as via online distribution, \r\nconsumer-electronics and office-supply retailers, software partners and \r\nmajor technology vendors. HP also has strong services and consulting \r\nbusiness around its products and partner products. It is the world''s largest PC vendor by 2012 unit sales.</p>\r\n<p>Major company events have included the spin-off of part of its business as Agilent Technologies in 1999, its merger with Compaq in 2002, the sponsor of Mission: Space in 2003, and the acquisition of EDS in 2008, which led to combined revenues of $118.4&nbsp;billion in 2008 and a Fortune 500 ranking of 9 in 2009. In November 2009, HP announced the acquisition of 3Com, with the deal closing on April 12, 2010. On April 28, 2010, HP announced the buyout of Palm for $1.2&nbsp;billion. On September 2, 2010, HP won its bidding war for 3PAR with a $33 a share offer ($2.07&nbsp;billion), which Dell declined to match.</p>\r\n<p>Hewlett-Packard is not affiliated with Packard Motor Car Corporation, founded by James Ward Packard and William Doud Packard, or with Packard Bell.</p><br></p>', '', '', '', 'en'),
(94, 'LG', '<p><b>LG Corporation</b> is a South Korean multinational conglomerate\r\n corporation. It is the fourth-largest company of its kind in South \r\nKorea, following Samsung Group, Hyundai Motors Group and SK group. Its \r\nheadquarters are situated in the LG Twin Towers building in Yeouido-dong, Yeongdeungpo-gu, Seoul. LG makes electronics, chemicals, and telecom products and operates subsidiaries such as LG Electronics, Zenith, LG Display, LG Telecom and LG Chem in over 80 countries.<br></p>', '', '', '', 'en'),
(95, 'D-Link', '<p><p><b>D-Link Corporation</b> was founded in March 1986 in Taipei as <i>Datex Systems Inc.</i> It began as a network adapter\r\n vendor and has gone on to become a designer, developer, and \r\nmanufacturer of networking solutions for both the consumer and business \r\nmarkets.</p>\r\n<p>In 2007, it was the leading networking company in the small to medium business (SMB) segment worldwide with 21.9% market share. In March 2008, it became the market leader in Wi-Fi product shipments worldwide, with 33% of the total market.\r\n In 2007, the company was featured in the "Info Tech 100", a listing of \r\nthe world''s best IT companies. It was also ranked as the 9th best IT \r\ncompany in the world for shareholder returns by BusinessWeek.</p>\r\n<p>The company has 127 sales offices in 64 countries and 10 global distribution centres serving 100 countries worldwide.</p>\r\n<p>D-Link operates an indirect channel model, selling through distributors, resellers, retailers, VARS, and Telecom Service Providers.</p>\r\n<p>Its main competitors are Cisco, Netgear, and HP.</p><br></p>', '', '', '', 'en'),
(96, 'Concord Records', '<p>Concord Records is a U.S. record label now based in Beverly Hills, California. Originally known as Concord Jazz, it was established in 1972 as an off-shoot of the Concord Jazz Festival in Concord, California, by festival founder Carl Jefferson, a local automobile dealer and jazz fan who sold his Lincoln Mercury dealership to found "the jazz label I can never find in record stores." Since then, the label has achieved international recognition, as well as 88 Grammy Award nominations and 14 Grammy Awards.<br></p>\r\n', '', '', '', 'en'),
(97, 'TP-Link', '<p><p><b>TP-Link Technologies CO., LTD.</b> (Twisted Pair-Link) founded in 1996 in Shenzhen, is a manufacturer of computer networking products based in China. Products include routers, switch, wireless equipment, ADSL modems, and network adapters for PCs. TP-Link is the largest Small Office and Home Office (SOHO) networking market share holder in China.</p><br></p>', '', '', '', 'en'),
(99, 'Intel', '<p><p><b>Intel Corporation</b> is an American multinational semiconductor chip maker corporation headquartered in Santa Clara, California. Intel is the world''s largest and highest valued semiconductor chip maker, based on revenue. It is the inventor of the x86 series of microprocessors, the processors found in most personal computers. Intel Corporation, founded on July 18, 1968, is a portmanteau of <b>Int</b>egrated <b>El</b>ectronics (the fact that "intel" is the term for intelligence information was also quite suitable). Intel also makes motherboard chipsets, network interface controllers and integrated circuits, flash memory, graphic chips, embedded processors and other devices related to communications and computing. Founded by semiconductor pioneers Robert Noyce and Gordon Moore and widely associated with the executive leadership and vision of Andrew Grove,\r\n Intel combines advanced chip design capability with a leading-edge \r\nmanufacturing capability. Though Intel was originally known primarily to\r\n engineers and technologists, its "Intel Inside" advertising campaign of\r\n the 1990s made it and its Pentium processor household names.</p>\r\n<p>Intel was an early developer of SRAM and DRAM\r\n memory chips, and this represented the majority of its business until \r\n1981. Although Intel created the world''s first commercial microprocessor\r\n chip in 1971, it was not until the success of the personal computer \r\n(PC) that this became its primary business. During the 1990s, Intel \r\ninvested heavily in new microprocessor designs fostering the rapid \r\ngrowth of the computer industry. During this period Intel became the dominant\r\n supplier of microprocessors for PCs, and was known for aggressive and \r\nsometimes illegal tactics in defense of its market position, \r\nparticularly against Advanced Micro Devices (AMD), as well as a struggle with Microsoft for control over the direction of the PC industry.\r\n The 2011 rankings of the world''s 100 most valuable brands published by \r\nMillward Brown Optimor showed the company''s brand value at number 58 and\r\n in 2012 at number 49.</p>\r\n<p>Intel has also begun research in electrical transmission and generation. Intel has recently introduced a 3-D transistor that improves performance and energy efficiency.\r\n Intel has begun mass-producing this 3-D transistor, named the Tri-Gate \r\ntransistor, with their 22&nbsp;nm process, which is currently used in their \r\n3rd generation core processors initially released on April 29, 2012. In 2011, SpectraWatt Inc., a solar cell spinoff of Intel, filed for bankruptcy under Chapter 11.</p>\r\n<p>The <b>Open Source Technology Center</b> at Intel hosts PowerTOP and LatencyTOP, and supports other open-source projects such as Wayland, Intel Array Building Blocks, Intel Threading Building Blocks, and Xen.</p><br></p>', '', '', '', 'en'),
(100, 'Pioneer', '<p><p><b>Pioneer Corporation</b> is a multinational corporation that specializes in digital entertainment products, based in Kawasaki, Kanagawa, Japan. The company was founded by Nozomu Matsumoto in 1938 in Tokyo as a radio and speaker repair shop, and its current president is Susumu Kotani.</p>\r\n<p>Pioneer played a role in the development of interactive cable TV, the Laser Disc player, the first automotive Compact Disc player, the first detachable face car stereo, Supertuner technology, DVD and DVD recording, plasma display (branded as Kuro), and Organic LED display (OLED). The company works with optical disc and display technology and software products and is also a manufacturer. Sharp Corporation took a 14% stake in Pioneer in 2007, which has been reduced to 9%, but Sharp still remains the largest shareholder of Pioneer Corporation, followed by Honda Motor Co., Ltd. who owns roughly 4% of Pioneer shares following a memorandum between the two companies in 2010 to strengthen business ties.</p>\r\n<p>In March 2010, Pioneer stopped producing televisions, announced on 12 February 2009.\r\n On June 25, 2009, Sharp Corporation agreed to form a joint venture on \r\ntheir optical business to be called "Pioneer Digital Design and \r\nManufacturing Corporation".</p><br></p>', '', '', '', 'en'),
(101, 'TomTom', '<p><b>TomTom NV</b> (Euronext:&nbsp;TOM2) is a Dutch manufacturer of automotive navigation systems, including both stand-alone units and software for personal digital assistants and mobile telephones. It is the leading manufacturer of navigation systems in Europe. TomTom''s customer service is located in Amsterdam, Netherlands. TomTom was a follow-up of Palmtop Software, founded by Peter-Frans Pauwels, Pieter Geelen, Harold Goddijn and Corinne Vigreux in 1991.</p>\r\n<p>In 2008, TomTom acquired Tele Atlas, a digital map maker, for €2.9 billion.</p>\r\n<p>On June 11, 2012, at an event for Apple''s iOS 6 preview, TomTom was announced as the main mapping data provider for Apple''s revamped iOS 6 "Maps" app replacing long time provider Google Maps.</p><p><br></p>', '', '', '', 'en'),
(102, 'Garmin', '<p><b>Garmin Ltd.</b>, incorporated in Schaffhausen, Switzerland, is the parent company of a group of companies founded in 1989 by Gary Burrell and Min Kao (hence the name GarMin), that develops consumer, aviation, and marine technologies for the Global Positioning System. Its subsidiary <b>Garmin International, Inc.</b> serves as headquarters for the Garmin Limited companies and is located in Olathe, Kansas in the United States. The largest operating subsidiary and primary production facility of Garmin Limited is <b>Garmin (Asia) Corporation</b>, located in Xizhi District, Taiwan, a district of New Taipei City.<br></p>', '', '', '', 'en'),
(103, 'Kenwood', '<p><b>Kenwood Corporation</b> is a Japanese manufacturer of amateur radio as well as Hi-Fidelity and portable audio equipment.<br></p>', '', '', '', 'en'),
(104, 'Cobra', '<p></p><p>\r\n	Cobra Electronics Corporation is a leading designer of mobile \r\ncommunications products in the United States, Canada, Europe and around \r\nthe world. After 50 years of innovation, the company continues to grow \r\nby boldly entering into new product categories.</p>\r\n<p>\r\n	Today the company''s products include:</p>\r\n<ul><li>\r\n		Mobile navigation devices</li><li>\r\n		Two-way radios</li><li>\r\n		Radar/laser detectors</li><li>\r\n		Citizens band radios</li><li>\r\n		Marine electronics</li><li>\r\n		Power inverters</li></ul>\r\n<p>\r\n	Cobra products are available in nearly 40,000 storefronts in North \r\nAmerica and in a growing number of retailers throughout the world.</p>\r\n<p>\r\n	Cobra has a significant presence in Europe through Performance Products\r\n Limited, a United Kingdom-based wholly owned subsidiary with a \r\nwell-established network of mass merchandisers and specialty retailers.</p>\r\n<p>\r\n	Cobra is headquartered in Chicago, Illinois with international offices in Dublin, Ireland and Hong Kong.</p><br><p></p>\r\n', '', '', '', 'en'),
(105, 'Roadrunner Records', '<p><b>Roadrunner Records</b> is an American record label that concentrates primarily on heavy metal bands. It is a subsidiary of Warner Music Group. It is based in New York.<br></p>\r\n', '', '', '', 'en'),
(106, 'Toshiba', '<p><p><b>Toshiba Corporation</b> is a Japanese multinational engineering and electronics conglomerate corporation headquartered in Tokyo, Japan.\r\n Its products and services include information technology and \r\ncommunications equipment and systems, electronic components and \r\nmaterials, power systems, industrial and social infrastructure systems, \r\nhousehold appliances, medical equipment, office equipment, lighting and \r\nlogistics.</p>\r\n<p>Toshiba was founded in 1939 as <b>Tokyo Shibaura Electric K.K.</b> \r\nthrough the merger of Shibaura Seisaku-sho (founded in 1875) and Tokyo \r\nDenki (founded in 1890). The company name was officially changed to \r\nToshiba Corporation in 1978. Toshiba has made numerous corporate \r\nacquisitions during its history, including of Semp in 1977, of \r\nWestinghouse Electric Company in 2006, of Landis+Gyr in 2011, and of IBM''s point-of-sale business in 2012.</p>\r\n<p>Toshiba is organised into four main business groupings: the Digital \r\nProducts Group, the Electronic Devices Group, the Home Appliances Group \r\nand the Social Infrastructure Group. In 2010, Toshiba was the world''s fifth-largest personal computer vendor measured by revenues (after Hewlett-Packard, Dell, Acer and Lenovo). In the same year, it was also the world''s fourth-largest manufacturer of semiconductors by revenues (after Intel Corporation, Samsung Electronics and Texas Instruments).</p>\r\n<p>Toshiba is listed on the Tokyo Stock Exchange, where it is a constituent of the Nikkei 225 and TOPIX indices, the Osaka Securities Exchange, the Nagoya Stock Exchange and the London Stock Exchange.</p><br></p>', '', '', '', 'en'),
(107, 'Rhino', '<p><b>Rhino Entertainment Company</b>&nbsp;is an American record label  and production company. It is owned by Warner Music Group.<br></p>\r\n', '', '', '', 'en'),
(109, 'Motorola', '<p><p><b>Motorola, Inc.</b> was an American multinational telecommunications company based in Schaumburg, Illinois. After having lost $4.3&nbsp;billion from 2007 to 2009, the company was divided into two independent public companies, Motorola Mobility and Motorola Solutions on January 4, 2011.\r\n Motorola Solutions is generally considered to be the direct successor \r\nto Motorola, Inc., as the reorganization was structured with Motorola \r\nMobility being spun off.</p>\r\n<p>Motorola designed and sold wireless network infrastructure equipment such as cellular transmission base stations and signal amplifiers. Motorola''s home and broadcast network products included set-top boxes, digital video recorders, and network equipment used to enable video broadcasting, computer telephony, and high-definition television.\r\n Its business and government customers consisted mainly of wireless \r\nvoice and broadband systems (used to build private networks), and, \r\npublic safety communications systems like Astro and Dimetra. These businesses (except for set-top boxes and cable modems) are now part of Motorola Solutions.</p>\r\n<p>Motorola''s wireless telephone\r\n handset division was a pioneer in cellular telephones. Also known as \r\nthe Personal Communication Sector (PCS) prior to 2004, it pioneered the \r\n"flip phone" with the MicroTAC – and, the "clam phone" with the StarTAC – in the mid-1990s. It had staged an enormously successful resurgence by the mid-2000s with the RAZR; but, lost significant market share in the second half of that decade. Lately, it has focused on smartphones using Google''s open-source Android\r\n mobile operating system. The first phone to use the newest version of \r\nGoogle''s open source OS, Android 2.0, was released on November 2, 2009 \r\nas the Motorola Droid (the GSM version launched a month later, in Europe, as the Motorola Milestone). The handset division, (along with cable set-top boxes and cable modems) has since then been spun off into the independent Motorola Mobility. On May 22, 2012, Google CEO Larry Page announced that Google closed on its deal to acquire Motorola Mobility.</p><br></p>', '', '', '', 'en'),
(108, 'HTC', '<p><p><b>HTC Corporation</b> is a Taiwanese manufacturer of smartphones and tablets headquartered in Taoyuan City, Taiwan. Initially making smartphones based mostly on Microsoft''s Windows Mobile operating system (OS) software, HTC expanded its focus in 2009 to devices based on the Android OS, and in 2010 to Windows Phone OS.</p>\r\n<p>HTC is a member of the Open Handset Alliance, a group of handset manufacturers and mobile network operators dedicated to the development of the Android mobile device platform. The HTC Dream, marketed by T-Mobile in many countries as the T-Mobile G1 or Era G1, was the first phone on the market to use the Android mobile device platform.</p><br></p>', '', '', '', 'en'),
(110, 'Nokia', '<p><p><b>Nokia Corporation</b> is a Finnish multinational communications and information technology corporation (originally a paper production plant) that is headquartered in Helsinki, Finland. Its principal products are mobile telephones and portable IT devices. It also offers Internet services including applications, games, music, media and messaging, and free-of-charge digital map information and navigation services through its wholly owned subsidiary Navteq. Nokia has a joint venture with Siemens, Nokia Siemens Networks, which provides telecommunications network equipment and services.</p>\r\n<p>Nokia has around 101,982 employees across 120 countries, sales in \r\nmore than 150 countries and annual revenues of around €30 billion. It is the world''s second-largest mobile phone maker by 2012 unit sales (after Samsung), with a global market share of 22.5% in the first quarter of that year. Nokia is a public limited-liability company listed on the Helsinki Stock Exchange and New York Stock Exchange. It is the world''s 143rd-largest company measured by 2011 revenues according to the <i>Fortune Global 500</i>.</p>\r\n<p>Nokia was the world''s largest vendor of mobile phones from 1998 to 2012.\r\n However, over the past five years it has suffered a declining market \r\nshare as a result of the growing use of smartphones from other vendors, \r\nprincipally the Apple iPhone and devices running on Google''s Android operating system. As a result, its share price has fallen from a high of US$40 in late 2007 to under US$2 in mid-2012. Since February 2011, Nokia has had a strategic partnership with Microsoft, as part of which all Nokia smartphones will incorporate Microsoft''s Windows Phone operating system (replacing Symbian). Since then previously increasing smartphone sales have been collapsing and the previously profitable smart devices business unit went loss-making.</p><br></p>', '', '', '', 'en'),
(111, 'Creative', '<p><b>Creative Technology Ltd.</b> is a Singapore-based global company headquartered in Jurong East,\r\n Singapore. The principal activities of the company and its subsidiaries\r\n consist of the design, manufacture and distribution of digitized sound \r\nand video boards, computers and related multimedia, and personal digital\r\n entertainment products.<br></p>', '', '', '', 'en'),
(112, 'Yamaha', '<p><b>Yamaha Corporation</b> is a Japanese multinational corporation and conglomerate based in Japan\r\n with a wide range of products and services, predominantly musical \r\ninstruments, electronics, motorcycles and power sports equipment.<br></p>', '', '', '', 'en'),
(113, 'Entertainment One Ltd', '<p><p><b>Entertainment One Ltd</b>, also known as <b>eOne</b>, (originally Records on Wheels Limited, then ROW Entertainment Income Fund, next Entertainment One Income Fund, Entertainment One (eOne), &amp; E1 Entertainment (E1) before reverting back to eOne),\r\n is an American entertainment business operating in the United States, \r\nCanada, the UK, Ireland, France, the Netherlands, Belgium, Australia and\r\n New Zealand.</p><br></p>', '', '', '', 'en'),
(114, 'Sony', '<p><p><b>Sony Corporation</b>, commonly referred to as <b>Sony</b>, is a Japanese multinational conglomerate corporation headquartered in Kōnan Minato, Tokyo, Japan. Its diversified business is primarily focused on the electronics, game, entertainment and financial services sectors. The company is one of the leading manufacturers of electronic products for the consumer and professional markets. Sony is ranked 87th on the 2012 list of Fortune Global 500.</p>\r\n<p>Sony Corporation is the electronics business unit and the parent company\r\n of the Sony Group, which is engaged in business through its four \r\noperating segments – Electronics (including video games, network \r\nservices and medical business), Motion pictures, Music and Financial Services.\r\n These make Sony one of the most comprehensive entertainment companies \r\nin the world. Sony''s principal business operations include Sony \r\nCorporation (Sony Electronics in the U.S.), Sony Pictures Entertainment, Sony Computer Entertainment, Sony Music Entertainment, Sony Mobile Communications (formerly Sony Ericsson), and Sony Financial. Sony is among the Worldwide Top 20 Semiconductor Sales Leaders and third-largest television manufacturer in the world, after Samsung Electronics and LG Electronics.</p>\r\n<p>The <b>Sony Group</b> is a Japan-based corporate group\r\n primarily focused on the Electronics (such as AV/IT products and \r\ncomponents), Game (such as PlayStation), Entertainment (such as motion \r\npictures and music), and Financial Services (such as insurance and \r\nbanking) sectors. The group consists of Sony Corporation (holding and \r\nelectronics), Sony Computer Entertainment (game), Sony Pictures Entertainment (motion pictures), Sony Music Entertainment (music), Sony/ATV Music Publishing (music publishing), Sony Financial Holdings (financial services) and others.</p>\r\n<p>Its founders Akio Morita and Masaru Ibuka derived the name from <i>sonus</i>, the Latin word for sound, and also from the English slang word "sonny", since they considered themselves to be "sonny boys", a loan word into Japanese which in the early 1950s connoted smart and presentable young men.</p><br></p>', '', '', '', 'en'),
(115, 'Koss', '<p><b>Koss Corporation</b> is an American company that designs and manufactures headphones.<br></p>', '', '', '', 'en'),
(116, 'Abbey Road Studios', '<p><b>Abbey Road Studios</b> is a recording studio located at 3 Abbey Road, St John''s Wood, City of Westminster, London, England. It was established in November 1931 by the Gramophone Company, a predecessor of British music company EMI, its present owner. Abbey Road Studios is most notable as being the venue in the 1960s for innovative recording techniques adopted by The Beatles, Pink Floyd, The Hollies, Badfinger and others.<br></p>\r\n', '', '', '', 'en'),
(117, 'Nikon', '<p><p><b>Nikon Corporation</b>, also known as just <b>Nikon</b>, is a Japanese multinational corporation headquartered in Tokyo, Japan, specializing in optics and imaging products.</p>\r\n<p>Its products include cameras, camera lenses, binoculars, microscopes, ophthalmic lenses, measurement instruments, and the steppers used in the photolithography steps of semiconductor fabrication, of which it is the world''s second largest manufacturer. The companies held by Nikon form the Nikon Group. Among its products are Nikkor imaging lenses (for F-mount cameras, large format photography, photographic enlargers, and other applications), the Nikon F-series of 135 film SLR cameras, the Nikon D-series of digital SLR cameras, the Coolpix series of compact digital cameras, and the Nikonos series of underwater film cameras. Nikon''s main competitors in camera and lens manufacturing include Canon, Sony, Pentax, and Olympus.</p>\r\n<p>\r\n</p><div><img>\r\n<div>\r\n<div><img>\r\nWest Building of Nikon in Nishi-Ōi,Tokyo</div>\r\n</div>\r\n</div>\r\n<p>Founded in 25 July 1917 as <i>Nippon Kōgaku Kōgyō Kabushikigaisha</i> , the company was \r\nrenamed Nikon Corporation, after its cameras, in 1988. Nikon is one of \r\nthe companies of the Mitsubishi Group.</p></p>', '', '', '', 'en'),
(118, 'Warner Bros.', '<p><p><b>Warner Bros. Entertainment Inc</b>., also known as Warner Bros. Pictures, and Warner Bros. (though the name was occasionally given in full form as Warner Brothers during the company''s early years), is an American producer of film, television, and music entertainment.<br><br>One of the major film studios, it is a subsidiary of Time Warner, with its headquarters in Burbank, California and New York. Warner Bros. has several subsidiary companies, including Warner Bros. Studios, Warner Bros. Pictures, Warner Bros. Interactive Entertainment, Warner Bros. Television, Warner Bros. Animation, Warner Home Video, New Line Cinema, TheWB.com, and DC Entertainment. Warner owns half of The CW Television Network.</p><br></p>\r\n', '', '', '', 'en'),
(119, 'Warner Home Video ', '<p>Warner Home Video is the home video distribution division of Warner Bros. Home Entertainment Group, itself part of Time Warner. It was founded in 1978 as WCI Home Video (for Warner Communications, Inc.). The company launched in the United States with twenty films on Betamax and VHS videocassettes in late 1979. The company later expanded its line to include additional titles throughout 1979 and 1980.<br></p>', '', '', '', 'en'),
(120, 'Arc System Works', '<p><b>Arc System Works</b> is a video game developer and publisher based in Yokohama, Japan. It was founded by Minoru Kidooka in 1988. Arc System Works is best known for its arcade 2D fighting game, Guilty Gear and its sequels.<br></p>', '', '', '', 'en'),
(121, 'SanDisk', '<p><p><b>SanDisk Corporation</b> is a multinational corporation\r\n that designs, develops and manufactures flash memory storage solutions \r\nand software. The Fortune 500 and S&amp;P 500 company is based in \r\nSilicon Valley and has more than half its sales outside the United \r\nStates.</p>\r\n<p>SanDisk was founded in 1988 by Dr. Eli Harari, Jack Yuan and Sanjay Mehrotra, non-volatile memory technology experts. SanDisk became a publicly traded company on NASDAQ in November 1995. As of March 2013, its market capitalization was over US$13 billion.</p>\r\n<p>SanDisk’s flash memory storage products include solid-state drives \r\n(SSDs) and caching software for laptop, PC and enterprise applications; \r\nmemory cards for smartphones and cameras; embedded flash drives for \r\nmobile phones and tablets, USB flash drives; and other flash-based \r\nproducts.</p>\r\n<p>The company markets its products directly to businesses, original \r\nequipment manufacturers (OEMs) and consumers, as well as through a new \r\ndistribution channel that offers SanDisk SSDs to a wider set of business\r\n customers including VARs, e-tailers and system integrators. SanDisk \r\nproducts are sold at more than 250,000 retail locations in more than 100\r\n countries.</p>\r\n<p>SanDisk is headquartered in Milpitas, California.\r\n The company has manufacturing facilities in China. It also has sales, \r\noperations, research and development, and administration in the U.S., \r\nChina, France, Germany, India, Ireland, Israel, Japan, Korea, Russia, \r\nScotland, Singapore, Spain, Sweden, Taiwan, and the United Arab \r\nEmirates. The company has more than 4,600 employees worldwide.</p>\r\n<p>SanDisk''s product portfolio includes flash memory cards for mobile \r\nphones, digital cameras and camcorders; digital audio/video players; USB\r\n flash drives for consumers and the enterprise; embedded memory for \r\nmobile devices; and solid state drives for computers. SanDisk is a \r\nSilicon Valley-based S&amp;P 500 company, with more than half its sales \r\noutside the United States.</p>\r\n<br></p>\r\n', '', '', '', 'en'),
(122, 'Namco', '<p>Namco Ltd.&nbsp; is a Japanese corporation best known as a former video game developer and publisher. Following a merger with Bandai in September 2005, the two companies'' game production assets were spun off into Namco Bandai Games on March 31, 2006. Namco was re-established to continue domestic operation of video arcades and amusement parks. Its headquarters are located in Ōta, Tokyo. The company''s English name is officially often written as NAMCO.<br></p>', '', '', '', 'en'),
(123, 'Namco Bandai Games', '<p>Namco Bandai Games Inc. (NBGI) is an arcade, mobile and home video game developer and publisher based in Japan. It is the product of a merger between the video game development divisions of Bandai and Namco.<br><br>Namco Bandai Games is a wholly owned subsidiary of Namco Bandai Holdings (NBHD) and specializes in production and sales of home video games. It is the head company of Bandai Namco Group''s Game Contents Strategic Business Unit (SBU).<br></p>', '', '', '', 'en'),
(124, 'Capcom', '<p>Capcom Co., Ltd. or just Capcom, is a Japanese developer and publisher of video games, known for creating multi-million-selling franchises such as Mega Man, Resident Evil, Devil May Cry and Street Fighter. Originally established in 1983, it has since become an international enterprise with branches and subsidiaries in North America, Europe, and East Asia.<br></p>', '', '', '', 'en'),
(125, 'Casio', '<p>Casio Computer Co., Ltd.&nbsp; is a multinational electronics manufacturing company headquartered in Shibuya, Tokyo, Japan. Its products include calculators, mobile phones, cameras, musical instruments and watches. It was founded in 1946, and in 1957 released the world''s first entirely electric compact calculator.<br></p>', '', '', '', 'en'),
(126, 'Quartet Manufacturing', '<p><b>Quartet Manufacturing</b> was founded in 1954 and quickly became the largest provider of&nbsp; whiteboard, bulletin and chalkboard products. In 1985 Quartet® introduced their 1st electronic copy board and continued to rise by providing high-quality, innovative products and expanding its dry-erase and whiteboard selections for business and education. Quartet merged with ACCO Brands in 2005 and strives to now help consumers across all industries succeed in their professional life.<br></p>', '', '', '', 'en'),
(127, 'Swingline ', '<p><b>Swingline</b> is a division of ACCO Brands Corporation that specializes in manufacturing staplers and hole punches. The company was formerly located in Long Island City, Queens, New York, United States, but is now headquartered with its parent company ACCO in Lincolnshire, Illinois.<br></p>', '', '', '', 'en'),
(128, 'Wilson Jones', '<p><b>Wilson Lionel Garton-Jones</b> (2 May 1922 – 5 October 2003) was a professional player of English billiards from India.\r\n Jones, a dominant national amateur champion for more than a decade, won\r\n the amateur world championship twice, in 1958 and 1964. He was awarded \r\nthe Arjuna Award in 1962, the Padma Shri Award in 1965, and the Dronacharya Award in 1996.<br></p>', '', '', '', 'en'),
(129, 'Aiko', '<p>Aiko Safes is the worldwide leader protecting thousands of homes and offices in over 70 countries for over 25 years. Aiko Safes are precisely engineered to surpass the strictest industry standard to provide high security safes. AIKO safes are designed to provide maximum protection against fire and foil any tampering and break-ins<br></p>', '', '', '', 'en'),
(130, 'Cleveland', '<p>Cleveland Golf is an American golf equipment company based in Huntington Beach, California. The company was founded in 1979 by Roger Cleveland, originally producing replicas of classic golf clubs from the 1940s and 1950s. Cleveland currently produces a full range of golf clubs and accessories.<br></p>', '', '', '', 'en'),
(131, 'Camelback', '<p><p>CamelBak Products, LLC is an outdoors equipment company based in Petaluma, California, known primarily for its hydration products, such as hydration packs and water bottles. CamelBak is also a supplier of hydration packs, protective gear, and other products to the U.S. military and law enforcement agencies around the world.</p><p>The CamelBak name comes from a play on the myth that a camel stores water in its hump. In reality, those humps store fat.</p></p>', '', '', '', 'en'),
(132, 'Wilson Staff', '<p>Wilson Staff is the professional and advanced amateur golf products division of Wilson Sporting Goods. Wilson designs and manufactures a full range of golf equipment, accessories, and apparel using the Wilson Staff, Wilson, ProStaff, Profile, and Hope brands. Wilson''s other lines are generally considered to be "big box," "value," or "economy" brands, while the Wilson Staff line provides higher quality equipment used on all major professional golf tours.</p>', '', '', '', 'en'),
(133, 'Montblanc', '<p>Montblanc International GmbH is a German manufacturer of writing instruments, watches, jewellery and leather goods, often identified by their "White Star" logo.<br></p>', '', '', '', 'en'),
(134, 'Tissot', '<p><p>Tissot is a luxury Swiss watchmaker company founded in 1853 by Charles-Félicien Tissot and his son Charles-Émile Tissot who established the Tissot factory in the Swiss city of Le Locle, in the Neuchâtel area of the Jura Mountains.</p><p>Tissot should not be confused with Mathey-Tissot, a separate Swiss watchmaking firm established by Edmond Mathey-Tissot in 1886.</p></p>', '', '', '', 'en'),
(135, 'GoPro', '<p>\r\n	We dream. We have passionate ideas about what’s possible in this world. Our passions lead us to create experiences and realities that expand our world and inspire those around us.\r\n</p>\r\n<p>\r\n	GoPro helps people capture and share their lives’ most meaningful experiences with others—to celebrate them together. Like how a day on the mountain with friends is more meaningful than one spent alone, the sharing of our collective experiences makes our lives more fun.\r\n</p>\r\n<p>\r\n	The world’s most versatile cameras are what we make.\r\n</p>\r\n<p>\r\n	Enabling you to share your life through incredible photos and video is what we do.\r\n</p>\r\n<p>\r\n	This is your life...GoPro.\r\n</p>\r\n<p>\r\n	<strong>Nicholas Woodman</strong>\r\n</p>\r\n<p>\r\n	Founder and CEO\r\n</p>', '', '', '', 'en'),
(192, 'Razer', '<p>\n	<strong style="background-color: initial;">Razer</strong> is a company specializing in products specifically marketed to gamers. The Razer brand is currently being marketed under Razer USA Ltd. Razer''s main slogan is ''FOR GAMERS, BY GAMERS''.</p>', '', '', '', 'en'),
(137, 'stationary', '', '', '', '', 'en'),
(138, '250 GB', '', '', '', '', 'en'),
(139, '500 GB', '', '', '', '', 'en'),
(140, '8192 MB, DDR3', '', '', '', '', 'en'),
(141, 'integrated AMD Radeon GPU', '', '', '', '', 'en'),
(142, '1.23 TFLOPs', '', '', '', '', 'en'),
(143, '1.75 GHz', '', '', '', '', 'en'),
(144, '8-core AMD', '', '', '', '', 'en'),
(145, 'HDMI', '', '', '', '', 'en'),
(146, 'USB x2', '', '', '', '', 'en'),
(147, 'optical audio output', '', '', '', '', 'en'),
(148, 'Wi-Fi (802.11b/g/n)', '', '', '', '', 'en'),
(149, 'Ethernet', '', '', '', '', 'en'),
(150, 'Blu-ray', '', '', '', '', 'en'),
(151, 'DVD', '', '', '', '', 'en'),
(152, 'DVD R', '', '', '', '', 'en'),
(153, 'DVD RW', '', '', '', '', 'en'),
(154, 'CD', '', '', '', '', 'en'),
(155, 'WMA', '', '', '', '', 'en'),
(156, 'Headset', '', '', '', '', 'en'),
(157, 'HDMI cable', '', '', '', '', 'en'),
(158, 'USB cable', '', '', '', '', 'en'),
(159, 'BD (Blu-ray Disc)', '', '', '', '', 'en'),
(160, 'Xbox One', '', '', '', '', 'en'),
(161, 'Black', '', '', '', '', 'en'),
(162, 'ATI C1/Xenos', '', '', '', '', 'en'),
(163, '512 MB, 700 MHz, GDDR3', '', '', '', '', 'en'),
(164, '1 TFLOP', '', '', '', '', 'en'),
(165, 'Power PC (3-core)', '', '', '', '', 'en'),
(166, '3.20 GHz', '', '', '', '', 'en'),
(167, 'CD R', '', '', '', '', 'en'),
(168, 'CR RW', '', '', '', '', 'en'),
(169, 'MP3', '', '', '', '', 'en'),
(170, 'JPEG', '', '', '', '', 'en'),
(171, 'AV-output', '', '', '', '', 'en'),
(172, 'USB x5', '', '', '', '', 'en'),
(173, 'composite AV cable', '', '', '', '', 'en'),
(174, 'Xbox', '', '', '', '', 'en'),
(175, 'DVD', '', '', '', '', 'en'),
(176, 'Xbox360', '', '', '', '', 'en'),
(177, 'Nintendo', '<p>A leading innovator of world-class in the field of interactive entertainment, Nintendo Co., Ltd., located in Kyoto, Japan. The company is engaged in manufacturing and marketing of hardware and software for the home console Wii Wee you portable Nintendo 3DS system line and Nintendo DS. In addition, by the company have been creating recognizable brands gaming industry as Mario, Donkey Kong, Metroid, Zelda and Pokémon.</p>', '', '', '', 'en'),
(178, 'AMD Radeon HD 5650', '', '', '', '', 'en'),
(179, '2000 MB, DDR3', '', '', '', '', 'en'),
(180, 'IBM PowerPC 750', '', '', '', '', 'en'),
(181, '1.24 GHz', '', '', '', '', 'en'),
(182, 'USB x4', '', '', '', '', 'en'),
(183, 'Nintendo WiiNintendo Wii U', '', '', '', '', 'en'),
(184, 'Wii U Optical Disc', '', '', '', '', 'en'),
(185, '8192 MB, GDDR5', '', '', '', '', 'en'),
(186, '1.84 TFLOPs', '', '', '', '', 'en'),
(187, 'Bluetooth', '', '', '', '', 'en'),
(188, 'PlayStation 4', '', '', '', '', 'en'),
(189, '32 GB', '', '', '', '', 'en'),
(191, 'Sucker Punch Productions', '<p>Sucker Punch is an American production company founded in 1997 and based in Bellevue, Washington.</p>', '', '', '', 'en'),
(190, 'Electronic Arts (EA)', '<p>EA Games&mdash;Home to the largest number of studio and development teams, this label is responsible for action-adventure, role playing, racing and combat games, marketed under the EA brand. In addition to traditional packaged-goods games, EA Games also develops massively multiplayer online role-playing games. Led by Patrick Söderlund.</p>', '', '', '', 'en');
INSERT INTO `[[dbprefix]]product_feature_variant_descriptions` VALUES
(136, 'Microsoft', '<p><strong style="background-color: initial;">Microsoft Corporation</strong> &mdash; is one of the biggest <a href="https://ru.wikipedia.org/wiki/%D0%A2%D1%80%D0%B0%D0%BD%D1%81%D0%BD%D0%B0%D1%86%D0%B8%D0%BE%D0%BD%D0%B0%D0%BB%D1%8C%D0%BD%D0%B0%D1%8F_%D0%BA%D0%BE%D0%BC%D0%BF%D0%B0%D0%BD%D0%B8%D1%8F" style="background-color: initial;">international companies</a> that develops&nbsp;<a href="https://ru.wikipedia.org/wiki/%D0%9F%D1%80%D0%BE%D0%BF%D1%80%D0%B8%D0%B5%D1%82%D0%B0%D1%80%D0%BD%D0%BE%D0%B5_%D0%9F%D0%9E" style="background-color: initial;">proprietary</a> <a href="https://ru.wikipedia.org/wiki/%D0%9F%D1%80%D0%BE%D0%B3%D1%80%D0%B0%D0%BC%D0%BC%D0%BD%D0%BE%D0%B5_%D0%BE%D0%B1%D0%B5%D1%81%D0%BF%D0%B5%D1%87%D0%B5%D0%BD%D0%B8%D0%B5" style="background-color: initial;">software</a> for different kinds of computing devices &mdash; <a href="https://ru.wikipedia.org/wiki/%D0%9F%D0%B5%D1%80%D1%81%D0%BE%D0%BD%D0%B0%D0%BB%D1%8C%D0%BD%D1%8B%D0%B9_%D0%BA%D0%BE%D0%BC%D0%BF%D1%8C%D1%8E%D1%82%D0%B5%D1%80" style="background-color: initial;">personal computers</a>, <a href="https://ru.wikipedia.org/wiki/%D0%98%D0%B3%D1%80%D0%BE%D0%B2%D0%B0%D1%8F_%D0%BF%D1%80%D0%B8%D1%81%D1%82%D0%B0%D0%B2%D0%BA%D0%B0" style="background-color: initial;">videogame consoles</a>, <a href="https://ru.wikipedia.org/wiki/%D0%9A%D0%B0%D1%80%D0%BC%D0%B0%D0%BD%D0%BD%D1%8B%D0%B9_%D0%BF%D0%B5%D1%80%D1%81%D0%BE%D0%BD%D0%B0%D0%BB%D1%8C%D0%BD%D1%8B%D0%B9_%D0%BA%D0%BE%D0%BC%D0%BF%D1%8C%D1%8E%D1%82%D0%B5%D1%80" style="background-color: initial;">PDAs</a>, <a href="https://ru.wikipedia.org/wiki/%D0%A1%D0%BE%D1%82%D0%BE%D0%B2%D1%8B%D0%B9_%D1%82%D0%B5%D0%BB%D0%B5%D1%84%D0%BE%D0%BD" style="background-color: initial;">mobile phones</a>, etc. Microsoft developed the most popular&nbsp;&mdash; <a href="https://ru.wikipedia.org/wiki/%D0%9E%D0%BF%D0%B5%D1%80%D0%B0%D1%86%D0%B8%D0%BE%D0%BD%D0%BD%D0%B0%D1%8F_%D1%81%D0%B8%D1%81%D1%82%D0%B5%D0%BC%D0%B0" style="background-color: initial;">operating system</a>—<a href="https://ru.wikipedia.org/wiki/Microsoft_Windows" style="background-color: initial;">Windows</a>.</p><p>The company divisions also produce <a href="https://ru.wikipedia.org/wiki/%D0%98%D0%B3%D1%80%D0%BE%D0%B2%D0%B0%D1%8F_%D0%BA%D0%BE%D0%BD%D1%81%D0%BE%D0%BB%D1%8C">the videogame console</a> <a href="https://ru.wikipedia.org/wiki/Xbox">Xbox</a>, and PC accessories (<a href="https://ru.wikipedia.org/wiki/%D0%9A%D0%BB%D0%B0%D0%B2%D0%B8%D0%B0%D1%82%D1%83%D1%80%D0%B0_%D0%BA%D0%BE%D0%BC%D0%BF%D1%8C%D1%8E%D1%82%D0%B5%D1%80%D0%B0">keyboards</a>, <a href="https://ru.wikipedia.org/wiki/%D0%9A%D0%BE%D0%BC%D0%BF%D1%8C%D1%8E%D1%82%D0%B5%D1%80%D0%BD%D0%B0%D1%8F_%D0%BC%D1%8B%D1%88%D1%8C">mouses</a>, etc.). In <a href="https://ru.wikipedia.org/wiki/2012_%D0%B3%D0%BE%D0%B4">2012</a> the company launched their own<a href="https://ru.wikipedia.org/wiki/%D0%9F%D0%BB%D0%B0%D0%BD%D1%88%D0%B5%D1%82%D0%BD%D1%8B%D0%B9_%D0%BA%D0%BE%D0%BC%D0%BF%D1%8C%D1%8E%D1%82%D0%B5%D1%80">tablet</a> &mdash; <a href="https://ru.wikipedia.org/wiki/Microsoft_Surface">Surface</a> and its Surface RT edition. Microsoft sells its products more than in 80 countries, software was translated into more than 45 languages.</p><p>Microsoft headquarters is located in <a href="https://ru.wikipedia.org/wiki/%D0%A0%D0%B5%D0%B4%D0%BC%D0%BE%D0%BD%D0%B4_(%D0%92%D0%B0%D1%88%D0%B8%D0%BD%D0%B3%D1%82%D0%BE%D0%BD)">Redmond</a>, <a href="https://ru.wikipedia.org/wiki/%D0%92%D0%B0%D1%88%D0%B8%D0%BD%D0%B3%D1%82%D0%BE%D0%BD_(%D1%88%D1%82%D0%B0%D1%82)">Washington</a>, <a href="https://ru.wikipedia.org/wiki/%D0%A1%D0%BE%D0%B5%D0%B4%D0%B8%D0%BD%D1%91%D0%BD%D0%BD%D1%8B%D0%B5_%D0%A8%D1%82%D0%B0%D1%82%D1%8B_%D0%90%D0%BC%D0%B5%D1%80%D0%B8%D0%BA%D0%B8">USA</a>.</p><p>On the 5th of June, 2014 the staff numbered 127104.</p><p>In <a href="https://ru.wikipedia.org/wiki/%D0%A0%D0%BE%D1%81%D1%81%D0%B8%D1%8F">Russia</a> Microsoft department was opened in <a href="https://ru.wikipedia.org/wiki/1992_%D0%B3%D0%BE%D0%B4">1992</a> (in July, <a href="https://ru.wikipedia.org/wiki/2004_%D0%B3%D0%BE%D0%B4">2004</a> &mdash; «<a href="https://ru.wikipedia.org/wiki/%D0%9C%D0%B0%D0%B9%D0%BA%D1%80%D0%BE%D1%81%D0%BE%D1%84%D1%82_%D0%A0%D1%83%D1%81">Microsoft Rus LLC</a>»).</p>', '', '', '', 'en'),
(1201, 'White', '', '', '', '', 'en'),
(1200, 'Black', '', '', '', '', 'en'),
(1199, 'Blue', '', '', '', '', 'en'),
(1198, 'Green', '', '', '', '', 'en'),
(1197, 'X Large', '', '', '', '', 'en'),
(1196, 'XX Large', '', '', '', '', 'en'),
(1195, 'Medium', '', '', '', '', 'en'),
(1194, 'Large', '', '', '', '', 'en'),
(1193, 'Small', '', '', '', '', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_files`
--

CREATE TABLE `[[dbprefix]]product_files` (
  `file_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `folder_id` mediumint(8) unsigned DEFAULT NULL,
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `file_path` varchar(255) NOT NULL DEFAULT '',
  `preview_path` varchar(255) NOT NULL DEFAULT '',
  `file_size` bigint(20) unsigned NOT NULL DEFAULT '0',
  `preview_size` int(11) unsigned NOT NULL DEFAULT '0',
  `agreement` char(1) NOT NULL DEFAULT 'N',
  `max_downloads` smallint(5) unsigned NOT NULL DEFAULT '0',
  `total_downloads` smallint(5) unsigned NOT NULL DEFAULT '0',
  `activation_type` char(1) NOT NULL DEFAULT 'M',
  `position` smallint(5) NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`file_id`),
  KEY `product_id` (`product_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_file_descriptions`
--

CREATE TABLE `[[dbprefix]]product_file_descriptions` (
  `file_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `file_name` varchar(255) NOT NULL DEFAULT '',
  `license` text,
  `readme` text,
  PRIMARY KEY (`file_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_file_ekeys`
--

CREATE TABLE `[[dbprefix]]product_file_ekeys` (
  `ekey` varchar(32) NOT NULL DEFAULT '',
  `file_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `order_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `downloads` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `active` char(1) NOT NULL DEFAULT 'N',
  `ttl` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`file_id`,`order_id`),
  UNIQUE KEY `ekey` (`ekey`),
  KEY `ttl` (`ttl`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_file_folders`
--

CREATE TABLE `[[dbprefix]]product_file_folders` (
  `folder_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `position` smallint(5) NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`folder_id`),
  KEY `product_id` (`product_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_file_folder_descriptions`
--

CREATE TABLE `[[dbprefix]]product_file_folder_descriptions` (
  `folder_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `folder_name` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`folder_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_filters`
--

CREATE TABLE `[[dbprefix]]product_filters` (
  `filter_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `categories_path` text,
  `company_id` int(11) unsigned DEFAULT '0',
  `feature_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `field_type` char(1) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'A',
  `round_to` varchar(8) NOT NULL DEFAULT '1',
  `display_count` smallint(5) unsigned NOT NULL DEFAULT '10',
  `display` char(1) NOT NULL DEFAULT 'Y',
  PRIMARY KEY (`filter_id`),
  KEY `feature_id` (`feature_id`),
  KEY `company_id` (`company_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=314 ;

--
-- Dumping data for table `[[dbprefix]]product_filters`
--

INSERT INTO `[[dbprefix]]product_filters` VALUES
(1, '', 1, 0, 0, 'P', 'A', '1', 10, 'Y'),
(7, '165,166,167,168,169,234,235,236,237,238,240', 1, 15, 10, '', 'A', '1', 10, 'Y'),
(8, '165,166,167,168,169,170,174,190,191,193,234,235,236,237,238,240', 1, 16, 20, '', 'A', '1', 10, 'Y'),
(9, '165,166,167,168,169,234,235,236,237,238,240', 1, 17, 30, '', 'A', '1', 10, 'Y'),
(10, '', 1, 18, 0, '', 'A', '1', 10, 'Y'),
(313, '', 1, 549, 0, '', 'A', '0.01', 10, 'Y'),
(312, '', 1, 548, 0, '', 'A', '0.01', 10, 'Y');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_filter_descriptions`
--

CREATE TABLE `[[dbprefix]]product_filter_descriptions` (
  `filter_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `filter` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`filter_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_filter_descriptions`
--

INSERT INTO `[[dbprefix]]product_filter_descriptions` VALUES
(1, 'en', 'Price'),
(9, 'en', 'Storage Capacity'),
(8, 'en', 'Display'),
(7, 'en', 'Operating System'),
(10, 'en', 'Brand'),
(312, 'en', 'Size'),
(313, 'en', 'Color');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_global_option_links`
--

CREATE TABLE `[[dbprefix]]product_global_option_links` (
  `option_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`option_id`,`product_id`),
  KEY `product_id` (`product_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_global_option_links`
--

INSERT INTO `[[dbprefix]]product_global_option_links` VALUES
(1, 11),
(1, 247),
(2, 7),
(2, 11),
(2, 12),
(2, 15),
(2, 27),
(2, 28),
(2, 31),
(2, 34),
(2, 38),
(2, 41),
(9, 12),
(10, 7),
(11, 240),
(13, 241),
(14, 240),
(14, 241),
(14, 247),
(15, 247),
(20, 248),
(25, 248);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_options`
--

CREATE TABLE `[[dbprefix]]product_options` (
  `option_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `option_type` char(1) NOT NULL DEFAULT 'S',
  `regexp` varchar(255) NOT NULL DEFAULT '',
  `required` char(1) NOT NULL DEFAULT 'N',
  `multiupload` char(1) NOT NULL DEFAULT 'N',
  `allowed_extensions` varchar(255) NOT NULL DEFAULT '',
  `max_file_size` bigint(20) unsigned NOT NULL DEFAULT '0',
  `missing_variants_handling` char(1) NOT NULL DEFAULT 'M',
  `status` char(1) NOT NULL DEFAULT 'A',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `value` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`option_id`),
  KEY `c_status` (`product_id`,`status`),
  KEY `position` (`position`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=26 ;

--
-- Dumping data for table `[[dbprefix]]product_options`
--

INSERT INTO `[[dbprefix]]product_options` VALUES
(1, 0, 1, 'S', '', 'N', 'N', '', 0, 'M', 'A', 10, ''),
(2, 0, 1, 'S', '', 'N', 'N', '', 0, 'M', 'A', 20, ''),
(9, 0, 1, 'S', '', 'N', 'N', '', 0, 'M', 'A', 0, ''),
(10, 0, 1, 'S', '', 'N', 'N', '', 0, 'M', 'A', 0, ''),
(11, 0, 1, 'C', '', 'N', 'N', '', 0, 'M', 'A', 0, ''),
(13, 0, 1, 'C', '', 'N', 'N', '', 0, 'M', 'A', 0, ''),
(14, 0, 1, 'S', '', 'N', 'N', '', 0, 'M', 'A', 0, ''),
(15, 0, 1, 'C', '', 'N', 'N', '', 0, 'M', 'A', 0, ''),
(20, 0, 1, 'C', '', 'N', 'N', '', 0, 'M', 'A', 0, ''),
(25, 0, 1, 'S', '', 'N', 'N', '', 0, 'M', 'A', 0, '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_options_descriptions`
--

CREATE TABLE `[[dbprefix]]product_options_descriptions` (
  `option_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `option_name` varchar(64) NOT NULL DEFAULT '',
  `internal_option_name` varchar(64) NOT NULL DEFAULT '',
  `option_text` varchar(255) NOT NULL DEFAULT '',
  `description` mediumtext,
  `comment` varchar(255) NOT NULL DEFAULT '',
  `inner_hint` varchar(255) NOT NULL DEFAULT '',
  `incorrect_message` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`option_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_options_descriptions`
--

INSERT INTO `[[dbprefix]]product_options_descriptions` VALUES
(1, 'en', 'Color', 'Monotone color', 'Color', NULL, '', '', ''),
(2, 'en', 'Size', 'Apparel Size', 'Size', NULL, '', '', ''),
(9, 'en', 'Color', 'Adidas pants color', '', '', '', '', ''),
(10, 'en', 'Color', 'Adidas hoodie color', '', '', '', '', ''),
(11, 'en', '3G Connectivity', 'Apple iPad 3G', '', '', '', '', ''),
(13, 'en', '3G Connectivity', 'Apple 3G', '', '', '', '', ''),
(14, 'en', 'Memory capacity', 'Memory capacity', '', '', '', '', ''),
(15, 'en', '3G Connectivity', 'Nokia 3G', '', '', '', '', ''),
(20, 'en', 'Additional controller', 'Additional controller', '', '', '', '', ''),
(25, 'en', 'Choose a free game', 'X-box', '', '', '', '', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_options_exceptions`
--

CREATE TABLE `[[dbprefix]]product_options_exceptions` (
  `exception_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `combination` text,
  PRIMARY KEY (`exception_id`),
  KEY `product` (`product_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_option_variants`
--

CREATE TABLE `[[dbprefix]]product_option_variants` (
  `variant_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `option_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `modifier` decimal(13,3) NOT NULL DEFAULT '0.000',
  `modifier_type` char(1) NOT NULL DEFAULT 'A',
  `weight_modifier` decimal(12,3) NOT NULL DEFAULT '0.000',
  `weight_modifier_type` char(1) NOT NULL DEFAULT 'A',
  `point_modifier` decimal(12,3) NOT NULL DEFAULT '0.000',
  `point_modifier_type` char(1) NOT NULL DEFAULT 'A',
  `status` char(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`variant_id`),
  KEY `position` (`position`),
  KEY `status` (`status`),
  KEY `option_id` (`option_id`,`status`),
  KEY `option_id_2` (`option_id`,`variant_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=181 ;

--
-- Dumping data for table `[[dbprefix]]product_option_variants`
--

INSERT INTO `[[dbprefix]]product_option_variants` VALUES
(1, 1, 10, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(6, 2, 10, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(5, 1, 20, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(10, 2, 20, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(4, 1, 30, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(9, 2, 30, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(3, 1, 40, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(8, 2, 40, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(2, 1, 50, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(7, 2, 50, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(11, 1, 60, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(17, 9, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(18, 9, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(19, 9, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(36, 10, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(37, 10, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(38, 10, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(42, 11, 1, '200.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(43, 11, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(47, 13, 1, '200.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(48, 13, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(49, 14, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(50, 14, 0, '100.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(51, 14, 0, '200.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(52, 14, 0, '300.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(53, 15, 1, '125.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(54, 15, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(180, 20, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(179, 20, 1, '52.650', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(154, 25, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(153, 25, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A'),
(152, 25, 0, '0.000', 'A', '0.000', 'A', '0.000', 'A', 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_option_variants_descriptions`
--

CREATE TABLE `[[dbprefix]]product_option_variants_descriptions` (
  `variant_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `variant_name` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`variant_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_option_variants_descriptions`
--

INSERT INTO `[[dbprefix]]product_option_variants_descriptions` VALUES
(1, 'en', 'White'),
(11, 'en', 'Yellow'),
(2, 'en', 'Green'),
(3, 'en', 'Red'),
(4, 'en', 'Blue'),
(5, 'en', 'Black'),
(6, 'en', 'Small'),
(7, 'en', 'XX Large'),
(8, 'en', 'X Large'),
(9, 'en', 'Large'),
(10, 'en', 'Medium'),
(17, 'en', 'Black/White/White'),
(18, 'en', 'Dark Navy/White/White'),
(19, 'en', 'White/Prime Green'),
(36, 'en', 'GreyHeather/Core Energy'),
(37, 'en', 'Cardinal/PRIME YELLOW'),
(38, 'en', 'Fairway/White'),
(42, 'en', ''),
(43, 'en', ''),
(47, 'en', ''),
(48, 'en', ''),
(49, 'en', '16GB'),
(50, 'en', '32GB'),
(51, 'en', '64GB'),
(52, 'en', '128GB'),
(53, 'en', ''),
(54, 'en', ''),
(154, 'en', 'Scene It? Bright Lights!'),
(153, 'en', 'Game Party: In Motion'),
(152, 'en', 'Batman: Arkham City'),
(179, 'en', ''),
(180, 'en', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_point_prices`
--

CREATE TABLE `[[dbprefix]]product_point_prices` (
  `point_price_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `point_price` int(11) unsigned NOT NULL DEFAULT '0',
  `lower_limit` smallint(5) unsigned NOT NULL DEFAULT '0',
  `usergroup_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`point_price_id`),
  UNIQUE KEY `unique_key` (`lower_limit`,`usergroup_id`,`product_id`),
  KEY `src_k` (`product_id`,`lower_limit`,`usergroup_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_popularity`
--

CREATE TABLE `[[dbprefix]]product_popularity` (
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `viewed` int(11) NOT NULL DEFAULT '0',
  `added` int(11) NOT NULL DEFAULT '0',
  `deleted` int(11) NOT NULL DEFAULT '0',
  `bought` int(11) NOT NULL DEFAULT '0',
  `total` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`product_id`),
  KEY `total` (`product_id`,`total`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_prices`
--

CREATE TABLE `[[dbprefix]]product_prices` (
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `price` decimal(12,2) NOT NULL DEFAULT '0.00',
  `percentage_discount` decimal(5,2) NOT NULL DEFAULT '0.00',
  `lower_limit` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `usergroup_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  UNIQUE KEY `usergroup` (`product_id`,`usergroup_id`,`lower_limit`),
  KEY `product_id` (`product_id`),
  KEY `lower_limit` (`lower_limit`),
  KEY `usergroup_id` (`usergroup_id`,`product_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_prices`
--

INSERT INTO `[[dbprefix]]product_prices` VALUES
(1, '5399.99', '0.00', 1, 0),
(4, '699.99', '0.00', 1, 0),
(5, '899.99', '0.00', 1, 0),
(6, '329.99', '0.00', 1, 0),
(7, '55.00', '0.00', 1, 0),
(8, '849.99', '0.00', 1, 0),
(9, '999.99', '0.00', 1, 0),
(10, '1199.99', '0.00', 1, 0),
(11, '30.00', '0.00', 1, 0),
(12, '30.00', '0.00', 1, 0),
(13, '11.96', '0.00', 1, 0),
(14, '499.99', '0.00', 1, 0),
(15, '150.00', '0.00', 1, 0),
(16, '349.99', '0.00', 1, 0),
(17, '11.16', '0.00', 1, 0),
(18, '299.99', '0.00', 1, 0),
(19, '79.99', '0.00', 1, 0),
(20, '19.95', '0.00', 1, 0),
(21, '29.99', '0.00', 1, 0),
(22, '799.99', '0.00', 1, 0),
(23, '599.99', '0.00', 1, 0),
(24, '449.99', '0.00', 1, 0),
(25, '599.99', '0.00', 1, 0),
(26, '34.99', '0.00', 1, 0),
(27, '55.00', '0.00', 1, 0),
(28, '100.00', '0.00', 1, 0),
(29, '199.95', '0.00', 1, 0),
(30, '349.95', '0.00', 1, 0),
(31, '32.00', '0.00', 1, 0),
(32, '299.99', '0.00', 1, 0),
(33, '169.99', '0.00', 1, 0),
(34, '25.00', '0.00', 1, 0),
(35, '31.99', '0.00', 1, 0),
(36, '51.00', '0.00', 1, 0),
(37, '159.95', '0.00', 1, 0),
(38, '16.97', '0.00', 1, 0),
(39, '419.00', '0.00', 1, 0),
(40, '229.00', '0.00', 1, 0),
(41, '35.00', '0.00', 1, 0),
(42, '79.00', '0.00', 1, 0),
(43, '369.00', '0.00', 1, 0),
(44, '25.00', '0.00', 1, 0),
(45, '74.00', '0.00', 1, 0),
(46, '21.00', '0.00', 1, 0),
(47, '29.99', '0.00', 1, 0),
(48, '180.00', '0.00', 1, 0),
(49, '120.00', '0.00', 1, 0),
(50, '220.00', '0.00', 1, 0),
(51, '180.00', '0.00', 1, 0),
(52, '139.99', '0.00', 1, 0),
(53, '38.99', '0.00', 1, 0),
(54, '269.00', '0.00', 1, 0),
(55, '359.00', '0.00', 1, 0),
(56, '220.00', '0.00', 1, 0),
(57, '309.00', '0.00', 1, 0),
(58, '779.00', '0.00', 1, 0),
(59, '599.00', '0.00', 1, 0),
(60, '1499.00', '0.00', 1, 0),
(62, '209.95', '0.00', 1, 0),
(63, '189.95', '0.00', 1, 0),
(64, '189.95', '0.00', 1, 0),
(65, '99.95', '0.00', 1, 0),
(66, '389.95', '0.00', 1, 0),
(67, '339.99', '0.00', 1, 0),
(68, '799.99', '0.00', 1, 0),
(69, '529.99', '0.00', 1, 0),
(70, '499.99', '0.00', 1, 0),
(71, '529.99', '0.00', 1, 0),
(72, '599.99', '0.00', 1, 0),
(73, '589.99', '0.00', 1, 0),
(74, '524.99', '0.00', 1, 0),
(75, '489.99', '0.00', 1, 0),
(76, '439.99', '0.00', 1, 0),
(117, '729.99', '0.00', 1, 0),
(78, '100.00', '0.00', 1, 0),
(79, '96.00', '0.00', 1, 0),
(80, '55.00', '0.00', 1, 0),
(81, '49.50', '0.00', 1, 0),
(82, '19.99', '0.00', 1, 0),
(83, '19.99', '0.00', 1, 0),
(84, '19.99', '0.00', 1, 0),
(85, '19.99', '0.00', 1, 0),
(86, '359.00', '0.00', 1, 0),
(87, '19.99', '0.00', 1, 0),
(88, '39.99', '0.00', 1, 0),
(89, '19.99', '0.00', 1, 0),
(90, '19.99', '0.00', 1, 0),
(91, '10700.00', '0.00', 1, 0),
(92, '3225.00', '0.00', 1, 0),
(93, '19.99', '0.00', 1, 0),
(94, '59.99', '0.00', 1, 0),
(95, '19.99', '0.00', 1, 0),
(96, '99.99', '0.00', 1, 0),
(97, '14.99', '0.00', 1, 0),
(112, '8.99', '0.00', 1, 0),
(113, '449.99', '0.00', 1, 0),
(100, '22.70', '0.00', 1, 0),
(101, '188.88', '0.00', 1, 0),
(102, '295.00', '0.00', 1, 0),
(103, '23.99', '0.00', 1, 0),
(104, '29.95', '0.00', 1, 0),
(105, '169.99', '0.00', 1, 0),
(106, '179.99', '0.00', 1, 0),
(107, '465.00', '0.00', 1, 0),
(108, '12.99', '0.00', 1, 0),
(109, '140.00', '0.00', 1, 0),
(110, '15.99', '0.00', 1, 0),
(111, '6.99', '0.00', 1, 0),
(114, '14.99', '0.00', 1, 0),
(115, '4595.00', '0.00', 1, 0),
(116, '6.99', '0.00', 1, 0),
(118, '30.99', '0.00', 1, 0),
(119, '17.99', '0.00', 1, 0),
(120, '199.99', '0.00', 1, 0),
(121, '17.99', '0.00', 1, 0),
(122, '5695.00', '0.00', 1, 0),
(123, '17.99', '0.00', 1, 0),
(124, '4595.00', '0.00', 1, 0),
(125, '149.99', '0.00', 1, 0),
(126, '129.99', '0.00', 1, 0),
(127, '4779.00', '0.00', 1, 0),
(128, '17.99', '0.00', 1, 0),
(129, '1799.00', '0.00', 1, 0),
(130, '49.95', '0.00', 1, 0),
(131, '1249.00', '0.00', 1, 0),
(132, '269.99', '0.00', 1, 0),
(133, '229.99', '0.00', 1, 0),
(134, '89.99', '0.00', 1, 0),
(135, '0.00', '0.00', 1, 0),
(136, '0.00', '0.00', 1, 0),
(137, '0.00', '0.00', 1, 0),
(138, '0.00', '0.00', 1, 0),
(139, '0.00', '0.00', 1, 0),
(140, '99.95', '0.00', 1, 0),
(141, '99.95', '0.00', 1, 0),
(142, '399.95', '0.00', 1, 0),
(143, '79.95', '0.00', 1, 0),
(144, '99.95', '0.00', 1, 0),
(145, '79.99', '0.00', 1, 0),
(146, '44.99', '0.00', 1, 0),
(147, '44.99', '0.00', 1, 0),
(148, '130.00', '0.00', 1, 0),
(149, '53.99', '0.00', 1, 0),
(150, '120.00', '0.00', 1, 0),
(151, '500.00', '0.00', 1, 0),
(152, '700.00', '0.00', 1, 0),
(153, '49.99', '0.00', 1, 0),
(154, '399.99', '0.00', 1, 0),
(155, '79.99', '0.00', 1, 0),
(156, '299.00', '0.00', 1, 0),
(157, '499.00', '0.00', 1, 0),
(158, '4750.00', '0.00', 1, 0),
(159, '11375.00', '0.00', 1, 0),
(160, '200.00', '0.00', 1, 0),
(161, '279.99', '0.00', 1, 0),
(162, '32750.00', '0.00', 1, 0),
(163, '899.99', '0.00', 1, 0),
(164, '249.99', '0.00', 1, 0),
(165, '599.95', '0.00', 1, 0),
(166, '749.95', '0.00', 1, 0),
(167, '549.95', '0.00', 1, 0),
(168, '1.00', '0.00', 1, 0),
(169, '749.95', '0.00', 1, 0),
(170, '145.99', '0.00', 1, 0),
(171, '499.00', '0.00', 1, 0),
(172, '299.99', '0.00', 1, 0),
(173, '349.99', '0.00', 1, 0),
(174, '100.75', '0.00', 1, 0),
(175, '179.99', '0.00', 1, 0),
(176, '648.95', '0.00', 1, 0),
(177, '400.00', '0.00', 1, 0),
(178, '6.83', '0.00', 1, 0),
(179, '299.97', '0.00', 1, 0),
(180, '199.99', '0.00', 1, 0),
(181, '899.99', '0.00', 1, 0),
(182, '6.80', '0.00', 1, 0),
(183, '249.99', '0.00', 1, 0),
(184, '299.99', '0.00', 1, 0),
(185, '139.99', '0.00', 1, 0),
(186, '299.99', '0.00', 1, 0),
(187, '299.99', '0.00', 1, 0),
(188, '10.00', '0.00', 1, 0),
(189, '1.00', '0.00', 1, 0),
(190, '899.95', '0.00', 1, 0),
(191, '11.98', '0.00', 1, 0),
(192, '15.00', '0.00', 1, 0),
(205, '149.99', '0.00', 1, 0),
(194, '10.60', '0.00', 1, 0),
(195, '29.99', '0.00', 1, 0),
(196, '17.00', '0.00', 1, 0),
(197, '14.98', '0.00', 1, 0),
(198, '17.99', '0.00', 1, 0),
(199, '29.98', '0.00', 1, 0),
(200, '26.92', '0.00', 1, 0),
(201, '12.67', '0.00', 1, 0),
(202, '34.68', '0.00', 1, 0),
(203, '34.68', '0.00', 1, 0),
(204, '14.99', '0.00', 1, 0),
(206, '179.99', '0.00', 1, 0),
(207, '42.00', '0.00', 1, 0),
(208, '82.94', '0.00', 1, 0),
(209, '109.99', '0.00', 1, 0),
(210, '89.99', '0.00', 1, 0),
(211, '299.99', '0.00', 1, 0),
(212, '129.95', '0.00', 1, 0),
(213, '295.00', '0.00', 1, 0),
(214, '972.00', '0.00', 1, 0),
(215, '1095.00', '0.00', 1, 0),
(227, '699.00', '0.00', 1, 0),
(217, '610.99', '0.00', 1, 0),
(218, '459.99', '0.00', 1, 0),
(219, '529.99', '0.00', 1, 0),
(220, '1099.99', '0.00', 1, 0),
(221, '2049.00', '0.00', 1, 0),
(222, '529.99', '0.00', 1, 0),
(223, '499.99', '0.00', 1, 0),
(224, '479.99', '0.00', 1, 0),
(225, '199.99', '0.00', 1, 0),
(226, '269.99', '0.00', 1, 0),
(228, '349.99', '0.00', 1, 0),
(229, '299.99', '0.00', 1, 0),
(230, '125.00', '0.00', 1, 0),
(231, '99.00', '0.00', 1, 0),
(232, '79.95', '0.00', 1, 0),
(233, '47.99', '0.00', 1, 0),
(234, '59.99', '0.00', 1, 0),
(235, '79.99', '0.00', 1, 0),
(236, '299.99', '0.00', 1, 0),
(237, '299.99', '0.00', 1, 0),
(238, '499.99', '0.00', 1, 0),
(239, '509.99', '0.00', 1, 0),
(240, '499.00', '0.00', 1, 0),
(241, '499.00', '0.00', 1, 0),
(242, '249.00', '0.00', 1, 0),
(243, '249.00', '0.00', 1, 0),
(244, '729.99', '0.00', 1, 0),
(245, '699.00', '0.00', 1, 0),
(246, '399.99', '0.00', 1, 0),
(247, '329.49', '0.00', 1, 0),
(248, '372.27', '0.00', 1, 0),
(278, '30.00', '0.00', 1, 0),
(279, '30.00', '0.00', 1, 0),
(281, '37.00', '0.00', 1, 0),
(280, '36.00', '0.00', 1, 0),
(282, '23.99', '0.00', 10, 0),
(282, '25.99', '0.00', 5, 0),
(282, '27.99', '0.00', 1, 0),
(283, '23.99', '0.00', 10, 0),
(283, '25.99', '0.00', 5, 0),
(283, '27.99', '0.00', 1, 0),
(284, '23.99', '0.00', 10, 0),
(284, '25.99', '0.00', 5, 0),
(284, '27.99', '0.00', 1, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_required_products`
--

CREATE TABLE `[[dbprefix]]product_required_products` (
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `required_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`product_id`,`required_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_reviews`
--

CREATE TABLE `[[dbprefix]]product_reviews` (
  `product_review_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) NOT NULL DEFAULT '',
  `advantages` mediumtext,
  `disadvantages` mediumtext,
  `comment` mediumtext,
  `rating_value` tinyint(4) unsigned NOT NULL DEFAULT '0',
  `ip_address` varbinary(40) NOT NULL DEFAULT '',
  `is_buyer` char(1) NOT NULL DEFAULT 'N',
  `product_review_timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `country_code` char(2) NOT NULL DEFAULT '',
  `city` varchar(255) NOT NULL DEFAULT '',
  `reply_user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `reply` mediumtext,
  `reply_timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `helpfulness` mediumint(8) NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'D',
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `images_count` int(2) unsigned NOT NULL DEFAULT '0',
  `vote_up` smallint(5) unsigned NOT NULL DEFAULT '0',
  `vote_down` smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`product_review_id`),
  KEY `idx_product_id` (`product_id`),
  KEY `idx_user_id` (`user_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=50 ;

--
-- Dumping data for table `[[dbprefix]]product_reviews`
--

INSERT INTO `[[dbprefix]]product_reviews` VALUES
(1, 228, 3, 'Tom', '+ Sharp focus\r\n+ No ghosting in games', '- Can''t rotate the screen', 'I first noticed this monitor at one of those computer stores where they place all the monitors on the same shelf. This one really stood out for color and very sharp focus. I watch movies and play some games and I haven''t noticed any ghosting. The only thing that I wish I could do is rotate the screen for word processing (kind of a minor complaint). Otherwise this is a very good monitor and the price is good for a 3D LCD. ', 4, '7f000001', 'N', 1129547428, '', '', 0, NULL, 0, -3, 'A', 1, 0, 1, 4),
(2, 228, 0, 'A PC Hardware Fan', '', 'Can''t configure brightness, contrast, etc. for a nice look', 'This monitor is way too light (everything appears faded out), and adjusting the contrast and brightness controls don''t help. No matter what brightness contrast setting is used, everything is either way too dim & gray or way too light. The monitor''s brightness & contrast controls seem to have the exact same function - contrast setting appears to actually be adjusting the brightness and nothing seems to be actually changing the contrast. This will probably be returned soon, unless someone can tell me how to get the correct brightness/contrast setting. ', 2, '7f000001', 'N', 1129559367, '', '', 1, 'Sorry to hear you ran into this problem. Have you tried enabling full dynamic range in your videocard driver settings? Usually it provides a much better image.', 1618556137, -3, 'A', 1, 0, 0, 3),
(3, 242, 0, 'Robert', NULL, NULL, 'Just a perfect product!', 5, '7f000001', 'N', 1129558427, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(4, 242, 0, 'Guest', NULL, NULL, 'I do not like. \n\nAt all.', 2, '7f000001', 'N', 1129558457, '', '', 0, NULL, 0, -1, 'A', 1, 0, 1, 2),
(5, 78, 3, 'Customer Customer', NULL, NULL, 'Beautiful boots.\n\nMy opinion is they are just best.', 4, '7f000001', 'N', 1129559626, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(6, 224, 0, 'John', NULL, NULL, 'I got the Galaxy Tab over on Friday from a local BestBuy apparent they are not suppose to sell it until Monday. The screen has very wide viewing angle, I looked at the Ipad2 before I looked at the Galaxy Tab, and I couldn''t tell the difference based on memory, but I''m sure Galaxy Tab is better. Though the screen is better than the Xoom which I also own.', 4, '7f000001', 'N', 1311063983, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(7, 224, 0, 'Michael', NULL, NULL, 'We don''t get much of a choice here in Russia, really only the Iconia, Xoom & the Samsung Galaxy, so far this Iconia is my favourite.', 5, '7f000001', 'N', 1311079049, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(8, 5, 0, 'John', NULL, NULL, 'Picture quality is a bit meh but overall nice TV, good for small living rooms', 4, '7f000001', 'N', 1484307840, '', '', 0, NULL, 0, 0, 'A', 1, 1, 2, 0),
(9, 5, 0, 'Stacy', NULL, NULL, 'I really like that TV! Much better than the bulky old one we had for almost 15 years! The image is so sharp and crisp! And the sound quality is really good too!', 5, '7f000001', 'N', 1484307840, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(10, 5, 0, 'Peter', '', '', 'I got headaches from this thing, had to return it to the store. Pity, it looks nice.', 2, '7f000001', 'N', 1484307900, '', '', 1, 'Sorry to hear that this TV didn''t suit you. We hope that you find something that suits you better. Let us know, and we can help with choosing.', 1618476835, -2, 'A', 1, 0, 2, 4),
(11, 1, 0, 'Brian', NULL, NULL, 'Absolutely enjoy this TV. The colors are amazing: the depth, the balance and everything else is just top notch! I can plug in my hard drive and watch videos instantly! I am still amazed at the clarity from all the angles. Just getting into Blue-ray capabilities now. Although the price is relatively high, I can truly say that it''s a stunning piece of technological craftsmanship.', 4, '7f000001', 'N', 1484308560, '', '', 0, NULL, 0, 3, 'A', 1, 1, 4, 1),
(12, 1, 0, 'J. Bond', '', '', 'Broke the next day. It probably got damaged during shipping. I had to ask for a replacement, and it has just arrived today. So far so good.', 3, '7f000001', 'N', 1484308560, '', '', 1, 'Sorry to hear about the problem! We hope that the replacement serves you well. If not, don''t hesitate to let us know!', 1618402959, 0, 'A', 1, 0, 0, 0),
(13, 1, 0, 'Major Tom', NULL, NULL, 'Very good quality.', 5, '7f000001', 'N', 1484308740, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(14, 23, 0, 'Sophie', '+ High frequencies are great\r\n+ The surround sound is awesome', '- Mid-range could be a bit clearer\r\n- Lacks lower frequencies', ' Purchased this for my home theater. I am a bit wary when it comes to 5.1 Channel systems, but decided to give it a try. The sound is nice, although the mid-range could have been a bit clearer. The system definitely lacks the low frequencies, so I am currently in search for a good sub-woofer. The high frequencies are crystal clear, though, and the surround sound simply blows you away. I wouldn''t recommend this to everyone, but it definitely is quite a good product in its segment, although not perfect. ', 3, '7f000001', 'N', 1383914425, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(15, 8, 0, 'Jeniffer', NULL, NULL, 'Good picture quality for a LED-based LCD, with relatively deep levels in dark scenes, as well as good white balance in the bright ones. It includes built-in Wi-Fi, 3D with a pair of glasses, and many other cool features.  Overall it''s quite good, although the picture sometimes loses fidelity from off-angle in dark scenes. ', 4, '7f000001', 'N', 1383914502, '', '', 0, NULL, 0, 3, 'A', 1, 1, 3, 0),
(16, 172, 0, 'Alex', NULL, NULL, 'I was looking for a handy and easy-to-use camcorder when I came across this little bird, and I have to say — it really does everything perfectly! Whether you just want to catch some memory in a form of a video, or plan to do a full video project — this camcorder will become your best friend! All the necessary features are present and easily adjustable. I didn''t come across any problem using this amazing piece of technology. Definitely worth its money! ', 4, '7f000001', 'N', 1383914559, '', '', 0, NULL, 0, 2, 'A', 1, 0, 2, 0),
(17, 238, 0, 'George', '+ Simple and stylish', '- Software updates and features get too complicated at times', 'A good and reliable phone is a necessity for a person like me, that''s why I decided to choose iPhone. Apple is a remarkable company, and it is always at pace with time, forward-thinking and innovative. The iPhone is clear-cut, easy-to-use and definitely the most stylish phone on the market now. I enjoy it, although I sometimes experience troubles with software & maintenance, and there phone is literally crammed with a lot of features I never use. I would recommend this mostly to younger generation, whereas people of my age might find it a bit bewildering at first. ', 4, '7f000001', 'N', 1383914632, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(18, 167, 0, 'Melissa', NULL, NULL, 'I was hesitant to choose between Nikon and Canon at first, but when I had a chance to compare the 2 similar models of the 2 competing giants, I chose Nikon. It just feels right, you know. The colors, the matrix, the interface — everything about this product is just beyond expectations! I''ve already made a portfolio with the help of it. Simply perfect! ', 5, '7f000001', 'N', 1383914678, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(19, 239, 0, 'John', 'It''s still good', 'Changes are few and far between', 'I’ve been using an iPhone 5 daily for the past year, and the iPhone 5s seems to feel exactly the same: the same curved edges, same dimensions, same everything. It''s only an updated Home button and the new camera flash which make you realize that this is not an iPhone 5.  Many people think that releasing the same design twice is bad, and there are others who realize that sometimes there''s no need for change. Apple might want to understand that the competition is strong, and it needs to stay relevant. ', 3, '7f000001', 'N', 1383914729, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(20, 150, 0, 'Julia', NULL, NULL, 'Got this bike with a discount, a really affordable option for most people out there. I got almost 100 miles on it, no problems so far. Don’t forget to clean it after every ride.', 5, '7f000001', 'N', 1484901840, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(21, 150, 0, 'Steve', '+ Price\r\n+ It worked for me... in a city.', '- It didn''t work for me when I went cross-country.', 'I know it’s not an MTB, but I used it for some hardcore cross-country riding! Had to replace almost half of the parts after the first two rides, they just won’t do at all. Can''t blame the manufacturer or the store for it though. So, if you''re looking for a city bike, this may as well be a good choice.', 4, '7f000001', 'N', 1484901900, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(22, 150, 0, 'Rosa', '', '', 'I wish it had a softer seat… Besides that, I use it for short park riding, and it provides a very smooth riding experience.', 3, '7f000001', 'N', 1484901900, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(23, 244, 0, 'Jack', '+ A big touch screen', '- May have to upgrade soon', 'I was looking for an all-in-one PC for my kid (he’s 9) and of course, my first choice was an iMac. But after consulting with the manager I realized that after a few years iMac will become obsolete and I’ll have to buy a new one. I’m not used to wasting money, so I asked for alternatives. And the manager showed me this thing. He said that for now, it will cover all needs of my son both in games and education. I got extended support so after 2 years I’ll be able to upgrade it to better specs.\r\n\r\nBTW, my son loves it. A big touch screen makes him really happy!', 3, '7f000001', 'N', 1484899800, '', '', 0, NULL, 0, 4, 'A', 1, 1, 6, 2),
(24, 244, 0, 'Tarina', NULL, NULL, 'Got a bunch of these for a private school classroom, they look easy enough both for users and engineers that will tinker with them.', 5, '7f000001', 'N', 1484899920, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(25, 244, 0, 'Frank', 'A bang for the buck', '', 'This thing is a bang for the buck. Bought it a while back, there was some minor problem, but the store agreed to fix the problem and offered compensation. Then I bought a more powerful CPU and more RAM for this thing.After the upgrade, it’s an iMac killer. For less than half the price.', 5, '7f000001', 'N', 1484899980, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(26, 245, 0, 'Mary', NULL, NULL, 'My first phone ever! My dad bought it for me for my tenth birthday, I love it!', 5, '7f000001', 'N', 1484900640, '', '', 0, NULL, 0, 4, 'A', 1, 1, 4, 0),
(27, 245, 0, 'Doug', '+ Easy to learn\r\n+ Affordable price', '', 'Bought it for my mother, she’s not used to phones with a touch screen so that’s her first experience. She’s very happy that we can make video calls through facetime and be in touch with each other every day. She listens to her fav music every day while reading books, she also has a small flower garden and likes to send everyone photos of her flowers, good that photos she takes are crisp, sharp, and vibrant.\r\n\r\nI think I wrote too many words already so let me cut it short: it’s a great starter phone for children or elders.', 4, '7f000001', 'N', 1484900700, '', '', 0, NULL, 0, 2, 'A', 1, 1, 3, 1),
(28, 245, 0, 'Flynn', NULL, NULL, 'Got it as a second phone, thank heavens that it has the same specs as iPhone 5 but in a cheaper plastic case. It also has all functions of the latter, no cut corners or anything. Good thing that Apple knows its job.', 5, '7f000001', 'N', 1484900700, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(29, 148, 0, 'Sam', NULL, NULL, 'This thing is the stuff of legends. If you are an audiophile like me, take it without question. You can listen to lossless music AND browse the web at the same time on the same device, fantastic!', 5, '7f000001', 'N', 1484306940, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(30, 148, 0, 'Joe', NULL, NULL, 'I don’t really need an overly functional super-duper music player that can brew me a coffee, I needed a replacement for my broken iPod. And this player handled that job really well. One extra pro is the fact that you don’t have to use pesky iTunes every time you connect the player.', 5, '7f000001', 'N', 1484307000, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(31, 148, 0, 'Nancy', NULL, NULL, 'A big screen is good and all, and I love to watch movies on it, but where are the buttons?', 3, '7f000001', 'N', 1484307000, '', '', 0, NULL, 0, 4, 'A', 1, 1, 6, 2),
(32, 149, 0, 'Catherine', NULL, NULL, 'An undying classic with new features. iPod killer. One word: superb!', 5, '7f000001', 'N', 1484307300, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(33, 149, 0, 'Phillip', NULL, NULL, 'Nice little player, my first player ever. Headphones that were in the box are nothing special though, bring some good ones. Built-in EQ is doing miracles to sound!', 4, '7f000001', 'N', 1484307300, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(34, 149, 0, 'Nancy', NULL, NULL, 'Oh, buttons! Here I go, instant buy!', 5, '7f000001', 'N', 1484307360, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(35, 246, 0, 'Mark', NULL, NULL, 'I received it as a present from my friends. I’m a lover of extreme activities and I also love to record my activities and share it with friends, family, and other people interested in all things extreme. My previous camera, the original Hero, was good enough, but my friends just thought that I may want to try this new Hero3+. It comes with a waterproof case so splashes and waves are not a problem. It also records video in 1080p with 50 frames per second which is a major improvement for me.', 5, '7f000001', 'N', 1484307720, '', '', 0, NULL, 0, 0, 'A', 1, 1, 2, 0),
(36, 246, 0, 'Jessica', NULL, NULL, 'We (me and my hubby) bought this camera for our trip to Italy. The videos we took on that trip were as sharp as photos! We tried to visit all the popular places in Italy and thanks to the quality of videos we can refresh our good memories as much as we want to!', 5, '7f000001', 'N', 1484307720, '', '', 0, NULL, 0, 2, 'A', 1, 1, 3, 1),
(37, 246, 0, 'Robert', '', '', 'It was a good camera… Unfortunately, now it’s lying at the bottom of the Adriatic. I’ll buy a new one soon and will be more careful next time.', 5, '7f000001', 'N', 1484307780, '', '', 1, 'Sorry to hear about that! We can offer you a small discount as consolation. We''ll reach out to you and let you know how you can claim it ;-)', 1618477438, 0, 'A', 1, 0, 0, 0),
(38, 247, 0, 'James', NULL, NULL, 'I would never anticipate that Nokia will make an android tablet one day. But they did.\r\nI bought it, tried it, it’s a typical 8-inch android tablet with a square-ish aspect ratio. Don’t expect miracles from it, it will deliver none. Specs are OK, the software is a bit of a different story though. After a month of use, it became a bit sluggish, and I had to install a cleaner app. I think Nokia can do better than that.', 3, '7f000001', 'N', 1484308980, '', '', 0, NULL, 0, 2, 'A', 1, 1, 4, 2),
(39, 247, 0, 'Jeremy', NULL, NULL, 'I left it on the driver seat of my car and accidentally sat on it. It broke in half and the service center refused to exchange it for a new one, telling me something about a “non-warranty case.” I’ll stick to a notebook and pen until they begin to manufacture something sturdier.', 2, '7f000001', 'N', 1484308980, '', '', 0, NULL, 0, 6, 'A', 1, 1, 6, 0),
(40, 247, 0, 'Richard', '+ Camera', '- Battery life\r\n- Performance', 'I already had an old iPad when I decided to get this. Interesting at first, it became clear that this tablet is in some areas not as good as an iPad. I’m talking about battery life, the responsiveness of user interface, and performance in the apps and games. One thing it excels over the iPad is the camera, it’s much better than on iPad. My personal score for this tablet is 6/10. Good for those who never had a tablet or iPad before, not so much for everyone else.', 3, '7f000001', 'N', 1484309040, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(41, 248, 0, 'Hugh', '+ Nice controller', '- Takes some time to get used to', 'Never had a game console before (not talking about old handheld ones, another story), this is a totally new experience for me. I was mesmerized by the abundance of various games of all types of genres, some of them look more like interactive movies than something made from polygons and textures. Some games require you to stand up and move your body, something I was not expecting and was very excited about. The Xbox controller is very nice, grippy, with adjustable rumbling levels. Controls are something to get used to though.\r\n\r\nOverall, I think I will recommend this console to my friends who still don’t have one or who have another one from Sony. Very joyful pastime.', 5, '7f000001', 'N', 1484309340, '', '', 0, NULL, 0, 5, 'A', 1, 1, 5, 0),
(42, 248, 0, 'Lisbeth', NULL, NULL, 'I got this for my twin sons so they could stop fighting each other and learn how to compete in peaceful, positive ways. The problem of violence has gone away, but now there’s another one. They spend all day long playing games. I can only hope they’ll get tired of it someday.', 4, '7f000001', 'N', 1484309400, '', '', 0, NULL, 0, 3, 'A', 1, 1, 4, 1),
(43, 248, 0, 'Bill', '+ Nice graphics and optimization', '- Controllers in general aren''t the most suitable for shooters', 'I have a PC already, got this to play some Xbox exclusives that didn’t come out yet on PC. I’m very satisfied with the optimization and graphics, less so with controls. Seriously, after a keyboard and mouse, how can a controller compare to them? Despite that, I really like to play low to mid active games, it’s very relaxing. But for real action gaming, you definitely need a PC.', 4, '7f000001', 'N', 1484309400, '', '', 1, 'Thank you for sharing your experience! X-Box One does support keyboard and mouse. Of course, the drawback is that you can''t play from the couch with them :(', 1618476542, 0, 'A', 1, 0, 0, 0),
(44, 241, 0, 'Jeremy', '+ Battery capacity\r\n+ Graphics and performance', '', 'I have an iPad Air 2 for work, and now I bought this one for personal use. I’m amazed by the battery life compared to all the other iPads in the past. I can play an online game on it for 7-8 hours and still have 15-20% battery life whereas Air 2 would be dead in under 2 hours. The ability to use a PS4 or Xbox1 controller with it is a plus also. The graphics are truly amazing, and the sound is great just like previous versions of the iPad. I got the 32 GB model, and I am very happy with the price for what I have. I highly recommend this product.', 5, '7f000001', 'N', 1484309460, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(45, 241, 0, 'Tom', NULL, NULL, 'This is a perfect media consumption device. It has a great screen, speakers and excellent battery life. I think for the price this is hands down the tablet to beat. Even if you are not an Apple or iOS fan there is not much in the market that can compete with this for the price.', 5, '7f000001', 'N', 1484309520, '', '', 0, NULL, 0, 4, 'A', 1, 1, 6, 2),
(46, 241, 0, 'Sarah', '+ Convenient for taking notes with a pen\r\n+ Big screen for watching videos', '', 'This was the first iPad I have ever purchased so I have to admit, I was scared when I bought it. I purchased this during Black Friday as a way for me to take notes in my college classes. I had been looking at reviews and watching videos for a while before I decided to go with this 7th generation iPad.\r\n\r\nI have been using it for a few weeks now and truthfully, this was definitely a great purchase! I enjoy taking notes on this, watching videos, and etc. The camera, sound, battery life, and compatibility with the pen is beyond amazing. And everything from the description, such as the lightning to USB cable and the USB power adapter came with it inside the box.\r\n\r\nDefinitely worth the price!', 5, '7f000001', 'N', 1484309520, '', '', 0, NULL, 0, 4, 'A', 1, 1, 5, 2),
(47, 280, 0, 'John', 'A very good fit', '', 'Ordering clothes online is a gamble: you never know whether or not it will fit, even if you know the size. The manager promised that if it didn''t fit, I could return this T-shirt and get something else instead. However, I didn''t need to! Here, take a look.', 5, '7f000001', 'N', 1618485377, '', '', 0, NULL, 0, 0, 'A', 1, 0, 0, 0),
(48, 282, 0, '', '', '', 'I''m not satisfied with the quality!', 2, '7f000001', 'N', 1618485542, '', '', 1, 'We are sorry to hear that! Could you tell us more? Just send us a message at sales@example.com, and we''ll see what we can do about it.', 1618485673, 0, 'A', 1, 0, 0, 0),
(49, 282, 0, 'Jane', '', '', 'Unlike that other negative review, I have nothing but the best to say about this T-shirt. My husband has this model in different colors, all ordered from this store. Not once has there been any problem, and we even got a discount for bulk order once. To prove my words, here are some photos.', 5, '7f000001', 'N', 1618486566, '', '', 1, 'Thank you for your support, Jane! Happy to be of service.', 1618556577, 0, 'A', 1, 0, 0, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_review_prepared_data`
--

CREATE TABLE `[[dbprefix]]product_review_prepared_data` (
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `average_rating` decimal(4,2) DEFAULT NULL,
  `reviews_count` mediumint(8) unsigned DEFAULT '0',
  PRIMARY KEY (`product_id`,`storefront_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_review_prepared_data`
--

INSERT INTO `[[dbprefix]]product_review_prepared_data` VALUES
(228, 0, '3.00', 2),
(228, 1, '3.00', 2),
(242, 0, '3.50', 2),
(242, 1, '3.50', 2),
(78, 0, '4.00', 1),
(78, 1, '4.00', 1),
(224, 0, '4.50', 2),
(224, 1, '4.50', 2),
(5, 0, '3.67', 3),
(5, 1, '3.67', 3),
(1, 0, '4.00', 3),
(1, 1, '4.00', 3),
(23, 0, '3.00', 1),
(23, 1, '3.00', 1),
(8, 0, '4.00', 1),
(8, 1, '4.00', 1),
(172, 0, '4.00', 1),
(172, 1, '4.00', 1),
(238, 0, '4.00', 1),
(238, 1, '4.00', 1),
(167, 0, '5.00', 1),
(167, 1, '5.00', 1),
(239, 0, '3.00', 1),
(239, 1, '3.00', 1),
(150, 0, '4.00', 3),
(150, 1, '4.00', 3),
(244, 0, '4.33', 3),
(244, 1, '4.33', 3),
(245, 0, '4.67', 3),
(245, 1, '4.67', 3),
(148, 0, '4.33', 3),
(148, 1, '4.33', 3),
(149, 0, '4.67', 3),
(149, 1, '4.67', 3),
(246, 0, '5.00', 3),
(246, 1, '5.00', 3),
(247, 0, '2.67', 3),
(247, 1, '2.67', 3),
(248, 0, '4.33', 3),
(248, 1, '4.33', 3),
(241, 0, '5.00', 3),
(241, 1, '5.00', 3),
(280, 0, '5.00', 1),
(280, 1, '5.00', 1),
(281, 0, '5.00', 1),
(281, 1, '5.00', 1),
(282, 0, '3.50', 2),
(282, 1, '3.50', 2),
(283, 0, '3.50', 2),
(283, 1, '3.50', 2),
(284, 0, '3.50', 2),
(284, 1, '3.50', 2);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_review_votes`
--

CREATE TABLE `[[dbprefix]]product_review_votes` (
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `product_review_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `value` int(2) NOT NULL DEFAULT '0',
  `ip_address` varbinary(40) NOT NULL DEFAULT '',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`user_id`,`product_review_id`,`ip_address`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_review_votes`
--

INSERT INTO `[[dbprefix]]product_review_votes` VALUES
(0, 45, 1, '7f000001', 1619767824),
(0, 45, 1, '7f000002', 1619767824),
(0, 45, 1, '7f000003', 1619767824),
(0, 45, 1, '7f000004', 1619767824),
(0, 45, 1, '7f000005', 1619767824),
(0, 45, 1, '7f000006', 1619767824),
(0, 45, -1, '7f000007', 1619767824),
(0, 45, -1, '7f000008', 1619767824),
(0, 46, 1, '7f000009', 1619767824),
(0, 46, 1, '7f00000a', 1619767824),
(0, 46, 1, '7f00000b', 1619767824),
(0, 46, 1, '7f00000c', 1619767824),
(0, 46, 1, '7f00000d', 1619767824),
(0, 46, -1, '7f00000e', 1619767824),
(0, 23, 1, '7f00000f', 1619767824),
(0, 23, 1, '7f000010', 1619767824),
(0, 23, 1, '7f000011', 1619767824),
(0, 23, 1, '7f000012', 1619767824),
(0, 23, 1, '7f000013', 1619767824),
(0, 23, -1, '7f000014', 1619767824),
(0, 23, -1, '7f000015', 1619767824),
(0, 23, 1, '7f000016', 1619767824),
(0, 26, 1, '7f000017', 1619767824),
(0, 26, 1, '7f000018', 1619767824),
(0, 26, 1, '7f000019', 1619767824),
(0, 26, 1, '7f00001a', 1619767824),
(0, 27, 1, '7f00001b', 1619767824),
(0, 27, 1, '7f00001c', 1619767824),
(0, 27, 1, '7f00001d', 1619767824),
(0, 27, -1, '7f00001e', 1619767824),
(0, 35, 1, '7f00001f', 1619767824),
(0, 35, 1, '7f000020', 1619767824),
(0, 36, 1, '7f000021', 1619767824),
(0, 36, 1, '7f000022', 1619767824),
(0, 36, 1, '7f000023', 1619767824),
(0, 36, -1, '7f000024', 1619767824),
(0, 38, 1, '7f000025', 1619767824),
(0, 38, 1, '7f000026', 1619767824),
(0, 39, 1, '7f000027', 1619767824),
(0, 39, 1, '7f000028', 1619767824),
(0, 39, 1, '7f000029', 1619767824),
(0, 39, 1, '7f00002a', 1619767824),
(0, 39, 1, '7f00002b', 1619767824),
(0, 39, 1, '7f00002c', 1619767824),
(0, 41, 1, '7f00002d', 1619767824),
(0, 41, 1, '7f00002e', 1619767824),
(0, 41, 1, '7f00002f', 1619767824),
(0, 41, 1, '7f000030', 1619767824),
(0, 41, 1, '7f000031', 1619767824),
(0, 42, 1, '7f000032', 1619767824),
(0, 42, 1, '7f000033', 1619767824),
(0, 42, 1, '7f000034', 1619767824),
(0, 42, -1, '7f000035', 1619767824),
(0, 42, 1, '7f000036', 1619767824),
(0, 31, 1, '7f000037', 1619767824),
(0, 31, 1, '7f000038', 1619767824),
(0, 31, 1, '7f000039', 1619767824),
(0, 31, 1, '7f00003a', 1619767824),
(0, 31, 1, '7f00003b', 1619767824),
(0, 8, 1, '7f00003c', 1619767824),
(0, 8, 1, '7f00003d', 1619767824),
(0, 11, 1, '7f00003e', 1619767824),
(0, 11, 1, '7f00003f', 1619767824),
(0, 11, 1, '7f000040', 1619767824),
(0, 11, 1, '7f000041', 1619767824),
(0, 11, -1, '7f000042', 1619767824),
(0, 15, 1, '7f000043', 1619767824),
(0, 15, 1, '7f000044', 1619767824),
(0, 15, 1, '7f000045', 1619767824),
(0, 16, 1, '7f000046', 1619767824),
(0, 16, 1, '7f000047', 1619767824),
(0, 1, 1, '7f000048', 1619767824),
(0, 1, -1, '7f000049', 1619767824),
(0, 1, -1, '7f00004a', 1619767824),
(0, 1, -1, '7f00004b', 1619767824),
(0, 1, -1, '7f00004c', 1619767824),
(0, 2, -1, '7f00004d', 1619767824),
(0, 2, -1, '7f00004e', 1619767824),
(0, 2, -1, '7f00004f', 1619767824),
(0, 4, 1, '7f000050', 1619767824),
(0, 4, -1, '7f000051', 1619767824),
(0, 4, -1, '7f000052', 1619767824),
(0, 10, 1, '7f000053', 1619767824),
(0, 10, 1, '7f000054', 1619767824),
(0, 10, -1, '7f000055', 1619767824),
(0, 10, -1, '7f000056', 1619767824),
(0, 10, -1, '7f000057', 1619767824),
(0, 10, -1, '7f000058', 1619767824),
(0, 31, 1, '7f000059', 1619767824),
(0, 31, -1, '7f00005a', 1619767824),
(0, 31, -1, '7f00005b', 1619767824),
(0, 38, 1, '7f00005c', 1619767824),
(0, 38, -1, '7f00005d', 1619767824),
(0, 38, -1, '7f00005e', 1619767824),
(0, 38, 1, '7f00005f', 1619767824);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_sales`
--

CREATE TABLE `[[dbprefix]]product_sales` (
  `category_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `amount` mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`category_id`,`product_id`),
  KEY `pa` (`product_id`,`amount`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_sales`
--

INSERT INTO `[[dbprefix]]product_sales` VALUES
(221, 44, 1),
(221, 45, 1),
(221, 46, 1),
(236, 67, 0),
(236, 68, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_subscriptions`
--

CREATE TABLE `[[dbprefix]]product_subscriptions` (
  `subscription_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `email` varchar(128) NOT NULL DEFAULT '',
  `company_id` int(11) unsigned DEFAULT NULL,
  PRIMARY KEY (`subscription_id`),
  UNIQUE KEY `pec` (`product_id`,`email`,`company_id`),
  KEY `pd` (`product_id`,`user_id`,`email`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_tabs`
--

CREATE TABLE `[[dbprefix]]product_tabs` (
  `tab_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `tab_type` char(1) NOT NULL DEFAULT 'B',
  `block_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `template` varchar(255) NOT NULL DEFAULT '',
  `addon` varchar(32) NOT NULL DEFAULT '',
  `position` int(11) NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'A',
  `is_primary` char(1) NOT NULL DEFAULT 'N',
  `product_ids` text,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `show_in_popup` char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (`tab_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=11 ;

--
-- Dumping data for table `[[dbprefix]]product_tabs`
--

INSERT INTO `[[dbprefix]]product_tabs` VALUES
(1, 'T', 0, 'blocks/product_tabs/description.tpl', '', 1, 'A', 'Y', NULL, 1, 'N'),
(2, 'T', 0, 'blocks/product_tabs/features.tpl', '', 2, 'A', 'Y', NULL, 1, 'N'),
(3, 'T', 0, 'blocks/product_tabs/files.tpl', '', 3, 'A', 'Y', NULL, 1, 'N'),
(4, 'T', 0, 'addons/tags/blocks/product_tabs/tags.tpl', 'tags', 4, 'A', 'Y', NULL, 1, 'N'),
(5, 'T', 0, 'addons/attachments/blocks/product_tabs/attachments.tpl', 'attachments', 5, 'A', 'Y', NULL, 1, 'N'),
(6, 'B', 52, '', 'product_variations', 6, 'A', 'N', NULL, 1, 'Y'),
(7, 'B', 53, 'addons/product_bundles/blocks/product_bundles.tpl', 'product_bundles', 7, 'A', 'N', NULL, 1, 'N'),
(8, 'T', 0, 'addons/discussion/blocks/product_tabs/discussion.tpl', 'discussion', 8, 'A', 'Y', NULL, 1, 'N'),
(9, 'T', 0, 'addons/product_reviews/blocks/product_tabs/product_reviews.tpl', 'product_reviews', 9, 'A', 'Y', NULL, 1, 'N'),
(10, 'T', 0, 'addons/required_products/blocks/product_tabs/required_products.tpl', 'required_products', 10, 'A', 'Y', NULL, 1, 'N');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_tabs_descriptions`
--

CREATE TABLE `[[dbprefix]]product_tabs_descriptions` (
  `tab_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `name` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`tab_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_tabs_descriptions`
--

INSERT INTO `[[dbprefix]]product_tabs_descriptions` VALUES
(1, 'en', 'Description'),
(2, 'en', 'Features'),
(3, 'en', 'Files'),
(4, 'en', 'Tags'),
(5, 'en', 'Attachments'),
(6, 'en', 'View all variations as list'),
(7, 'en', 'Bundles with this product'),
(8, 'en', 'Reviews'),
(9, 'en', 'Reviews'),
(10, 'en', 'Required products');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_variation_data_identity_map`
--

CREATE TABLE `[[dbprefix]]product_variation_data_identity_map` (
  `table_id` varchar(32) NOT NULL DEFAULT '',
  `id` varchar(64) NOT NULL DEFAULT '',
  `parent_id` varchar(64) NOT NULL DEFAULT '',
  `product_id` mediumint(8) unsigned NOT NULL,
  PRIMARY KEY (`table_id`,`id`,`parent_id`),
  KEY `idx_product_id` (`product_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_variation_groups`
--

CREATE TABLE `[[dbprefix]]product_variation_groups` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `code` varchar(128) DEFAULT NULL,
  `created_at` int(11) unsigned NOT NULL DEFAULT '0',
  `updated_at` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE KEY `idx_group_code` (`code`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=11 ;

--
-- Dumping data for table `[[dbprefix]]product_variation_groups`
--

INSERT INTO `[[dbprefix]]product_variation_groups` VALUES
(10, 'PV-27186628F', 1545294915, 1545294915);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_variation_group_features`
--

CREATE TABLE `[[dbprefix]]product_variation_group_features` (
  `feature_id` mediumint(8) unsigned NOT NULL,
  `purpose` varchar(32) NOT NULL,
  `group_id` mediumint(8) unsigned NOT NULL,
  PRIMARY KEY (`feature_id`,`group_id`),
  KEY `idx_group_id` (`group_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_variation_group_features`
--

INSERT INTO `[[dbprefix]]product_variation_group_features` VALUES
(548, 'group_variation_catalog_item', 10),
(549, 'group_catalog_item', 10);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]product_variation_group_products`
--

CREATE TABLE `[[dbprefix]]product_variation_group_products` (
  `product_id` mediumint(8) unsigned NOT NULL,
  `parent_product_id` mediumint(8) unsigned NOT NULL,
  `group_id` mediumint(8) unsigned NOT NULL,
  PRIMARY KEY (`product_id`,`group_id`),
  KEY `idx_group_id` (`group_id`),
  KEY `idx_parent_product_id` (`parent_product_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]product_variation_group_products`
--

INSERT INTO `[[dbprefix]]product_variation_group_products` VALUES
(278, 0, 10),
(279, 278, 10),
(280, 0, 10),
(281, 280, 10),
(282, 0, 10),
(284, 282, 10),
(283, 282, 10);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]profile_fields`
--

CREATE TABLE `[[dbprefix]]profile_fields` (
  `field_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `field_name` varchar(32) NOT NULL DEFAULT '',
  `profile_show` char(1) DEFAULT 'N',
  `profile_required` char(1) DEFAULT 'N',
  `checkout_show` char(1) DEFAULT 'N',
  `checkout_required` char(1) DEFAULT 'N',
  `partner_show` char(1) DEFAULT 'N',
  `partner_required` char(1) DEFAULT 'N',
  `storefront_show` char(1) DEFAULT 'Y',
  `field_type` char(1) NOT NULL DEFAULT 'I',
  `profile_type` char(1) NOT NULL DEFAULT 'U',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `is_default` char(1) DEFAULT 'N',
  `section` char(1) DEFAULT 'C',
  `matching_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `class` varchar(100) NOT NULL DEFAULT '',
  `wrapper_class` varchar(100) NOT NULL DEFAULT '',
  `autocomplete_type` varchar(100) NOT NULL DEFAULT '',
  PRIMARY KEY (`field_id`),
  KEY `field_name` (`field_name`),
  KEY `checkout_show` (`checkout_show`,`field_type`),
  KEY `profile_show` (`profile_show`,`field_type`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=36 ;

--
-- Dumping data for table `[[dbprefix]]profile_fields`
--

INSERT INTO `[[dbprefix]]profile_fields` VALUES
(6, 'firstname', 'Y', 'N', 'Y', 'N', 'N', 'N', 'Y', 'I', 'U', 10, 'Y', 'C', 0, 'first-name', '', 'given-name'),
(7, 'lastname', 'Y', 'N', 'Y', 'N', 'N', 'N', 'Y', 'I', 'U', 20, 'Y', 'C', 0, 'last-name', '', 'surname'),
(8, 'company', 'N', 'N', 'N', 'N', 'N', 'N', 'Y', 'I', 'U', 30, 'Y', 'C', 0, 'company', '', 'organization'),
(9, 'phone', 'Y', 'N', 'Y', 'N', 'N', 'N', 'Y', 'P', 'U', 40, 'Y', 'C', 0, 'phone', '', 'tel'),
(32, 'email', 'Y', 'Y', 'Y', 'Y', 'Y', 'Y', 'Y', 'E', 'U', 50, 'Y', 'C', 0, 'litecheckout__field--full', '', 'off'),
(14, 'b_firstname', 'N', 'N', 'Y', 'N', 'N', 'N', 'Y', 'I', 'U', 10, 'Y', 'B', 15, 'billing-first-name', '', 'given-name'),
(16, 'b_lastname', 'N', 'N', 'Y', 'N', 'N', 'N', 'Y', 'I', 'U', 20, 'Y', 'B', 17, 'billing-last-name', '', 'surname'),
(18, 'b_address', 'N', 'N', 'Y', 'N', 'N', 'N', 'Y', 'I', 'U', 30, 'Y', 'B', 19, 'billing-address', 'litecheckout__field--xlarge', 'street-address'),
(20, 'b_address_2', 'N', 'N', 'N', 'N', 'N', 'N', 'Y', 'I', 'U', 40, 'Y', 'B', 21, 'billing-address-line2', '', 'address-line2'),
(22, 'b_city', 'N', 'N', 'Y', 'N', 'N', 'N', 'Y', 'I', 'U', 50, 'Y', 'B', 23, 'billing-city', '', 'city'),
(24, 'b_state', 'N', 'N', 'Y', 'N', 'N', 'N', 'Y', 'A', 'U', 70, 'Y', 'B', 25, 'billing-state', '', 'state'),
(26, 'b_country', 'N', 'N', 'Y', 'N', 'N', 'N', 'Y', 'O', 'U', 60, 'Y', 'B', 27, 'billing-country', '', 'country'),
(28, 'b_zipcode', 'N', 'N', 'Y', 'N', 'N', 'N', 'Y', 'Z', 'U', 80, 'Y', 'B', 29, 'billing-zip-code', 'litecheckout__field--xsmall', 'postal-code'),
(30, 'b_phone', 'N', 'N', 'Y', 'N', 'N', 'N', 'Y', 'P', 'U', 90, 'Y', 'B', 31, 'billing-phone', '', 'tel'),
(15, 's_firstname', 'N', 'N', 'N', 'N', 'N', 'N', 'Y', 'I', 'U', 10, 'Y', 'S', 14, 'shipping-first-name', '', 'given-name'),
(17, 's_lastname', 'N', 'N', 'N', 'N', 'N', 'N', 'Y', 'I', 'U', 20, 'Y', 'S', 16, 'shipping-last-name', '', 'surname'),
(19, 's_address', 'Y', 'N', 'Y', 'Y', 'N', 'N', 'Y', 'I', 'U', 30, 'Y', 'S', 18, 'shipping-address', 'litecheckout__field--xlarge', 'shipping street-address'),
(21, 's_address_2', 'N', 'N', 'N', 'N', 'N', 'N', 'Y', 'I', 'U', 40, 'Y', 'S', 20, 'shipping-address-line2', '', 'address-line2'),
(23, 's_city', 'Y', 'N', 'Y', 'Y', 'N', 'N', 'Y', 'I', 'U', 50, 'Y', 'S', 22, 'shipping-city', '', 'city'),
(27, 's_country', 'Y', 'N', 'Y', 'Y', 'N', 'N', 'Y', 'O', 'U', 60, 'Y', 'S', 26, 'shipping-country', '', 'country'),
(25, 's_state', 'Y', 'N', 'Y', 'Y', 'N', 'N', 'Y', 'A', 'U', 70, 'Y', 'S', 24, 'shipping-state', '', 'state'),
(29, 's_zipcode', 'Y', 'N', 'Y', 'Y', 'N', 'N', 'Y', 'Z', 'U', 80, 'Y', 'S', 28, 'shipping-zip-code', 'litecheckout__field--xsmall', 'shipping postal-code'),
(31, 's_phone', 'N', 'N', 'N', 'N', 'N', 'N', 'Y', 'P', 'U', 90, 'Y', 'S', 30, 'shipping-phone', '', 'tel'),
(35, 's_address_type', 'N', 'N', 'N', 'N', 'N', 'N', 'Y', 'N', 'U', 100, 'Y', 'S', 34, 'shipping-address-type', '', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]profile_fields_data`
--

CREATE TABLE `[[dbprefix]]profile_fields_data` (
  `object_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `object_type` char(1) NOT NULL DEFAULT 'U',
  `field_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `value` varchar(255) NOT NULL DEFAULT '0',
  PRIMARY KEY (`object_id`,`object_type`,`field_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]profile_field_descriptions`
--

CREATE TABLE `[[dbprefix]]profile_field_descriptions` (
  `object_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `description` varchar(255) NOT NULL DEFAULT '',
  `object_type` char(1) NOT NULL DEFAULT 'F',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`object_id`,`object_type`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]profile_field_descriptions`
--

INSERT INTO `[[dbprefix]]profile_field_descriptions` VALUES
(6, 'First name', 'F', 'en'),
(7, 'Last name', 'F', 'en'),
(8, 'Company', 'F', 'en'),
(32, 'E-mail', 'F', 'en'),
(9, 'Phone', 'F', 'en'),
(14, 'First name', 'F', 'en'),
(15, 'First name', 'F', 'en'),
(16, 'Last name', 'F', 'en'),
(17, 'Last name', 'F', 'en'),
(18, 'Address', 'F', 'en'),
(20, 'Address', 'F', 'en'),
(19, 'Address', 'F', 'en'),
(21, 'Address', 'F', 'en'),
(22, 'City', 'F', 'en'),
(23, 'City', 'F', 'en'),
(24, 'State/province', 'F', 'en'),
(25, 'State/province', 'F', 'en'),
(26, 'Country', 'F', 'en'),
(27, 'Country', 'F', 'en'),
(28, 'Zip/postal code', 'F', 'en'),
(29, 'Zip/postal code', 'F', 'en'),
(30, 'Phone', 'F', 'en'),
(31, 'Phone', 'F', 'en'),
(35, 'Address type', 'F', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]profile_field_sections`
--

CREATE TABLE `[[dbprefix]]profile_field_sections` (
  `section_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `code` char(1) NOT NULL,
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`section_id`),
  UNIQUE KEY `code` (`code`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=4 ;

--
-- Dumping data for table `[[dbprefix]]profile_field_sections`
--

INSERT INTO `[[dbprefix]]profile_field_sections` VALUES
(1, 'C', 2, 'A'),
(2, 'S', 1, 'A'),
(3, 'B', 3, 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]profile_field_values`
--

CREATE TABLE `[[dbprefix]]profile_field_values` (
  `value_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `field_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`value_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]promotions`
--

CREATE TABLE `[[dbprefix]]promotions` (
  `promotion_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `conditions` text,
  `bonuses` text,
  `to_date` int(11) unsigned NOT NULL DEFAULT '0',
  `from_date` int(11) unsigned NOT NULL DEFAULT '0',
  `priority` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `stop` char(1) NOT NULL DEFAULT 'N',
  `stop_other_rules` char(1) NOT NULL DEFAULT 'N',
  `zone` enum('cart','catalog') NOT NULL DEFAULT 'catalog',
  `conditions_hash` text,
  `status` char(1) NOT NULL DEFAULT 'A',
  `number_of_usages` mediumint(8) NOT NULL DEFAULT '0',
  `users_conditions_hash` text,
  PRIMARY KEY (`promotion_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=28 ;

--
-- Dumping data for table `[[dbprefix]]promotions`
--

INSERT INTO `[[dbprefix]]promotions` VALUES
(14, 1, 'a:3:{s:3:"set";s:3:"all";s:9:"set_value";s:1:"1";s:10:"conditions";a:1:{i:1;a:3:{s:8:"operator";s:2:"in";s:9:"condition";s:10:"categories";s:5:"value";s:3:"243";}}}', 'a:1:{i:1;a:3:{s:5:"bonus";s:16:"product_discount";s:14:"discount_bonus";s:13:"to_percentage";s:14:"discount_value";s:2:"95";}}', 1419451199, 1411502400, 0, 'N', 'N', 'catalog', 'categories=243', 'A', 3, ''),
(24, 1, 'a:3:{s:3:"set";s:3:"all";s:9:"set_value";s:1:"1";s:10:"conditions";a:2:{i:1;a:3:{s:8:"operator";s:3:"gte";s:9:"condition";s:8:"subtotal";s:5:"value";d:100;}i:2;a:3:{s:8:"operator";s:2:"eq";s:9:"condition";s:11:"coupon_code";s:5:"value";s:3:"123";}}}', 'a:1:{i:1;a:2:{s:5:"bonus";s:13:"free_shipping";s:5:"value";s:1:"1";}}', 0, 0, 1, 'N', 'N', 'cart', 'subtotal=100;coupon_code=123', 'A', 0, ''),
(15, 1, 'a:3:{s:3:"set";s:3:"all";s:9:"set_value";s:1:"1";s:10:"conditions";a:2:{i:1;a:3:{s:8:"operator";s:3:"gte";s:9:"condition";s:8:"subtotal";s:5:"value";d:100;}i:2;a:3:{s:8:"operator";s:2:"eq";s:9:"condition";s:11:"coupon_code";s:5:"value";s:7:"sale-20";}}}', 'a:1:{i:1;a:3:{s:5:"bonus";s:14:"order_discount";s:14:"discount_bonus";s:13:"by_percentage";s:14:"discount_value";s:2:"20";}}', 0, 0, 3, 'N', 'N', 'cart', 'subtotal=100;coupon_code=sale-20', 'A', 5, ''),
(18, 1, 'a:3:{s:3:"set";s:3:"all";s:9:"set_value";s:1:"1";s:10:"conditions";a:1:{i:1;a:3:{s:8:"operator";s:2:"eq";s:9:"condition";s:11:"coupon_code";s:5:"value";s:8:"EMAIL-10";}}}', 'a:1:{i:1;a:3:{s:5:"bonus";s:14:"order_discount";s:14:"discount_bonus";s:13:"by_percentage";s:14:"discount_value";s:2:"10";}}', 0, 0, 5, 'N', 'N', 'cart', 'coupon_code=EMAIL-10', 'A', 0, ''),
(19, 1, 'a:3:{s:3:"set";s:3:"all";s:9:"set_value";s:1:"1";s:10:"conditions";a:2:{i:1;a:3:{s:8:"operator";s:2:"eq";s:9:"condition";s:8:"shipping";s:5:"value";s:1:"1";}i:2;a:3:{s:8:"operator";s:3:"gte";s:9:"condition";s:8:"subtotal";s:5:"value";d:100;}}}', 'a:1:{i:1;a:3:{s:5:"bonus";s:14:"order_discount";s:14:"discount_bonus";s:8:"by_fixed";s:14:"discount_value";s:1:"8";}}', 0, 0, 4, 'N', 'N', 'cart', 'shipping=1;subtotal=100', 'A', 1, ''),
(23, 1, 'a:3:{s:3:"set";s:3:"all";s:9:"set_value";s:1:"1";s:10:"conditions";a:1:{i:5;a:3:{s:8:"operator";s:2:"in";s:9:"condition";s:8:"products";s:5:"value";a:1:{i:1267114885;a:2:{s:10:"product_id";s:3:"248";s:6:"amount";s:1:"1";}}}}}', 'a:1:{i:3;a:4:{s:5:"bonus";s:20:"discount_on_products";s:5:"value";s:3:"248";s:14:"discount_bonus";s:13:"by_percentage";s:14:"discount_value";d:5;}}', 0, 0, 2, 'N', 'N', 'cart', 'products=1267114885', 'A', 0, ''),
(25, 0, 'a:3:{s:3:"set";s:3:"all";s:9:"set_value";s:1:"1";s:10:"conditions";a:1:{i:1;a:3:{s:8:"operator";s:2:"in";s:9:"condition";s:8:"products";s:5:"value";a:1:{i:0;a:2:{s:10:"product_id";i:12;s:6:"amount";i:3;}}}}}', 'a:1:{i:0;a:3:{s:5:"bonus";s:14:"order_discount";s:14:"discount_bonus";s:8:"by_fixed";s:14:"discount_value";d:29.9969999999999998863131622783839702606201171875;}}', 0, 0, 0, 'N', 'N', 'cart', 'products=0', 'A', 0, ''),
(26, 0, 'a:3:{s:3:"set";s:3:"all";s:9:"set_value";s:1:"1";s:10:"conditions";a:3:{i:1;a:3:{s:8:"operator";s:2:"in";s:9:"condition";s:8:"products";s:5:"value";a:1:{i:0;a:2:{s:10:"product_id";i:39;s:6:"amount";i:1;}}}i:2;a:3:{s:8:"operator";s:2:"in";s:9:"condition";s:8:"products";s:5:"value";a:1:{i:1;a:2:{s:10:"product_id";i:51;s:6:"amount";i:1;}}}i:3;a:3:{s:8:"operator";s:2:"in";s:9:"condition";s:8:"products";s:5:"value";a:1:{i:2;a:2:{s:10:"product_id";i:52;s:6:"amount";i:1;}}}}}', 'a:1:{i:0;a:3:{s:5:"bonus";s:14:"order_discount";s:14:"discount_bonus";s:8:"by_fixed";s:14:"discount_value";d:369.4950000000000045474735088646411895751953125;}}', 0, 0, 0, 'N', 'N', 'cart', 'products=0;products=1;products=2', 'A', 0, ''),
(27, 0, 'a:3:{s:3:"set";s:3:"all";s:9:"set_value";s:1:"1";s:10:"conditions";a:3:{i:1;a:3:{s:8:"operator";s:2:"in";s:9:"condition";s:8:"products";s:5:"value";a:1:{i:0;a:2:{s:10:"product_id";i:237;s:6:"amount";i:1;}}}i:2;a:3:{s:8:"operator";s:2:"in";s:9:"condition";s:8:"products";s:5:"value";a:1:{i:1;a:2:{s:10:"product_id";i:230;s:6:"amount";i:1;}}}i:3;a:3:{s:8:"operator";s:2:"in";s:9:"condition";s:8:"products";s:5:"value";a:1:{i:2;a:2:{s:10:"product_id";i:234;s:6:"amount";i:1;}}}}}', 'a:1:{i:0;a:3:{s:5:"bonus";s:14:"order_discount";s:14:"discount_bonus";s:8:"by_fixed";s:14:"discount_value";d:160.04340000000001964508555829524993896484375;}}', 0, 0, 0, 'N', 'N', 'cart', 'products=0;products=1;products=2', 'A', 0, '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]promotion_descriptions`
--

CREATE TABLE `[[dbprefix]]promotion_descriptions` (
  `promotion_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) NOT NULL DEFAULT '',
  `short_description` text,
  `detailed_description` mediumtext,
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`promotion_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]promotion_descriptions`
--

INSERT INTO `[[dbprefix]]promotion_descriptions` VALUES
(14, 'DVD 5% off', '', '', 'en'),
(24, 'Free shipping', '', '<p>We''ll ship any order above $100 for free</p>', 'en'),
(15, '20% discount coupon', '', '<p>Get 20% off your order with the bonus code "sale-20"</p>', 'en'),
(18, 'DEMO Store discount', '', '<p>10% off our entire range of products</p>', 'en'),
(19, 'Discount on pick-up', '', '<p>$8 off for collecting orders from our store</p>', 'en'),
(23, 'X-Box discount', '', '<p>5% off the price of this gaming console</p>', 'en'),
(25, 'Sports pants bundle', NULL, NULL, 'en'),
(26, 'Car audio bundle', NULL, NULL, 'en'),
(27, 'Camping bundle', NULL, NULL, 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]promotion_images`
--

CREATE TABLE `[[dbprefix]]promotion_images` (
  `promotion_image_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `promotion_id` int(11) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`promotion_image_id`),
  UNIQUE KEY `promo` (`promotion_id`,`lang_code`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=11 ;

--
-- Dumping data for table `[[dbprefix]]promotion_images`
--

INSERT INTO `[[dbprefix]]promotion_images` VALUES
(6, 15, 'en'),
(9, 23, 'en'),
(8, 19, 'en'),
(7, 18, 'en'),
(10, 24, 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]quick_menu`
--

CREATE TABLE `[[dbprefix]]quick_menu` (
  `menu_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` mediumint(8) unsigned NOT NULL,
  `url` varchar(255) NOT NULL,
  `parent_id` mediumint(8) unsigned NOT NULL,
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`menu_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=24 ;

--
-- Dumping data for table `[[dbprefix]]quick_menu`
--

INSERT INTO `[[dbprefix]]quick_menu` VALUES
(1, 1, '', 0, 1),
(2, 1, '', 0, 2),
(4, 1, '', 0, 4),
(5, 1, 'themes.manage?show_all_logos', 1, 1),
(6, 1, 'settings.manage?section_id=Company', 1, 1),
(7, 1, 'customization.update_mode?type=theme_editor&status=enable', 1, 2),
(8, 1, 'languages.translations?q=terms_and_conditions_content', 2, 1),
(9, 1, 'pages.update?page_id=3', 2, 2),
(10, 1, 'addons.manage?q=gdpr', 2, 3),
(11, 1, 'pages.update?page_id=21', 2, 4),
(19, 1, 'customization.update_mode?type=block_manager&status=enable&frontend_url=customization.edit_checkout', 4, 1),
(20, 1, 'profile_fields.manage', 4, 2),
(21, 1, 'payments.manage', 4, 3),
(22, 1, 'shippings.manage', 4, 4),
(23, 1, 'taxes.manage', 4, 5);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]reward_points`
--

CREATE TABLE `[[dbprefix]]reward_points` (
  `reward_point_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `object_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `usergroup_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `amount` int(11) unsigned NOT NULL DEFAULT '0',
  `amount_type` char(1) NOT NULL DEFAULT 'A',
  `object_type` char(1) NOT NULL DEFAULT 'P',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`reward_point_id`),
  UNIQUE KEY `unique_key` (`object_id`,`usergroup_id`,`object_type`,`company_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]reward_point_changes`
--

CREATE TABLE `[[dbprefix]]reward_point_changes` (
  `change_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `amount` int(11) NOT NULL DEFAULT '0',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `action` char(1) NOT NULL DEFAULT 'A',
  `reason` text,
  PRIMARY KEY (`change_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]rma_properties`
--

CREATE TABLE `[[dbprefix]]rma_properties` (
  `property_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT '',
  `type` char(1) NOT NULL DEFAULT 'R',
  `update_totals_and_inventory` char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (`property_id`),
  KEY `c_status` (`property_id`,`status`),
  KEY `status` (`status`,`type`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=14 ;

--
-- Dumping data for table `[[dbprefix]]rma_properties`
--

INSERT INTO `[[dbprefix]]rma_properties` VALUES
(11, 10, 'A', 'R', 'N'),
(12, 20, 'A', 'R', 'N'),
(3, 30, 'A', 'R', 'N'),
(4, 40, 'A', 'R', 'N'),
(5, 50, 'A', 'R', 'N'),
(6, 60, 'A', 'R', 'N'),
(7, 70, 'A', 'R', 'N'),
(8, 80, 'A', 'R', 'N'),
(1, 10, 'A', 'A', 'N'),
(2, 20, 'A', 'A', 'Y'),
(13, 90, 'A', 'R', 'N');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]rma_property_descriptions`
--

CREATE TABLE `[[dbprefix]]rma_property_descriptions` (
  `property_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `property` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`property_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]rma_property_descriptions`
--

INSERT INTO `[[dbprefix]]rma_property_descriptions` VALUES
(12, 'en', 'Wrong item ordered'),
(3, 'en', 'Wrong description online'),
(4, 'en', 'Can''t make it work'),
(5, 'en', 'Manufacturer defect'),
(6, 'en', 'Wrong item delivered'),
(7, 'en', 'Out of warranty'),
(8, 'en', 'Damaged during shipping'),
(1, 'en', 'Replace item'),
(2, 'en', 'Refund'),
(13, 'en', 'Other'),
(11, 'en', 'Dead on arrival');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]rma_returns`
--

CREATE TABLE `[[dbprefix]]rma_returns` (
  `return_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `order_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `action` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'O',
  `total_amount` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `comment` text,
  `extra` text,
  PRIMARY KEY (`return_id`),
  KEY `order_id` (`order_id`),
  KEY `timestamp` (`timestamp`),
  KEY `user_id` (`user_id`),
  KEY `status` (`status`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]rma_return_products`
--

CREATE TABLE `[[dbprefix]]rma_return_products` (
  `return_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `item_id` int(11) unsigned NOT NULL DEFAULT '0',
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `reason` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `amount` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `type` char(1) NOT NULL DEFAULT 'A',
  `price` decimal(12,2) NOT NULL DEFAULT '0.00',
  `product_options` text,
  `product` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`return_id`,`item_id`,`type`),
  KEY `reason` (`reason`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]robots_data`
--

CREATE TABLE `[[dbprefix]]robots_data` (
  `robots_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `data` text NOT NULL,
  PRIMARY KEY (`robots_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]robots_data`
--

INSERT INTO `[[dbprefix]]robots_data` VALUES
(1, 1, 'User-agent: *\nDisallow: /app/\nDisallow: /store_closed.html\n');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sales_reports`
--

CREATE TABLE `[[dbprefix]]sales_reports` (
  `report_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `name` varchar(255) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'A',
  `type` char(1) NOT NULL DEFAULT '',
  `period` char(2) NOT NULL DEFAULT 'A',
  `time_from` int(11) NOT NULL DEFAULT '0',
  `time_to` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`report_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=6 ;

--
-- Dumping data for table `[[dbprefix]]sales_reports`
--

INSERT INTO `[[dbprefix]]sales_reports` VALUES
(5, 10, '', 'A', 'O', 'Y', 1147723200, 1147809600),
(3, 30, '', 'A', 'O', 'Y', 1147723200, 1147809600),
(2, 40, '', 'A', 'O', 'Y', 1147723200, 1147809600),
(1, 50, '', 'A', 'O', 'Y', 1147723200, 1147809600),
(4, 60, '', 'A', 'O', 'Y', 1147723200, 1147809600);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sales_reports_descriptions`
--

CREATE TABLE `[[dbprefix]]sales_reports_descriptions` (
  `report_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `description` varchar(255) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`report_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]sales_reports_descriptions`
--

INSERT INTO `[[dbprefix]]sales_reports_descriptions` VALUES
(1, 'Top 10 Products', 'en'),
(2, 'Top 10 Categories', 'en'),
(3, 'Top 10 Customers', 'en'),
(4, 'Payment Methods', 'en'),
(5, 'Order Reports', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sales_reports_elements`
--

CREATE TABLE `[[dbprefix]]sales_reports_elements` (
  `element_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `code` varchar(66) NOT NULL DEFAULT '',
  `type` char(1) NOT NULL DEFAULT 'O',
  `depend_on_it` char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (`element_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=16 ;

--
-- Dumping data for table `[[dbprefix]]sales_reports_elements`
--

INSERT INTO `[[dbprefix]]sales_reports_elements` VALUES
(1, 'order_amount', 'O', 'N'),
(2, 'order_number', 'O', 'N'),
(3, 'order', 'O', 'Y'),
(4, 'status', 'O', 'Y'),
(5, 'payment', 'O', 'Y'),
(6, 'location', 'O', 'Y'),
(7, 'user', 'O', 'Y'),
(8, 'discount', 'O', 'N'),
(9, 'tax', 'O', 'N'),
(10, 'shipping', 'O', 'N'),
(11, 'category', 'O', 'Y'),
(12, 'product', 'O', 'Y'),
(13, 'product_cost', 'O', 'N'),
(14, 'product_number', 'O', 'N'),
(15, 'issuer', 'O', 'Y');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sales_reports_intervals`
--

CREATE TABLE `[[dbprefix]]sales_reports_intervals` (
  `interval_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `value` int(11) unsigned NOT NULL DEFAULT '0',
  `interval_code` varchar(64) NOT NULL DEFAULT '',
  PRIMARY KEY (`interval_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=10 ;

--
-- Dumping data for table `[[dbprefix]]sales_reports_intervals`
--

INSERT INTO `[[dbprefix]]sales_reports_intervals` VALUES
(1, 0, 'total'),
(7, 2592000, 'month'),
(5, 604800, 'week'),
(3, 86400, 'day'),
(9, 31536000, 'year');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sales_reports_tables`
--

CREATE TABLE `[[dbprefix]]sales_reports_tables` (
  `table_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `report_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `type` char(1) NOT NULL DEFAULT 'T',
  `display` varchar(64) NOT NULL DEFAULT 'order_amount',
  `interval_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `auto` char(1) NOT NULL DEFAULT 'Y',
  PRIMARY KEY (`table_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=20 ;

--
-- Dumping data for table `[[dbprefix]]sales_reports_tables`
--

INSERT INTO `[[dbprefix]]sales_reports_tables` VALUES
(1, 1, 10, 'P', 'product_number', 1, 'Y'),
(3, 2, 10, 'P', 'product_number', 1, 'Y'),
(5, 3, 10, 'T', 'order_amount', 1, 'Y'),
(11, 4, 10, 'P', 'order_number', 1, 'Y'),
(14, 5, 10, 'T', 'product_cost', 7, 'Y'),
(2, 1, 20, 'B', 'product_cost', 1, 'Y'),
(4, 2, 20, 'B', 'product_cost', 1, 'Y'),
(6, 3, 20, 'T', 'product_number', 1, 'Y'),
(13, 4, 20, 'P', 'order_amount', 1, 'Y'),
(16, 5, 20, 'T', 'order_amount', 7, 'Y'),
(7, 1, 30, 'T', 'product_cost', 1, 'Y'),
(8, 2, 30, 'T', 'product_number', 7, 'Y'),
(15, 5, 30, 'T', 'order_amount', 1, 'Y'),
(9, 2, 40, 'T', 'product_cost', 7, 'Y'),
(10, 1, 40, 'T', 'product_number', 7, 'Y'),
(19, 5, 50, 'T', 'shipping', 1, 'Y'),
(17, 5, 60, 'P', 'order_number', 1, 'Y');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sales_reports_table_conditions`
--

CREATE TABLE `[[dbprefix]]sales_reports_table_conditions` (
  `table_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `code` varchar(64) NOT NULL DEFAULT '0',
  `sub_element_id` varchar(16) NOT NULL DEFAULT '0',
  PRIMARY KEY (`table_id`,`code`,`sub_element_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sales_reports_table_descriptions`
--

CREATE TABLE `[[dbprefix]]sales_reports_table_descriptions` (
  `table_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `description` varchar(255) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`table_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]sales_reports_table_descriptions`
--

INSERT INTO `[[dbprefix]]sales_reports_table_descriptions` VALUES
(1, 'Top 10 Products - Items Sold', 'en'),
(2, 'Top 10 Products - Cost', 'en'),
(3, 'Top 10 Categories - Items Sold', 'en'),
(4, 'Top 10 Categories - Cost', 'en'),
(5, 'Top 10 Customers - Orders cost', 'en'),
(6, 'Top 10 Customers - Items bought', 'en'),
(7, 'Top 10 Products - Cost  (table)', 'en'),
(8, 'Top 10 Categories - Items Sold  (table)', 'en'),
(9, 'Top 10 Categories - Cost (table)', 'en'),
(10, 'Top 10 Products - Items Sold  (table)', 'en'),
(13, 'Payment methods chart - Cost', 'en'),
(11, 'Payment methods chart - Orders placed', 'en'),
(14, 'Products sales  - Cost (table)', 'en'),
(15, 'Most active customer locations', 'en'),
(16, 'Categories sales  - Cost (table)', 'en'),
(17, 'Order statuses', 'en'),
(19, 'Shipping cost per order', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sales_reports_table_elements`
--

CREATE TABLE `[[dbprefix]]sales_reports_table_elements` (
  `report_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `table_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `element_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `element_hash` int(11) NOT NULL DEFAULT '0',
  `color` varchar(64) NOT NULL DEFAULT 'blueviolet',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'A',
  `dependence` varchar(64) NOT NULL DEFAULT 'max_p',
  `limit_auto` mediumint(8) unsigned NOT NULL DEFAULT '5',
  PRIMARY KEY (`report_id`,`table_id`,`element_hash`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]sales_reports_table_elements`
--

INSERT INTO `[[dbprefix]]sales_reports_table_elements` VALUES
(1, 1, 12, 12156775, 'blueviolet', 0, 'A', 'max_n', 10),
(1, 2, 12, 1962573517, 'blueviolet', 0, 'A', 'max_p', 10),
(2, 3, 11, 867821142, 'blueviolet', 0, 'A', 'max_n', 10),
(2, 4, 11, 1368465681, 'blueviolet', 0, 'A', 'max_p', 10),
(3, 5, 7, 1484724989, 'blueviolet', 0, 'A', 'max_p', 10),
(3, 6, 7, 1513727140, 'blueviolet', 0, 'A', 'max_n', 10),
(1, 7, 12, 634527931, 'blueviolet', 0, 'A', 'max_p', 10),
(2, 8, 11, 457678505, 'blueviolet', 0, 'A', 'max_n', 10),
(2, 9, 11, 1543767602, 'blueviolet', 0, 'A', 'max_p', 10),
(1, 10, 12, 1021140683, 'blueviolet', 0, 'A', 'max_n', 10),
(4, 11, 5, 829820942, 'blueviolet', 0, 'A', 'max_n', 10),
(4, 13, 5, 611229353, 'blueviolet', 0, 'A', 'max_p', 20),
(5, 14, 12, 935187175, 'blueviolet', 0, 'A', 'max_p', 99999),
(5, 15, 6, 1175800927, 'blueviolet', 0, 'A', 'max_p', 23),
(5, 16, 11, 2134945619, 'blueviolet', 0, 'A', 'max_p', 99999),
(5, 17, 4, 1415579363, 'blueviolet', 0, 'A', 'max_n', 10),
(5, 19, 3, 1063600566, 'blueviolet', 0, 'A', 'max_p', 99999);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sales_reports_table_element_conditions`
--

CREATE TABLE `[[dbprefix]]sales_reports_table_element_conditions` (
  `table_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `element_hash` varchar(32) NOT NULL DEFAULT '',
  `element_code` varchar(64) NOT NULL DEFAULT '',
  `ids` varchar(16) NOT NULL DEFAULT '',
  PRIMARY KEY (`table_id`,`element_hash`,`ids`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]seo_names`
--

CREATE TABLE `[[dbprefix]]seo_names` (
  `name` varchar(250) NOT NULL DEFAULT '',
  `object_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `type` char(1) NOT NULL DEFAULT '',
  `dispatch` varchar(64) NOT NULL DEFAULT '',
  `path` varchar(255) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`object_id`,`type`,`dispatch`,`lang_code`,`company_id`),
  KEY `name` (`name`,`lang_code`),
  KEY `type` (`name`,`type`,`lang_code`),
  KEY `dispatch` (`dispatch`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]seo_names`
--

INSERT INTO `[[dbprefix]]seo_names` VALUES
('login', 0, 1, 's', 'auth.login_form', '', 'en'),
('cart', 0, 1, 's', 'checkout.cart', '', 'en'),
('checkout', 0, 1, 's', 'checkout.checkout', '', 'en'),
('checkout-customer-info', 0, 1, 's', 'checkout.customer_info', '', 'en'),
('checkout-summary', 0, 1, 's', 'checkout.summary', '', 'en'),
('gift-certificates', 0, 1, 's', 'gift_certificates.add', '', 'en'),
('gift-certificates-update', 0, 1, 's', 'gift_certificates.update', '', 'en'),
('profiles-add', 0, 1, 's', 'profiles.add', '', 'en'),
('profiles-update', 0, 1, 's', 'profiles.update', '', 'en'),
('promotions', 0, 1, 's', 'promotions.list', '', 'en'),
('wishlist', 0, 1, 's', 'wishlist.view', '', 'en'),
('sitemap', 0, 1, 's', 'sitemap.view', '', 'en'),
('catalog', 0, 1, 's', 'categories.catalog', '', 'en'),
('compare', 0, 1, 's', 'product_features.compare', '', 'en'),
('returns', 0, 1, 's', 'rma.returns', '', 'en'),
('orders', 0, 1, 's', 'orders.search', '', 'en'),
('privacy-policy', 3, 0, 'a', '', '', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]seo_redirects`
--

CREATE TABLE `[[dbprefix]]seo_redirects` (
  `redirect_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `src` varchar(255) NOT NULL DEFAULT '',
  `dest` varchar(255) NOT NULL DEFAULT '',
  `type` char(1) NOT NULL DEFAULT 's',
  `object_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`redirect_id`),
  KEY `src` (`src`,`company_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sessions`
--

CREATE TABLE `[[dbprefix]]sessions` (
  `session_id` varchar(64) NOT NULL DEFAULT '',
  `expiry` int(11) unsigned NOT NULL DEFAULT '0',
  `data` mediumblob,
  PRIMARY KEY (`session_id`),
  KEY `src` (`session_id`,`expiry`),
  KEY `expiry` (`expiry`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]sessions`
--

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]settings_descriptions`
--

CREATE TABLE `[[dbprefix]]settings_descriptions` (
  `object_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `object_type` varchar(1) NOT NULL DEFAULT 'O',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `value` text,
  `tooltip` text,
  PRIMARY KEY (`object_id`,`object_type`,`lang_code`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=5930 ;

--
-- Dumping data for table `[[dbprefix]]settings_descriptions`
--

INSERT INTO `[[dbprefix]]settings_descriptions` VALUES
(4, 'S', 'en', 'Appearance', NULL),
(5, 'S', 'en', 'Company', NULL),
(1, 'S', 'en', 'E-mails', NULL),
(2, 'S', 'en', 'General', NULL),
(11, 'S', 'en', 'Image verification', NULL),
(12, 'S', 'en', 'Logging', NULL),
(10, 'S', 'en', 'Reports', NULL),
(15, 'S', 'en', 'Security settings', NULL),
(6, 'S', 'en', 'Checkout', NULL),
(8, 'S', 'en', 'Sitemap', NULL),
(17, 'S', 'en', 'Stores', NULL),
(9, 'S', 'en', 'Thumbnails', NULL),
(13, 'S', 'en', 'Upgrade center', NULL),
(31, 'O', 'en', 'Company name', NULL),
(56, 'O', 'en', 'Enable secure connection in the administration panel', 'SSL certificate must be installed on your server.'),
(55, 'O', 'en', 'Enable secure connection for the storefront', 'SSL certificate must be installed on your server.'),
(12, 'O', 'en', 'License number', NULL),
(15, 'O', 'en', 'Alternative currency display format', NULL),
(27, 'O', 'en', 'Company address', NULL),
(105, 'O', 'en', 'Show the ''Categories'' section', NULL),
(108, 'O', 'en', 'Method of sending e-mails', NULL),
(133, 'O', 'en', 'Image width', NULL),
(312, 'O', 'en', 'Days before a log entry is removed', 'Enter 0 if you don''t want any automatic removal of old logs.'),
(158, 'O', 'en', 'Orders', NULL),
(159, 'O', 'en', 'Users', NULL),
(160, 'O', 'en', 'Products', NULL),
(161, 'O', 'en', 'Categories', NULL),
(162, 'O', 'en', 'Database', NULL),
(163, 'O', 'en', 'Requests', NULL),
(174, 'O', 'en', 'Minimum password length', NULL),
(203, 'O', 'en', 'Administrator  settings', NULL),
(204, 'O', 'en', 'Format of time intervals', NULL),
(2000, 'O', 'en', 'Share users among stores', NULL),
(274, 'O', 'en', 'General', NULL),
(54, 'O', 'en', 'Backend default language', NULL),
(26, 'O', 'en', 'Company city', NULL),
(84, 'O', 'en', 'Day', NULL),
(106, 'O', 'en', 'Show only root level categories links in the ''Categories'' section', NULL),
(117, 'O', 'en', 'Image height', NULL),
(175, 'O', 'en', 'Password must contain both letters and numbers', NULL),
(206, 'O', 'en', 'SMTP server settings', NULL),
(219, 'O', 'en', 'FTP server options', NULL),
(2001, 'O', 'en', 'Default state of the "Update for all stores" icon', NULL),
(8, 'O', 'en', 'Hostname', NULL),
(16, 'O', 'en', 'Weight symbol', NULL),
(34, 'O', 'en', 'Company country', NULL),
(85, 'O', 'en', 'Week', NULL),
(109, 'O', 'en', 'SMTP host', NULL),
(118, 'O', 'en', 'String length', NULL),
(176, 'O', 'en', 'Force administrators to change password on the first login', NULL),
(107, 'O', 'en', 'Show the ''Site info'' section', NULL),
(125, 'O', 'en', 'Number of grid lines', NULL),
(126, 'O', 'en', 'Grid color (hexadecimal code)', NULL),
(9, 'O', 'en', 'Username', NULL),
(25, 'O', 'en', 'Company state', NULL),
(42, 'O', 'en', 'Grams in the unit of weight defined by the weight symbol', NULL),
(86, 'O', 'en', 'Month', NULL),
(111, 'O', 'en', 'SMTP username', NULL),
(119, 'O', 'en', 'Minimum font size', NULL),
(177, 'O', 'en', 'Password validity period in days (0 - unlimited)', NULL),
(10, 'O', 'en', 'Password', NULL),
(33, 'O', 'en', 'Company zip code', NULL),
(87, 'O', 'en', 'Year', NULL),
(112, 'O', 'en', 'SMTP password', NULL),
(120, 'O', 'en', 'Maximum font size', NULL),
(168, 'O', 'en', 'Close storefront', NULL),
(178, 'O', 'en', 'Access key to cron script which sends e-mail notifications of password change.', 'Use: http://www.example.com/admin.php?dispatch=profiles.password_reminder&cron_password=key_value.'),
(62, 'O', 'en', 'Initial order ID value', 'Use a number between 1 and 10000000 or leave empty for auto-filling.'),
(179, 'O', 'en', 'Tax calculation method based on', NULL),
(7, 'O', 'en', 'Help us improve software', NULL),
(14, 'O', 'en', 'Check for updates automatically', NULL),
(11, 'O', 'en', 'Directory', NULL),
(24, 'O', 'en', 'Elements per page', NULL),
(28, 'O', 'en', 'Company phone', NULL),
(49, 'O', 'en', 'Default wysiwyg editor', NULL),
(110, 'O', 'en', 'Use SMTP authentication', NULL),
(121, 'O', 'en', 'String type', NULL),
(207, 'O', 'en', 'Default customer location', NULL),
(122, 'O', 'en', 'Character shadows', NULL),
(17, 'O', 'en', 'Default address', NULL),
(29, 'O', 'en', 'Company phone 2', NULL),
(335, 'O', 'en', 'Image file size', 'The maximum size of an uploaded image file in megabytes. Leave empty to use the server settings.'),
(91, 'O', 'en', 'Thumbnail background color', 'Leave empty for transparent background.'),
(123, 'O', 'en', 'Color', NULL),
(208, 'O', 'en', 'Customer settings', NULL),
(209, 'O', 'en', 'Sendmail settings', NULL),
(18, 'O', 'en', 'Default zipcode', NULL),
(53, 'O', 'en', 'Frontend default language', NULL),
(334, 'O', 'en', 'Frontend default currency', NULL),
(90, 'O', 'en', 'Thumbnail format', NULL),
(113, 'O', 'en', 'Path to sendmail program', NULL),
(124, 'O', 'en', 'Background image', NULL),
(134, 'O', 'en', 'Do not use verification if user is logged in', NULL),
(165, 'O', 'en', 'Do not use verification after first valid answer', NULL),
(19, 'O', 'en', 'Default city', NULL),
(32, 'O', 'en', 'Company website', NULL),
(46, 'O', 'en', 'Orders per page', NULL),
(89, 'O', 'en', 'JPEG format quality (0-100)', NULL),
(40, 'O', 'en', 'Year when the store started its operation', NULL),
(20, 'O', 'en', 'Default country', NULL),
(22, 'O', 'en', 'Products per page', NULL),
(35, 'O', 'en', 'User department e-mail address', NULL),
(138, 'O', 'en', 'Use for', NULL),
(184, 'O', 'en', 'Products list (category, search, etc) thumbnail width', NULL),
(21, 'O', 'en', 'Default state', NULL),
(36, 'O', 'en', 'Site administrator e-mail address', NULL),
(185, 'O', 'en', 'Products list (category, search, etc) thumbnail height', NULL),
(37, 'O', 'en', 'Order department e-mail address', NULL),
(41, 'O', 'en', 'Default phone', NULL),
(186, 'O', 'en', 'Product details page thumbnail width', NULL),
(210, 'O', 'en', 'Catalog', NULL),
(38, 'O', 'en', 'Help/Support department e-mail address', NULL),
(47, 'O', 'en', 'Elements per page', NULL),
(58, 'O', 'en', 'Enable inventory tracking', NULL),
(187, 'O', 'en', 'Product details page thumbnail height', NULL),
(44, 'O', 'en', 'Allow negative amount in inventory', NULL),
(292, 'O', 'en', 'Product quick view thumbnail width', NULL),
(293, 'O', 'en', 'Product quick view thumbnail height', NULL),
(309, 'O', 'en', 'Admin panel: product mini-icon thumbnail width', NULL),
(310, 'O', 'en', 'Admin panel: product mini-icon thumbnail height', NULL),
(39, 'O', 'en', 'Reply-To newsletter e-mail address', NULL),
(65, 'O', 'en', 'Download key TTL (for electronically distributed products), hours', NULL),
(77, 'O', 'en', 'Low stock notification threshold', NULL),
(63, 'O', 'en', 'Number of columns in the product list', NULL),
(72, 'O', 'en', 'Show products from subcategories of the selected category', NULL),
(93, 'O', 'en', 'Display modifiers for product options', NULL),
(317, 'O', 'en', 'Options type', NULL),
(331, 'O', 'en', 'Track inventory', NULL),
(319, 'O', 'en', 'Exceptions type', NULL),
(321, 'O', 'en', 'Zero price action', NULL),
(323, 'O', 'en', 'Minimum quantity to buy per product', 'Sell no less than X units of a product in an order.'),
(325, 'O', 'en', 'Maximum quantity to buy per product', 'Sell no more than X units of a product in an order.'),
(327, 'O', 'en', 'Quantity step', 'Increase or decrease the number of purchased product units only by X.'),
(329, 'O', 'en', 'Number of available quantities', 'Replace product quantity selector with a dropdown list with X variants.'),
(3, 'O', 'en', 'Exception style', NULL),
(190, 'O', 'en', 'Product cart page thumbnail width', NULL),
(191, 'O', 'en', 'Product cart page thumbnail height', NULL),
(94, 'O', 'en', 'Show out of stock products', NULL),
(192, 'O', 'en', 'Categories list thumbnail width', NULL),
(150, 'O', 'en', 'Estimate taxes using default address on cart/checkout pages', NULL),
(116, 'O', 'en', 'Display prices with taxes on category/product pages', 'Only if the tax calculation method is based on unit price.'),
(145, 'O', 'en', 'Display prices with taxes on cart/checkout pages', 'Only if the tax calculation method is based on unit price.'),
(146, 'O', 'en', 'Show number of available products', NULL),
(147, 'O', 'en', 'Display mini thumbnail images as a gallery', NULL),
(148, 'O', 'en', 'Use ''Value changer'' for the Quantity field', NULL),
(149, 'O', 'en', 'Display the ''Pagination section'' on the top of the listed object', NULL),
(50, 'O', 'en', 'Default image previewer', NULL),
(193, 'O', 'en', 'Categories list thumbnail height', NULL),
(180, 'O', 'en', 'Product detailed page view', NULL),
(288, 'O', 'en', 'Display product details in tabs', NULL),
(272, 'O', 'en', 'Display track my orders section', NULL),
(221, 'O', 'en', 'Products list layouts settings', NULL),
(171, 'O', 'en', 'Available product list views', NULL),
(169, 'O', 'en', 'Product list default view', NULL),
(170, 'O', 'en', 'Use the selected view for current category or search page only', NULL),
(289, 'O', 'en', 'Available product list sortings', NULL),
(64, 'O', 'en', 'Product list default sorting', NULL),
(290, 'O', 'en', 'Enable quick view', NULL),
(211, 'O', 'en', 'Common settings', NULL),
(52, 'O', 'en', 'Date format', NULL),
(194, 'O', 'en', 'Category details page thumbnail width', NULL),
(66, 'O', 'en', 'Time format', NULL),
(195, 'O', 'en', 'Category details page thumbnail height', NULL),
(212, 'O', 'en', 'Promotions', NULL),
(139, 'O', 'en', 'Time zone', NULL),
(196, 'O', 'en', 'Detailed category image width', NULL),
(98, 'O', 'en', 'Allow customers to use single discount coupon only', NULL),
(166, 'O', 'en', 'Calendar date format', NULL),
(197, 'O', 'en', 'Detailed category image height', NULL),
(213, 'O', 'en', 'Users', NULL),
(67, 'O', 'en', 'Allow users to create multiple profiles for one account', 'A profile is a combination of shipping and billing address.'),
(167, 'O', 'en', 'Calendar week starts from', NULL),
(69, 'O', 'en', 'Minimum order amount', NULL),
(70, 'O', 'en', 'Define minimum order amount by', NULL),
(71, 'O', 'en', 'Allow shopping for unlogged customers', NULL),
(73, 'O', 'en', 'Disable anonymous checkout', NULL),
(173, 'O', 'en', 'Allow checkout only from cart', 'Show the Checkout button only on the Cart Content page.'),
(2, 'O', 'en', 'Allow customer to signup for user group', NULL),
(78, 'O', 'en', 'Administrator must activate new user accounts', NULL),
(182, 'O', 'en', 'Profile address section order', NULL),
(183, 'O', 'en', 'Unsaved changes warning', NULL),
(48, 'O', 'en', 'Notice displaying time (to turn off the autohide function enter 0)', NULL),
(275, 'O', 'en', 'Quick registration', 'Require only contact information for registration.'),
(100, 'O', 'en', 'Ask customers to agree with terms &amp; conditions during checkout', 'The text of terms & conditions is in the "terms_and_conditions_content" language variable.'),
(140, 'O', 'en', 'Estimate shipping cost on cart page', NULL),
(141, 'O', 'en', 'Offer guest to create an account after successful order', NULL),
(223, 'O', 'en', 'Disregard product options when calculating quantity discounts', NULL),
(216, 'O', 'en', 'Proxy server for outgoing connections', NULL),
(151, 'O', 'en', 'Proxy host', NULL),
(152, 'O', 'en', 'Proxy port', NULL),
(153, 'O', 'en', 'Proxy user', NULL),
(154, 'O', 'en', 'Proxy password', NULL),
(217, 'O', 'en', 'Search options', NULL),
(156, 'O', 'en', 'Search also in', NULL),
(295, 'O', 'en', 'Use Encrypted Connection', NULL),
(300, 'O', 'en', 'Configure "Sign in" step', 'This step can be hidden only if it doesn''t have any required contact info fields and anonymous checkout is allowed.'),
(305, 'O', 'en', 'Default option for the "New customer" section at the "Sign in"', NULL),
(301, 'O', 'en', 'Display "Shipping method" step', 'If the step is hidden, the first active method will be used by default.'),
(308, 'O', 'en', 'Email templates mode', NULL),
(313, 'O', 'en', 'Supported phone numbers', NULL),
(302, 'O', 'en', 'Display "Payment method" step', 'If the step is hidden, the first active method will be used by default.'),
(306, 'O', 'en', 'Enable selling downloadable products', NULL),
(307, 'O', 'en', 'Allow customers to compare products', NULL),
(311, 'O', 'en', 'Monitor changes in core files', NULL),
(314, 'O', 'en', 'Show unavailable shippings', 'Show real-time shipping methods even if their servers haven''t returned the rates'),
(315, 'O', 'en', 'Product variant selector thumbnail width', NULL),
(316, 'O', 'en', 'Product variant selector thumbnail height', NULL),
(276, 'O', 'en', 'Show "Delete my account" button', 'Customers will see it on their profile page on the site.'),
(23, 'V', 'en', 'Default', NULL),
(6, 'V', 'en', 'Manual feedback', NULL),
(7, 'V', 'en', 'Automatic feedback', NULL),
(10, 'V', 'en', '29/09/2005 (day/month/year)', NULL),
(26, 'V', 'en', '15:43', NULL),
(36, 'V', 'en', 'Allow', NULL),
(57, 'V', 'en', 'Digits only', NULL),
(159, 'V', 'en', '09/30/2008 (month/day/year)', NULL),
(161, 'V', 'en', 'Sunday', NULL),
(165, 'V', 'en', 'Billing first', NULL),
(167, 'V', 'en', 'Runtime', NULL),
(2000, 'V', 'en', 'Not Active', NULL),
(11, 'V', 'en', '29-09-2005 (day-month-year)', NULL),
(27, 'V', 'en', '15.43', NULL),
(35, 'V', 'en', 'Products with shipping', NULL),
(38, 'V', 'en', 'Hide the "Add to cart" button', NULL),
(58, 'V', 'en', 'Letters only', NULL),
(160, 'V', 'en', '30/09/2008 (day/month/year)', NULL),
(162, 'V', 'en', 'Monday', NULL),
(166, 'V', 'en', 'Shipping first', NULL),
(168, 'V', 'en', 'Deprecated features', NULL),
(2001, 'V', 'en', 'Active', NULL),
(12, 'V', 'en', '29.09.2005 (day.month.year)', NULL),
(28, 'V', 'en', '3:43 PM', NULL),
(34, 'V', 'en', 'Products', NULL),
(37, 'V', 'en', 'Hide price and the "Add to cart" button', NULL),
(59, 'V', 'en', 'Mixed', NULL),
(13, 'V', 'en', '09/29/2005 (month/day/year)', NULL),
(29, 'V', 'en', '3.43 PM', NULL),
(138, 'V', 'en', 'Create', NULL),
(139, 'V', 'en', 'Delete', NULL),
(140, 'V', 'en', 'Update', NULL),
(147, 'V', 'en', 'Create', NULL),
(148, 'V', 'en', 'Delete', NULL),
(149, 'V', 'en', 'Update', NULL),
(142, 'V', 'en', 'Create', NULL),
(143, 'V', 'en', 'Delete', NULL),
(144, 'V', 'en', 'Update', NULL),
(151, 'V', 'en', 'Create', NULL),
(152, 'V', 'en', 'Delete', NULL),
(153, 'V', 'en', 'Update', NULL),
(14, 'V', 'en', '09-29-2005 (month-day-year)', NULL),
(30, 'V', 'en', '15:43:55', NULL),
(47, 'V', 'en', 'January, 2006', NULL),
(141, 'V', 'en', 'Change', NULL),
(145, 'V', 'en', 'Session', NULL),
(146, 'V', 'en', 'Failed logins', NULL),
(150, 'V', 'en', 'Low stock', NULL),
(154, 'V', 'en', 'Restore', NULL),
(155, 'V', 'en', 'Backup', NULL),
(156, 'V', 'en', 'Optimize', NULL),
(157, 'V', 'en', 'Errors', NULL),
(158, 'V', 'en', 'HTTP/HTTPS', NULL),
(15, 'V', 'en', '09.29.2005 (month.day.year)', NULL),
(31, 'V', 'en', '15.43.55', NULL),
(16, 'V', 'en', '2005/09/29 (year/month/day)', NULL),
(32, 'V', 'en', '3:43:55 PM', NULL),
(17, 'V', 'en', '2005-09-29 (year-month-day)', NULL),
(33, 'V', 'en', '3.43.55 PM', NULL),
(18, 'V', 'en', '2005.09.29 (year.month.day)', NULL),
(1, 'V', 'en', 'Hide exception', NULL),
(9, 'V', 'en', 'Show prices in selected currency only', NULL),
(19, 'V', 'en', 'Sep 29, 2005 (month day, year)', NULL),
(24, 'V', 'en', 'Product name', NULL),
(39, 'V', 'en', 'Tue, Jan 3', NULL),
(44, 'V', 'en', '1 week', NULL),
(48, 'V', 'en', 'January', NULL),
(52, 'V', 'en', '2006', NULL),
(54, 'V', 'en', 'via SMTP server', NULL),
(163, 'V', 'en', 'Unit price', NULL),
(20, 'V', 'en', '29 Sep 2005 (day month year)', NULL),
(21, 'V', 'en', 'Thursday, September 29, 2005 (day of week, month day, year)', NULL),
(22, 'V', 'en', 'Thursday, 29 September 2005 (day of week, day month year)', NULL),
(40, 'V', 'en', 'January 3, 2006', NULL),
(2, 'V', 'en', 'Show warning on exception', NULL),
(253, 'V', 'en', 'Simultaneous', NULL),
(254, 'V', 'en', 'Sequential', NULL),
(255, 'V', 'en', 'Forbidden', NULL),
(256, 'V', 'en', 'Allowed', NULL),
(257, 'V', 'en', 'Do not allow customers to add the product to cart', NULL),
(258, 'V', 'en', 'Allow customers to add the product to cart', NULL),
(259, 'V', 'en', 'Ask customer to enter the price', NULL),
(8, 'V', 'en', 'Show prices in default and selected currencies', NULL),
(25, 'V', 'en', 'Price', NULL),
(41, 'V', 'en', '01.03.06', NULL),
(45, 'V', 'en', '01.03', NULL),
(49, 'V', 'en', '01', NULL),
(53, 'V', 'en', '06', NULL),
(55, 'V', 'en', 'via php mail function', NULL),
(131, 'V', 'en', '(GMT-11:00) Samoa', NULL),
(164, 'V', 'en', 'Subtotal', NULL),
(169, 'V', 'en', 'None', NULL),
(42, 'V', 'en', 'Tue Jan 3, 2006', NULL),
(46, 'V', 'en', '1, Jan', NULL),
(50, 'V', 'en', 'Jan', NULL),
(56, 'V', 'en', 'via sendmail program', NULL),
(130, 'V', 'en', '(GMT-10:00) Hawaii', NULL),
(43, 'V', 'en', 'Jan 3', NULL),
(51, 'V', 'en', '01-2006', NULL),
(129, 'V', 'en', '(GMT-09:00) Alaska', NULL),
(128, 'V', 'en', '(GMT-08:00) Pacific Time (US & Canada); Tijuana', NULL),
(127, 'V', 'en', '(GMT-07:00) Mountain Time (US & Canada)', NULL),
(126, 'V', 'en', '(GMT-07:00) Chihuahua, Mazatlan', NULL),
(125, 'V', 'en', '(GMT-07:00) Arizona', NULL),
(124, 'V', 'en', '(GMT-06:00) Saskatchewan', NULL),
(123, 'V', 'en', '(GMT-06:00) Guadalajara, Mexico City, Monterrey', NULL),
(122, 'V', 'en', '(GMT-06:00) Central Time (US & Canada)', NULL),
(121, 'V', 'en', '(GMT-06:00) Central America', NULL),
(119, 'V', 'en', '(GMT-05:00) Eastern Time (US & Canada)', NULL),
(118, 'V', 'en', '(GMT-05:00) Bogota, Lima, Quito', NULL),
(117, 'V', 'en', '(GMT-04:00) Santiago', NULL),
(116, 'V', 'en', '(GMT-04:00) Caracas, La Paz', NULL),
(115, 'V', 'en', '(GMT-04:00) Atlantic Time (Canada)', NULL),
(114, 'V', 'en', '(GMT-03:30) Newfoundland', NULL),
(113, 'V', 'en', '(GMT-03:00) Greenland', NULL),
(111, 'V', 'en', '(GMT-03:00) Brasilia', NULL),
(110, 'V', 'en', '(GMT-02:00) Mid-Atlantic', NULL),
(109, 'V', 'en', '(GMT-01:00) Cape Verde Is.', NULL),
(108, 'V', 'en', '(GMT-01:00) Azores', NULL),
(107, 'V', 'en', '(GMT) Reykjavik, Monrovia', NULL),
(106, 'V', 'en', '(GMT) Greenwich Mean Time: Edinburgh, Lisbon, London', NULL),
(105, 'V', 'en', '(GMT+01:00) Amsterdam, Berlin, Bern, Rome, Stockholm, Vienna', NULL),
(104, 'V', 'en', '(GMT+01:00) Belgrade, Bratislava, Budapest, Ljubljana, Prague', NULL),
(102, 'V', 'en', '(GMT+01:00) Brussels, Copenhagen, Madrid, Paris', NULL),
(103, 'V', 'en', '(GMT+01:00) Sarajevo, Skopje, Warsaw, Zagreb', NULL),
(101, 'V', 'en', '(GMT+01:00) West Central Africa', NULL),
(100, 'V', 'en', '(GMT+03:00) Istanbul', NULL),
(237, 'V', 'en', '(GMT+02:00) Athens', NULL),
(238, 'V', 'en', '(GMT+02:00) Beirut', NULL),
(228, 'V', 'en', '(GMT+02:00) Bucharest', NULL),
(98, 'V', 'en', '(GMT+02:00) Cairo', NULL),
(97, 'V', 'en', '(GMT+02:00) Harare, Pretoria', NULL),
(96, 'V', 'en', '(GMT+02:00) Helsinki, Kyiv, Riga, Sofia, Tallinn, Vilnius', NULL),
(95, 'V', 'en', '(GMT+02:00) Jerusalem', NULL),
(94, 'V', 'en', '(GMT+03:00) Baghdad', NULL),
(93, 'V', 'en', '(GMT+03:00) Kuwait, Riyadh', NULL),
(92, 'V', 'en', '(GMT+03:00) Moscow, St. Petersburg', NULL),
(99, 'V', 'en', '(GMT+03:00) Minsk', NULL),
(91, 'V', 'en', '(GMT+03:00) Nairobi', NULL),
(90, 'V', 'en', '(GMT+03:30) Tehran', NULL),
(89, 'V', 'en', '(GMT+04:00) Abu Dhabi, Muscat', NULL),
(88, 'V', 'en', '(GMT+04:00) Baku, Tbilisi, Yerevan', NULL),
(87, 'V', 'en', '(GMT+04:30) Kabul', NULL),
(86, 'V', 'en', '(GMT+05:00) Ekaterinburg', NULL),
(85, 'V', 'en', '(GMT+05:00) Islamabad, Karachi, Tashkent', NULL),
(84, 'V', 'en', '(GMT+05:30) Chennai, Kolkata, Mumbai, New Delhi', NULL),
(83, 'V', 'en', '(GMT+05:45) Kathmandu', NULL),
(82, 'V', 'en', '(GMT+07:00) Novosibirsk', NULL),
(81, 'V', 'en', '(GMT+06:00) Nur-Sultan, Dhaka', NULL),
(80, 'V', 'en', '(GMT+06:00) Sri Jayawardenepura', NULL),
(79, 'V', 'en', '(GMT+06:30) Yangon', NULL),
(78, 'V', 'en', '(GMT+07:00) Bangkok, Hanoi, Jakarta', NULL),
(77, 'V', 'en', '(GMT+07:00) Krasnoyarsk', NULL),
(76, 'V', 'en', '(GMT+08:00) Beijing, Chongqing, Hong Kong', NULL),
(75, 'V', 'en', '(GMT+08:00) Irkutsk, Ulaanbaatar', NULL),
(74, 'V', 'en', '(GMT+08:00) Kuala Lumpur, Singapore', NULL),
(73, 'V', 'en', '(GMT+08:00) Perth', NULL),
(72, 'V', 'en', '(GMT+08:00) Taipei', NULL),
(71, 'V', 'en', '(GMT+09:00) Osaka, Sapporo, Tokyo', NULL),
(70, 'V', 'en', '(GMT+09:00) Seoul', NULL),
(69, 'V', 'en', '(GMT+09:00) Yakutsk', NULL),
(68, 'V', 'en', '(GMT+09:30) Adelaide', NULL),
(67, 'V', 'en', '(GMT+09:30) Darwin', NULL),
(66, 'V', 'en', '(GMT+10:00) Brisbane', NULL),
(65, 'V', 'en', '(GMT+10:00) Canberra, Melbourne, Sydney', NULL),
(64, 'V', 'en', '(GMT+10:00) Guam, Port Moresby', NULL),
(63, 'V', 'en', '(GMT+10:00) Hobart', NULL),
(133, 'V', 'en', '(GMT+10:00) Vladivostok', NULL),
(134, 'V', 'en', '(GMT+11:00) Magadan, Solomon Is., New Caledonia', NULL),
(135, 'V', 'en', '(GMT+12:00) Auckland, Wellington', NULL),
(136, 'V', 'en', '(GMT+12:00) Fiji', NULL),
(239, 'V', 'en', '(GMT+12:00) Kamchatka, Marshall Is.', NULL),
(137, 'V', 'en', '(GMT+13:00) Nuku''alofa', NULL),
(235, 'V', 'en', 'Old (stored on file system)', NULL),
(236, 'V', 'en', 'New (nice and editable via admin panel)', NULL),
(241, 'V', 'en', 'International phone number', NULL),
(242, 'V', 'en', 'Any digits and +-()', NULL),
(243, 'V', 'en', 'Any symbols', NULL),
(260, 'V', 'en', 'Phone number with country selection', NULL),
(200, 'V', 'en', 'None', NULL),
(201, 'V', 'en', 'TLS', NULL),
(202, 'V', 'en', 'SSL', NULL),
(221, 'V', 'en', 'Display "New customer" first', NULL),
(220, 'V', 'en', 'Display "Returning customer" first', NULL),
(222, 'V', 'en', 'Hide step completely', NULL),
(223, 'V', 'en', 'Register', NULL),
(224, 'V', 'en', 'Checkout as guest', NULL),
(240, 'V', 'en', 'Realtime shipping errors', NULL),
(112, 'V', 'en', '(GMT-03:00) Bermuda', NULL),
(120, 'V', 'en', '(GMT+06:00) Almaty', NULL),
(132, 'V', 'en', '(GMT+06:30) Cocos', NULL),
(244, 'V', 'en', '(GMT-08:00) Pitcairn', NULL),
(245, 'V', 'en', '(GMT-08:00) Vancouver', NULL),
(246, 'V', 'en', '(GMT-09:00) Gambier', NULL),
(247, 'V', 'en', '(GMT+10:30) Lord Howe', NULL),
(248, 'V', 'en', '(GMT+12:45) Chatham', NULL),
(249, 'V', 'en', '(GMT+01:00) Casablanca', NULL),
(250, 'V', 'en', '(GMT+01:00) Dublin', NULL),
(251, 'V', 'en', '(GMT-11:00) United States Minor Outlying Islands', NULL),
(252, 'V', 'en', '(GMT+06:00) Urumqi', NULL),
(19, 'S', 'en', 'General', NULL),
(5679, 'O', 'en', 'Consider all uploaded images HiDPI', 'Make the "I''m uploading a HiDPI image" checkboxes ticked by default everywhere where images are uploaded. You''ll be able to untick those checkboxes when necessary.'),
(21, 'S', 'en', 'Twitter', NULL),
(5680, 'O', 'en', 'Show Twitter button', ''),
(5681, 'O', 'en', 'Via', 'User name to attribute the Tweet to (i.e. ''via @username'')'),
(5682, 'O', 'en', 'Button size', ''),
(2002, 'V', 'en', 'Medium', NULL),
(2003, 'V', 'en', 'Large', NULL),
(5683, 'O', 'en', 'Display count', ''),
(2004, 'V', 'en', 'None', NULL),
(2005, 'V', 'en', 'Horizontal', NULL),
(2006, 'V', 'en', 'vertical', NULL),
(5684, 'O', 'en', 'Display on', ''),
(2007, 'V', 'en', 'Product details pages', NULL),
(2008, 'V', 'en', 'Pages', NULL),
(22, 'S', 'en', 'Facebook', NULL),
(5685, 'O', 'en', 'Show Facebook button', ''),
(5686, 'O', 'en', 'Facebook app ID', 'Specify any Facebook app ID, otherwise the button will not be shown'),
(5687, 'O', 'en', 'The URL of the page to like', 'Leave empty to use an actual page URL'),
(5688, 'O', 'en', 'Include a Send button with the Like button', ''),
(5689, 'O', 'en', 'Width of the Like button (px)', ''),
(5690, 'O', 'en', 'Button layout', ''),
(2009, 'V', 'en', 'Standard', NULL),
(2010, 'V', 'en', 'With count', NULL),
(2011, 'V', 'en', 'With large count', NULL),
(5691, 'O', 'en', 'Display profile photos', 'Enable to display profile photos below the button (standard layout only)'),
(5692, 'O', 'en', 'Button verb', ''),
(2012, 'V', 'en', 'Like', NULL),
(2013, 'V', 'en', 'Recommend', NULL),
(5693, 'O', 'en', 'Language', ''),
(2014, 'V', 'en', 'Afrikaans', NULL),
(2015, 'V', 'en', 'Arabic', NULL),
(2016, 'V', 'en', 'Azerbaijani', NULL),
(2017, 'V', 'en', 'Belarusian', NULL),
(2018, 'V', 'en', 'Bulgarian', NULL),
(2019, 'V', 'en', 'Bengali', NULL),
(2020, 'V', 'en', 'Bosnian', NULL),
(2021, 'V', 'en', 'Catalan', NULL),
(2022, 'V', 'en', 'Czech', NULL),
(2023, 'V', 'en', 'Welsh', NULL),
(2024, 'V', 'en', 'Danish', NULL),
(2025, 'V', 'en', 'German', NULL),
(2026, 'V', 'en', 'Greek', NULL),
(2027, 'V', 'en', 'English (UK)', NULL),
(2028, 'V', 'en', 'English (Pirate)', NULL),
(2029, 'V', 'en', 'English (Upside Down)', NULL),
(2030, 'V', 'en', 'English (US)', NULL),
(2031, 'V', 'en', 'Esperanto', NULL),
(2032, 'V', 'en', 'Spanish (Spain)', NULL),
(2033, 'V', 'en', 'Spanish', NULL),
(2034, 'V', 'en', 'Estonian', NULL),
(2035, 'V', 'en', 'Basque', NULL),
(2036, 'V', 'en', 'Persian', NULL),
(2037, 'V', 'en', 'Leet Speak', NULL),
(2038, 'V', 'en', 'Finnish', NULL),
(2039, 'V', 'en', 'Faroese', NULL),
(2040, 'V', 'en', 'French (Canada)', NULL),
(2041, 'V', 'en', 'French (France)', NULL),
(2042, 'V', 'en', 'Frisian', NULL),
(2043, 'V', 'en', 'Irish', NULL),
(2044, 'V', 'en', 'Galician', NULL),
(2045, 'V', 'en', 'Hebrew', NULL),
(2046, 'V', 'en', 'Hindi', NULL),
(2047, 'V', 'en', 'Croatian', NULL),
(2048, 'V', 'en', 'Hungarian', NULL),
(2049, 'V', 'en', 'Armenian', NULL),
(2050, 'V', 'en', 'Indonesian', NULL),
(2051, 'V', 'en', 'Icelandic', NULL),
(2052, 'V', 'en', 'Italian', NULL),
(2053, 'V', 'en', 'Japanese', NULL),
(2054, 'V', 'en', 'Georgian', NULL),
(2055, 'V', 'en', 'Khmer', NULL),
(2056, 'V', 'en', 'Korean', NULL),
(2057, 'V', 'en', 'Kurdish', NULL),
(2058, 'V', 'en', 'Latin', NULL),
(2059, 'V', 'en', 'Lithuanian', NULL),
(2060, 'V', 'en', 'Latvian', NULL),
(2061, 'V', 'en', 'Macedonian', NULL),
(2062, 'V', 'en', 'Malayalam', NULL),
(2063, 'V', 'en', 'Malay', NULL),
(2064, 'V', 'en', 'Norwegian (bokmal)', NULL),
(2065, 'V', 'en', 'Nepali', NULL),
(2066, 'V', 'en', 'Dutch', NULL),
(2067, 'V', 'en', 'Norwegian (nynorsk)', NULL),
(2068, 'V', 'en', 'Punjabi', NULL),
(2069, 'V', 'en', 'Polish', NULL),
(2070, 'V', 'en', 'Pashto', NULL),
(2071, 'V', 'en', 'Portuguese (Brazil)', NULL),
(2072, 'V', 'en', 'Portuguese (Portugal)', NULL),
(2073, 'V', 'en', 'Romanian', NULL),
(2074, 'V', 'en', 'Russian', NULL),
(2075, 'V', 'en', 'Slovak', NULL),
(2076, 'V', 'en', 'Slovenian', NULL),
(2077, 'V', 'en', 'Albanian', NULL),
(2078, 'V', 'en', 'Serbian', NULL),
(2079, 'V', 'en', 'Swedish', NULL),
(2080, 'V', 'en', 'Swahili', NULL),
(2081, 'V', 'en', 'Tamil', NULL),
(2082, 'V', 'en', 'Telugu', NULL),
(2083, 'V', 'en', 'Thai', NULL),
(2084, 'V', 'en', 'Filipino', NULL),
(2085, 'V', 'en', 'Turkish', NULL),
(2086, 'V', 'en', 'Ukrainian', NULL),
(2087, 'V', 'en', 'Vietnamese', NULL),
(2088, 'V', 'en', 'Simplified Chinese (China)', NULL),
(2089, 'V', 'en', 'Traditional Chinese (Hong Kong)', NULL),
(2090, 'V', 'en', 'Traditional Chinese (Taiwan)', NULL),
(5694, 'O', 'en', 'Button font', ''),
(2091, 'V', 'en', 'Arial', NULL),
(2092, 'V', 'en', 'Lucida grande', NULL),
(2093, 'V', 'en', 'Segoe ui', NULL),
(2094, 'V', 'en', 'Tahoma', NULL),
(2095, 'V', 'en', 'Trebuchet ms', NULL),
(2096, 'V', 'en', 'Verdana', NULL),
(5695, 'O', 'en', 'Color scheme', ''),
(2097, 'V', 'en', 'Light', NULL),
(2098, 'V', 'en', 'Dark', NULL),
(5696, 'O', 'en', 'Display on', ''),
(2099, 'V', 'en', 'Product details pages', NULL),
(2100, 'V', 'en', 'Pages', NULL),
(23, 'S', 'en', 'Vkontakte', NULL),
(5697, 'O', 'en', 'Show Vkontakte button', ''),
(5698, 'O', 'en', 'Vkontakte app ID', ''),
(5699, 'O', 'en', 'Button layout', ''),
(2101, 'V', 'en', 'Button with a text counter', NULL),
(2102, 'V', 'en', 'Button with a little counter', NULL),
(2103, 'V', 'en', 'Mini button', NULL),
(2104, 'V', 'en', 'Mini button, counter on top', NULL),
(5700, 'O', 'en', 'Button height (px)', ''),
(5701, 'O', 'en', 'Button width (px)', 'Only for the button with text counter'),
(5702, 'O', 'en', 'Button name', ''),
(2105, 'V', 'en', 'Like', NULL),
(2106, 'V', 'en', 'It''s interesting', NULL),
(5703, 'O', 'en', 'Display on', ''),
(2107, 'V', 'en', 'Product details pages', NULL),
(2108, 'V', 'en', 'Pages', NULL),
(24, 'S', 'en', 'Yandex', NULL),
(5704, 'O', 'en', 'Show Yandex.Share block', ''),
(5705, 'O', 'en', 'Yandex.Share code', 'You can configure the block and get the code at <a href="http://api.yandex.ru/share/" target="_blank">http://api.yandex.ru/share/</a>'),
(5706, 'O', 'en', 'Display on', ''),
(2109, 'V', 'en', 'Product details pages', NULL),
(2110, 'V', 'en', 'Pages', NULL),
(25, 'S', 'en', 'Pinterest', NULL),
(5707, 'O', 'en', 'Show Pinterest button', ''),
(5708, 'O', 'en', 'Button size', ''),
(2111, 'V', 'en', 'Small', NULL),
(2112, 'V', 'en', 'Large', NULL),
(5709, 'O', 'en', 'Shape', ''),
(2113, 'V', 'en', 'Rectangular', NULL),
(2114, 'V', 'en', 'Circular', NULL),
(5710, 'O', 'en', 'Display on', ''),
(2115, 'V', 'en', 'Product details pages', NULL),
(2116, 'V', 'en', 'Pages', NULL),
(27, 'S', 'en', 'General', NULL),
(5711, 'O', 'en', 'Tags for products', ''),
(5712, 'O', 'en', 'Tags for pages', ''),
(29, 'S', 'en', 'General', NULL),
(5713, 'O', 'en', 'Content editor', 'Enter the content editor''s email and real name, e.g. john@example.com (John Doe)'),
(5714, 'O', 'en', 'Show RSS feed for each category', 'RSS icon near category title.'),
(5715, 'O', 'en', 'Max product number per category', ''),
(31, 'S', 'en', 'General', NULL),
(5716, 'O', 'en', 'Newsletters sent per step', ''),
(5717, 'O', 'en', 'Advanced mailing server options', ''),
(5718, 'O', 'en', 'Method of sending e-mails', ''),
(2117, 'V', 'en', 'via SMTP server', NULL),
(2118, 'V', 'en', 'via php mail function', NULL),
(2119, 'V', 'en', 'use default settings', NULL),
(5719, 'O', 'en', 'SMTP server settings', ''),
(5720, 'O', 'en', 'SMTP host', ''),
(5721, 'O', 'en', 'SMTP username', ''),
(5722, 'O', 'en', 'SMTP password', ''),
(5723, 'O', 'en', 'Use Encrypted Connection', ''),
(2120, 'V', 'en', 'None', NULL),
(2121, 'V', 'en', 'TLS', NULL),
(2122, 'V', 'en', 'SSL', NULL),
(5724, 'O', 'en', 'Use SMTP authentication', ''),
(32, 'S', 'en', 'Promotions', NULL),
(5725, 'O', 'en', 'Choose a promotion whose promo code will be given at subscription', ''),
(34, 'S', 'en', 'General', NULL),
(5726, 'O', 'en', 'Newsletter checkbox on checkout', ''),
(5727, 'O', 'en', 'Tick off by default', ''),
(5728, 'O', 'en', 'Double opt-in', ''),
(5729, 'O', 'en', 'Send a welcome letter with the unsubscribe link', ''),
(5730, 'O', 'en', 'Email integration provider', ''),
(2123, 'V', 'en', '--', NULL),
(2124, 'V', 'en', 'MailChimp', NULL),
(2125, 'V', 'en', 'MadMimi', NULL),
(5731, 'O', 'en', '', ''),
(5732, 'O', 'en', '', ''),
(35, 'S', 'en', 'MailChimp', NULL),
(5733, 'O', 'en', 'API key', ''),
(5734, 'O', 'en', 'List', ''),
(36, 'S', 'en', 'MadMimi', NULL),
(5735, 'O', 'en', 'E-mail', ''),
(5736, 'O', 'en', 'API key', ''),
(5737, 'O', 'en', 'List', ''),
(38, 'S', 'en', 'General', NULL),
(5738, 'O', 'en', 'Save attachments to your server', 'Attachments listed as URLs in the imported file will be downloaded to your server.'),
(40, 'S', 'en', 'For customers', NULL),
(5739, 'O', 'en', 'Contact button on product pages', 'Show the "Ask a question" button on product pages.'),
(5740, 'O', 'en', 'Contact button at "Messages" menu', ''),
(5741, 'O', 'en', 'Contact button on detailed order page', 'Show the "Start communication" button on detailed order page.'),
(42, 'S', 'en', 'General', NULL),
(5742, 'O', 'en', 'Provider', ''),
(2126, 'V', 'en', 'Google', NULL),
(2127, 'V', 'en', 'Yandex', NULL),
(5743, 'O', 'en', 'Show shipping cost and time on product pages', ''),
(43, 'S', 'en', 'Yandex', NULL),
(5744, 'O', 'en', 'API key', 'Get the API key and Geosuggest API key here: <a href="https://developer.tech.yandex.ru/" target="_blank">https://developer.tech.yandex.ru</a>'),
(5745, 'O', 'en', 'Geosuggest API key', ''),
(5746, 'O', 'en', 'I use the paid version of the API', ''),
(5747, 'O', 'en', '', ''),
(44, 'S', 'en', 'Google', NULL),
(5748, 'O', 'en', '', ''),
(5749, 'O', 'en', 'API key', 'Get the API key here: <a href=" https://console.developers.google.com" target="_blank"> https://console.developers.google.com</a>'),
(5750, 'O', 'en', '', ''),
(46, 'S', 'en', 'General', NULL),
(5751, 'O', 'en', 'Minimal amount', ''),
(5752, 'O', 'en', 'Maximal amount', ''),
(5753, 'O', 'en', 'GC Code prefix', ''),
(5754, 'O', 'en', 'Gift certificates per page', ''),
(5755, 'O', 'en', 'Allow to use free products', ''),
(5756, 'O', 'en', 'Allow to redeem shipping cost with gift certificate', ''),
(48, 'S', 'en', 'General', NULL),
(5757, 'O', 'en', 'Show map in order-related documents', 'Print the map on the packing slip and invoice'),
(5758, 'O', 'en', 'Use list of cities instead of a map', 'Affects the Customer Geolocation block. The list will be generated from cities that have stores and pickup points.'),
(50, 'S', 'en', 'General', NULL),
(5759, 'O', 'en', 'Allow own images for child variations', 'If child variations aren''t allowed to have their own images, they will use the images from the default variation of the catalog item.'),
(5760, 'O', 'en', 'Allow own feature values for child variations', 'If child variations aren''t allowed to have their own values for features, they will use the values from the default variation of the catalog item.'),
(5761, 'O', 'en', 'Change default variation when it gets hidden or runs out of stock', 'Ensure that customers always see the products that are in stock first. We recommend leaving this setting enabled for better filtering of variations.'),
(5762, 'O', 'en', 'Show all possible feature variants', 'Show a feature variant even if it is not available for this variation.'),
(5763, 'O', 'en', 'Give quantity discount on different product variations', 'All variations in the same group will count to the quantity that is eligible for a discount.'),
(52, 'S', 'en', 'General', NULL),
(5764, 'O', 'en', '', ''),
(5765, 'O', 'en', 'reCAPTCHA v2 settings', ''),
(5766, 'O', 'en', 'Site key', ''),
(5767, 'O', 'en', 'Secret', ''),
(5768, 'O', 'en', 'Theme', ''),
(2128, 'V', 'en', 'Light', NULL),
(2129, 'V', 'en', 'Dark', NULL),
(5769, 'O', 'en', 'Size', ''),
(2130, 'V', 'en', 'Normal', NULL),
(2131, 'V', 'en', 'Compact', NULL),
(5770, 'O', 'en', 'Type', ''),
(2132, 'V', 'en', 'Image', NULL),
(2133, 'V', 'en', 'Audio', NULL),
(5771, 'O', 'en', 'reCAPTCHA v3 settings', ''),
(5772, 'O', 'en', 'Site key', ''),
(5773, 'O', 'en', 'Secret', ''),
(5774, 'O', 'en', 'Required rating to pass the check', ''),
(2134, 'V', 'en', '0.9 (even some humans can''t pass)', NULL),
(2135, 'V', 'en', '0.8', NULL),
(2136, 'V', 'en', '0.7', NULL),
(2137, 'V', 'en', '0.6', NULL),
(2138, 'V', 'en', '0.5 (recommended value)', NULL),
(2139, 'V', 'en', '0.4', NULL),
(2140, 'V', 'en', '0.3', NULL),
(2141, 'V', 'en', '0.2', NULL),
(2142, 'V', 'en', '0.1 (bots are welcome)', NULL),
(5775, 'O', 'en', 'Antibot settings', ''),
(5776, 'O', 'en', '', ''),
(5777, 'O', 'en', '', ''),
(5778, 'O', 'en', '', ''),
(53, 'S', 'en', 'Excluded countries', NULL),
(5779, 'O', 'en', '', ''),
(5780, 'O', 'en', 'Excluded countries', ''),
(55, 'S', 'en', 'General', NULL),
(5781, 'O', 'en', 'Show bundles', ''),
(2143, 'V', 'en', 'Before product description', NULL),
(2144, 'V', 'en', 'In a product tab', NULL),
(57, 'S', 'en', 'General', NULL),
(5782, 'O', 'en', 'Returnable', 'This will be the default value for new products.'),
(5783, 'O', 'en', 'Return period (days)', 'This will be the default value for new products.'),
(5784, 'O', 'en', 'Display product return period', ''),
(5785, 'O', 'en', 'Do not take weekends into account when calculating product return period', ''),
(59, 'S', 'en', 'General', NULL),
(5786, 'O', 'en', 'Minimum final sale discount (%)', ''),
(5787, 'O', 'en', 'Minimum sales amount to define bestsellers', ''),
(60, 'S', 'en', 'Newest', NULL),
(5788, 'O', 'en', 'Period', ''),
(2145, 'V', 'en', 'All days', NULL),
(2146, 'V', 'en', 'Today', NULL),
(2147, 'V', 'en', 'Last days', NULL),
(5789, 'O', 'en', 'Last days', ''),
(62, 'S', 'en', 'General', NULL),
(5790, 'O', 'en', 'Product SEO URL format', ''),
(2148, 'V', 'en', '/product-name/', NULL),
(2149, 'V', 'en', '/product-name.html', NULL),
(2150, 'V', 'en', '/category-name/[subcategory-name/]product-name/', NULL),
(2151, 'V', 'en', '/category-name/[subcategory-name/]product-name.html', NULL),
(5791, 'O', 'en', 'Category SEO URL format', ''),
(2152, 'V', 'en', '/parent-category/category-[page-2].html', NULL),
(2153, 'V', 'en', '/parent-category/category/[page-2/]', NULL),
(2154, 'V', 'en', '/category[-page-2].html', NULL),
(2155, 'V', 'en', '/category/[page-2/]', NULL),
(5792, 'O', 'en', 'Page SEO URL format', ''),
(2156, 'V', 'en', '/parent-page/page.html', NULL),
(2157, 'V', 'en', '/parent-page/page/', NULL),
(2158, 'V', 'en', '/page.html', NULL),
(2159, 'V', 'en', '/page/', NULL),
(5793, 'O', 'en', 'Other SEO URL format', ''),
(2160, 'V', 'en', '/item/', NULL),
(2161, 'V', 'en', '/item.html', NULL),
(5794, 'O', 'en', 'Show additional language in the URL', ''),
(5795, 'O', 'en', 'Use single URL for all languages', ''),
(5796, 'O', 'en', 'Allow non-latin symbols in URL', ''),
(64, 'S', 'en', 'General', NULL),
(5797, 'O', 'en', 'Points Exchange Rate (PER - the number of points equal to 1 conventional unit)', ''),
(5798, 'O', 'en', '"Price in points" is calculated automatically on PER basis', ''),
(5799, 'O', 'en', '"Price in points" is recalculated taking into account discounts', ''),
(5800, 'O', 'en', '"Points" is recalculated taking into account discounts', ''),
(5801, 'O', 'en', '"Price in points" is recalculated taking into account order discounts', ''),
(5802, 'O', 'en', '"Points" is recalculated taking into account order discounts', ''),
(5803, 'O', 'en', 'If the product and the product category do not have defined reward points but the higher level category has such reward points, extract data from it', ''),
(5804, 'O', 'en', 'If several reward points can be applied, set', ''),
(2162, 'V', 'en', 'Absolute minimal value', NULL),
(2163, 'V', 'en', 'Minimal percentage value', NULL),
(2164, 'V', 'en', 'Absolute maximal value', NULL),
(2165, 'V', 'en', 'Maximal percentage value', NULL),
(5805, 'O', 'en', 'Apply zero reward point values', 'The reward points rules with the zero values should be considered'),
(5806, 'O', 'en', 'Log lines per page', ''),
(66, 'S', 'en', 'General', NULL),
(5807, 'O', 'en', 'Google Analytics account number', ''),
(5808, 'O', 'en', 'Track e-commerce transactions', ''),
(68, 'S', 'en', 'General', NULL),
(5809, 'O', 'en', 'Facebook Pixel Identifier', ''),
(5810, 'O', 'en', 'Track all page views', ''),
(5811, 'O', 'en', 'Track adding product to cart', ''),
(5812, 'O', 'en', 'Track placing order', ''),
(70, 'S', 'en', 'General', NULL),
(5813, 'O', 'en', 'General', ''),
(5814, 'O', 'en', '', ''),
(5815, 'O', 'en', 'Rewrite phone', ''),
(5816, 'O', 'en', 'Highlight first chars [Deprecated]', 'Including parenthesis, spaces, etc. Use to highlight country code, area code, and phone prefix.'),
(5817, 'O', 'en', 'Phone mask [Deprecated]', 'Leave empty to use automatic country-based phone pattern, or type in a custom pattern. You can use spaces, commas, +, -, and digits. Note that 9 represents any digit; if you need a 9, type \\\\9. Examples: +9 (999) 999 99 99, 99999999, 999 999 99 or +99-99-9999-9999.'),
(5818, 'O', 'en', 'Enable the "Buy now with one click" option', ''),
(5819, 'O', 'en', 'Order status', ''),
(72, 'S', 'en', 'General', NULL),
(5820, 'O', 'en', 'Image', ''),
(5821, 'O', 'en', 'Example Image', ''),
(5822, 'O', 'en', 'Configs', ''),
(5823, 'O', 'en', 'Type', ''),
(2166, 'V', 'en', 'Code 128-A', NULL),
(2167, 'V', 'en', 'Code 128-B', NULL),
(2168, 'V', 'en', 'Code 128-C', NULL),
(2169, 'V', 'en', 'Interleaved 2 of 5', NULL),
(2170, 'V', 'en', 'Code 39', NULL),
(5824, 'O', 'en', 'Output', ''),
(2171, 'V', 'en', 'Portable Network Graphics (PNG)', NULL),
(2172, 'V', 'en', 'Joint Photographic Experts Group (JPEG)', NULL),
(5825, 'O', 'en', 'Text', ''),
(2173, 'V', 'en', 'Disabled', NULL),
(2174, 'V', 'en', 'Enabled', NULL),
(5826, 'O', 'en', 'Height,px', ''),
(5827, 'O', 'en', 'Width,px', ''),
(5828, 'O', 'en', 'Barcode prefix', ''),
(5829, 'O', 'en', 'Specification', ''),
(5830, 'O', 'en', 'Spec Description', ''),
(74, 'S', 'en', 'General', NULL),
(5831, 'O', 'en', 'Votes on page', ''),
(5832, 'O', 'en', 'Answers on page', ''),
(76, 'S', 'en', 'General', NULL),
(5833, 'O', 'en', 'Administrator area settings', ''),
(5834, 'O', 'en', 'Allow login to the admin area from specified IPs only', ''),
(5835, 'O', 'en', 'Block IP after a number of unsuccessful attempts', ''),
(5836, 'O', 'en', 'Number of unsuccessful attempts', ''),
(5837, 'O', 'en', 'Time between unsuccessful login attempts (seconds)', ''),
(5838, 'O', 'en', 'Time for which the IP should be blocked (hours)', ''),
(5839, 'O', 'en', 'Customer area settings', ''),
(5840, 'O', 'en', 'Block IP after a number of unsuccessful attempts', ''),
(5841, 'O', 'en', 'Number of unsuccessful attempts', ''),
(5842, 'O', 'en', 'Time between unsuccessful login attempts (seconds)', ''),
(5843, 'O', 'en', 'Time for which the IP should be blocked (hours)', ''),
(78, 'S', 'en', 'General', NULL),
(5844, 'O', 'en', 'Enable multi-language Images/URLs', ''),
(80, 'S', 'en', 'Products', NULL),
(5845, 'O', 'en', 'Posts per page', ''),
(5846, 'O', 'en', 'Administrator must approve posts submitted by', ''),
(2175, 'V', 'en', 'Any customer', NULL),
(2176, 'V', 'en', 'Only anonymous customers', NULL),
(2177, 'V', 'en', 'No approval needed', NULL),
(5847, 'O', 'en', 'Only one post from one IP is allowed', ''),
(5848, 'O', 'en', 'Default value', 'Determines if comments and/or reviews are allowed for newly-created products. Doesn''t affect existing products.'),
(5849, 'O', 'en', 'Share discussions with all stores', 'Show all comments and reviews of a product on all storefronts that the product is shared with'),
(5850, 'O', 'en', 'Only buyers can post', 'Allow leaving reviews for a product only to those who bought that product.'),
(81, 'S', 'en', 'Categories', NULL),
(5851, 'O', 'en', 'Posts per page', ''),
(5852, 'O', 'en', 'Administrator must approve posts submitted by', ''),
(2178, 'V', 'en', 'Any customer', NULL),
(2179, 'V', 'en', 'Only anonymous customers', NULL),
(2180, 'V', 'en', 'No approval needed', NULL),
(5853, 'O', 'en', 'Only one post from one IP is allowed', ''),
(5854, 'O', 'en', 'Default value', 'Determines if comments and/or reviews are allowed for newly-created categories. Doesn''t affect existing categories.'),
(82, 'S', 'en', 'Orders', NULL),
(5855, 'O', 'en', 'Posts per page', ''),
(5856, 'O', 'en', 'Allow customer to initiate discussion', ''),
(83, 'S', 'en', 'Pages', NULL),
(5857, 'O', 'en', 'Posts per page', ''),
(5858, 'O', 'en', 'Administrator must approve posts submitted by', ''),
(2181, 'V', 'en', 'Any customer', NULL),
(2182, 'V', 'en', 'Only anonymous customers', NULL),
(2183, 'V', 'en', 'No approval needed', NULL),
(5859, 'O', 'en', 'Only one post from one IP is allowed', ''),
(5860, 'O', 'en', 'Default value', 'Determines if comments and/or reviews are allowed for newly-created pages. Doesn''t affect existing pages.'),
(5861, 'O', 'en', 'Share discussions with all stores', 'Show all comments and reviews of a page on all storefronts that the page is shared with'),
(84, 'S', 'en', 'Testimonials', NULL),
(5862, 'O', 'en', 'Posts per page', ''),
(5863, 'O', 'en', 'Administrator must approve posts submitted by', ''),
(2184, 'V', 'en', 'Any customer', NULL),
(2185, 'V', 'en', 'Only anonymous customers', NULL),
(2186, 'V', 'en', 'No approval needed', NULL),
(5864, 'O', 'en', 'Only one post from one IP is allowed', ''),
(5865, 'O', 'en', 'Testimonials', ''),
(5866, 'O', 'en', 'Show testimonials from all stores', ''),
(86, 'S', 'en', 'General', NULL),
(5867, 'O', 'en', 'Watermark', ''),
(5868, 'O', 'en', '', ''),
(5869, 'O', 'en', 'Product watermarks', ''),
(5870, 'O', 'en', 'Resized images', ''),
(5871, 'O', 'en', 'Original size images', ''),
(5872, 'O', 'en', 'Category watermarks', ''),
(5873, 'O', 'en', 'Resized images', ''),
(5874, 'O', 'en', 'Original size images', ''),
(5875, 'O', 'en', 'Images access', ''),
(88, 'S', 'en', '', NULL),
(5876, 'O', 'en', '', ''),
(5877, 'O', 'en', 'Reviews per page', ''),
(5878, 'O', 'en', 'Administrator must approve posts submitted by', ''),
(2187, 'V', 'en', 'Any customer', NULL),
(2188, 'V', 'en', 'Only anonymous customers', NULL),
(2189, 'V', 'en', 'No approval needed', NULL),
(5879, 'O', 'en', 'Allow one review per IP address', ''),
(5880, 'O', 'en', 'Review fields', ''),
(2190, 'V', 'en', 'Comment with advantages and disadvantages', NULL),
(2191, 'V', 'en', 'Only comment', NULL),
(5881, 'O', 'en', 'Only buyers can post', 'Allow leaving reviews for a product only to those who bought that product.'),
(5882, 'O', 'en', 'Ask for customer location', ''),
(2192, 'V', 'en', 'None', NULL),
(2193, 'V', 'en', 'Country', NULL),
(2194, 'V', 'en', 'City', NULL),
(5883, 'O', 'en', 'Split reviews by storefront', ''),
(5884, 'O', 'en', '', ''),
(5885, 'O', 'en', '', ''),
(5886, 'O', 'en', '', ''),
(90, 'S', 'en', 'General', NULL),
(5887, 'O', 'en', 'Animation time', 'Duration of the animation effects in milliseconds.'),
(5888, 'O', 'en', 'Zoom position', 'Specifies position of zoom window.'),
(2195, 'V', 'en', 'Upper right corner', NULL),
(2196, 'V', 'en', 'Bottom right corner', NULL),
(2197, 'V', 'en', 'Upper left corner', NULL),
(2198, 'V', 'en', 'Bottom left corner', NULL),
(92, 'S', 'en', 'General', NULL),
(5889, 'O', 'en', 'Information', ''),
(5890, 'O', 'en', 'Clear cache', ''),
(5891, 'O', 'en', '', ''),
(5892, 'O', 'en', 'Homepage settings', ''),
(5893, 'O', 'en', 'Update frequency', ''),
(5894, 'O', 'en', 'Priority', ''),
(5895, 'O', 'en', 'Products settings', ''),
(5896, 'O', 'en', 'Include in sitemap', ''),
(5897, 'O', 'en', 'Update frequency', ''),
(5898, 'O', 'en', 'Priority', ''),
(5899, 'O', 'en', 'Categories settings', ''),
(5900, 'O', 'en', 'Include in sitemap', ''),
(5901, 'O', 'en', 'Update frequency', ''),
(5902, 'O', 'en', 'Priority', ''),
(5903, 'O', 'en', 'Pages settings', ''),
(5904, 'O', 'en', 'Include in sitemap', ''),
(5905, 'O', 'en', 'Update frequency', ''),
(5906, 'O', 'en', 'Priority', ''),
(5907, 'O', 'en', 'Brand/Manufacturer feature pages settings', ''),
(5908, 'O', 'en', 'Include in sitemap', ''),
(5909, 'O', 'en', 'Update frequency', ''),
(5910, 'O', 'en', 'Priority', ''),
(94, 'S', 'en', 'General', NULL),
(5911, 'O', 'en', 'Cron password', ''),
(96, 'S', 'en', 'General', NULL),
(5912, 'O', 'en', '', ''),
(5913, 'O', 'en', 'Fields', ''),
(5914, 'O', 'en', 'Sort by', ''),
(5915, 'O', 'en', 'Group by category', ''),
(5916, 'O', 'en', 'Include product options', ''),
(98, 'S', 'en', 'General', NULL),
(5917, 'O', 'en', 'General info', ''),
(5918, 'O', 'en', 'API Key', ''),
(5919, 'O', 'en', 'Application Domain', ''),
(100, 'S', 'en', 'General', NULL),
(5920, 'O', 'en', 'Store operation mode', ''),
(2199, 'V', 'en', 'Catalog', NULL),
(2200, 'V', 'en', 'Store', NULL),
(5921, 'O', 'en', 'Allow purchasing products with empty Buy Now URL', ''),
(102, 'S', 'en', 'General', NULL),
(5922, 'O', 'en', 'Icons pack', 'Directory with the social networks icons. A path to the directory: media/images/addons/addons/hybrid_auth/icons/.'),
(5923, 'O', 'en', 'Autogeneration email', 'Enables the email auto generation in case that a social network does not pass the address.'),
(104, 'S', 'en', '', NULL),
(5924, 'O', 'en', '', ''),
(106, 'S', 'en', 'General', NULL),
(5925, 'O', 'en', 'Cookie consent', '"Implicit consent" is a simple notification that the site uses cookies. "Explicit consent" means that visitors can select the services that can or can''t set cookies.'),
(2201, 'V', 'en', 'None', NULL),
(2202, 'V', 'en', 'Implicit', NULL),
(2203, 'V', 'en', 'Explicit', NULL),
(5926, 'O', 'en', 'Privacy policy page', ''),
(5927, 'O', 'en', '', ''),
(107, 'S', 'en', 'GDPR', NULL),
(5928, 'O', 'en', '', ''),
(5929, 'O', 'en', '', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]settings_objects`
--

CREATE TABLE `[[dbprefix]]settings_objects` (
  `object_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `edition_type` set('NONE','ROOT','VENDOR','STOREFRONT','MVE:NONE','MVE:ROOT','MVE:STOREFRONT','ULT:NONE','ULT:ROOT','ULT:VENDOR','ULT:VENDORONLY','ULT:STOREFRONT') NOT NULL DEFAULT 'ROOT',
  `name` varchar(128) NOT NULL DEFAULT '',
  `section_id` int(11) unsigned NOT NULL,
  `section_tab_id` int(11) unsigned NOT NULL,
  `type` char(1) NOT NULL DEFAULT 'I',
  `value` text,
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `is_global` char(1) NOT NULL DEFAULT 'Y',
  `handler` varchar(128) NOT NULL DEFAULT '',
  `parent_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`object_id`),
  KEY `name` (`name`),
  KEY `is_global` (`is_global`),
  KEY `position` (`position`),
  KEY `section_id` (`section_id`,`section_tab_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=5930 ;

--
-- Dumping data for table `[[dbprefix]]settings_objects`
--

INSERT INTO `[[dbprefix]]settings_objects` VALUES
(2, 'ROOT,STOREFRONT', 'allow_usergroup_signup', 2, 0, 'C', 'Y', 249, 'Y', '', 0),
(3, 'ROOT,STOREFRONT', 'exception_style', 2, 0, 'S', 'hide', 160, 'Y', '', 0),
(7, 'ROOT', 'feedback_type', 2, 0, 'S', 'manual', 57, 'Y', '', 0),
(8, 'ROOT', 'ftp_hostname', 13, 0, 'I', '', 30, 'N', '', 0),
(9, 'ROOT', 'ftp_username', 13, 0, 'I', '', 40, 'N', '', 0),
(10, 'ROOT', 'ftp_password', 13, 0, 'P', '', 50, 'N', '', 0),
(11, 'ROOT', 'ftp_directory', 13, 0, 'I', '', 60, 'N', '', 0),
(12, 'ROOT', 'license_number', 13, 0, 'A', '', 10, 'N', '', 0),
(13, 'ROOT', 'product_release_info', 13, 0, 'O', '', 11, 'N', '', 0),
(14, 'ROOT', 'auto_check_updates', 2, 0, 'C', 'Y', 58, 'Y', '', 0),
(15, 'ROOT,STOREFRONT', 'alternative_currency', 2, 0, 'S', 'use_only_selected', 10, 'Y', '', 0),
(16, 'ROOT,STOREFRONT', 'weight_symbol', 2, 0, 'I', 'lbs', 30, 'Y', '', 0),
(17, 'ROOT,STOREFRONT', 'default_address', 6, 0, 'I', 'Boston street', 410, 'Y', '', 0),
(18, 'ROOT,STOREFRONT', 'default_zipcode', 6, 0, 'I', '02125', 420, 'Y', '', 0),
(19, 'ROOT,STOREFRONT', 'default_city', 6, 0, 'I', 'Boston', 430, 'Y', '', 0),
(20, 'ROOT,STOREFRONT', 'default_country', 6, 0, 'X', 'US', 440, 'Y', '', 0),
(21, 'ROOT,STOREFRONT', 'default_state', 6, 0, 'W', 'MA', 450, 'Y', '', 0),
(22, 'ROOT,STOREFRONT', 'products_per_page', 4, 0, 'U', '12', 100, 'Y', '', 0),
(24, 'ROOT', 'admin_elements_per_page', 4, 0, 'U', '50', 60, 'Y', '', 0),
(25, 'ROOT,ULT:VENDOR', 'company_state', 5, 0, 'W', 'MA', 40, 'Y', '', 0),
(26, 'ROOT,ULT:VENDOR', 'company_city', 5, 0, 'I', 'Boston', 20, 'Y', '', 0),
(27, 'ROOT,ULT:VENDOR', 'company_address', 5, 0, 'I', '44 Main street', 10, 'Y', '', 0),
(28, 'ROOT,ULT:VENDOR', 'company_phone', 5, 0, 'L', '+19177227425', 60, 'Y', '', 0),
(29, 'ROOT,ULT:VENDOR', 'company_phone_2', 5, 0, 'L', '', 70, 'Y', '', 0),
(31, 'ROOT,ULT:VENDOR', 'company_name', 5, 0, 'I', '[[site_name]]', 0, 'Y', '', 0),
(32, 'ROOT,ULT:VENDOR', 'company_website', 5, 0, 'I', 'http://www.example.com/', 90, 'Y', '', 0),
(33, 'ROOT,ULT:VENDOR', 'company_zipcode', 5, 0, 'I', '02116', 50, 'Y', '', 0),
(34, 'ROOT,ULT:VENDOR', 'company_country', 5, 0, 'X', 'US', 30, 'Y', '', 0),
(35, 'ROOT,ULT:VENDOR', 'company_users_department', 5, 0, 'I', '[[admin_email]]', 100, 'Y', '', 0),
(36, 'ROOT,ULT:VENDOR', 'company_site_administrator', 5, 0, 'I', '[[admin_email]]', 110, 'Y', '', 0),
(37, 'ROOT,ULT:VENDOR', 'company_orders_department', 5, 0, 'I', '[[admin_email]]', 120, 'Y', '', 0),
(38, 'ROOT,ULT:VENDOR', 'company_support_department', 5, 0, 'I', '[[admin_email]]', 130, 'Y', '', 0),
(39, 'ROOT,ULT:VENDOR', 'company_newsletter_email', 5, 0, 'I', '[[admin_email]]', 140, 'Y', '', 0),
(40, 'ROOT,ULT:VENDOR', 'company_start_year', 5, 0, 'I', '2004', 95, 'Y', '', 0),
(41, 'ROOT,STOREFRONT', 'default_phone', 6, 0, 'L', '+16175556985', 460, 'Y', '', 0),
(42, 'ROOT,STOREFRONT', 'weight_symbol_grams', 2, 0, 'I', '453.6', 40, 'Y', '', 0),
(44, 'ROOT', 'allow_negative_amount', 2, 0, 'C', 'N', 135, 'Y', '', 0),
(46, 'ROOT,STOREFRONT', 'orders_per_page', 4, 0, 'U', '10', 90, 'Y', '', 0),
(47, 'ROOT,STOREFRONT', 'elements_per_page', 4, 0, 'U', '10', 130, 'Y', '', 0),
(48, 'ROOT', 'notice_displaying_time', 4, 0, 'I', '5', 260, 'Y', '', 0),
(49, 'ROOT', 'default_wysiwyg_editor', 4, 0, 'S', 'redactor2', 60, 'Y', '', 0),
(50, 'ROOT', 'default_image_previewer', 4, 0, 'S', 'owl', 189, 'Y', '', 0),
(52, 'ROOT', 'date_format', 4, 0, 'S', '%m/%d/%Y', 200, 'Y', '', 0),
(53, 'ROOT,STOREFRONT', 'frontend_default_language', 4, 0, 'S', 'en', 80, 'Y', '', 0),
(54, 'ROOT', 'backend_default_language', 4, 0, 'S', 'en', 15, 'Y', '', 0),
(55, 'ROOT,STOREFRONT', 'secure_storefront', 15, 0, 'C', '[[https_enable]]', 1, 'Y', '', 0),
(56, 'ROOT', 'secure_admin', 15, 0, 'C', '[[https_enable]]', 2, 'Y', '', 0),
(58, 'ROOT,ULT:VENDOR', 'inventory_tracking', 2, 0, 'C', 'Y', 130, 'Y', '', 0),
(61, 'ROOT,ULT:VENDOR', 'store_access_key', 2, 0, 'O', '', 51, 'Y', 'fn_get_store_access_key_notice', 0),
(62, 'ROOT', 'order_start_id', 6, 0, 'I', '', 340, 'Y', '', 0),
(63, 'ROOT,STOREFRONT', 'columns_in_products_list', 4, 0, 'I', '3', 150, 'Y', '', 0),
(64, 'ROOT,STOREFRONT', 'default_products_sorting', 4, 0, 'K', 'product-asc', 198, 'Y', '', 0),
(65, 'ROOT,ULT:VENDOR', 'edp_key_ttl', 2, 0, 'I', '24', 140, 'Y', '', 0),
(66, 'ROOT', 'time_format', 4, 0, 'S', '%H:%M', 210, 'Y', '', 0),
(67, 'ROOT,STOREFRONT', 'user_multiple_profiles', 2, 0, 'C', 'N', 240, 'Y', '', 0),
(69, 'ROOT,STOREFRONT', 'min_order_amount', 6, 0, 'I', '0', 360, 'Y', '', 0),
(70, 'ROOT,STOREFRONT', 'min_order_amount_type', 2, 0, 'D', 'only_products', 242, 'Y', '', 0),
(71, 'ROOT,STOREFRONT', 'allow_anonymous_shopping', 6, 0, 'S', 'allow_shopping', 370, 'Y', '', 0),
(72, 'ROOT,STOREFRONT', 'show_products_from_subcategories', 2, 0, 'C', 'Y', 150, 'Y', '', 0),
(73, 'ROOT,STOREFRONT', 'disable_anonymous_checkout', 6, 0, 'C', 'N', 244, 'Y', '', 0),
(77, 'ROOT,ULT:VENDOR', 'low_stock_threshold', 2, 0, 'I', '0', 145, 'Y', '', 0),
(78, 'ROOT,STOREFRONT', 'approve_user_profiles', 2, 0, 'C', 'N', 250, 'Y', '', 0),
(84, 'ROOT,ULT:VENDOR', 'day', 10, 0, 'S', '%a, %b %e', 20, 'Y', '', 0),
(85, 'ROOT,ULT:VENDOR', 'week', 10, 0, 'S', '%U, %b', 30, 'Y', '', 0),
(86, 'ROOT,ULT:VENDOR', 'month', 10, 0, 'S', '%B', 40, 'Y', '', 0),
(87, 'ROOT,ULT:VENDOR', 'year', 10, 0, 'S', '%Y', 50, 'Y', '', 0),
(89, 'ROOT', 'jpeg_quality', 9, 0, 'U', '80', 90, 'Y', '', 0),
(90, 'ROOT', 'convert_to', 9, 0, 'S', 'original', 80, 'Y', '', 0),
(91, 'ROOT,STOREFRONT', 'thumbnail_background_color', 9, 0, 'I', '#ffffff', 70, 'Y', '', 0),
(93, 'ROOT,STOREFRONT', 'display_options_modifiers', 2, 0, 'C', 'Y', 155, 'Y', '', 0),
(94, 'ROOT,STOREFRONT', 'show_out_of_stock_products', 2, 0, 'C', 'Y', 180, 'Y', '', 0),
(98, 'ROOT,STOREFRONT', 'use_single_coupon', 2, 0, 'C', 'Y', 225, 'Y', '', 0),
(100, 'ROOT,STOREFRONT', 'agree_terms_conditions', 6, 0, 'D', 'N', 270, 'Y', '', 0),
(105, 'ROOT,STOREFRONT', 'show_cats', 8, 0, 'C', 'Y', 10, 'N', '', 0),
(106, 'ROOT,STOREFRONT', 'show_rootcats_only', 8, 0, 'C', 'N', 20, 'N', '', 0),
(107, 'ROOT,STOREFRONT', 'show_site_info', 8, 0, 'C', 'Y', 35, 'N', '', 0),
(108, 'ROOT', 'mailer_send_method', 1, 0, 'S', 'mail', 10, 'N', '', 0),
(109, 'ROOT,ULT:VENDOR', 'mailer_smtp_host', 1, 0, 'I', '', 30, 'N', '', 0),
(110, 'ROOT,ULT:VENDOR', 'mailer_smtp_auth', 1, 0, 'C', 'N', 60, 'N', '', 0),
(111, 'ROOT,ULT:VENDOR', 'mailer_smtp_username', 1, 0, 'I', '', 40, 'N', '', 0),
(112, 'ROOT,ULT:VENDOR', 'mailer_smtp_password', 1, 0, 'P', '', 50, 'N', '', 0),
(295, 'ROOT,ULT:VENDOR', 'mailer_smtp_ecrypted_connection', 1, 0, 'S', '', 55, 'N', '', 0),
(113, 'ROOT', 'mailer_sendmail_path', 1, 0, 'I', '/usr/sbin/sendmail', 80, 'N', '', 0),
(116, 'ROOT,STOREFRONT', 'show_prices_taxed_clean', 4, 0, 'C', 'N', 184, 'Y', '', 0),
(117, 'ROOT,STOREFRONT', 'height', 11, 0, 'D', '30', 20, 'N', '', 0),
(118, 'ROOT,STOREFRONT', 'string_length', 11, 0, 'D', '5', 30, 'N', '', 0),
(119, 'ROOT,STOREFRONT', 'min_font_size', 11, 0, 'D', '14', 40, 'N', '', 0),
(120, 'ROOT,STOREFRONT', 'max_font_size', 11, 0, 'D', '16', 50, 'N', '', 0),
(121, 'ROOT,STOREFRONT', 'string_type', 11, 0, 'D', 'mixed', 60, 'N', '', 0),
(122, 'ROOT,STOREFRONT', 'char_shadow', 11, 0, 'D', 'N', 65, 'N', '', 0),
(123, 'ROOT,STOREFRONT', 'colour', 11, 0, 'D', 'N', 70, 'N', '', 0),
(124, 'ROOT,STOREFRONT', 'background_image', 11, 0, 'D', '', 80, 'N', '', 0),
(125, 'ROOT,STOREFRONT', 'lines_number', 11, 0, 'D', '20', 35, 'N', '', 0),
(126, 'ROOT,STOREFRONT', 'grid_color', 11, 0, 'D', 'cccccc', 36, 'N', '', 0),
(133, 'ROOT,STOREFRONT', 'width', 11, 0, 'D', '110', 10, 'N', '', 0),
(134, 'ROOT,STOREFRONT', 'hide_if_logged', 11, 0, 'C', 'Y', 85, 'Y', '', 0),
(138, 'ROOT,STOREFRONT', 'use_for', 11, 0, 'N', '#M#register=Y&form_builder=Y&email_share=Y&discussion=Y&checkout=Y&polls=Y&gift_certificates=Y', 5, 'Y', '', 0),
(139, 'ROOT', 'timezone', 4, 0, 'S', 'America/Los_Angeles', 220, 'Y', '', 0),
(140, 'ROOT,STOREFRONT', 'estimate_shipping_cost', 6, 0, 'C', 'Y', 390, 'Y', '', 0),
(141, 'ROOT,STOREFRONT', 'allow_create_account_after_order', 6, 0, 'C', 'Y', 305, 'Y', '', 0),
(143, 'ROOT', 'init_addons', 0, 0, 'C', '', 0, 'Y', '', 0),
(145, 'ROOT,STOREFRONT', 'cart_prices_w_taxes', 4, 0, 'C', 'N', 185, 'Y', '', 0),
(146, 'ROOT,STOREFRONT', 'in_stock_field', 4, 0, 'C', 'N', 186, 'Y', '', 0),
(147, 'ROOT,STOREFRONT', 'thumbnails_gallery', 4, 0, 'C', 'N', 186, 'Y', '', 0),
(148, 'ROOT,STOREFRONT', 'quantity_changer', 4, 0, 'C', 'Y', 186, 'Y', '', 0),
(149, 'ROOT,STOREFRONT', 'top_pagination', 4, 0, 'C', 'N', 187, 'Y', '', 0),
(150, 'ROOT,STOREFRONT', 'taxes_using_default_address', 4, 0, 'C', 'N', 183, 'Y', '', 0),
(151, 'ROOT', 'proxy_host', 2, 0, 'I', '', 320, 'Y', '', 0),
(152, 'ROOT', 'proxy_port', 2, 0, 'I', '', 330, 'Y', '', 0),
(153, 'ROOT', 'proxy_user', 2, 0, 'I', '', 340, 'Y', '', 0),
(154, 'ROOT', 'proxy_password', 2, 0, 'P', '', 350, 'Y', '', 0),
(156, 'ROOT,STOREFRONT', 'search_objects', 2, 0, 'N', '', 1010, 'Y', '', 0),
(158, 'ROOT,ULT:VENDOR', 'log_type_orders', 12, 0, 'N', '#M#create=Y&delete=Y&update=Y&status=Y', 10, 'Y', '', 0),
(159, 'ROOT,ULT:VENDOR', 'log_type_users', 12, 0, 'N', '#M#create=Y&delete=Y&update=Y&session=Y&failed_login=Y', 10, 'Y', '', 0),
(160, 'ROOT,ULT:VENDOR', 'log_type_products', 12, 0, 'N', '#M#create=Y&delete=Y&update=Y&low_stock=Y', 10, 'Y', '', 0),
(161, 'ROOT,ULT:VENDOR', 'log_type_categories', 12, 0, 'N', '#M#create=Y&delete=Y&update=Y', 10, 'Y', '', 0),
(162, 'ROOT,ULT:VENDOR', 'log_type_database', 12, 0, 'N', '#M#restore=Y&backup=Y&optimize=Y&error=Y', 10, 'Y', '', 0),
(163, 'ROOT,ULT:VENDOR', 'log_type_requests', 12, 0, 'N', '#M#http=Y&shipping=Y', 10, 'Y', '', 0),
(165, 'ROOT,STOREFRONT', 'hide_after_validation', 11, 0, 'C', 'Y', 87, 'Y', '', 0),
(166, 'ROOT', 'calendar_date_format', 4, 0, 'S', 'month_first', 230, 'Y', '', 0),
(167, 'ROOT', 'calendar_week_format', 4, 0, 'S', 'monday_first', 240, 'Y', '', 0),
(168, 'ROOT,ULT:VENDOR', 'store_mode', 2, 0, 'O', 'N', 50, 'Y', 'fn_get_store_mode_notice', 0),
(169, 'ROOT,STOREFRONT', 'default_products_view', 4, 0, 'K', 'products_multicolumns', 195, 'Y', '', 0),
(170, 'ROOT,STOREFRONT', 'save_selected_view', 4, 0, 'C', 'Y', 196, 'Y', '', 0),
(171, 'ROOT,STOREFRONT', 'default_products_view_templates', 4, 0, 'G', '#M#products_multicolumns=Y&products_without_options=Y&short_list=Y', 194, 'Y', '', 0),
(173, 'ROOT,STOREFRONT', 'checkout_redirect', 6, 0, 'C', 'N', 380, 'Y', '', 0),
(174, 'ROOT', 'min_account_password_length', 15, 0, 'I', '5', 10, 'Y', '', 0),
(175, 'ROOT', 'account_passwords_must_contain_mix', 15, 0, 'C', 'N', 20, 'Y', '', 0),
(176, 'ROOT', 'change_admin_password_on_first_login', 15, 0, 'C', 'N', 30, 'Y', '', 0),
(177, 'ROOT', 'account_password_expiration_period', 15, 0, 'I', '0', 40, 'Y', '', 0),
(178, 'ROOT', 'cron_password', 15, 0, 'I', 'MYPASS', 50, 'Y', '', 0),
(179, 'ROOT', 'tax_calculation', 6, 0, 'S', 'subtotal', 350, 'Y', '', 0),
(180, 'ROOT,STOREFRONT', 'default_product_details_view', 4, 0, 'S', 'default_template', 191, 'Y', '', 0),
(333, 'ROOT,STOREFRONT', 'global_product_details_view', 4, 0, 'S', 'default_template', 191, 'Y', '', 0),
(288, 'ROOT,STOREFRONT', 'product_details_in_tab', 4, 0, 'C', 'Y', 191, 'Y', '', 0),
(182, 'ROOT,STOREFRONT', 'address_position', 6, 0, 'D', 'shipping_first', 250, 'Y', '', 0),
(183, 'ROOT', 'changes_warning', 4, 0, 'C', 'Y', 250, 'Y', '', 0),
(184, 'ROOT,STOREFRONT', 'product_lists_thumbnail_width', 9, 0, 'U', '150', 100, 'Y', '', 0),
(185, 'ROOT,STOREFRONT', 'product_lists_thumbnail_height', 9, 0, 'U', '150', 110, 'Y', '', 0),
(186, 'ROOT,STOREFRONT', 'product_details_thumbnail_width', 9, 0, 'U', '280', 120, 'Y', '', 0),
(187, 'ROOT,STOREFRONT', 'product_details_thumbnail_height', 9, 0, 'U', '', 130, 'Y', '', 0),
(190, 'ROOT,STOREFRONT', 'product_cart_thumbnail_width', 9, 0, 'U', '120', 160, 'Y', '', 0),
(191, 'ROOT,STOREFRONT', 'product_cart_thumbnail_height', 9, 0, 'U', '', 170, 'Y', '', 0),
(192, 'ROOT,STOREFRONT', 'category_lists_thumbnail_width', 9, 0, 'U', '60', 180, 'Y', '', 0),
(193, 'ROOT,STOREFRONT', 'category_lists_thumbnail_height', 9, 0, 'U', '', 190, 'Y', '', 0),
(194, 'ROOT,STOREFRONT', 'category_details_thumbnail_width', 9, 0, 'U', '120', 200, 'Y', '', 0),
(195, 'ROOT,STOREFRONT', 'category_details_thumbnail_height', 9, 0, 'U', '', 210, 'Y', '', 0),
(196, 'ROOT,STOREFRONT', 'category_detailed_image_width', 9, 0, 'U', '', 220, 'Y', '', 0),
(197, 'ROOT,STOREFRONT', 'category_detailed_image_height', 9, 0, 'U', '', 230, 'Y', '', 0),
(201, 'ROOT', 'store_key', 0, 0, 'I', '[[store_key]];[[domhost]][[relativeurl]];[[admin_email]]', 0, 'Y', '', 0),
(203, 'ROOT', 'header_1', 4, 0, 'H', '', 10, 'N', '', 0),
(5678, 'ROOT', 'current_timestamp', 0, 0, 'T', '[[timestamp]]', 10, 'Y', '', 0),
(204, 'ROOT,ULT:VENDOR', 'header_7010', 10, 0, 'H', '', 10, 'N', '', 0),
(206, 'ROOT,ULT:VENDOR', 'header_10003', 1, 0, 'H', '', 20, 'N', '', 0),
(207, 'ROOT,STOREFRONT', 'header_7003', 6, 0, 'H', '', 400, 'N', '', 0),
(208, 'ROOT,STOREFRONT', 'header_2', 4, 0, 'H', '', 70, 'N', '', 0),
(209, 'ROOT', 'header_10004', 1, 0, 'H', '', 70, 'N', '', 0),
(210, 'ROOT,STOREFRONT', 'header_7004', 2, 0, 'H', '', 125, 'N', '', 0),
(211, 'ROOT', 'header_10080', 4, 0, 'H', '', 199, 'N', '', 0),
(212, 'ROOT,STOREFRONT', 'header_7024', 2, 0, 'H', '', 215, 'N', '', 0),
(213, 'ROOT,STOREFRONT', 'header_7005', 2, 0, 'H', '', 235, 'N', '', 0),
(216, 'ROOT', 'header_8057', 2, 0, 'H', '', 310, 'N', '', 0),
(217, 'ROOT,STOREFRONT', 'header_15000', 2, 0, 'H', '', 1000, 'N', '', 0),
(219, 'ROOT', 'header_8158', 13, 0, 'H', '', 20, 'N', '', 0),
(221, 'ROOT,STOREFRONT', 'header_10070', 4, 0, 'H', '', 192, 'N', '', 0),
(2000, 'ROOT', 'share_users', 17, 0, 'C', 'N', 10, 'Y', '', 0),
(223, 'ROOT,STOREFRONT', 'disregard_options_for_discounts', 2, 0, 'C', 'N', 190, 'Y', '', 0),
(272, 'ROOT', 'display_track_orders', 4, 0, 'C', 'Y', 191, 'Y', '', 0),
(274, 'ROOT,ULT:VENDOR', 'log_type_general', 12, 0, 'N', '#M#runtime=Y&deprecated=Y&', 10, 'Y', '', 0),
(275, 'ROOT,STOREFRONT', 'quick_registration', 2, 0, 'C', 'Y', 260, 'Y', '', 0),
(276, 'ROOT,STOREFRONT', 'show_delete_account_button', 2, 0, 'C', 'N', 270, 'Y', '', 0),
(289, 'ROOT,STOREFRONT', 'available_product_list_sortings', 4, 0, 'G', '#M#timestamp-desc=Y&product-asc=Y&product-desc=Y&price-asc=Y&price-desc=Y&popularity-desc=Y', 197, 'Y', '', 0),
(290, 'ROOT,STOREFRONT', 'enable_quick_view', 4, 0, 'C', 'Y', 198, 'Y', '', 0),
(291, 'ROOT', 'storage', 0, 0, 'I', 'a:1:{s:7:"storage";s:4:"file";}', 10, 'N', '', 0),
(292, 'ROOT,STOREFRONT', 'product_quick_view_thumbnail_width', 9, 0, 'U', '220', 135, 'Y', '', 0),
(293, 'ROOT,STOREFRONT', 'product_quick_view_thumbnail_height', 9, 0, 'U', '', 136, 'Y', '', 0),
(294, 'ROOT', 'cdn', 0, 0, 'I', '', 10, 'N', '', 0),
(300, 'ROOT,STOREFRONT', 'configure_sign_in_step', 6, 0, 'D', 'returning_customer_first', 310, 'Y', '', 0),
(301, 'ULT:ROOT,ULT:STOREFRONT', 'display_shipping_step', 6, 0, 'D', 'Y', 320, 'Y', '', 0),
(302, 'ROOT,STOREFRONT', 'display_payment_step', 6, 0, 'D', 'Y', 330, 'Y', '', 0),
(305, 'ROOT,STOREFRONT', 'sign_in_default_action', 6, 0, 'D', 'register', 315, 'Y', '', 0),
(306, 'ROOT,ULT:VENDOR', 'enable_edp', 2, 0, 'C', 'N', 135, 'Y', '', 0),
(307, 'ROOT,STOREFRONT', 'enable_compare_products', 2, 0, 'C', 'Y', 130, 'Y', '', 0),
(308, 'ROOT', 'email_templates', 4, 0, 'S', 'new', 400, 'Y', '', 0),
(309, 'ROOT', 'product_admin_mini_icon_width', 9, 0, 'U', '40', 300, 'Y', '', 0),
(310, 'ROOT', 'product_admin_mini_icon_height', 9, 0, 'U', '', 310, 'Y', '', 0),
(311, 'ROOT', 'monitor_core_changes', 2, 0, 'C', 'Y', 59, 'Y', '', 0),
(312, 'ROOT', 'log_lifetime', 12, 0, 'I', '90', 5, 'Y', '', 0),
(313, 'ROOT', 'phone_validation_mode', 4, 0, 'S', 'phone_number_with_country_selection', 450, 'Y', '', 0),
(314, 'ROOT,STOREFRONT', 'show_unavailable_shipping_methods', 6, 0, 'C', 'N', 390, 'Y', '', 0),
(315, 'ROOT,STOREFRONT', 'product_variant_mini_icon_width', 9, 0, 'U', '70', 171, 'Y', '', 0),
(316, 'ROOT,STOREFRONT', 'product_variant_mini_icon_height', 9, 0, 'U', '70', 172, 'Y', '', 0),
(317, 'ROOT', 'default_options_type', 2, 0, 'S', 'P', 157, 'Y', '', 0),
(318, 'ROOT', 'global_options_type', 2, 0, 'S', 'P', 157, 'Y', '', 0),
(319, 'ROOT', 'default_exceptions_type', 2, 0, 'S', 'F', 158, 'Y', '', 0),
(320, 'ROOT', 'global_exceptions_type', 2, 0, 'S', 'F', 158, 'Y', '', 0),
(321, 'ROOT', 'default_zero_price_action', 6, 0, 'S', 'R', 341, 'Y', '', 0),
(322, 'ROOT', 'global_zero_price_action', 6, 0, 'S', 'R', 341, 'Y', '', 0),
(323, 'ROOT', 'default_min_qty', 6, 0, 'I', '0', 342, 'Y', '', 0),
(324, 'ROOT', 'global_min_qty', 6, 0, 'I', '0', 342, 'Y', '', 0),
(325, 'ROOT', 'default_max_qty', 6, 0, 'I', '0', 343, 'Y', '', 0),
(326, 'ROOT', 'global_max_qty', 6, 0, 'I', '0', 343, 'Y', '', 0),
(327, 'ROOT', 'default_qty_step', 6, 0, 'I', '0', 344, 'Y', '', 0),
(328, 'ROOT', 'global_qty_step', 6, 0, 'I', '0', 344, 'Y', '', 0),
(329, 'ROOT', 'default_list_qty_count', 6, 0, 'I', '0', 345, 'Y', '', 0),
(330, 'ROOT', 'global_list_qty_count', 6, 0, 'I', '0', 345, 'Y', '', 0),
(331, 'ROOT,ULT:VENDOR', 'default_tracking', 2, 0, 'C', 'B', 130, 'Y', '', 0),
(332, 'ROOT,ULT:VENDOR', 'global_tracking', 2, 0, 'C', 'B', 130, 'Y', '', 0),
(334, 'ROOT,STOREFRONT', 'frontend_default_currency', 4, 0, 'S', 'USD', 85, 'Y', '', 0),
(335, 'ROOT', 'image_file_size', 9, 0, 'Q', '', 60, 'Y', '', 0),
(2001, 'ROOT', 'default_state_update_for_all', 17, 0, 'S', 'not_active', 20, 'Y', '', 0),
(5679, 'ROOT', 'default_upload_high_res_image', 18, 19, 'C', 'N', 0, 'N', '', 0),
(5680, 'ROOT,STOREFRONT', 'twitter_enable', 20, 21, 'C', 'Y', 0, 'N', '', 0),
(5681, 'ROOT,STOREFRONT', 'twitter_via', 20, 21, 'I', '', 10, 'N', '', 0),
(5682, 'ROOT,STOREFRONT', 'twitter_size', 20, 21, 'S', 'medium', 20, 'N', '', 0),
(5683, 'ROOT,STOREFRONT', 'twitter_display_count', 20, 21, 'S', 'horizontal', 30, 'N', '', 0),
(5684, 'ROOT,STOREFRONT', 'twitter_display_on', 20, 21, 'N', '#M#products=Y', 40, 'N', '', 0),
(5685, 'ROOT,STOREFRONT', 'facebook_enable', 20, 22, 'C', 'Y', 0, 'N', '', 0),
(5686, 'ROOT,STOREFRONT', 'facebook_app_id', 20, 22, 'I', '', 10, 'N', '', 0),
(5687, 'ROOT,STOREFRONT', 'facebook_href', 20, 22, 'I', '', 20, 'N', '', 0),
(5688, 'ROOT,STOREFRONT', 'facebook_send', 20, 22, 'C', 'Y', 30, 'N', '', 0),
(5689, 'ROOT,STOREFRONT', 'facebook_width', 20, 22, 'I', '450', 40, 'N', '', 0),
(5690, 'ROOT,STOREFRONT', 'facebook_layout', 20, 22, 'S', 'button_count', 50, 'N', '', 0),
(5691, 'ROOT,STOREFRONT', 'facebook_show_faces', 20, 22, 'C', 'N', 60, 'N', '', 0),
(5692, 'ROOT,STOREFRONT', 'facebook_action', 20, 22, 'S', 'like', 70, 'N', '', 0),
(5693, 'ROOT,STOREFRONT', 'facebook_lang', 20, 22, 'S', 'en_US', 80, 'N', '', 0),
(5694, 'ROOT,STOREFRONT', 'facebook_action_font', 20, 22, 'S', 'arial', 90, 'N', '', 0),
(5695, 'ROOT,STOREFRONT', 'facebook_colorscheme', 20, 22, 'S', 'light', 100, 'N', '', 0),
(5696, 'ROOT,STOREFRONT', 'facebook_display_on', 20, 22, 'N', '#M#products=Y', 110, 'N', '', 0),
(5697, 'ROOT,STOREFRONT', 'vkontakte_enable', 20, 23, 'C', '', 0, 'N', '', 0),
(5698, 'ROOT,STOREFRONT', 'vkontakte_appid', 20, 23, 'I', '', 10, 'N', '', 0),
(5699, 'ROOT,STOREFRONT', 'vkontakte_button_style', 20, 23, 'S', 'mini', 20, 'N', '', 0),
(5700, 'ROOT,STOREFRONT', 'vkontakte_height', 20, 23, 'I', '22', 30, 'N', '', 0),
(5701, 'ROOT,STOREFRONT', 'vkontakte_width', 20, 23, 'I', '350', 40, 'N', '', 0),
(5702, 'ROOT,STOREFRONT', 'vkontakte_buttons_name', 20, 23, 'S', 'like', 50, 'N', '', 0),
(5703, 'ROOT,STOREFRONT', 'vkontakte_display_on', 20, 23, 'N', '', 60, 'N', '', 0),
(5704, 'ROOT,STOREFRONT', 'yandex_enable', 20, 24, 'C', 'Y', 0, 'N', '', 0),
(5705, 'ROOT,STOREFRONT', 'yandex_share_code', 20, 24, 'T', '<div class="ya-share2" data-services="collections,vkontakte,facebook,twitter,odnoklassniki,moimir"></div>', 10, 'N', '', 0),
(5706, 'ROOT,STOREFRONT', 'yandex_display_on', 20, 24, 'N', 'products,pages', 20, 'N', '', 0),
(5707, 'ROOT,STOREFRONT', 'pinterest_enable', 20, 25, 'C', 'Y', 0, 'N', '', 0),
(5708, 'ROOT,STOREFRONT', 'pinterest_size', 20, 25, 'S', '20', 10, 'N', '', 0),
(5709, 'ROOT,STOREFRONT', 'pinterest_shape', 20, 25, 'S', 'rect', 20, 'N', '', 0),
(5710, 'ROOT,STOREFRONT', 'pinterest_display_on', 20, 25, 'N', '#M#products=Y', 30, 'N', '', 0),
(5711, 'ROOT,ULT:VENDOR', 'tags_for_products', 26, 27, 'C', 'Y', 0, 'N', '', 0),
(5712, 'ROOT,ULT:VENDOR', 'tags_for_pages', 26, 27, 'C', 'Y', 10, 'N', '', 0),
(5713, 'ROOT', 'managing_editor', 28, 29, 'I', '', 0, 'N', '', 0),
(5714, 'ROOT', 'display_rss_feed_in_category', 28, 29, 'C', 'N', 10, 'N', '', 0),
(5715, 'ROOT', 'category_max_products_items', 28, 29, 'I', '5', 20, 'N', '', 0),
(5716, 'ROOT', 'newsletters_per_pass', 30, 31, 'I', '10', 0, 'N', '', 0),
(5717, 'ROOT', 'elm_advanced_mailing_server_options', 30, 31, 'H', '', 10, 'N', '', 0),
(5718, 'ROOT', 'mailer_send_method', 30, 31, 'S', 'default', 20, 'N', '', 0),
(5719, 'ROOT', 'elm_smtp_server_settings', 30, 31, 'H', '', 30, 'N', '', 0),
(5720, 'ROOT', 'mailer_smtp_host', 30, 31, 'I', '', 40, 'N', '', 0),
(5721, 'ROOT', 'mailer_smtp_username', 30, 31, 'I', '', 50, 'N', '', 0),
(5722, 'ROOT', 'mailer_smtp_password', 30, 31, 'I', '', 60, 'N', '', 0),
(5723, 'ROOT', 'mailer_smtp_ecrypted_connection', 30, 31, 'S', 'none', 70, 'N', '', 0),
(5724, 'ROOT', 'mailer_smtp_auth', 30, 31, 'C', 'N', 80, 'N', '', 0),
(5725, 'ROOT', 'coupon', 30, 32, 'S', '', 0, 'N', '', 0),
(5726, 'ROOT,STOREFRONT', 'em_show_on_checkout', 33, 34, 'C', 'N', 0, 'N', '', 0),
(5727, 'ROOT,STOREFRONT', 'em_checkout_enabled', 33, 34, 'C', 'N', 10, 'N', '', 5726),
(5728, 'ROOT,STOREFRONT', 'em_double_opt_in', 33, 34, 'C', 'N', 20, 'N', '', 0),
(5729, 'ROOT,STOREFRONT', 'em_welcome_letter', 33, 34, 'C', 'N', 30, 'N', '', 0),
(5730, 'ROOT,STOREFRONT', 'em_service', 33, 34, 'S', 'dummy', 40, 'N', '', 0),
(5731, 'ROOT,STOREFRONT', 'em_token', 33, 34, 'D', '[[em_token]]', 50, 'N', '', 0),
(5732, 'ROOT,STOREFRONT', 'em_lastsync', 33, 34, 'D', '[[timestamp]]', 60, 'N', '', 0),
(5733, 'ROOT,STOREFRONT', 'em_mailchimp_api_key', 33, 35, 'I', '', 0, 'N', '', 0),
(5734, 'ROOT,STOREFRONT', 'em_mailchimp_list', 33, 35, 'S', '', 10, 'N', '', 0),
(5735, 'ROOT,STOREFRONT', 'em_madmimi_username', 33, 36, 'I', '', 0, 'N', '', 0),
(5736, 'ROOT,STOREFRONT', 'em_madmimi_api_key', 33, 36, 'I', '', 10, 'N', '', 0),
(5737, 'ROOT,STOREFRONT', 'em_madmimi_list', 33, 36, 'S', '', 20, 'N', '', 0),
(5738, 'ROOT', 'allow_save_attachments_to_server', 37, 38, 'C', 'N', 0, 'N', '', 0),
(5739, 'ROOT,STOREFRONT', 'show_on_product', 39, 40, 'C', 'Y', 0, 'N', '', 0),
(5740, 'ULT:VENDOR', 'show_on_messages', 39, 40, 'C', 'Y', 20, 'N', '', 0),
(5741, 'ROOT,STOREFRONT', 'show_on_order', 39, 40, 'C', 'Y', 30, 'N', '', 0),
(5742, 'ROOT', 'provider', 41, 42, 'S', 'google', 0, 'N', '', 0),
(5743, 'ROOT', 'show_shippings_on_product', 41, 42, 'C', 'N', 10, 'N', '', 0),
(5744, 'ROOT', 'yandex_api_key', 41, 43, 'I', '', 0, 'N', '', 0),
(5745, 'ROOT', 'yandex_suggest_api_key', 41, 43, 'I', '', 10, 'N', '', 0),
(5746, 'ROOT', 'yandex_commercial', 41, 43, 'C', '', 20, 'N', '', 0),
(5747, 'ROOT', 'yandex_map', 41, 43, 'E', 'map.tpl', 30, 'N', '', 0),
(5748, 'ROOT', 'google_api_notice', 41, 44, 'O', '', 0, 'N', 'fn_geo_maps_settings_google_api_notice_handler', 0),
(5749, 'ROOT', 'google_api_key', 41, 44, 'I', '', 10, 'N', '', 0),
(5750, 'ROOT', 'google_map', 41, 44, 'E', 'map.tpl', 20, 'N', '', 0),
(5751, 'ROOT', 'min_amount', 45, 46, 'I', '50', 0, 'N', '', 0),
(5752, 'ROOT', 'max_amount', 45, 46, 'I', '1500', 10, 'N', '', 0),
(5753, 'ROOT', 'code_prefix', 45, 46, 'I', 'GC', 20, 'N', '', 0),
(5754, 'ROOT', 'cert_per_page', 45, 46, 'I', '10', 30, 'N', '', 0),
(5755, 'ROOT', 'free_products_allow', 45, 46, 'C', 'Y', 40, 'N', '', 0),
(5756, 'ROOT', 'redeem_shipping_cost', 45, 46, 'C', 'Y', 50, 'N', '', 0),
(5757, 'ROOT,STOREFRONT', 'print_map', 47, 48, 'C', 'Y', 0, 'N', '', 0),
(5758, 'ROOT,STOREFRONT', 'show_locations_at_geolocator', 47, 48, 'C', 'N', 10, 'N', '', 0),
(5759, 'ROOT', 'variations_allow_own_images', 49, 50, 'C', 'Y', 0, 'N', '', 0),
(5760, 'ROOT', 'variations_allow_own_features', 49, 50, 'C', 'N', 10, 'N', '', 0),
(5761, 'ROOT', 'variations_allow_auto_change_default_variation', 49, 50, 'C', 'Y', 20, 'N', '', 0),
(5762, 'ROOT,STOREFRONT', 'variations_show_all_possible_feature_variants', 49, 50, 'C', 'Y', 30, 'N', '', 0),
(5763, 'ROOT', 'quantity_discount_on_different_variations', 49, 50, 'C', 'N', 40, 'N', '', 0),
(5764, 'ROOT', 'notice', 51, 52, 'O', '', 0, 'N', 'fn_recaptcha_settings_notice_handler', 0),
(5765, 'ROOT,STOREFRONT', 'recaptcha_v2_settings', 51, 52, 'H', '', 10, 'N', '', 0),
(5766, 'ROOT', 'recaptcha_site_key', 51, 52, 'I', '', 20, 'N', '', 0),
(5767, 'ROOT', 'recaptcha_secret', 51, 52, 'I', '', 30, 'N', '', 0),
(5768, 'ROOT,STOREFRONT', 'recaptcha_theme', 51, 52, 'S', 'light', 40, 'N', '', 0),
(5769, 'ROOT,STOREFRONT', 'recaptcha_size', 51, 52, 'S', 'normal', 50, 'N', '', 0),
(5770, 'ROOT,STOREFRONT', 'recaptcha_type', 51, 52, 'S', 'image', 60, 'N', '', 0),
(5771, 'ROOT', 'recaptcha_v3_settings', 51, 52, 'H', '', 70, 'N', '', 0),
(5772, 'ROOT', 'recaptcha_v3_site_key', 51, 52, 'I', '', 80, 'N', '', 0),
(5773, 'ROOT', 'recaptcha_v3_secret', 51, 52, 'I', '', 90, 'N', '', 0),
(5774, 'ROOT', 'recaptcha_v3_success_score', 51, 52, 'S', '0.5', 100, 'N', '', 0),
(5775, 'ROOT,STOREFRONT', 'use_for_settings', 51, 52, 'H', '', 110, 'N', '', 0),
(5776, 'ROOT,STOREFRONT', 'recaptcha_use_for_value', 51, 52, 'D', '', 120, 'N', '', 0),
(5777, 'ROOT,STOREFRONT', 'recaptcha_use_for', 51, 52, 'E', 'use_for_settings.tpl', 130, 'N', '', 0),
(5778, 'ROOT,STOREFRONT', 'settings_proxy', 51, 52, 'O', '', 140, 'N', 'fn_recaptcha_image_verification_settings_proxy', 0),
(5779, 'ROOT', 'forbidden_countries_notice', 51, 53, 'O', '', 0, 'N', 'fn_recaptcha_forbidden_countries_notice_handler', 0),
(5780, 'ROOT', 'forbidden_countries', 51, 53, 'B', '#M#CN=Y&CG=Y&IR=Y', 10, 'N', '', 0),
(5781, 'ROOT,STOREFRONT', 'show_bundles', 54, 55, 'S', 'before_product_description', 0, 'N', '', 0),
(5782, 'ROOT', 'returnable', 56, 57, 'C', 'Y', 0, 'N', '', 0),
(5783, 'ROOT', 'return_period', 56, 57, 'I', '10', 10, 'N', '', 0),
(5784, 'ROOT', 'display_product_return_period', 56, 57, 'C', 'Y', 20, 'N', '', 0),
(5785, 'ROOT', 'dont_take_weekends_into_account', 56, 57, 'C', 'Y', 30, 'N', '', 0),
(5786, 'ROOT,STOREFRONT', 'final_sale_from', 58, 59, 'I', '40', 0, 'N', '', 0),
(5787, 'ROOT,STOREFRONT', 'sales_amount_from', 58, 59, 'I', '1', 10, 'N', '', 0),
(5788, 'ROOT,STOREFRONT', 'period', 58, 60, 'S', 'all', 0, 'N', '', 0),
(5789, 'ROOT,STOREFRONT', 'last_days', 58, 60, 'I', '3', 10, 'N', '', 0),
(5790, 'ROOT,ULT:VENDOR', 'seo_product_type', 61, 62, 'S', 'product_category_nohtml', 0, 'N', '', 0),
(5791, 'ROOT,ULT:VENDOR', 'seo_category_type', 61, 62, 'S', 'category_nohtml', 10, 'N', '', 0),
(5792, 'ROOT,ULT:VENDOR', 'seo_page_type', 61, 62, 'S', 'page_nohtml', 20, 'N', '', 0),
(5793, 'ROOT,ULT:VENDOR', 'seo_other_type', 61, 62, 'S', 'directory', 30, 'N', '', 0),
(5794, 'ROOT,ULT:VENDOR', 'seo_language', 61, 62, 'C', 'N', 40, 'N', '', 0),
(5795, 'ROOT,ULT:VENDOR', 'single_url', 61, 62, 'C', 'Y', 50, 'N', '', 0),
(5796, 'ROOT,ULT:VENDOR', 'non_latin_symbols', 61, 62, 'C', 'N', 60, 'N', '', 0),
(5797, 'ROOT,ULT:VENDOR', 'point_rate', 63, 64, 'I', '1', 0, 'N', '', 0),
(5798, 'ROOT,ULT:VENDOR', 'auto_price_in_points', 63, 64, 'C', 'Y', 10, 'N', '', 0),
(5799, 'ROOT,ULT:VENDOR', 'price_in_points_with_discounts', 63, 64, 'C', 'Y', 20, 'N', '', 0),
(5800, 'ROOT,ULT:VENDOR', 'points_with_discounts', 63, 64, 'C', 'Y', 30, 'N', '', 0),
(5801, 'ROOT,ULT:VENDOR', 'price_in_points_order_discount', 63, 64, 'C', 'Y', 40, 'N', '', 0),
(5802, 'ROOT,ULT:VENDOR', 'reward_points_order_discount', 63, 64, 'C', 'Y', 50, 'N', '', 0),
(5803, 'ROOT,ULT:VENDOR', 'higher_level_extract', 63, 64, 'C', 'Y', 60, 'N', '', 0),
(5804, 'ROOT,ULT:VENDOR', 'several_points_action', 63, 64, 'S', 'minimal_absolute', 70, 'N', '', 0),
(5805, 'ROOT,ULT:VENDOR', 'consider_zero_values', 63, 64, 'C', 'N', 80, 'N', '', 0),
(5806, 'ROOT,ULT:VENDOR', 'log_per_page', 63, 64, 'I', '10', 90, 'N', '', 0),
(5807, 'ROOT,STOREFRONT', 'tracking_code', 65, 66, 'I', '', 0, 'N', '', 0),
(5808, 'ROOT,STOREFRONT', 'track_ecommerce', 65, 66, 'C', 'Y', 10, 'N', '', 0),
(5809, 'ROOT,STOREFRONT', 'pixel_id', 67, 68, 'I', '', 0, 'N', '', 0),
(5810, 'ROOT,STOREFRONT', 'track_all_page_views', 67, 68, 'C', 'Y', 10, 'N', '', 0),
(5811, 'ROOT,STOREFRONT', 'track_add_to_cart', 67, 68, 'C', 'N', 20, 'N', '', 0),
(5812, 'ROOT,STOREFRONT', 'track_order_placed', 67, 68, 'C', 'N', 30, 'N', '', 0),
(5813, 'ROOT,STOREFRONT', 'general', 69, 70, 'H', '', 0, 'N', '', 0),
(5814, 'ROOT,STOREFRONT', 'info', 69, 70, 'O', '', 10, 'N', 'fn_call_requests_info', 0),
(5815, 'ROOT,STOREFRONT', 'phone', 69, 70, 'I', '', 20, 'N', '', 0),
(5816, 'ROOT,STOREFRONT', 'phone_prefix_length', 69, 70, 'I', '7', 30, 'N', '', 0),
(5817, 'ROOT,STOREFRONT', 'phone_mask', 69, 70, 'I', '', 40, 'N', '', 0),
(5818, 'ROOT,STOREFRONT', 'buy_now_with_one_click', 69, 70, 'C', 'Y', 50, 'N', '', 0),
(5819, 'ROOT,ULT:VENDOR', 'order_status', 69, 70, 'S', 'Y', 70, 'N', '', 0),
(5820, 'ROOT', 'elm_image', 71, 72, 'H', '', 0, 'N', '', 0),
(5821, 'ROOT', 'elm_image_info', 71, 72, 'O', '', 10, 'N', 'fn_get_barcode_image', 0),
(5822, 'ROOT', 'elm_configs', 71, 72, 'H', '', 20, 'N', '', 0),
(5823, 'ROOT', 'type', 71, 72, 'S', 'C128B', 30, 'N', '', 0),
(5824, 'ROOT', 'output', 71, 72, 'S', 'png', 40, 'N', '', 0),
(5825, 'ROOT', 'text', 71, 72, 'S', 'Y', 50, 'N', '', 0),
(5826, 'ROOT', 'height', 71, 72, 'I', '60', 60, 'N', '', 0),
(5827, 'ROOT', 'width', 71, 72, 'I', '250', 70, 'N', '', 0),
(5828, 'ROOT', 'prefix', 71, 72, 'I', 'FF45CR99', 80, 'N', '', 0),
(5829, 'ROOT', 'elm_specification', 71, 72, 'H', '', 90, 'N', '', 0),
(5830, 'ROOT', 'elm_spec_descr', 71, 72, 'O', '', 100, 'N', 'fn_get_barcode_specification', 0),
(5831, 'ROOT', 'polls_votes_on_page', 73, 74, 'I', '20', 0, 'N', '', 0),
(5832, 'ROOT', 'polls_comments_on_page', 73, 74, 'I', '20', 10, 'N', '', 0),
(5833, 'ROOT', 'elm_administrator_area_settings', 75, 76, 'H', '', 0, 'N', '', 0),
(5834, 'ROOT', 'admin_reverse_ip_access', 75, 76, 'C', '', 10, 'N', '', 0),
(5835, 'ROOT', 'unsuccessful_attempts_login', 75, 76, 'C', '', 20, 'N', '', 0),
(5836, 'ROOT', 'number_unsuccessful_attempts', 75, 76, 'I', '5', 30, 'N', '', 0),
(5837, 'ROOT', 'login_intervals', 75, 76, 'I', '60', 40, 'N', '', 0),
(5838, 'ROOT', 'time_block', 75, 76, 'I', '24', 50, 'N', '', 0),
(5839, 'ROOT', 'elm_customer_and_affiliate_area_settings', 75, 76, 'H', '', 60, 'N', '', 0),
(5840, 'ROOT', 'unsuccessful_attempts_login_customer', 75, 76, 'C', '', 70, 'N', '', 0),
(5841, 'ROOT', 'number_unsuccessful_attempts_customer', 75, 76, 'I', '5', 80, 'N', '', 0),
(5842, 'ROOT', 'login_intervals_customer', 75, 76, 'I', '60', 90, 'N', '', 0),
(5843, 'ROOT', 'time_block_customer', 75, 76, 'I', '24', 100, 'N', '', 0),
(5844, 'ROOT', 'banner_multilang', 77, 78, 'C', 'Y', 0, 'N', '', 0),
(5845, 'ROOT,STOREFRONT', 'product_posts_per_page', 79, 80, 'I', '10', 0, 'N', '', 0),
(5846, 'ROOT,ULT:VENDOR', 'product_post_approval', 79, 80, 'S', 'any', 10, 'N', '', 0),
(5847, 'ROOT,ULT:VENDOR', 'product_post_ip_check', 79, 80, 'C', 'N', 20, 'N', '', 0),
(5848, 'ROOT,ULT:VENDOR', 'product_discussion_type', 79, 80, 'S', 'D', 30, 'N', '', 0),
(5849, 'ULT:ROOT', 'product_share_discussion', 79, 80, 'C', 'N', 40, 'N', '', 0),
(5850, 'ROOT,ULT:VENDOR', 'product_review_after_purchase', 79, 80, 'C', 'N', 50, 'N', '', 0),
(5851, 'ROOT,STOREFRONT', 'category_posts_per_page', 79, 81, 'I', '10', 0, 'N', '', 0),
(5852, 'ROOT,ULT:VENDOR', 'category_post_approval', 79, 81, 'S', 'any', 10, 'N', '', 0),
(5853, 'ROOT,ULT:VENDOR', 'category_post_ip_check', 79, 81, 'C', 'N', 20, 'N', '', 0),
(5854, 'ROOT,ULT:VENDOR', 'category_discussion_type', 79, 81, 'S', 'D', 30, 'N', '', 0),
(5855, 'ROOT,STOREFRONT', 'order_posts_per_page', 79, 82, 'I', '10', 0, 'N', '', 0),
(5856, 'ROOT,STOREFRONT', 'order_initiate', 79, 82, 'C', 'Y', 10, 'N', '', 0),
(5857, 'ROOT,STOREFRONT', 'page_posts_per_page', 79, 83, 'I', '10', 0, 'N', '', 0),
(5858, 'ROOT,ULT:VENDOR', 'page_post_approval', 79, 83, 'S', 'disabled', 10, 'N', '', 0),
(5859, 'ROOT,ULT:VENDOR', 'page_post_ip_check', 79, 83, 'C', 'N', 20, 'N', '', 0),
(5860, 'ROOT,ULT:VENDOR', 'page_discussion_type', 79, 83, 'S', 'D', 30, 'N', '', 0),
(5861, 'ULT:ROOT', 'page_share_discussion', 79, 83, 'C', 'N', 40, 'N', '', 0),
(5862, 'ROOT,STOREFRONT', 'home_page_posts_per_page', 79, 84, 'I', '10', 0, 'N', '', 0),
(5863, 'ROOT,ULT:VENDOR', 'home_page_post_approval', 79, 84, 'S', 'any', 10, 'N', '', 0),
(5864, 'ROOT,ULT:VENDOR', 'home_page_post_ip_check', 79, 84, 'C', 'Y', 20, 'N', '', 0),
(5865, 'ROOT,ULT:VENDOR', 'home_page_testimonials', 79, 84, 'S', 'B', 30, 'N', '', 0),
(5866, 'ULT:ROOT', 'testimonials_from_all_stores', 79, 84, 'C', 'N', 40, 'N', '', 0),
(5867, 'ROOT,ULT:VENDOR', 'watermark', 85, 86, 'H', '', 0, 'N', '', 0),
(5868, 'ROOT,ULT:VENDOR', 'watermark_settings', 85, 86, 'E', 'watermark.tpl', 10, 'N', '', 0),
(5869, 'ROOT,ULT:VENDOR', 'apply_to_product', 85, 86, 'H', '', 20, 'N', '', 0),
(5870, 'ROOT,ULT:VENDOR', 'use_for_product_icons', 85, 86, 'C', 'N', 30, 'N', '', 0),
(5871, 'ROOT,ULT:VENDOR', 'use_for_product_detailed', 85, 86, 'C', 'N', 40, 'N', '', 0),
(5872, 'ROOT,ULT:VENDOR', 'apply_to_categories', 85, 86, 'H', '', 50, 'N', '', 0),
(5873, 'ROOT,ULT:VENDOR', 'use_for_category_icons', 85, 86, 'C', 'N', 60, 'N', '', 0),
(5874, 'ROOT,ULT:VENDOR', 'use_for_category_detailed', 85, 86, 'C', 'N', 70, 'N', '', 0),
(5875, 'ROOT,ULT:VENDOR', 'images_access_info', 85, 86, 'O', '', 80, 'N', 'fn_watermarks_images_access_info', 0),
(5876, 'ROOT,STOREFRONT', 'notice', 87, 88, 'O', '', 0, 'N', 'fn_product_reviews_copy_old_reviews_notice', 0),
(5877, 'ROOT,STOREFRONT', 'reviews_per_page', 87, 88, 'I', '10', 10, 'N', '', 0),
(5878, 'ROOT,STOREFRONT', 'review_approval', 87, 88, 'S', 'any', 20, 'N', '', 0),
(5879, 'ROOT,STOREFRONT', 'review_ip_check', 87, 88, 'C', 'N', 30, 'N', '', 0),
(5880, 'ROOT,ULT:VENDOR', 'review_fields', 87, 88, 'S', 'advanced', 40, 'N', '', 0),
(5881, 'ROOT,STOREFRONT', 'review_after_purchase', 87, 88, 'C', 'N', 50, 'N', '', 0),
(5882, 'ROOT,STOREFRONT', 'review_ask_for_customer_location', 87, 88, 'S', 'none', 60, 'N', '', 0),
(5883, 'ROOT', 'split_reviews_by_storefronts', 87, 88, 'C', 'N', 70, 'N', '', 0),
(5884, 'ROOT,STOREFRONT', 'images_upload_allowed', 87, 88, 'D', 'Y', 80, 'N', '', 0),
(5885, 'ROOT', 'product_variations', 87, 88, 'E', 'product_variations.tpl', 90, 'N', '', 0),
(5886, 'ROOT', 'split_reviews_for_variations_as_separate_products', 87, 88, 'D', 'Y', 100, 'N', '', 0),
(5887, 'ROOT,STOREFRONT', 'cz_animation_time', 89, 90, 'I', '200', 0, 'N', '', 0),
(5888, 'ROOT,STOREFRONT', 'cz_zoom_position', 89, 90, 'S', '3', 10, 'N', '', 0),
(5889, 'ROOT,STOREFRONT', 'information', 91, 92, 'H', '', 0, 'N', '', 0),
(5890, 'ROOT,STOREFRONT', 'clear_url', 91, 92, 'O', '', 10, 'N', 'fn_google_sitemap_clear_url_info', 0),
(5891, 'ROOT,STOREFRONT', 'cron_command', 91, 92, 'E', 'cron_command.tpl', 20, 'N', '', 0),
(5892, 'ROOT,STOREFRONT', 'site_setting', 91, 92, 'H', '', 30, 'N', '', 0),
(5893, 'ROOT,STOREFRONT', 'site_change', 91, 92, 'S', 'daily', 40, 'N', '', 0),
(5894, 'ROOT,STOREFRONT', 'site_priority', 91, 92, 'S', '1', 50, 'N', '', 0),
(5895, 'ROOT,STOREFRONT', 'products_setting', 91, 92, 'H', '', 60, 'N', '', 0),
(5896, 'ROOT,STOREFRONT', 'include_products', 91, 92, 'C', 'Y', 70, 'N', '', 0),
(5897, 'ROOT,STOREFRONT', 'products_change', 91, 92, 'S', 'daily', 80, 'N', '', 0),
(5898, 'ROOT,STOREFRONT', 'products_priority', 91, 92, 'S', '0.5', 90, 'N', '', 0),
(5899, 'ROOT,STOREFRONT', 'categories_setting', 91, 92, 'H', '', 100, 'N', '', 0),
(5900, 'ROOT,STOREFRONT', 'include_categories', 91, 92, 'C', 'Y', 110, 'N', '', 0),
(5901, 'ROOT,STOREFRONT', 'categories_change', 91, 92, 'S', 'daily', 120, 'N', '', 0),
(5902, 'ROOT,STOREFRONT', 'categories_priority', 91, 92, 'S', '0.5', 130, 'N', '', 0),
(5903, 'ROOT,STOREFRONT', 'pages_setting', 91, 92, 'H', '', 140, 'N', '', 0),
(5904, 'ROOT,STOREFRONT', 'include_pages', 91, 92, 'C', 'Y', 150, 'N', '', 0),
(5905, 'ROOT,STOREFRONT', 'pages_change', 91, 92, 'S', 'daily', 160, 'N', '', 0),
(5906, 'ROOT,STOREFRONT', 'pages_priority', 91, 92, 'S', '0.5', 170, 'N', '', 0),
(5907, 'ROOT,STOREFRONT', 'extended_setting', 91, 92, 'H', '', 180, 'N', '', 0),
(5908, 'ROOT,STOREFRONT', 'include_extended', 91, 92, 'C', 'Y', 190, 'N', '', 0),
(5909, 'ROOT,STOREFRONT', 'extended_change', 91, 92, 'S', 'daily', 200, 'N', '', 0),
(5910, 'ROOT,STOREFRONT', 'extended_priority', 91, 92, 'S', '0.5', 210, 'N', '', 0),
(5911, 'ROOT', 'cron_password', 93, 94, 'I', 'MYPASS', 0, 'N', '', 0),
(5912, 'ROOT,STOREFRONT', 'price_list_info', 95, 96, 'O', '', 0, 'N', 'fn_price_list_info', 0),
(5913, 'ROOT,ULT:VENDOR', 'price_list_fields', 95, 96, 'B', '#M#product_code=Y&product=Y&amount=Y&price=Y', 10, 'N', '', 0),
(5914, 'ROOT,ULT:VENDOR', 'price_list_sorting', 95, 96, 'S', 'product_code', 20, 'N', '', 0),
(5915, 'ROOT,ULT:VENDOR', 'group_by_category', 95, 96, 'C', 'Y', 30, 'N', '', 0),
(5916, 'ROOT,ULT:VENDOR', 'include_options', 95, 96, 'C', 'N', 40, 'N', '', 0),
(5917, 'ROOT', 'general_info', 97, 98, 'O', '', 0, 'N', 'fn_janrain_generate_info', 0),
(5918, 'ROOT', 'apikey', 97, 98, 'I', '', 10, 'N', '', 0),
(5919, 'ROOT', 'appdomain', 97, 98, 'I', '', 20, 'N', '', 0),
(5920, 'ROOT,STOREFRONT', 'main_store_mode', 99, 100, 'R', 'catalog', 0, 'N', '', 0),
(5921, 'ROOT,STOREFRONT', 'add_to_cart_empty_buy_now_url', 99, 100, 'C', 'N', 10, 'N', '', 0),
(5922, 'ROOT,STOREFRONT', 'icons_pack', 101, 102, 'S', 'flat_32x32', 0, 'N', '', 0),
(5923, 'ROOT', 'autogen_email', 101, 102, 'C', 'N', 10, 'N', '', 0),
(5924, 'ROOT', 'text_general', 103, 104, 'E', 'general.tpl', 0, 'N', '', 0),
(5925, 'ROOT', 'gdpr_cookie_consent', 105, 106, 'S', 'explicit', 0, 'N', '', 0),
(5926, 'ROOT', 'privacy_policy_page', 105, 106, 'S', '3', 10, 'N', '', 0),
(5927, 'ROOT', 'gdpr_cookie_consent_texts', 105, 106, 'E', 'cookie_consent_texts.tpl', 20, 'N', '', 0),
(5928, 'ROOT', 'gdpr_settings', 105, 107, 'E', 'settings.tpl', 0, 'N', '', 0),
(5929, 'ROOT', 'gdpr_settings_data', 105, 107, 'D', '{"checkout_place_order":{"enable":"Y"},"checkout_profiles_update":{"enable":"N"},"user_registration":{"enable":"Y"},"profiles_update":{"enable":"Y"},"product_subscription":{"enable":"Y"},"apply_for_vendor":{"enable":"Y"},"newsletters_subscribe":{"enable":"Y"},"call_requests":{"enable":"Y"},"discussions_add_review":{"enable":"Y"}}', 10, 'N', '', 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]settings_sections`
--

CREATE TABLE `[[dbprefix]]settings_sections` (
  `section_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `parent_id` int(11) unsigned NOT NULL,
  `edition_type` set('NONE','ROOT','VENDOR','STOREFRONT','MVE:NONE','MVE:ROOT','MVE:STOREFRONT','ULT:NONE','ULT:ROOT','ULT:VENDOR','ULT:VENDORONLY','ULT:STOREFRONT') NOT NULL DEFAULT 'ROOT',
  `name` varchar(128) NOT NULL DEFAULT '',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `type` enum('CORE','ADDON','TAB','SEPARATE_TAB') NOT NULL DEFAULT 'CORE',
  PRIMARY KEY (`section_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=108 ;

--
-- Dumping data for table `[[dbprefix]]settings_sections`
--

INSERT INTO `[[dbprefix]]settings_sections` VALUES
(1, 0, 'ROOT,VENDOR', 'Emails', 0, 'CORE'),
(2, 0, 'ROOT,STOREFRONT', 'General', 10, 'CORE'),
(4, 0, 'ROOT,STOREFRONT', 'Appearance', 20, 'CORE'),
(5, 0, 'ROOT,ULT:VENDOR', 'Company', 0, 'CORE'),
(6, 0, 'ROOT,STOREFRONT', 'Checkout', 40, 'CORE'),
(8, 0, 'ROOT,STOREFRONT', 'Sitemap', 80, 'CORE'),
(9, 0, 'ROOT,STOREFRONT', 'Thumbnails', 110, 'CORE'),
(10, 0, 'ROOT,VENDOR', 'Reports', 140, 'CORE'),
(11, 0, 'ROOT,STOREFRONT', 'Image_verification', 0, 'CORE'),
(12, 0, 'ROOT,VENDOR', 'Logging', 100, 'CORE'),
(13, 0, 'ROOT', 'Upgrade_center', 0, 'CORE'),
(15, 0, 'ROOT,STOREFRONT', 'Security', 0, 'CORE'),
(17, 0, 'ROOT', 'Stores', 0, 'CORE'),
(18, 0, 'ROOT', 'hidpi', 0, 'ADDON'),
(19, 18, 'ROOT', 'general', 0, 'TAB'),
(20, 0, 'ROOT,STOREFRONT', 'social_buttons', 0, 'ADDON'),
(21, 20, 'ROOT,STOREFRONT', 'twitter', 0, 'TAB'),
(22, 20, 'ROOT,STOREFRONT', 'facebook', 10, 'TAB'),
(23, 20, 'ROOT,STOREFRONT', 'vkontakte', 20, 'TAB'),
(24, 20, 'ROOT,STOREFRONT', 'yandex', 30, 'TAB'),
(25, 20, 'ROOT,STOREFRONT', 'pinterest', 40, 'TAB'),
(26, 0, 'ROOT,ULT:VENDOR', 'tags', 0, 'ADDON'),
(27, 26, 'ROOT,ULT:VENDOR', 'general', 0, 'TAB'),
(28, 0, 'ROOT', 'rss_feed', 0, 'ADDON'),
(29, 28, 'ROOT', 'general', 0, 'TAB'),
(30, 0, 'ROOT', 'newsletters', 0, 'ADDON'),
(31, 30, 'ROOT', 'general', 0, 'TAB'),
(32, 30, 'ROOT', 'promotions', 10, 'TAB'),
(33, 0, 'ROOT,STOREFRONT', 'email_marketing', 0, 'ADDON'),
(34, 33, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(35, 33, 'ROOT,STOREFRONT', 'mailchimp', 10, 'TAB'),
(36, 33, 'ROOT,STOREFRONT', 'madmimi', 20, 'TAB'),
(37, 0, 'ROOT', 'attachments', 0, 'ADDON'),
(38, 37, 'ROOT', 'general', 0, 'TAB'),
(39, 0, 'ROOT,STOREFRONT', 'vendor_communication', 0, 'ADDON'),
(40, 39, 'ROOT,STOREFRONT', 'vendor_to_customer', 10, 'TAB'),
(41, 0, 'ROOT', 'geo_maps', 0, 'ADDON'),
(42, 41, 'ROOT', 'general', 0, 'TAB'),
(43, 41, 'ROOT', 'yandex', 10, 'TAB'),
(44, 41, 'ROOT', 'google', 20, 'TAB'),
(45, 0, 'ROOT', 'gift_certificates', 0, 'ADDON'),
(46, 45, 'ROOT', 'general', 0, 'TAB'),
(47, 0, 'ROOT,STOREFRONT', 'store_locator', 0, 'ADDON'),
(48, 47, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(49, 0, 'ROOT,STOREFRONT', 'product_variations', 0, 'ADDON'),
(50, 49, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(51, 0, 'ROOT,STOREFRONT', 'recaptcha', 0, 'ADDON'),
(52, 51, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(53, 51, 'ROOT', 'forbidden_countries', 10, 'TAB'),
(54, 0, 'ROOT,STOREFRONT', 'product_bundles', 0, 'ADDON'),
(55, 54, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(56, 0, 'ROOT', 'rma', 0, 'ADDON'),
(57, 56, 'ROOT', 'general', 0, 'TAB'),
(58, 0, 'ROOT,STOREFRONT', 'bestsellers', 0, 'ADDON'),
(59, 58, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(60, 58, 'ROOT,STOREFRONT', 'newest', 10, 'TAB'),
(61, 0, 'ROOT,ULT:VENDOR', 'seo', 0, 'ADDON'),
(62, 61, 'ROOT,ULT:VENDOR', 'general', 0, 'TAB'),
(63, 0, 'ROOT,ULT:VENDOR', 'reward_points', 0, 'ADDON'),
(64, 63, 'ROOT,ULT:VENDOR', 'general', 0, 'TAB'),
(65, 0, 'ROOT,STOREFRONT', 'google_analytics', 0, 'ADDON'),
(66, 65, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(67, 0, 'ROOT,STOREFRONT', 'facebook_pixel', 0, 'ADDON'),
(68, 67, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(69, 0, 'ROOT,STOREFRONT', 'call_requests', 0, 'ADDON'),
(70, 69, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(71, 0, 'ROOT', 'barcode', 0, 'ADDON'),
(72, 71, 'ROOT', 'general', 0, 'TAB'),
(73, 0, 'ROOT', 'polls', 0, 'ADDON'),
(74, 73, 'ROOT', 'general', 0, 'TAB'),
(75, 0, 'ROOT', 'access_restrictions', 0, 'ADDON'),
(76, 75, 'ROOT', 'general', 0, 'TAB'),
(77, 0, 'ROOT', 'banners', 0, 'ADDON'),
(78, 77, 'ROOT', 'general', 0, 'TAB'),
(79, 0, 'ROOT,STOREFRONT', 'discussion', 0, 'ADDON'),
(80, 79, 'ROOT,STOREFRONT', 'products', 0, 'TAB'),
(81, 79, 'ROOT,STOREFRONT', 'categories', 10, 'TAB'),
(82, 79, 'ROOT,STOREFRONT', 'orders', 20, 'TAB'),
(83, 79, 'ROOT,STOREFRONT', 'pages', 30, 'TAB'),
(84, 79, 'ROOT,STOREFRONT', 'testimonials', 40, 'TAB'),
(85, 0, 'ROOT,ULT:VENDOR', 'watermarks', 0, 'ADDON'),
(86, 85, 'ROOT,ULT:VENDOR', 'general', 0, 'TAB'),
(87, 0, 'ROOT,STOREFRONT', 'product_reviews', 0, 'ADDON'),
(88, 87, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(89, 0, 'ROOT,STOREFRONT', 'image_zoom', 0, 'ADDON'),
(90, 89, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(91, 0, 'ROOT,STOREFRONT', 'google_sitemap', 0, 'ADDON'),
(92, 91, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(93, 0, 'ROOT', 'data_feeds', 0, 'ADDON'),
(94, 93, 'ROOT', 'general', 0, 'TAB'),
(95, 0, 'ROOT,STOREFRONT', 'price_list', 0, 'ADDON'),
(96, 95, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(97, 0, 'ROOT', 'janrain', 0, 'ADDON'),
(98, 97, 'ROOT', 'general', 0, 'TAB'),
(99, 0, 'ROOT,STOREFRONT', 'catalog_mode', 0, 'ADDON'),
(100, 99, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(101, 0, 'ROOT,STOREFRONT', 'hybrid_auth', 0, 'ADDON'),
(102, 101, 'ROOT,STOREFRONT', 'general', 0, 'TAB'),
(103, 0, 'ROOT', 'zapier', 0, 'ADDON'),
(104, 103, 'ROOT', 'general', 0, 'TAB'),
(105, 0, 'ROOT', 'gdpr', 0, 'ADDON'),
(106, 105, 'ROOT', 'general', 0, 'TAB'),
(107, 105, 'ROOT', 'gdpr', 10, 'TAB');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]settings_variants`
--

CREATE TABLE `[[dbprefix]]settings_variants` (
  `variant_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `object_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `name` varchar(64) NOT NULL DEFAULT '',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`variant_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2204 ;

--
-- Dumping data for table `[[dbprefix]]settings_variants`
--

INSERT INTO `[[dbprefix]]settings_variants` VALUES
(1, 3, 'hide', 10),
(2, 3, 'warning', 20),
(6, 7, 'manual', 1),
(7, 7, 'auto', 1),
(8, 15, 'use_selected_and_alternative', 20),
(9, 15, 'use_only_selected', 10),
(10, 52, '%d/%m/%Y', 1),
(11, 52, '%d-%m-%Y', 2),
(12, 52, '%d.%m.%Y', 3),
(13, 52, '%m/%d/%Y', 4),
(14, 52, '%m-%d-%Y', 5),
(15, 52, '%m.%d.%Y', 6),
(16, 52, '%Y/%m/%d', 7),
(17, 52, '%Y-%m-%d', 8),
(18, 52, '%Y.%m.%d', 9),
(19, 52, '%b %e, %Y', 10),
(20, 52, '%d %b %Y', 11),
(21, 52, '%A, %B %e, %Y', 12),
(22, 52, '%A, %e %B %Y', 13),
(23, 64, 'position', 0),
(24, 64, 'product', 10),
(25, 64, 'price', 20),
(169, 64, 'null', 30),
(26, 66, '%H:%M', 1),
(27, 66, '%H.%M', 2),
(28, 66, '%I:%M %p', 3),
(29, 66, '%I.%M %p', 4),
(30, 66, '%H:%M:%S', 5),
(31, 66, '%H.%M.%S', 6),
(32, 66, '%I:%M:%S %p', 7),
(33, 66, '%I.%M.%S %p', 8),
(34, 70, 'only_products', 3),
(35, 70, 'products_with_shippings', 2),
(36, 71, 'allow_shopping', 1),
(37, 71, 'hide_price_and_add_to_cart', 3),
(38, 71, 'hide_add_to_cart', 2),
(39, 84, '%a, %b %e', 10),
(40, 84, '%B %e, %Y', 15),
(41, 84, '%m.%e.%y', 20),
(42, 84, '%a %b %e, %Y', 30),
(43, 84, '%b %e', 40),
(44, 85, '%U', 10),
(45, 85, '%m.%e', 20),
(46, 85, '%U, %b', 30),
(47, 86, '%B, %Y', 5),
(48, 86, '%B', 10),
(49, 86, '%m', 20),
(50, 86, '%b', 30),
(51, 86, '%m-%Y', 40),
(52, 87, '%Y', 10),
(53, 87, '%y', 20),
(54, 108, 'smtp', 10),
(55, 108, 'mail', 20),
(56, 108, 'sendmail', 30),
(57, 121, 'digits', 1),
(58, 121, 'letters', 2),
(59, 121, 'mixed', 3),
(63, 139, 'Australia/Hobart', 700),
(64, 139, 'Pacific/Port_Moresby', 690),
(65, 139, 'Australia/Sydney', 680),
(66, 139, 'Australia/Brisbane', 670),
(67, 139, 'Australia/Darwin', 660),
(68, 139, 'Australia/Adelaide', 650),
(69, 139, 'Asia/Yakutsk', 640),
(70, 139, 'Asia/Seoul', 630),
(71, 139, 'Asia/Tokyo', 620),
(72, 139, 'Asia/Taipei', 610),
(73, 139, 'Australia/Perth', 600),
(74, 139, 'Asia/Singapore', 590),
(75, 139, 'Asia/Irkutsk', 580),
(76, 139, 'Asia/Shanghai', 570),
(77, 139, 'Asia/Krasnoyarsk', 560),
(78, 139, 'Asia/Bangkok', 550),
(79, 139, 'Asia/Yangon', 540),
(80, 139, 'Asia/Colombo', 530),
(81, 139, 'Asia/Dhaka', 520),
(82, 139, 'Asia/Novosibirsk', 510),
(83, 139, 'Asia/Kathmandu', 500),
(84, 139, 'Asia/Kolkata', 490),
(85, 139, 'Asia/Tashkent', 480),
(86, 139, 'Asia/Yekaterinburg', 470),
(87, 139, 'Asia/Kabul', 460),
(88, 139, 'Asia/Yerevan', 450),
(89, 139, 'Asia/Dubai', 440),
(90, 139, 'Asia/Tehran', 430),
(91, 139, 'Africa/Nairobi', 420),
(92, 139, 'Europe/Moscow', 410),
(93, 139, 'Asia/Riyadh', 400),
(94, 139, 'Asia/Baghdad', 390),
(95, 139, 'Asia/Jerusalem', 380),
(96, 139, 'Europe/Kyiv', 370),
(97, 139, 'Africa/Johannesburg', 360),
(98, 139, 'Africa/Cairo', 350),
(99, 139, 'Europe/Minsk', 415),
(100, 139, 'Europe/Istanbul', 330),
(101, 139, 'Africa/Lagos', 320),
(102, 139, 'Europe/Paris', 300),
(103, 139, 'Europe/Warsaw', 310),
(104, 139, 'Europe/Budapest', 290),
(105, 139, 'Europe/Berlin', 280),
(106, 139, 'Europe/London', 270),
(107, 139, 'Atlantic/Reykjavik', 260),
(108, 139, 'Atlantic/Azores', 250),
(109, 139, 'Atlantic/Cape_Verde', 240),
(110, 139, 'Atlantic/South_Georgia', 230),
(111, 139, 'America/Sao_Paulo', 220),
(112, 139, 'Atlantic/Bermuda', 210),
(113, 139, 'America/Nuuk', 200),
(114, 139, 'America/St_Johns', 190),
(115, 139, 'America/Halifax', 180),
(116, 139, 'America/La_Paz', 170),
(117, 139, 'America/Santiago', 160),
(118, 139, 'America/Bogota', 150),
(119, 139, 'America/New_York', 140),
(120, 139, 'Asia/Almaty', 130),
(121, 139, 'America/Guatemala', 120),
(122, 139, 'America/Chicago', 110),
(123, 139, 'America/Mexico_City', 100),
(124, 139, 'America/Regina', 90),
(125, 139, 'America/Phoenix', 80),
(126, 139, 'America/Chihuahua', 70),
(127, 139, 'America/Denver', 60),
(128, 139, 'America/Los_Angeles', 50),
(129, 139, 'America/Anchorage', 40),
(130, 139, 'Pacific/Honolulu', 30),
(131, 139, 'Pacific/Apia', 20),
(132, 139, 'Indian/Cocos', 10),
(133, 139, 'Asia/Vladivostok', 710),
(134, 139, 'Pacific/Guadalcanal', 720),
(135, 139, 'Pacific/Auckland', 730),
(136, 139, 'Pacific/Fiji', 740),
(137, 139, 'Pacific/Tongatapu', 750),
(138, 158, 'create', 5),
(139, 158, 'delete', 5),
(140, 158, 'update', 5),
(141, 158, 'status', 5),
(142, 159, 'create', 5),
(143, 159, 'delete', 5),
(144, 159, 'update', 5),
(145, 159, 'session', 5),
(146, 159, 'failed_login', 5),
(147, 160, 'create', 5),
(148, 160, 'delete', 5),
(149, 160, 'update', 5),
(150, 160, 'low_stock', 5),
(151, 161, 'create', 5),
(152, 161, 'delete', 5),
(153, 161, 'update', 5),
(154, 162, 'restore', 5),
(155, 162, 'backup', 5),
(156, 162, 'optimize', 5),
(157, 162, 'error', 5),
(158, 163, 'http', 5),
(159, 166, 'month_first', 1),
(160, 166, 'day_first', 2),
(161, 167, 'sunday_first', 1),
(162, 167, 'monday_first', 2),
(163, 179, 'unit_price', 10),
(164, 179, 'subtotal', 20),
(165, 182, 'billing_first', 1),
(166, 182, 'shipping_first', 2),
(167, 274, 'runtime', 1),
(168, 274, 'deprecated', 2),
(200, 295, 'none', 10),
(201, 295, 'tls', 20),
(202, 295, 'ssl', 30),
(220, 300, 'returning_customer_first', 10),
(221, 300, 'new_customer_first', 20),
(222, 300, 'hide', 30),
(223, 305, 'register', 10),
(224, 305, 'checkout_as_guest', 20),
(228, 139, 'Europe/Bucharest', 335),
(235, 308, 'old', 10),
(236, 308, 'new', 20),
(237, 139, 'Europe/Athens', 331),
(238, 139, 'Asia/Beirut', 332),
(239, 139, 'Asia/Kamchatka', 333),
(240, 163, 'shipping', 20),
(241, 313, 'international_format', 10),
(242, 313, 'any_digits', 20),
(243, 313, 'any_symbols', 30),
(244, 139, 'Pacific/Pitcairn', 760),
(245, 139, 'America/Vancouver', 770),
(246, 139, 'Pacific/Gambier', 780),
(247, 139, 'Australia/Lord_Howe', 790),
(248, 139, 'Pacific/Chatham', 800),
(249, 139, 'Africa/Casablanca', 810),
(250, 139, 'Europe/Dublin', 820),
(251, 139, 'Pacific/Midway', 830),
(252, 139, 'Asia/Urumqi', 840),
(253, 317, 'P', 10),
(254, 317, 'S', 20),
(255, 319, 'F', 10),
(256, 319, 'A', 20),
(257, 321, 'R', 10),
(258, 321, 'P', 20),
(259, 321, 'A', 30),
(260, 313, 'phone_number_with_country_selection', 5),
(2000, 2001, 'not_active', 1),
(2001, 2001, 'active', 2),
(2002, 5682, 'medium', 0),
(2003, 5682, 'large', 10),
(2004, 5683, 'none', 0),
(2005, 5683, 'horizontal', 10),
(2006, 5683, 'vertical', 20),
(2007, 5684, 'products', 0),
(2008, 5684, 'pages', 10),
(2009, 5690, 'standard', 0),
(2010, 5690, 'button_count', 10),
(2011, 5690, 'box_count', 20),
(2012, 5692, 'like', 0),
(2013, 5692, 'recommend', 10),
(2014, 5693, 'af_ZA', 0),
(2015, 5693, 'ar_AR', 10),
(2016, 5693, 'az_AZ', 20),
(2017, 5693, 'be_BY', 30),
(2018, 5693, 'bg_BG', 40),
(2019, 5693, 'bn_IN', 50),
(2020, 5693, 'bs_BA', 60),
(2021, 5693, 'ca_ES', 70),
(2022, 5693, 'cs_CZ', 80),
(2023, 5693, 'cy_GB', 90),
(2024, 5693, 'da_DK', 100),
(2025, 5693, 'de_DE', 110),
(2026, 5693, 'el_GR', 120),
(2027, 5693, 'en_GB', 130),
(2028, 5693, 'en_PI', 140),
(2029, 5693, 'en_UD', 150),
(2030, 5693, 'en_US', 160),
(2031, 5693, 'eo_EO', 170),
(2032, 5693, 'es_ES', 180),
(2033, 5693, 'es_LA', 190),
(2034, 5693, 'et_EE', 200),
(2035, 5693, 'eu_ES', 210),
(2036, 5693, 'fa_IR', 220),
(2037, 5693, 'fb_LT', 230),
(2038, 5693, 'fi_FI', 240),
(2039, 5693, 'fo_FO', 250),
(2040, 5693, 'fr_CA', 260),
(2041, 5693, 'fr_FR', 270),
(2042, 5693, 'fy_NL', 280),
(2043, 5693, 'ga_IE', 290),
(2044, 5693, 'gl_ES', 300),
(2045, 5693, 'he_IL', 310),
(2046, 5693, 'hi_IN', 320),
(2047, 5693, 'hr_HR', 330),
(2048, 5693, 'hu_HU', 340),
(2049, 5693, 'hy_AM', 350),
(2050, 5693, 'id_ID', 360),
(2051, 5693, 'is_IS', 370),
(2052, 5693, 'it_IT', 380),
(2053, 5693, 'ja_JP', 390),
(2054, 5693, 'ka_GE', 400),
(2055, 5693, 'km_KH', 410),
(2056, 5693, 'ko_KR', 420),
(2057, 5693, 'ku_TR', 430),
(2058, 5693, 'la_VA', 440),
(2059, 5693, 'lt_LT', 450),
(2060, 5693, 'lv_LV', 460),
(2061, 5693, 'mk_MK', 470),
(2062, 5693, 'ml_IN', 480),
(2063, 5693, 'ms_MY', 490),
(2064, 5693, 'nb_NO', 500),
(2065, 5693, 'ne_NP', 510),
(2066, 5693, 'nl_NL', 520),
(2067, 5693, 'nn_NO', 530),
(2068, 5693, 'pa_IN', 540),
(2069, 5693, 'pl_PL', 550),
(2070, 5693, 'ps_AF', 560),
(2071, 5693, 'pt_BR', 570),
(2072, 5693, 'pt_PT', 580),
(2073, 5693, 'ro_RO', 590),
(2074, 5693, 'ru_RU', 600),
(2075, 5693, 'sk_SK', 610),
(2076, 5693, 'sl_SI', 620),
(2077, 5693, 'sq_AL', 630),
(2078, 5693, 'sr_RS', 640),
(2079, 5693, 'sv_SE', 650),
(2080, 5693, 'sw_KE', 660),
(2081, 5693, 'ta_IN', 670),
(2082, 5693, 'te_IN', 680),
(2083, 5693, 'th_TH', 690),
(2084, 5693, 'tl_PH', 700),
(2085, 5693, 'tr_TR', 710),
(2086, 5693, 'uk_UA', 720),
(2087, 5693, 'vi_VN', 730),
(2088, 5693, 'zh_CN', 740),
(2089, 5693, 'zh_HK', 750),
(2090, 5693, 'zh_TW', 760),
(2091, 5694, 'arial', 0),
(2092, 5694, 'lucida grande', 10),
(2093, 5694, 'segoe ui', 20),
(2094, 5694, 'tahoma', 30),
(2095, 5694, 'trebuchet ms', 40),
(2096, 5694, 'verdana', 50),
(2097, 5695, 'light', 0),
(2098, 5695, 'dark', 10),
(2099, 5696, 'products', 0),
(2100, 5696, 'pages', 10),
(2101, 5699, 'full', 0),
(2102, 5699, 'button', 10),
(2103, 5699, 'mini', 20),
(2104, 5699, 'Vertical', 30),
(2105, 5702, 'like', 0),
(2106, 5702, 'interesting', 10),
(2107, 5703, 'products', 0),
(2108, 5703, 'pages', 10),
(2109, 5706, 'products', 0),
(2110, 5706, 'pages', 10),
(2111, 5708, '20', 0),
(2112, 5708, '28', 10),
(2113, 5709, 'rect', 0),
(2114, 5709, 'round', 10),
(2115, 5710, 'products', 0),
(2116, 5710, 'pages', 10),
(2117, 5718, 'smtp', 0),
(2118, 5718, 'mail', 10),
(2119, 5718, 'default', 20),
(2120, 5723, 'none', 0),
(2121, 5723, 'tls', 10),
(2122, 5723, 'ssl', 20),
(2123, 5730, 'dummy', 0),
(2124, 5730, 'mailchimp', 10),
(2125, 5730, 'madmimi', 20),
(2126, 5742, 'google', 0),
(2127, 5742, 'yandex', 10),
(2128, 5768, 'light', 0),
(2129, 5768, 'dark', 10),
(2130, 5769, 'normal', 0),
(2131, 5769, 'compact', 10),
(2132, 5770, 'image', 0),
(2133, 5770, 'audio', 10),
(2134, 5774, '0.9', 0),
(2135, 5774, '0.8', 10),
(2136, 5774, '0.7', 20),
(2137, 5774, '0.6', 30),
(2138, 5774, '0.5', 40),
(2139, 5774, '0.4', 50),
(2140, 5774, '0.3', 60),
(2141, 5774, '0.2', 70),
(2142, 5774, '0.1', 80),
(2143, 5781, 'before_product_description', 0),
(2144, 5781, 'in_a_product_tab', 10),
(2145, 5788, 'all', 0),
(2146, 5788, 'today', 10),
(2147, 5788, 'last_days', 20),
(2148, 5790, 'product_file_nohtml', 0),
(2149, 5790, 'product_file', 10),
(2150, 5790, 'product_category_nohtml', 20),
(2151, 5790, 'product_category', 30),
(2152, 5791, 'category', 0),
(2153, 5791, 'category_nohtml', 10),
(2154, 5791, 'file', 20),
(2155, 5791, 'root_category', 30),
(2156, 5792, 'page', 0),
(2157, 5792, 'page_nohtml', 10),
(2158, 5792, 'file', 20),
(2159, 5792, 'root_page', 30),
(2160, 5793, 'directory', 0),
(2161, 5793, 'file', 10),
(2162, 5804, 'minimal_absolute', 0),
(2163, 5804, 'minimal_percentage', 10),
(2164, 5804, 'maximal_absolute', 20),
(2165, 5804, 'maximal_percentage', 30),
(2166, 5823, 'C128A', 0),
(2167, 5823, 'C128B', 10),
(2168, 5823, 'C128C', 20),
(2169, 5823, 'I25', 30),
(2170, 5823, 'C39', 40),
(2171, 5824, 'png', 0),
(2172, 5824, 'jpeg', 10),
(2173, 5825, 'N', 0),
(2174, 5825, 'Y', 10),
(2175, 5846, 'any', 0),
(2176, 5846, 'anonymous', 10),
(2177, 5846, 'disabled', 20),
(2178, 5852, 'any', 0),
(2179, 5852, 'anonymous', 10),
(2180, 5852, 'disabled', 20),
(2181, 5858, 'any', 0),
(2182, 5858, 'anonymous', 10),
(2183, 5858, 'disabled', 20),
(2184, 5863, 'any', 0),
(2185, 5863, 'anonymous', 10),
(2186, 5863, 'disabled', 20),
(2187, 5878, 'any', 0),
(2188, 5878, 'anonymous', 10),
(2189, 5878, 'disabled', 20),
(2190, 5880, 'advanced', 0),
(2191, 5880, 'simple', 10),
(2192, 5882, 'none', 0),
(2193, 5882, 'country', 10),
(2194, 5882, 'city', 20),
(2195, 5888, '3', 0),
(2196, 5888, '5', 10),
(2197, 5888, '13', 20),
(2198, 5888, '11', 30),
(2199, 5920, 'catalog', 0),
(2200, 5920, 'store', 10),
(2201, 5925, 'none', 0),
(2202, 5925, 'implicit', 10),
(2203, 5925, 'explicit', 20);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]settings_vendor_values`
--

CREATE TABLE `[[dbprefix]]settings_vendor_values` (
  `object_id` mediumint(8) unsigned NOT NULL,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `value` text,
  PRIMARY KEY (`object_id`,`company_id`,`storefront_id`),
  KEY `storefront_id` (`storefront_id`),
  KEY `company_id` (`company_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shipments`
--

CREATE TABLE `[[dbprefix]]shipments` (
  `shipment_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `shipping_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `tracking_number` varchar(255) NOT NULL DEFAULT '',
  `carrier` varchar(255) NOT NULL DEFAULT '',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `comments` mediumtext,
  `status` char(1) NOT NULL DEFAULT 'P',
  PRIMARY KEY (`shipment_id`),
  KEY `status` (`status`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shipment_items`
--

CREATE TABLE `[[dbprefix]]shipment_items` (
  `item_id` int(11) unsigned NOT NULL,
  `shipment_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `order_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `amount` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`item_id`,`shipment_id`),
  KEY `shipment_id` (`shipment_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shippings`
--

CREATE TABLE `[[dbprefix]]shippings` (
  `shipping_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `destination` char(1) NOT NULL DEFAULT 'I',
  `min_weight` decimal(13,3) NOT NULL DEFAULT '0.000',
  `max_weight` decimal(13,3) NOT NULL DEFAULT '0.000',
  `usergroup_ids` varchar(255) NOT NULL DEFAULT '0',
  `rate_calculation` char(1) NOT NULL DEFAULT 'M',
  `service_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `service_params` text,
  `localization` varchar(255) NOT NULL DEFAULT '',
  `tax_ids` varchar(255) NOT NULL DEFAULT '',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'D',
  `free_shipping` char(1) NOT NULL DEFAULT 'N',
  `is_address_required` char(1) NOT NULL DEFAULT 'Y',
  UNIQUE KEY `shipping_id` (`shipping_id`),
  KEY `position` (`position`),
  KEY `localization` (`localization`),
  KEY `c_status` (`usergroup_ids`,`min_weight`,`max_weight`,`status`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=6 ;

--
-- Dumping data for table `[[dbprefix]]shippings`
--

INSERT INTO `[[dbprefix]]shippings` VALUES
(1, 1, 'I', '0.000', '0.000', '0', 'M', 0, '', '', '6', 0, 'A', 'N', 'Y'),
(3, 1, 'I', '0.000', '0.000', '0', 'R', 213, 'a:11:{s:8:"user_key";s:0:"";s:17:"user_key_password";s:0:"";s:14:"account_number";s:0:"";s:12:"meter_number";s:0:"";s:9:"test_mode";s:1:"Y";s:12:"package_type";s:14:"YOUR_PACKAGING";s:13:"drop_off_type";s:14:"REGULAR_PICKUP";s:17:"max_weight_of_box";s:1:"0";s:6:"height";s:2:"10";s:5:"width";s:2:"10";s:6:"length";s:2:"10";}', '', '6', 0, 'D', 'N', 'Y'),
(4, 1, 'I', '0.000', '0.000', '0', 'R', 87, 'a:11:{s:9:"client_id";s:0:"";s:13:"client_secret";s:0:"";s:16:"negotiated_rates";s:1:"N";s:14:"shipper_number";s:0:"";s:9:"test_mode";s:1:"Y";s:11:"pickup_type";s:2:"01";s:12:"package_type";s:2:"02";s:17:"max_weight_of_box";s:1:"0";s:5:"width";s:2:"10";s:6:"height";s:2:"10";s:6:"length";s:2:"10";}', '', '', 0, 'D', 'N', 'Y'),
(5, 1, 'I', '0.000', '70.000', '0', 'R', 50, 'a:38:{s:8:"username";s:0:"";s:9:"test_mode";s:1:"N";s:8:"mailtype";s:7:"Package";s:9:"container";s:0:"";s:18:"intl_package_width";s:1:"0";s:19:"intl_package_length";s:1:"0";s:19:"intl_package_height";s:1:"0";s:18:"intl_package_girth";s:1:"0";s:17:"intl_package_size";s:7:"REGULAR";s:28:"intl_service_registered_mail";s:1:"N";s:22:"intl_service_insurance";s:1:"N";s:27:"intl_service_return_receipt";s:1:"N";s:32:"intl_service_restricted_delivery";s:1:"N";s:30:"intl_service_pick_up_on_demand";s:1:"N";s:35:"intl_service_certificate_of_mailing";s:1:"N";s:12:"package_size";s:8:"Oversize";s:21:"first_class_mail_type";s:6:"LETTER";s:10:"machinable";s:4:"True";s:18:"container_priority";s:13:"Flat Rate Box";s:17:"container_express";s:18:"Flat Rate Envelope";s:14:"priority_width";s:2:"10";s:15:"priority_length";s:2:"10";s:15:"priority_height";s:2:"10";s:14:"priority_girth";s:1:"5";s:26:"domestic_service_certified";s:1:"N";s:26:"domestic_service_insurance";s:1:"N";s:36:"domestic_service_restricted_delivery";s:1:"N";s:45:"domestic_service_registered_without_insurance";s:1:"N";s:42:"domestic_service_registered_with_insurance";s:1:"N";s:36:"domestic_service_collect_on_delivery";s:1:"N";s:47:"domestic_service_return_receipt_for_merchandise";s:1:"N";s:31:"domestic_service_return_receipt";s:1:"N";s:62:"domestic_service_certificate_of_mailing_per_individual_article";s:1:"N";s:62:"domestic_service_certificate_of_mailing_for_firm_mailing_books";s:1:"N";s:39:"domestic_service_express_mail_insurance";s:1:"N";s:38:"domestic_service_delivery_confirmation";s:1:"N";s:39:"domestic_service_signature_confirmation";s:1:"N";s:42:"domestic_service_return_receipt_electronic";s:1:"N";}', '', '', 0, 'D', 'N', 'Y');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shipping_descriptions`
--

CREATE TABLE `[[dbprefix]]shipping_descriptions` (
  `shipping_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `shipping` varchar(255) NOT NULL DEFAULT '',
  `delivery_time` varchar(64) NOT NULL DEFAULT '',
  `description` mediumtext,
  PRIMARY KEY (`shipping_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]shipping_descriptions`
--

INSERT INTO `[[dbprefix]]shipping_descriptions` VALUES
(1, 'en', 'Custom shipping method', '3-5 days', '<p>Delivery time is calculated in business days.</p><p>Products in stock will be sent after the payment is verified. Mail service is responsible for the goods during transportation.</p><p>Please, open the package delivered under your order the moment you receive it. If any damage is revealed, make claims against mail service.</p><p>Any questions? Contact our Customer Service at 123-12-23</p>'),
(3, 'en', 'FedEx 2nd day', '2 days', '<p>Delivery time is calculated in business days.</p><p>Products in stock will be sent after the payment is verified. Mail service is responsible for the goods during transportation.</p><p>Please, open the package delivered under your order the moment you receive it. If any damage is revealed, make claims against mail service.</p><p>Any questions? Contact our Customer Service at 123-12-23</p>'),
(4, 'en', 'UPS 3day Select', '3 days', '<p>Delivery time is calculated in business days.</p><p>Products in stock will be sent after the payment is verified. Mail service is responsible for the goods during transportation.</p><p>Please, open the package delivered under your order the moment you receive it. If any damage is revealed, make claims against mail service.</p><p>Any questions? Contact our Customer Service at 123-12-23</p>'),
(5, 'en', 'USPS Media Mail', '1-2 days', '<p>Delivery time is calculated in business days.</p><p>Products in stock will be sent after the payment is verified. Mail service is responsible for the goods during transportation.</p><p>Please, open the package delivered under your order the moment you receive it. If any damage is revealed, make claims against mail service.</p><p>Any questions? Contact our Customer Service at 123-12-23</p>');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shipping_rates`
--

CREATE TABLE `[[dbprefix]]shipping_rates` (
  `rate_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `shipping_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `destination_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `base_rate` decimal(12,2) unsigned NOT NULL DEFAULT '0.00',
  `rate_value` text,
  PRIMARY KEY (`rate_id`),
  UNIQUE KEY `shipping_rate` (`shipping_id`,`destination_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=46 ;

--
-- Dumping data for table `[[dbprefix]]shipping_rates`
--

INSERT INTO `[[dbprefix]]shipping_rates` VALUES
(1, 1, 7, '0.00', 'a:2:{s:1:"C";a:3:{i:0;a:3:{s:16:"range_from_value";i:0;s:14:"range_to_value";i:30;s:5:"value";i:40;}i:30;a:3:{s:16:"range_from_value";i:30;s:14:"range_to_value";i:50;s:5:"value";i:10;}i:50;a:3:{s:16:"range_from_value";i:50;s:14:"range_to_value";s:0:"";s:5:"value";i:5;}}s:1:"I";a:2:{i:0;a:3:{s:16:"range_from_value";i:0;s:14:"range_to_value";i:10;s:5:"value";i:23;}i:10;a:3:{s:16:"range_from_value";i:10;s:14:"range_to_value";s:0:"";s:5:"value";i:15;}}}'),
(11, 1, 8, '0.00', 'a:2:{s:1:"W";a:1:{i:0;a:3:{s:16:"range_from_value";i:0;s:14:"range_to_value";s:0:"";s:5:"value";i:10;}}s:1:"I";a:1:{i:0;a:3:{s:16:"range_from_value";i:0;s:14:"range_to_value";s:0:"";s:5:"value";i:15;}}}'),
(45, 1, 1, '0.00', 'a:1:{s:1:"C";a:2:{i:0;a:3:{s:16:"range_from_value";i:0;s:14:"range_to_value";i:100;s:5:"value";s:4:"0.00";}i:100;a:3:{s:16:"range_from_value";i:100;s:14:"range_to_value";s:0:"";s:5:"value";s:5:"25.45";}}}');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shipping_services`
--

CREATE TABLE `[[dbprefix]]shipping_services` (
  `service_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `status` char(1) NOT NULL DEFAULT 'A',
  `module` varchar(32) NOT NULL DEFAULT '',
  `code` varchar(64) NOT NULL DEFAULT '',
  `sp_file` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`service_id`),
  KEY `sa` (`service_id`,`status`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=600 ;

--
-- Dumping data for table `[[dbprefix]]shipping_services`
--

INSERT INTO `[[dbprefix]]shipping_services` VALUES
(70, 'A', 'usps', 'First Class Mail', ''),
(81, 'A', 'ups', '01', ''),
(82, 'A', 'ups', '02', ''),
(83, 'A', 'ups', '03', ''),
(84, 'A', 'ups', '07', ''),
(85, 'A', 'ups', '08', ''),
(86, 'A', 'ups', '11', ''),
(87, 'A', 'ups', '12', ''),
(88, 'A', 'ups', '13', ''),
(89, 'A', 'ups', '14', ''),
(90, 'A', 'ups', '54', ''),
(91, 'A', 'ups', '59', ''),
(92, 'A', 'ups', '65', ''),
(93, 'A', 'ups', '01', ''),
(94, 'A', 'ups', '02', ''),
(95, 'A', 'ups', '03', ''),
(96, 'A', 'ups', '07', ''),
(97, 'A', 'ups', '08', ''),
(98, 'A', 'ups', '14', ''),
(99, 'A', 'ups', '54', ''),
(100, 'A', 'ups', '65', ''),
(101, 'A', 'ups', '01', ''),
(103, 'A', 'ups', '07', ''),
(104, 'A', 'ups', '08', ''),
(105, 'A', 'ups', '11', ''),
(106, 'A', 'ups', '12', ''),
(107, 'A', 'ups', '14', ''),
(108, 'A', 'ups', '65', ''),
(109, 'A', 'ups', '07', ''),
(110, 'A', 'ups', '08', ''),
(111, 'A', 'ups', '54', ''),
(112, 'A', 'ups', '65', ''),
(113, 'A', 'ups', '07', ''),
(114, 'A', 'ups', '08', ''),
(124, 'A', 'ups', '11', ''),
(125, 'A', 'ups', '54', ''),
(126, 'A', 'ups', '65', ''),
(127, 'A', 'ups', '82', ''),
(128, 'A', 'ups', '83', ''),
(130, 'A', 'ups', '85', ''),
(131, 'A', 'ups', '86', ''),
(132, 'A', 'ups', '07', ''),
(133, 'A', 'ups', '08', ''),
(134, 'A', 'ups', '11', ''),
(135, 'A', 'ups', '54', ''),
(136, 'A', 'ups', '65', ''),
(137, 'A', 'ups', '07', ''),
(138, 'A', 'ups', '08', ''),
(139, 'A', 'ups', '11', ''),
(140, 'A', 'ups', '54', ''),
(141, 'A', 'ups', '65', ''),
(445, 'A', 'ups', '70', ''),
(446, 'A', 'ups', '54', ''),
(447, 'A', 'ups', '70', ''),
(448, 'A', 'ups', '70', ''),
(449, 'A', 'ups', '11', ''),
(450, 'A', 'ups', '70', ''),
(451, 'A', 'ups', '96', ''),
(592, 'A', 'ups', '02', ''),
(593, 'A', 'ups', '13', ''),
(594, 'A', 'ups', '54', ''),
(595, 'A', 'ups', '72', ''),
(596, 'A', 'ups', '17', ''),
(597, 'A', 'ups', '71', ''),
(598, 'A', 'ups', '74', ''),
(167, 'A', 'swisspost', 'int_pr_standart_letter.csv', ''),
(168, 'A', 'swisspost', 'int_ur_goods.csv', ''),
(169, 'A', 'swisspost', 'int_pr_postpac.csv', ''),
(170, 'A', 'swisspost', 'int_ec_standart_letter.csv', ''),
(171, 'A', 'swisspost', 'int_ec_postpac.csv', ''),
(172, 'A', 'swisspost', 'prv_pr_postpac.csv', ''),
(173, 'A', 'swisspost', 'prv_ec_postpac.csv', ''),
(174, 'A', 'swisspost', 'int_ur_goods.csv', ''),
(175, 'A', 'swisspost', 'prv_ec_bulky_goods.csv', ''),
(176, 'A', 'swisspost', 'int_pr_large_letter.csv', ''),
(177, 'A', 'swisspost', 'int_pr_maxi_letter.csv', ''),
(178, 'A', 'swisspost', 'int_ec_large_letter.csv', ''),
(179, 'A', 'swisspost', 'int_ec_maxi_letter.csv', ''),
(212, 'A', 'fedex', 'PRIORITY_OVERNIGHT', ''),
(213, 'A', 'fedex', 'FEDEX_2_DAY', ''),
(214, 'A', 'fedex', 'FEDEX_EXPRESS_SAVER', ''),
(215, 'A', 'fedex', 'FEDEX_GROUND', ''),
(216, 'A', 'fedex', 'GROUND_HOME_DELIVERY', ''),
(217, 'A', 'fedex', 'STANDARD_OVERNIGHT', ''),
(218, 'A', 'fedex', 'FIRST_OVERNIGHT', ''),
(219, 'A', 'fedex', 'FEDEX_1_DAY_FREIGHT', ''),
(220, 'A', 'fedex', 'FEDEX_2_DAY_FREIGHT', ''),
(221, 'A', 'fedex', 'FEDEX_3_DAY_FREIGHT', ''),
(222, 'A', 'fedex', 'INTERNATIONAL_PRIORITY', ''),
(223, 'A', 'fedex', 'INTERNATIONAL_ECONOMY', ''),
(225, 'A', 'fedex', 'INTERNATIONAL_FIRST', ''),
(226, 'A', 'fedex', 'INTERNATIONAL_PRIORITY_FREIGHT', ''),
(227, 'A', 'fedex', 'INTERNATIONAL_ECONOMY_FREIGHT', ''),
(228, 'A', 'fedex', 'EUROPE_FIRST_INTERNATIONAL_PRIORITY', ''),
(229, 'A', 'fedex', 'SMART_POST', ''),
(452, 'A', 'fedex', 'FEDEX_2_DAY_AM', ''),
(453, 'A', 'fedex', 'FEDEX_DISTANCE_DEFERRED', ''),
(454, 'A', 'fedex', 'FEDEX_FIRST_FREIGHT', ''),
(455, 'A', 'fedex', 'FEDEX_FREIGHT_ECONOMY', ''),
(456, 'A', 'fedex', 'FEDEX_FREIGHT_PRIORITY', ''),
(457, 'A', 'fedex', 'FEDEX_NEXT_DAY_AFTERNOON', ''),
(458, 'A', 'fedex', 'FEDEX_NEXT_DAY_EARLY_MORNING', ''),
(459, 'A', 'fedex', 'FEDEX_NEXT_DAY_END_OF_DAY', ''),
(460, 'A', 'fedex', 'FEDEX_NEXT_DAY_FREIGHT', ''),
(461, 'A', 'fedex', 'FEDEX_NEXT_DAY_MID_MORNING', ''),
(462, 'A', 'fedex', 'SAME_DAY', ''),
(463, 'A', 'fedex', 'SAME_DAY_CITY', ''),
(40, 'A', 'usps', 'Global Express Guaranteed GXG', ''),
(41, 'A', 'usps', 'Global Express Guaranteed Non Document Rectangular', ''),
(42, 'A', 'usps', 'Global Express Guaranteed Non Document Non Rectangular', ''),
(43, 'A', 'usps', 'Priority Mail Express International', ''),
(44, 'A', 'usps', 'Express Mail International Flat Rate Envelope', ''),
(45, 'A', 'usps', 'Priority Mail International', ''),
(47, 'A', 'usps', 'Priority Mail Express', ''),
(48, 'A', 'usps', 'Standard Post M', ''),
(49, 'A', 'usps', 'Standard Post N', ''),
(50, 'A', 'usps', 'Media Mail Parcel', ''),
(51, 'A', 'usps', 'Priority Mail', ''),
(52, 'A', 'usps', 'Priority Mail International Flat Rate Envelope', ''),
(53, 'A', 'usps', 'Priority Mail International Flat Rate Box', ''),
(68, 'A', 'usps', 'Bound Printed Matter', ''),
(69, 'A', 'usps', 'Library Mail Parcel', ''),
(204, 'A', 'usps', 'Ground Advantage', ''),
(208, 'A', 'usps', 'Priority Mail International Small Flat Rate Box', ''),
(209, 'A', 'usps', 'Priority Mail International Medium Flat Rate Box', ''),
(210, 'A', 'usps', 'Priority Mail International Large Flat Rate Box', ''),
(211, 'A', 'usps', 'USPS GXG Envelopes', ''),
(233, 'A', 'usps', 'Priority Mail Regional Rate', ''),
(384, 'A', 'dhl', 'X', ''),
(385, 'A', 'dhl', 'P', ''),
(386, 'A', 'dhl', 'U', ''),
(387, 'A', 'dhl', 'K', ''),
(388, 'A', 'dhl', 'L', ''),
(389, 'A', 'dhl', 'T', ''),
(390, 'A', 'dhl', 'N', ''),
(391, 'A', 'dhl', '7', ''),
(474, 'A', 'dhl', 'D', ''),
(475, 'A', 'dhl', 'M', ''),
(476, 'A', 'dhl', 'H', ''),
(477, 'A', 'dhl', 'E', ''),
(392, 'A', 'can', 'DOM.RP', ''),
(393, 'A', 'can', 'DOM.EP', ''),
(394, 'A', 'can', 'DOM.XP', ''),
(395, 'A', 'can', 'DOM.XP.CERT', ''),
(396, 'A', 'can', 'DOM.PC', ''),
(397, 'A', 'can', 'DOM.DT', ''),
(398, 'A', 'can', 'DOM.LIB', ''),
(399, 'A', 'can', 'USA.EP', ''),
(400, 'A', 'can', 'USA.PW.ENV', ''),
(401, 'A', 'can', 'USA.PW.PAK', ''),
(402, 'A', 'can', 'USA.PW.PARCEL', ''),
(403, 'A', 'can', 'USA.SP.AIR', ''),
(404, 'A', 'can', 'USA.TP', ''),
(405, 'A', 'can', 'USA.TP.LVM', ''),
(406, 'A', 'can', 'USA.XP', ''),
(407, 'A', 'can', 'INT.XP', ''),
(408, 'A', 'can', 'INT.IP.AIR', ''),
(409, 'A', 'can', 'INT.IP.SURF', ''),
(410, 'A', 'can', 'INT.PW.ENV', ''),
(411, 'A', 'can', 'INT.PW.PAK', ''),
(412, 'A', 'can', 'INT.PW.PARCEL', ''),
(413, 'A', 'can', 'INT.SP.AIR', ''),
(414, 'A', 'can', 'INT.SP.SURF', ''),
(415, 'A', 'can', 'INT.TP', ''),
(416, 'A', 'aup', 'AUS_PARCEL_REGULAR', ''),
(417, 'A', 'aup', 'AUS_PARCEL_REGULAR_SATCHEL_500G', ''),
(419, 'A', 'aup', 'AUS_PARCEL_REGULAR_SATCHEL_5KG', ''),
(420, 'A', 'aup', 'AUS_PARCEL_EXPRESS', ''),
(421, 'A', 'aup', 'AUS_PARCEL_EXPRESS_SATCHEL_SMALL', ''),
(423, 'A', 'aup', 'AUS_PARCEL_EXPRESS_SATCHEL_EXTRA_LARGE', ''),
(426, 'A', 'aup', 'INT_PARCEL_COR_OWN_PACKAGING', ''),
(427, 'A', 'aup', 'INT_PARCEL_EXP_OWN_PACKAGING', ''),
(428, 'A', 'aup', 'INT_PARCEL_STD_OWN_PACKAGING', ''),
(430, 'A', 'aup', 'INT_PARCEL_SEA_OWN_PACKAGING', ''),
(431, 'A', 'aup', 'AUS_LETTER_REGULAR_SMALL', ''),
(432, 'A', 'aup', 'AUS_LETTER_PRIORITY_SMALL', ''),
(433, 'A', 'aup', 'AUS_LETTER_REGULAR_LARGE_125', ''),
(434, 'A', 'aup', 'AUS_LETTER_PRIORITY_LARGE_125', ''),
(435, 'A', 'aup', 'AUS_LETTER_EXPRESS_SMALL', ''),
(436, 'A', 'aup', 'AUS_LETTER_EXPRESS_MEDIUM', ''),
(437, 'A', 'aup', 'AUS_LETTER_EXPRESS_LARGE', ''),
(438, 'A', 'aup', 'INT_LETTER_COR_OWN_PACKAGING', ''),
(439, 'A', 'aup', 'INT_LETTER_EXP_OWN_PACKAGING', ''),
(440, 'A', 'aup', 'INT_LETTER_REG_SMALL_ENVELOPE', ''),
(441, 'A', 'aup', 'INT_LETTER_REG_LARGE_ENVELOPE', ''),
(442, 'A', 'aup', 'INT_LETTER_AIR_OWN_PACKAGING_LIGHT', ''),
(443, 'A', 'aup', 'INT_LETTER_AIR_OWN_PACKAGING_MEDIUM', ''),
(444, 'A', 'aup', 'INT_LETTER_AIR_OWN_PACKAGING_HEAVY', ''),
(464, 'A', 'aup', 'AUS_PARCEL_REGULAR_SATCHEL_MEDIUM', ''),
(465, 'A', 'aup', 'AUS_PARCEL_REGULAR_SATCHEL_EXTRA_LARGE', ''),
(466, 'A', 'aup', 'AUS_PARCEL_REGULAR_PACKAGE_SMALL', ''),
(467, 'A', 'aup', 'AUS_PARCEL_REGULAR_PACKAGE_LARGE', ''),
(468, 'A', 'aup', 'AUS_PARCEL_REGULAR_PACKAGE_EXTRA_LARGE', ''),
(469, 'A', 'aup', 'AUS_PARCEL_EXPRESS_SATCHEL_MEDIUM', ''),
(470, 'A', 'aup', 'AUS_LETTER_REGULAR_LARGE_250', ''),
(471, 'A', 'aup', 'AUS_LETTER_PRIORITY_LARGE_250', ''),
(472, 'A', 'aup', 'AUS_LETTER_REGULAR_LARGE_500', ''),
(473, 'A', 'aup', 'AUS_LETTER_PRIORITY_LARGE_500', ''),
(599, 'A', 'store_locator', 'pickup', '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shipping_service_descriptions`
--

CREATE TABLE `[[dbprefix]]shipping_service_descriptions` (
  `service_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `description` varchar(255) NOT NULL DEFAULT '',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`service_id`,`lang_code`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=600 ;

--
-- Dumping data for table `[[dbprefix]]shipping_service_descriptions`
--

INSERT INTO `[[dbprefix]]shipping_service_descriptions` VALUES
(81, 'UPS USA: Next Day Air', 'en'),
(82, 'UPS USA: 2nd Day Air', 'en'),
(83, 'UPS USA: Ground', 'en'),
(84, 'UPS USA: Worldwide Express', 'en'),
(85, 'UPS USA: Worldwide Expedited', 'en'),
(86, 'UPS USA: Standard', 'en'),
(87, 'UPS USA: 3 Day Select', 'en'),
(88, 'UPS USA: Next Day Air Saver', 'en'),
(89, 'UPS USA: Next Day Air Early', 'en'),
(90, 'UPS USA: Worldwide Express Plus', 'en'),
(91, 'UPS USA: 2nd Day Air A.M.', 'en'),
(92, 'UPS USA: Worldwide Saver', 'en'),
(93, 'UPS Puerto Rico: Next Day Air', 'en'),
(94, 'UPS Puerto Rico: 2nd Day Air', 'en'),
(95, 'UPS Puerto Rico: Ground', 'en'),
(96, 'UPS Puerto Rico: Worldwide Express', 'en'),
(97, 'UPS Puerto Rico: Worldwide Expedited', 'en'),
(98, 'UPS Puerto Rico: Next Day Air Early', 'en'),
(99, 'UPS Puerto Rico: Worldwide Express Plus', 'en'),
(100, 'UPS Puerto Rico: Worldwide Saver', 'en'),
(101, 'UPS Canada: Express', 'en'),
(103, 'UPS Canada: Worldwide Express', 'en'),
(104, 'UPS Canada: Worldwide Expedited', 'en'),
(105, 'UPS Canada: Standard', 'en'),
(106, 'UPS Canada: 3 Day Select', 'en'),
(107, 'UPS Canada: Express Early (domestic shipments)', 'en'),
(108, 'UPS Canada: Express Saver (international shipments from Canada)', 'en'),
(109, 'UPS Mexico: Express', 'en'),
(110, 'UPS Mexico: Expedited', 'en'),
(111, 'UPS Mexico: Worldwide Express Plus', 'en'),
(112, 'UPS Mexico: Worldwide Saver', 'en'),
(113, 'UPS Poland: Express', 'en'),
(114, 'UPS Poland: Expedited', 'en'),
(124, 'UPS Poland: Standard', 'en'),
(125, 'UPS Poland: Express Plus', 'en'),
(126, 'UPS Poland: Express Saver', 'en'),
(127, 'UPS Poland: Today Standard', 'en'),
(128, 'UPS Poland: Today Dedicated Courier', 'en'),
(130, 'UPS Poland: Today Express', 'en'),
(131, 'UPS Poland: Today Express Saver', 'en'),
(132, 'UPS Europe: Express', 'en'),
(133, 'UPS Europe: Expedited', 'en'),
(134, 'UPS Europe: Standard', 'en'),
(135, 'UPS Europe: Worldwide Express Plus', 'en'),
(136, 'UPS Europe: Worldwide Saver', 'en'),
(137, 'UPS Other: Express', 'en'),
(138, 'UPS Other: Worldwide Expedited', 'en'),
(139, 'UPS Other: Standard', 'en'),
(140, 'UPS Other: Worldwide Express Plus', 'en'),
(141, 'UPS Other: Worldwide Saver', 'en'),
(445, 'UPS Canada: Access Point Economy', 'en'),
(446, 'UPS Canada: Worldwide Express Plus', 'en'),
(447, 'UPS Europe: Access Point Economy', 'en'),
(448, 'UPS Mexico: Access Point Economy', 'en'),
(449, 'UPS Mexico: Standard', 'en'),
(450, 'UPS Poland: Access Point Economy', 'en'),
(451, 'UPS All countries: Worldwide Express Freight', 'en'),
(592, 'UPS Canada: Expedited', 'en'),
(593, 'UPS Canada: Express Saver (domestic shipments)', 'en'),
(594, 'UPS Canada: Express Early (shipments from Canada to CA and US 48)', 'en'),
(595, 'UPS All countries: Worldwide Economy DDP', 'en'),
(596, 'UPS All countries: Worldwide Economy DDU', 'en'),
(597, 'UPS All countries: Worldwide Express Freight Midday', 'en'),
(598, 'UPS Germany: Express 12:00', 'en'),
(167, 'Swiss Post International PRIORITY Standart letter', 'en'),
(168, 'Swiss Post International Document URGENT', 'en'),
(169, 'Swiss Post International PostPac PRIORITY', 'en'),
(170, 'Swiss Post International ECONOMY Standart letter', 'en'),
(171, 'Swiss Post International PostPac ECONOMY', 'en'),
(172, 'Swiss Post Private Customers PostPac PRIORITY', 'en'),
(173, 'Swiss Post Private Customers PostPac ECONOMY', 'en'),
(174, 'Swiss Post International URGENT goods', 'en'),
(175, 'Swiss Post Private Customers Bulky Goods ECONOMY', 'en'),
(176, 'Swiss Post International PRIORITY Large letter', 'en'),
(177, 'Swiss Post International PRIORITY Maxi letter', 'en'),
(178, 'Swiss Post International ECONOMY Large letter', 'en'),
(179, 'Swiss Post International ECONOMY Maxi letter', 'en'),
(212, 'FedEx Priority Overnight®', 'en'),
(213, 'FedEx 2nd Day®', 'en'),
(214, 'FedEx Express Saver®', 'en'),
(215, 'FedEx Ground®', 'en'),
(216, 'FedEx Home Delivery®', 'en'),
(217, 'FedEx Standard Overnight®', 'en'),
(218, 'FedEx First Overnight®', 'en'),
(219, 'FedEx 1Day Freight®', 'en'),
(220, 'FedEx 2Day Freight®', 'en'),
(221, 'FedEx 3Day Freight®', 'en'),
(222, 'FedEx International Priority®', 'en'),
(223, 'FedEx International Economy®', 'en'),
(225, 'FedEx International First®', 'en'),
(226, 'FedEx International Priority Freight®', 'en'),
(227, 'FedEx International Economy Freight®', 'en'),
(228, 'FedEx Europe First International Priority®', 'en'),
(229, 'FedEx Smart Post®', 'en'),
(452, 'FedEx 2nd Day® AM', 'en'),
(453, 'FedEx Distance Deferred®', 'en'),
(454, 'FedEx First Freight®', 'en'),
(455, 'FedEx Freight® Ecomomy', 'en'),
(456, 'FedEx Freight® Priority', 'en'),
(457, 'FedEx Overnight® Afternoon', 'en'),
(458, 'FedEx Overnight® Early morning', 'en'),
(459, 'FedEx Overnight® End of day', 'en'),
(460, 'FedEx Overnight® Freight', 'en'),
(461, 'FedEx Overnight® Midmorning', 'en'),
(462, 'FedEx SameDay®', 'en'),
(463, 'FedEx SameDay® City', 'en'),
(40, 'USPS Global Express Guaranteed', 'en'),
(41, 'USPS Global Express Guaranteed Non-Document Rectangular', 'en'),
(42, 'USPS Global Express Guaranteed Non-Document Non-Rectangular', 'en'),
(43, 'USPS Priority Mail Express International', 'en'),
(44, 'USPS Express Mail International Flat-Rate Envelope', 'en'),
(45, 'USPS Priority Mail International', 'en'),
(47, 'USPS Priority Mail Express', 'en'),
(48, 'USPS Standard Machinable', 'en'),
(49, 'USPS Standard Non Machinable', 'en'),
(50, 'USPS Media Mail', 'en'),
(51, 'USPS Priority Mail', 'en'),
(52, 'USPS Priority Mail International Flat-Rate Envelope', 'en'),
(53, 'USPS Priority Mail International Flat-Rate Box', 'en'),
(68, 'USPS Bound Printed Matter', 'en'),
(69, 'USPS Library Mail', 'en'),
(70, 'USPS First-Class Mail', 'en'),
(204, 'USPS Ground Advantage', 'en'),
(208, 'USPS Priority Mail International Small Flat Rate Box', 'en'),
(209, 'USPS Priority Mail International Medium Flat Rate Box', 'en'),
(210, 'USPS Priority Mail International Large Flat Rate Box', 'en'),
(211, 'USPS GXG Envelopes', 'en'),
(233, 'USPS Priority Mail Regional Rate', 'en'),
(384, 'DHL Express Envelope', 'en'),
(385, 'DHL Express Worldwide (Dutiable)', 'en'),
(386, 'DHL Express Worldwide (EU)', 'en'),
(387, 'DHL Express 9:00 (Non-dutiable)', 'en'),
(388, 'DHL Express 10:30', 'en'),
(389, 'DHL Express 12:00', 'en'),
(390, 'DHL Domestic Express', 'en'),
(391, 'DHL Express Easy', 'en'),
(474, 'DHL Express Worldwide (Non-dutiable)', 'en'),
(475, 'DHL Express 10:30 Premium', 'en'),
(476, 'DHL Express Economy Select', 'en'),
(477, 'DHL Express 9:00 (Dutiable)', 'en'),
(392, 'Regular Parcel', 'en'),
(393, 'Expedited Parcel', 'en'),
(394, 'Xpresspost', 'en'),
(395, 'Xpresspost Certified', 'en'),
(396, 'Priority', 'en'),
(397, 'Delivered Tonight', 'en'),
(398, 'Library Books', 'en'),
(399, 'Expedited Parcel USA', 'en'),
(400, 'Priority Worldwide Envelope USA', 'en'),
(401, 'Priority Worldwide pak USA', 'en'),
(402, 'Priority Worldwide Parcel USA', 'en'),
(403, 'Small Packet USA Air', 'en'),
(404, 'Tracked Packet - USA', 'en'),
(405, 'Tracked Packet - USA (LVM - large volume mailers)', 'en'),
(406, 'Xpresspost USA', 'en'),
(407, 'Xpresspost International', 'en'),
(408, 'International Parcel Air', 'en'),
(409, 'International Parcel Surface', 'en'),
(410, 'Priority Worldwide Envelope Int’l', 'en'),
(411, 'Priority Worldwide pak Int’l', 'en'),
(412, 'Priority Worldwide parcel Int’l', 'en'),
(413, 'Small Packet International Air', 'en'),
(414, 'Small Packet International Surface', 'en'),
(415, 'Tracked Packet - International', 'en'),
(416, 'Domestic Parcels: Parcel Post', 'en'),
(417, 'Domestic Parcels: Parcel Post Small Satchel', 'en'),
(419, 'Domestic Parcels: Parcel Post Large Satchel', 'en'),
(420, 'Domestic Parcels: Express Post', 'en'),
(421, 'Domestic Parcels: Express Post Small Satchel', 'en'),
(423, 'Domestic Parcels: Express Post Extra Large Satchel', 'en'),
(426, 'International Parcels: Courier', 'en'),
(427, 'International Parcels: Express', 'en'),
(428, 'International Parcels: Standard', 'en'),
(430, 'International Parcels: Economy Sea', 'en'),
(431, 'Domestic Letters: Small Letter', 'en'),
(432, 'Domestic Letters: Small Priority Letter', 'en'),
(433, 'Domestic Letters: Large Letter', 'en'),
(434, 'Domestic Letters: Large Priority Letter', 'en'),
(435, 'Domestic Letters: Express Post Small Envelope', 'en'),
(436, 'Domestic Letters: Express Post Medium Envelope', 'en'),
(437, 'Domestic Letters: Express Post Large Envelope', 'en'),
(438, 'International Letters: Courier', 'en'),
(439, 'International Letters: Express', 'en'),
(440, 'International Letters: Registered Post DL', 'en'),
(441, 'International Letters: Registered Post B4', 'en'),
(442, 'International Letters: Economy Air (Light)', 'en'),
(443, 'International Letters: Economy Air (Medium)', 'en'),
(444, 'International Letters: Economy Air (Heavy)', 'en'),
(464, 'Domestic Parcels: Parcel Post Medium Satchel', 'en'),
(465, 'Domestic Parcels: Parcel Post Extra Large Satchel', 'en'),
(466, 'Domestic Parcels: Parcel Post Small Package', 'en'),
(467, 'Domestic Parcels: Parcel Post Large Package', 'en'),
(468, 'Domestic Parcels: Parcel Post Extra Large Package', 'en'),
(469, 'Domestic Parcels: Express Post Medium Satchel', 'en'),
(470, 'Domestic Letters: Large Letter 250g', 'en'),
(471, 'Domestic Letters: Large Priority Letter 250g', 'en'),
(472, 'Domestic Letters: Large Letter 500g', 'en'),
(473, 'Domestic Letters: Large Priority Letter 500g', 'en'),
(599, 'Pickup', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shipping_time_descriptions`
--

CREATE TABLE `[[dbprefix]]shipping_time_descriptions` (
  `shipping_id` int(11) unsigned NOT NULL DEFAULT '0',
  `destination_id` int(11) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `delivery_time` varchar(128) NOT NULL DEFAULT '',
  PRIMARY KEY (`shipping_id`,`destination_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]shopify_imports`
--

CREATE TABLE `[[dbprefix]]shopify_imports` (
  `import_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` int(11) unsigned NOT NULL,
  `status` char(1) NOT NULL DEFAULT 'N',
  `updated_at` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`import_id`),
  KEY `idx_company_id` (`company_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sitemap_links`
--

CREATE TABLE `[[dbprefix]]sitemap_links` (
  `link_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `link_href` varchar(255) NOT NULL DEFAULT '',
  `section_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'A',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `link_type` varchar(255) NOT NULL DEFAULT '',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`link_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=5 ;

--
-- Dumping data for table `[[dbprefix]]sitemap_links`
--

INSERT INTO `[[dbprefix]]sitemap_links` VALUES
(4, 'profiles.update', 2, 'A', 10, '', 1),
(1, 'checkout.cart', 2, 'A', 20, '', 1),
(3, 'checkout.checkout', 2, 'A', 30, '', 1),
(2, 'wishlist.view', 2, 'A', 40, '', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sitemap_sections`
--

CREATE TABLE `[[dbprefix]]sitemap_sections` (
  `section_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `status` char(1) NOT NULL DEFAULT 'A',
  `section_type` varchar(255) NOT NULL DEFAULT '1',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`section_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=3 ;

--
-- Dumping data for table `[[dbprefix]]sitemap_sections`
--

INSERT INTO `[[dbprefix]]sitemap_sections` VALUES
(2, 'A', '1', 10, 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]states`
--

CREATE TABLE `[[dbprefix]]states` (
  `state_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `country_code` varchar(2) NOT NULL DEFAULT '',
  `code` varchar(32) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`state_id`),
  UNIQUE KEY `cs` (`country_code`,`code`),
  KEY `code` (`code`),
  KEY `country_code` (`country_code`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=857 ;

--
-- Dumping data for table `[[dbprefix]]states`
--

INSERT INTO `[[dbprefix]]states` VALUES
(15, 'US', 'CA', 'A'),
(13, 'US', 'AR', 'A'),
(12, 'US', 'AZ', 'A'),
(11, 'US', 'AK', 'A'),
(10, 'US', 'AL', 'A'),
(16, 'US', 'CO', 'A'),
(17, 'US', 'CT', 'A'),
(18, 'US', 'DE', 'A'),
(19, 'US', 'DC', 'A'),
(20, 'US', 'FL', 'A'),
(21, 'US', 'GA', 'A'),
(22, 'US', 'GU', 'A'),
(23, 'US', 'HI', 'A'),
(24, 'US', 'ID', 'A'),
(25, 'US', 'IL', 'A'),
(26, 'US', 'IN', 'A'),
(27, 'US', 'IA', 'A'),
(28, 'US', 'KS', 'A'),
(29, 'US', 'KY', 'A'),
(30, 'US', 'LA', 'A'),
(31, 'US', 'ME', 'A'),
(32, 'US', 'MD', 'A'),
(33, 'US', 'MA', 'A'),
(34, 'US', 'MI', 'A'),
(35, 'US', 'MN', 'A'),
(36, 'US', 'MS', 'A'),
(37, 'US', 'MO', 'A'),
(38, 'US', 'MT', 'A'),
(39, 'US', 'NE', 'A'),
(40, 'US', 'NV', 'A'),
(41, 'US', 'NH', 'A'),
(42, 'US', 'NJ', 'A'),
(43, 'US', 'NM', 'A'),
(44, 'US', 'NY', 'A'),
(45, 'US', 'NC', 'A'),
(46, 'US', 'ND', 'A'),
(47, 'US', 'OH', 'A'),
(48, 'US', 'OK', 'A'),
(49, 'US', 'OR', 'A'),
(50, 'US', 'PA', 'A'),
(51, 'US', 'PR', 'A'),
(52, 'US', 'RI', 'A'),
(53, 'US', 'SC', 'A'),
(54, 'US', 'SD', 'A'),
(55, 'US', 'TN', 'A'),
(56, 'US', 'TX', 'A'),
(57, 'US', 'UT', 'A'),
(58, 'US', 'VT', 'A'),
(59, 'US', 'VI', 'A'),
(60, 'US', 'VA', 'A'),
(61, 'US', 'WA', 'A'),
(62, 'US', 'WV', 'A'),
(63, 'US', 'WI', 'A'),
(64, 'US', 'WY', 'A'),
(74, 'FR', '01', 'A'),
(66, 'FR', '02', 'A'),
(67, 'FR', '03', 'A'),
(68, 'FR', '04', 'A'),
(69, 'FR', '06', 'A'),
(70, 'FR', '07', 'A'),
(71, 'FR', '08', 'A'),
(72, 'FR', '09', 'A'),
(73, 'FR', '10', 'A'),
(75, 'FR', '11', 'A'),
(76, 'FR', '12', 'A'),
(77, 'FR', '13', 'A'),
(78, 'FR', '14', 'A'),
(79, 'FR', '15', 'A'),
(80, 'FR', '16', 'A'),
(81, 'FR', '17', 'A'),
(82, 'FR', '18', 'A'),
(83, 'FR', '19', 'A'),
(84, 'FR', '2A', 'A'),
(85, 'FR', '21', 'A'),
(86, 'FR', '22', 'A'),
(87, 'FR', '23', 'A'),
(88, 'FR', '24', 'A'),
(89, 'FR', '25', 'A'),
(90, 'FR', '26', 'A'),
(91, 'FR', '91', 'A'),
(92, 'FR', '27', 'A'),
(93, 'FR', '28', 'A'),
(94, 'FR', '29', 'A'),
(95, 'FR', '30', 'A'),
(96, 'FR', '32', 'A'),
(97, 'FR', '33', 'A'),
(98, 'FR', '2B', 'A'),
(99, 'FR', '31', 'A'),
(100, 'FR', '43', 'A'),
(101, 'FR', '52', 'A'),
(102, 'FR', '87', 'A'),
(103, 'FR', '05', 'A'),
(104, 'FR', '92', 'A'),
(105, 'FR', '34', 'A'),
(106, 'FR', '35', 'A'),
(107, 'FR', '36', 'A'),
(108, 'FR', '37', 'A'),
(109, 'FR', '38', 'A'),
(110, 'FR', '39', 'A'),
(111, 'FR', '40', 'A'),
(112, 'FR', '41', 'A'),
(113, 'FR', '42', 'A'),
(114, 'FR', '44', 'A'),
(115, 'FR', '45', 'A'),
(116, 'FR', '46', 'A'),
(117, 'FR', '47', 'A'),
(118, 'FR', '48', 'A'),
(119, 'FR', '49', 'A'),
(120, 'FR', '50', 'A'),
(121, 'FR', '51', 'A'),
(122, 'FR', '75', 'A'),
(123, 'FR', '93', 'A'),
(124, 'FR', '80', 'A'),
(125, 'FR', '81', 'A'),
(126, 'FR', '82', 'A'),
(127, 'FR', '90', 'A'),
(128, 'FR', '95', 'A'),
(129, 'FR', '94', 'A'),
(130, 'FR', '83', 'A'),
(131, 'FR', '84', 'A'),
(132, 'FR', '85', 'A'),
(133, 'FR', '86', 'A'),
(134, 'FR', '88', 'A'),
(135, 'FR', '89', 'A'),
(136, 'CA', 'AB', 'A'),
(137, 'CA', 'BC', 'A'),
(138, 'CA', 'MB', 'A'),
(139, 'CA', 'NB', 'A'),
(140, 'CA', 'NL', 'A'),
(141, 'CA', 'NT', 'A'),
(142, 'CA', 'NS', 'A'),
(143, 'CA', 'NU', 'A'),
(144, 'CA', 'ON', 'A'),
(145, 'CA', 'PE', 'A'),
(146, 'CA', 'QC', 'A'),
(147, 'CA', 'SK', 'A'),
(148, 'CA', 'YT', 'A'),
(149, 'AU', 'ACT', 'A'),
(150, 'AU', 'NSW', 'A'),
(151, 'AU', 'NT', 'A'),
(152, 'AU', 'QLD', 'A'),
(153, 'AU', 'SA', 'A'),
(154, 'AU', 'TAS', 'A'),
(155, 'AU', 'VIC', 'A'),
(156, 'AU', 'WA', 'A'),
(157, 'NL', 'DR', 'A'),
(158, 'NL', 'FL', 'A'),
(159, 'NL', 'FR', 'A'),
(160, 'NL', 'GE', 'A'),
(161, 'NL', 'GR', 'A'),
(162, 'NL', 'LI', 'A'),
(163, 'NL', 'NB', 'A'),
(164, 'NL', 'NH', 'A'),
(165, 'NL', 'OV', 'A'),
(166, 'NL', 'UT', 'A'),
(167, 'NL', 'ZE', 'A'),
(168, 'NL', 'ZH', 'A'),
(169, 'DE', 'BAW', 'A'),
(170, 'DE', 'BAY', 'A'),
(171, 'DE', 'BER', 'A'),
(172, 'DE', 'BRG', 'A'),
(173, 'DE', 'BRE', 'A'),
(174, 'DE', 'HAM', 'A'),
(175, 'DE', 'HES', 'A'),
(176, 'DE', 'MEC', 'A'),
(177, 'DE', 'NDS', 'A'),
(178, 'DE', 'NRW', 'A'),
(179, 'DE', 'RHE', 'A'),
(180, 'DE', 'SAR', 'A'),
(181, 'DE', 'SAS', 'A'),
(182, 'DE', 'SAC', 'A'),
(183, 'DE', 'SCN', 'A'),
(184, 'DE', 'THE', 'A'),
(185, 'GB', 'ABN', 'A'),
(186, 'GB', 'ABNS', 'A'),
(187, 'GB', 'ANG', 'A'),
(188, 'GB', 'AGS', 'A'),
(189, 'GB', 'ARY', 'A'),
(190, 'GB', 'BEDS', 'A'),
(191, 'GB', 'BERKS', 'A'),
(192, 'GB', 'BLA', 'A'),
(193, 'GB', 'BRI', 'A'),
(194, 'GB', 'BSTL', 'A'),
(195, 'GB', 'BUCKS', 'A'),
(196, 'GB', 'CAE', 'A'),
(197, 'GB', 'CAMBS', 'A'),
(198, 'GB', 'CDF', 'A'),
(199, 'GB', 'CARM', 'A'),
(200, 'GB', 'CDGN', 'A'),
(201, 'GB', 'CHES', 'A'),
(202, 'GB', 'CLACK', 'A'),
(203, 'GB', 'CON', 'A'),
(204, 'GB', 'CORN', 'A'),
(205, 'GB', 'DNBG', 'A'),
(206, 'GB', 'DERBY', 'A'),
(207, 'GB', 'DVN', 'A'),
(208, 'GB', 'DOR', 'A'),
(209, 'GB', 'DGL', 'A'),
(210, 'GB', 'DUND', 'A'),
(211, 'GB', 'DHM', 'A'),
(212, 'GB', 'ARYE', 'A'),
(213, 'GB', 'DUNBE', 'A'),
(214, 'GB', 'LOTE', 'A'),
(215, 'GB', 'RENE', 'A'),
(216, 'GB', 'ERYS', 'A'),
(217, 'GB', 'SXE', 'A'),
(218, 'GB', 'EDIN', 'A'),
(219, 'GB', 'ESX', 'A'),
(220, 'GB', 'FALK', 'A'),
(221, 'GB', 'FFE', 'A'),
(222, 'GB', 'FLINT', 'A'),
(223, 'GB', 'GLAS', 'A'),
(224, 'GB', 'GLOS', 'A'),
(225, 'GB', 'LDN', 'A'),
(226, 'GB', 'MCH', 'A'),
(227, 'GB', 'GDD', 'A'),
(228, 'GB', 'HANTS', 'A'),
(229, 'GB', 'HWR', 'A'),
(230, 'GB', 'HERTS', 'A'),
(231, 'GB', 'HLD', 'A'),
(232, 'GB', 'IVER', 'A'),
(233, 'GB', 'IOW', 'A'),
(234, 'GB', 'KNT', 'A'),
(235, 'GB', 'LANCS', 'A'),
(236, 'GB', 'LEICS', 'A'),
(237, 'GB', 'LINCS', 'A'),
(238, 'GB', 'MSY', 'A'),
(239, 'GB', 'MERT', 'A'),
(240, 'GB', 'MLOT', 'A'),
(241, 'GB', 'MMOUTH', 'A'),
(242, 'GB', 'MORAY', 'A'),
(243, 'GB', 'NPRTAL', 'A'),
(244, 'GB', 'NEWPT', 'A'),
(245, 'GB', 'NOR', 'A'),
(246, 'GB', 'ARYN', 'A'),
(247, 'GB', 'LANN', 'A'),
(248, 'GB', 'YSN', 'A'),
(249, 'GB', 'NHM', 'A'),
(250, 'GB', 'NLD', 'A'),
(251, 'GB', 'NOT', 'A'),
(252, 'GB', 'ORK', 'A'),
(253, 'GB', 'OFE', 'A'),
(254, 'GB', 'PEM', 'A'),
(255, 'GB', 'PERTH', 'A'),
(256, 'GB', 'PWS', 'A'),
(257, 'GB', 'REN', 'A'),
(258, 'GB', 'RHON', 'A'),
(259, 'GB', 'RUT', 'A'),
(260, 'GB', 'BOR', 'A'),
(261, 'GB', 'SHET', 'A'),
(262, 'GB', 'SPE', 'A'),
(263, 'GB', 'SOM', 'A'),
(264, 'GB', 'ARYS', 'A'),
(265, 'GB', 'LANS', 'A'),
(266, 'GB', 'YKS', 'A'),
(267, 'GB', 'SFD', 'A'),
(268, 'GB', 'STIR', 'A'),
(269, 'GB', 'SFK', 'A'),
(270, 'GB', 'SRY', 'A'),
(271, 'GB', 'SWAN', 'A'),
(272, 'GB', 'TORF', 'A'),
(273, 'GB', 'TWR', 'A'),
(274, 'GB', 'VGLAM', 'A'),
(275, 'GB', 'WARKS', 'A'),
(276, 'GB', 'WDUN', 'A'),
(277, 'GB', 'WLOT', 'A'),
(278, 'GB', 'WMD', 'A'),
(279, 'GB', 'SXW', 'A'),
(280, 'GB', 'YSW', 'A'),
(281, 'GB', 'WIL', 'A'),
(282, 'GB', 'WLT', 'A'),
(283, 'GB', 'WORCS', 'A'),
(284, 'GB', 'WRX', 'A'),
(285, 'CH', 'GR', 'A'),
(286, 'CH', 'BE', 'A'),
(287, 'CH', 'VS', 'A'),
(288, 'CH', 'VD', 'A'),
(289, 'CH', 'TI', 'A'),
(290, 'CH', 'SG', 'A'),
(291, 'CH', 'ZH', 'A'),
(292, 'CH', 'FR', 'A'),
(293, 'CH', 'LU', 'A'),
(294, 'CH', 'AG', 'A'),
(295, 'CH', 'UR', 'A'),
(296, 'CH', 'TG', 'A'),
(297, 'CH', 'SZ', 'A'),
(298, 'CH', 'JU', 'A'),
(299, 'CH', 'NE', 'A'),
(300, 'CH', 'SO', 'A'),
(301, 'CH', 'GL', 'A'),
(302, 'CH', 'BL', 'A'),
(303, 'CH', 'OW', 'A'),
(304, 'CH', 'SH', 'A'),
(305, 'CH', 'GE', 'A'),
(306, 'CH', 'NW', 'A'),
(307, 'CH', 'AR', 'A'),
(308, 'CH', 'ZG', 'A'),
(309, 'CH', 'AI', 'A'),
(310, 'CH', 'BS', 'A'),
(385, 'IT', '65', 'A'),
(386, 'IT', '77', 'A'),
(387, 'IT', '78', 'A'),
(388, 'IT', '72', 'A'),
(389, 'IT', '45', 'A'),
(390, 'IT', '62', 'A'),
(391, 'IT', '42', 'A'),
(392, 'IT', '25', 'A'),
(393, 'IT', '57', 'A'),
(394, 'IT', '67', 'A'),
(395, 'IT', '21', 'A'),
(396, 'IT', '75', 'A'),
(397, 'IT', '52', 'A'),
(398, 'IT', '55', 'A'),
(399, 'IT', '34', 'A'),
(400, 'IT', '36', 'A'),
(401, 'IT', '88', 'A'),
(402, 'IT', '82', 'A'),
(403, 'IT', '32', 'A'),
(404, 'IT', '23', 'A'),
(492, 'GB', 'ANT', 'A'),
(493, 'GB', 'ARM', 'A'),
(494, 'GB', 'DOW', 'A'),
(495, 'GB', 'FER', 'A'),
(496, 'GB', 'LDY', 'A'),
(497, 'GB', 'TYR', 'A'),
(498, 'US', 'MP', 'A'),
(499, 'GB', 'AVN', 'A'),
(500, 'GB', 'CLV', 'A'),
(501, 'GB', 'CMA', 'A'),
(502, 'GB', 'MDX', 'A'),
(503, 'GB', 'IOS', 'A'),
(504, 'GB', 'HUM', 'A'),
(505, 'GB', 'SYK', 'A'),
(506, 'GB', 'BAN', 'A'),
(507, 'GB', 'BEW', 'A'),
(508, 'GB', 'CAI', 'A'),
(509, 'GB', 'DFS', 'A'),
(510, 'GB', 'INV', 'A'),
(511, 'GB', 'KCD', 'A'),
(512, 'GB', 'NAI', 'A'),
(513, 'GB', 'PEE', 'A'),
(514, 'GB', 'ROX', 'A'),
(515, 'GB', 'SEL', 'A'),
(516, 'GB', 'STI', 'A'),
(517, 'GB', 'SUT', 'A'),
(518, 'GB', 'WIG', 'A'),
(519, 'GB', 'CWD', 'A'),
(520, 'GB', 'DFD', 'A'),
(521, 'GB', 'MER', 'A'),
(522, 'RU', 'AD', 'A'),
(523, 'RU', 'AL', 'A'),
(524, 'RU', 'BA', 'A'),
(525, 'RU', 'BU', 'A'),
(526, 'RU', 'DA', 'A'),
(527, 'RU', 'IN', 'A'),
(528, 'RU', 'KB', 'A'),
(529, 'RU', 'KL', 'A'),
(530, 'RU', 'KC', 'A'),
(531, 'RU', 'KR', 'A'),
(532, 'RU', 'KO', 'A'),
(533, 'RU', 'ME', 'A'),
(534, 'RU', 'MO', 'A'),
(535, 'RU', 'SA', 'A'),
(536, 'RU', 'SE', 'A'),
(537, 'RU', 'TA', 'A'),
(538, 'RU', 'TY', 'A'),
(539, 'RU', 'UD', 'A'),
(540, 'RU', 'KK', 'A'),
(541, 'RU', 'CE', 'A'),
(542, 'RU', 'CU', 'A'),
(543, 'RU', 'ALT', 'A'),
(544, 'RU', 'KDA', 'A'),
(545, 'RU', 'KYA', 'A'),
(546, 'RU', 'PER', 'A'),
(547, 'RU', 'PRI', 'A'),
(548, 'RU', 'STA', 'A'),
(549, 'RU', 'KHA', 'A'),
(550, 'RU', 'AMU', 'A'),
(551, 'RU', 'ARK', 'A'),
(552, 'RU', 'AST', 'A'),
(553, 'RU', 'BEL', 'A'),
(554, 'RU', 'BRY', 'A'),
(555, 'RU', 'VLA', 'A'),
(556, 'RU', 'VGG', 'A'),
(557, 'RU', 'VLG', 'A'),
(558, 'RU', 'VOR', 'A'),
(559, 'RU', 'IVA', 'A'),
(560, 'RU', 'IRK', 'A'),
(561, 'RU', 'KGD', 'A'),
(562, 'RU', 'KLU', 'A'),
(564, 'RU', 'KEM', 'A'),
(565, 'RU', 'KIR', 'A'),
(566, 'RU', 'KOS', 'A'),
(567, 'RU', 'KGN', 'A'),
(568, 'RU', 'KRS', 'A'),
(569, 'RU', 'LEN', 'A'),
(570, 'RU', 'LIP', 'A'),
(571, 'RU', 'MAG', 'A'),
(572, 'RU', 'MOS', 'A'),
(573, 'RU', 'MUR', 'A'),
(574, 'RU', 'NIZ', 'A'),
(575, 'RU', 'NGR', 'A'),
(576, 'RU', 'NVS', 'A'),
(577, 'RU', 'OMS', 'A'),
(578, 'RU', 'ORE', 'A'),
(579, 'RU', 'ORL', 'A'),
(580, 'RU', 'PNZ', 'A'),
(581, 'RU', 'PSK', 'A'),
(582, 'RU', 'ROS', 'A'),
(583, 'RU', 'RYA', 'A'),
(584, 'RU', 'SAM', 'A'),
(585, 'RU', 'SAR', 'A'),
(586, 'RU', 'SAK', 'A'),
(587, 'RU', 'SVE', 'A'),
(588, 'RU', 'SMO', 'A'),
(589, 'RU', 'TAM', 'A'),
(590, 'RU', 'TVE', 'A'),
(591, 'RU', 'TOM', 'A'),
(592, 'RU', 'TUL', 'A'),
(593, 'RU', 'TYU', 'A'),
(594, 'RU', 'ULY', 'A'),
(595, 'RU', 'CHE', 'A'),
(597, 'RU', 'YAR', 'A'),
(598, 'RU', 'MOW', 'A'),
(599, 'RU', 'SPE', 'A'),
(600, 'RU', 'YEV', 'A'),
(603, 'RU', 'NEN', 'A'),
(605, 'RU', 'KHM', 'A'),
(606, 'RU', 'CHU', 'A'),
(607, 'RU', 'YAN', 'A'),
(608, 'RU', 'ZAB', 'A'),
(609, 'RU', 'KAM', 'A'),
(610, 'FR', '53', 'A'),
(611, 'FR', '54', 'A'),
(612, 'FR', '55', 'A'),
(613, 'FR', '56', 'A'),
(614, 'FR', '57', 'A'),
(615, 'FR', '58', 'A'),
(616, 'FR', '59', 'A'),
(617, 'FR', '60', 'A'),
(618, 'FR', '61', 'A'),
(619, 'FR', '62', 'A'),
(620, 'FR', '63', 'A'),
(621, 'FR', '64', 'A'),
(622, 'FR', '65', 'A'),
(623, 'FR', '66', 'A'),
(624, 'FR', '67', 'A'),
(625, 'FR', '68', 'A'),
(626, 'FR', '69', 'A'),
(627, 'FR', '70', 'A'),
(628, 'FR', '71', 'A'),
(629, 'FR', '72', 'A'),
(630, 'FR', '73', 'A'),
(631, 'FR', '74', 'A'),
(632, 'FR', '76', 'A'),
(633, 'FR', '77', 'A'),
(634, 'FR', '78', 'A'),
(635, 'FR', '79', 'A'),
(636, 'ES', 'C', 'A'),
(637, 'ES', 'VI', 'A'),
(638, 'ES', 'AB', 'A'),
(639, 'ES', 'A', 'A'),
(640, 'ES', 'AL', 'A'),
(641, 'ES', 'O', 'A'),
(642, 'ES', 'AV', 'A'),
(643, 'ES', 'BA', 'A'),
(644, 'ES', 'PM', 'A'),
(645, 'ES', 'B', 'A'),
(646, 'ES', 'BU', 'A'),
(647, 'ES', 'CC', 'A'),
(648, 'ES', 'CA', 'A'),
(649, 'ES', 'S', 'A'),
(650, 'ES', 'CS', 'A'),
(651, 'ES', 'CE', 'A'),
(652, 'ES', 'CR', 'A'),
(653, 'ES', 'CO', 'A'),
(654, 'ES', 'CU', 'A'),
(655, 'ES', 'GI', 'A'),
(656, 'ES', 'GR', 'A'),
(657, 'ES', 'GU', 'A'),
(658, 'ES', 'SS', 'A'),
(659, 'ES', 'H', 'A'),
(660, 'ES', 'HU', 'A'),
(661, 'ES', 'J', 'A'),
(662, 'ES', 'LO', 'A'),
(663, 'ES', 'GC', 'A'),
(664, 'ES', 'LE', 'A'),
(665, 'ES', 'L', 'A'),
(666, 'ES', 'LU', 'A'),
(667, 'ES', 'M', 'A'),
(668, 'ES', 'MA', 'A'),
(669, 'ES', 'ML', 'A'),
(670, 'ES', 'MU', 'A'),
(671, 'ES', 'NA', 'A'),
(672, 'ES', 'OR', 'A'),
(673, 'ES', 'P', 'A'),
(674, 'ES', 'PO', 'A'),
(675, 'ES', 'SA', 'A'),
(676, 'ES', 'TF', 'A'),
(677, 'ES', 'SG', 'A'),
(678, 'ES', 'SE', 'A'),
(679, 'ES', 'SO', 'A'),
(680, 'ES', 'T', 'A'),
(681, 'ES', 'TE', 'A'),
(682, 'ES', 'TO', 'A'),
(683, 'ES', 'V', 'A'),
(684, 'ES', 'VA', 'A'),
(685, 'ES', 'BI', 'A'),
(686, 'ES', 'ZA', 'A'),
(687, 'ES', 'Z', 'A'),
(688, 'BG', 'SF', 'A'),
(702, 'GR', 'ΑΙΤ', 'A'),
(703, 'GR', 'ΑΡΓ', 'A'),
(704, 'GR', 'ΑΡΚ', 'A'),
(705, 'GR', 'ΑΡΤ', 'A'),
(706, 'GR', 'ΑΧΑ', 'A'),
(707, 'GR', 'ΑΤΤ', 'A'),
(708, 'GR', 'ΒΟΙ', 'A'),
(709, 'GR', 'ΓΡΕ', 'A'),
(710, 'GR', 'ΔΡΑ', 'A'),
(711, 'GR', 'ΔΩΔ', 'A'),
(712, 'GR', 'ΕΒΡ', 'A'),
(713, 'GR', 'ΕΥΒ', 'A'),
(714, 'GR', 'ΕΥΡ', 'A'),
(715, 'GR', 'ΖΑΚ', 'A'),
(716, 'GR', 'ΗΛΕ', 'A'),
(717, 'GR', 'ΗΜΑ', 'A'),
(718, 'GR', 'ΗΡΑ', 'A'),
(719, 'GR', 'ΘΣΠ', 'A'),
(720, 'GR', 'ΘΕΣ', 'A'),
(721, 'GR', 'ΙΩΑ', 'A'),
(722, 'GR', 'ΚΑΒ', 'A'),
(723, 'GR', 'ΚΑΡ', 'A'),
(724, 'GR', 'ΚΑΣ', 'A'),
(725, 'GR', 'ΚΕΡ', 'A'),
(726, 'GR', 'ΚΕΦ', 'A'),
(727, 'GR', 'ΚΙΛ', 'A'),
(728, 'GR', 'ΚΟΖ', 'A'),
(729, 'GR', 'ΚΟΡ', 'A'),
(730, 'GR', 'ΚΥΚ', 'A'),
(731, 'GR', 'ΛΑΚ', 'A'),
(732, 'GR', 'ΛΑΡ', 'A'),
(733, 'GR', 'ΛΑΣ', 'A'),
(734, 'GR', 'ΛΕΣ', 'A'),
(735, 'GR', 'ΛΕΥ', 'A'),
(736, 'GR', 'ΜΑΓ', 'A'),
(737, 'GR', 'ΜΕΣ', 'A'),
(738, 'GR', 'ΞΑΝ', 'A'),
(739, 'GR', 'ΠΕΛ', 'A'),
(740, 'GR', 'ΠΙΕ', 'A'),
(741, 'GR', 'ΠΡΕ', 'A'),
(742, 'GR', 'ΡΕΘ', 'A'),
(743, 'GR', 'ΡΟΔ', 'A'),
(744, 'GR', 'ΣΑΜ', 'A'),
(745, 'GR', 'ΣΕΡ', 'A'),
(746, 'GR', 'ΤΡΙ', 'A'),
(747, 'GR', 'ΦΘΙ', 'A'),
(748, 'GR', 'ΦΛΩ', 'A'),
(749, 'GR', 'ΦΩΚ', 'A'),
(750, 'GR', 'ΧΑΛ', 'A'),
(751, 'GR', 'ΧΑΝ', 'A'),
(752, 'GR', 'ΧΙΟ', 'A'),
(753, 'AM', 'AG', 'A'),
(754, 'AM', 'AR', 'A'),
(755, 'AM', 'AV', 'A'),
(756, 'AM', 'VD', 'A'),
(757, 'AM', 'GR', 'A'),
(758, 'AM', 'KT', 'A'),
(759, 'AM', 'LO', 'A'),
(760, 'AM', 'SU', 'A'),
(761, 'AM', 'TV', 'A'),
(762, 'AM', 'SH', 'A'),
(763, 'AM', 'ER', 'A'),
(764, 'BY', 'BR', 'A'),
(765, 'BY', 'HO', 'A'),
(766, 'BY', 'HR', 'A'),
(767, 'BY', 'MA', 'A'),
(768, 'BY', 'MI', 'A'),
(769, 'BY', 'HM', 'A'),
(770, 'BY', 'VI', 'A'),
(771, 'KG', 'B', 'A'),
(772, 'KG', 'N', 'A'),
(773, 'KG', 'C', 'A'),
(774, 'KG', 'O', 'A'),
(775, 'KG', 'GB', 'A'),
(776, 'KG', 'T', 'A'),
(777, 'KG', 'J', 'A'),
(778, 'KG', 'Y', 'A'),
(779, 'KZ', 'ALA', 'A'),
(780, 'KZ', 'AST', 'A'),
(781, 'KZ', 'ALM', 'A'),
(782, 'KZ', 'AKM', 'A'),
(783, 'KZ', 'AKT', 'A'),
(784, 'KZ', 'ATY', 'A'),
(785, 'KZ', 'VOS', 'A'),
(786, 'KZ', 'ZHA', 'A'),
(787, 'KZ', 'ZAP', 'A'),
(788, 'KZ', 'KAR', 'A'),
(789, 'KZ', 'KUS', 'A'),
(790, 'KZ', 'KZY', 'A'),
(791, 'KZ', 'MAN', 'A'),
(792, 'KZ', 'PAV', 'A'),
(793, 'KZ', 'SEV', 'A'),
(794, 'KZ', 'YUZ', 'A'),
(795, 'UA', '05', 'A'),
(796, 'UA', '07', 'A'),
(797, 'UA', '09', 'A'),
(798, 'UA', '12', 'A'),
(799, 'UA', '14', 'A'),
(800, 'UA', '18', 'A'),
(801, 'UA', '56', 'A'),
(802, 'UA', '21', 'A'),
(803, 'UA', '23', 'A'),
(804, 'UA', '26', 'A'),
(805, 'UA', '30', 'A'),
(806, 'UA', '32', 'A'),
(807, 'UA', '35', 'A'),
(808, 'UA', '46', 'A'),
(809, 'UA', '48', 'A'),
(810, 'UA', '51', 'A'),
(811, 'UA', '53', 'A'),
(812, 'UA', '59', 'A'),
(813, 'UA', '61', 'A'),
(814, 'UA', '63', 'A'),
(815, 'UA', '65', 'A'),
(816, 'UA', '68', 'A'),
(817, 'UA', '71', 'A'),
(818, 'UA', '74', 'A'),
(819, 'UA', '77', 'A'),
(820, 'IE', 'CW', 'A'),
(821, 'IE', 'CN', 'A'),
(822, 'IE', 'CE', 'A'),
(823, 'IE', 'CO', 'A'),
(824, 'IE', 'DL', 'A'),
(825, 'IE', 'D', 'A'),
(826, 'IE', 'G', 'A'),
(827, 'IE', 'KY', 'A'),
(828, 'IE', 'KE', 'A'),
(829, 'IE', 'KK', 'A'),
(830, 'IE', 'LS', 'A'),
(831, 'IE', 'LM', 'A'),
(832, 'IE', 'LK', 'A'),
(833, 'IE', 'LD', 'A'),
(834, 'IE', 'LH', 'A'),
(835, 'IE', 'MO', 'A'),
(836, 'IE', 'MH', 'A'),
(837, 'IE', 'MN', 'A'),
(838, 'IE', 'OY', 'A'),
(839, 'IE', 'RN', 'A'),
(840, 'IE', 'SO', 'A'),
(841, 'IE', 'TA', 'A'),
(842, 'IE', 'WD', 'A'),
(843, 'IE', 'WH', 'A'),
(844, 'IE', 'WX', 'A'),
(845, 'IE', 'WW', 'A'),
(846, 'GB', 'ANN', 'A'),
(847, 'GB', 'AND', 'A'),
(848, 'GB', 'ABC', 'A'),
(849, 'GB', 'BFS', 'A'),
(850, 'GB', 'CCG', 'A'),
(851, 'GB', 'DRS', 'A'),
(852, 'GB', 'FMO', 'A'),
(853, 'GB', 'LBC', 'A'),
(854, 'GB', 'MEA', 'A'),
(855, 'GB', 'MUL', 'A'),
(856, 'GB', 'NMD', 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]state_descriptions`
--

CREATE TABLE `[[dbprefix]]state_descriptions` (
  `state_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `state` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`state_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]state_descriptions`
--

INSERT INTO `[[dbprefix]]state_descriptions` VALUES
(13, 'en', 'Arkansas'),
(12, 'en', 'Arizona'),
(11, 'en', 'Alaska'),
(10, 'en', 'Alabama'),
(15, 'en', 'California'),
(16, 'en', 'Colorado'),
(17, 'en', 'Connecticut'),
(18, 'en', 'Delaware'),
(19, 'en', 'District of Columbia'),
(20, 'en', 'Florida'),
(21, 'en', 'Georgia'),
(22, 'en', 'Guam'),
(23, 'en', 'Hawaii'),
(24, 'en', 'Idaho'),
(25, 'en', 'Illinois'),
(26, 'en', 'Indiana'),
(27, 'en', 'Iowa'),
(28, 'en', 'Kansas'),
(29, 'en', 'Kentucky'),
(30, 'en', 'Louisiana'),
(31, 'en', 'Maine'),
(32, 'en', 'Maryland'),
(33, 'en', 'Massachusetts'),
(34, 'en', 'Michigan'),
(35, 'en', 'Minnesota'),
(36, 'en', 'Mississippi'),
(37, 'en', 'Missouri'),
(38, 'en', 'Montana'),
(39, 'en', 'Nebraska'),
(40, 'en', 'Nevada'),
(41, 'en', 'New Hampshire'),
(42, 'en', 'New Jersey'),
(43, 'en', 'New Mexico'),
(44, 'en', 'New York'),
(45, 'en', 'North Carolina'),
(46, 'en', 'North Dakota'),
(47, 'en', 'Ohio'),
(48, 'en', 'Oklahoma'),
(49, 'en', 'Oregon'),
(50, 'en', 'Pennsylvania'),
(51, 'en', 'Puerto Rico'),
(52, 'en', 'Rhode Island'),
(53, 'en', 'South Carolina'),
(54, 'en', 'South Dakota'),
(55, 'en', 'Tennessee'),
(56, 'en', 'Texas'),
(57, 'en', 'Utah'),
(58, 'en', 'Vermont'),
(59, 'en', 'Virgin Islands'),
(60, 'en', 'Virginia'),
(61, 'en', 'Washington'),
(62, 'en', 'West Virginia'),
(63, 'en', 'Wisconsin'),
(64, 'en', 'Wyoming'),
(74, 'en', 'Ain'),
(66, 'en', 'Aisne'),
(67, 'en', 'Allier'),
(68, 'en', 'Alpes-de-Haute-Provence'),
(69, 'en', 'Alpes-Maritimes'),
(70, 'en', 'Ardèche'),
(71, 'en', 'Ardennes'),
(72, 'en', 'Ariège'),
(73, 'en', 'Aube'),
(75, 'en', 'Aude'),
(76, 'en', 'Aveyron'),
(77, 'en', 'Bouches-du-Rhône'),
(78, 'en', 'Calvados'),
(79, 'en', 'Cantal'),
(80, 'en', 'Charente'),
(81, 'en', 'Charente-Maritime'),
(82, 'en', 'Cher'),
(83, 'en', 'Corrèze'),
(84, 'en', 'Corse-du-Sud'),
(85, 'en', 'Côte-d''Or'),
(86, 'en', 'Côtes-d''Armor'),
(87, 'en', 'Creuse'),
(88, 'en', 'Dordogne'),
(89, 'en', 'Doubs'),
(90, 'en', 'Drôme'),
(91, 'en', 'Essonne'),
(92, 'en', 'Eure'),
(93, 'en', 'Eure-et-Loir'),
(94, 'en', 'Finistère'),
(95, 'en', 'Gard'),
(96, 'en', 'Gers'),
(97, 'en', 'Gironde'),
(98, 'en', 'Haute-Corse'),
(99, 'en', 'Haute-Garonne'),
(100, 'en', 'Haute-Loire'),
(101, 'en', 'Haute-Marne'),
(102, 'en', 'Haute-Vienne'),
(103, 'en', 'Hautes-Alpes'),
(104, 'en', 'Hauts-de-Seine'),
(105, 'en', 'Hérault'),
(106, 'en', 'Ille-et-Vilaine'),
(107, 'en', 'Indre'),
(108, 'en', 'Indre-et-Loire'),
(109, 'en', 'Isère'),
(110, 'en', 'Jura'),
(111, 'en', 'Landes'),
(112, 'en', 'Loir-et-Cher'),
(113, 'en', 'Loire'),
(114, 'en', 'Loire-Atlantique'),
(115, 'en', 'Loiret'),
(116, 'en', 'Lot'),
(117, 'en', 'Lot-et-Garonne'),
(118, 'en', 'Lozère'),
(119, 'en', 'Maine-et-Loire'),
(120, 'en', 'Manche'),
(121, 'en', 'Marne'),
(122, 'en', 'Paris'),
(123, 'en', 'Seine-Saint-Denis'),
(124, 'en', 'Somme'),
(125, 'en', 'Tarn'),
(126, 'en', 'Tarn-et-Garonne'),
(127, 'en', 'Territoire de Belfort'),
(128, 'en', 'Val-d''Oise'),
(129, 'en', 'Val-de-Marne'),
(130, 'en', 'Var'),
(131, 'en', 'Vaucluse'),
(132, 'en', 'Vendée'),
(133, 'en', 'Vienne'),
(134, 'en', 'Vosges'),
(135, 'en', 'Yonne'),
(136, 'en', 'Alberta'),
(137, 'en', 'British Columbia'),
(138, 'en', 'Manitoba'),
(139, 'en', 'New Brunswick'),
(140, 'en', 'Newfoundland and Labrador'),
(141, 'en', 'Northwest Territories'),
(142, 'en', 'Nova Scotia'),
(143, 'en', 'Nunavut'),
(144, 'en', 'Ontario'),
(145, 'en', 'Prince Edward Island'),
(146, 'en', 'Quebec'),
(147, 'en', 'Saskatchewan'),
(148, 'en', 'Yukon'),
(149, 'en', 'Australian Capital Territory'),
(150, 'en', 'New South Wales'),
(151, 'en', 'Northern Territory'),
(152, 'en', 'Queensland'),
(153, 'en', 'South Australia'),
(154, 'en', 'Tasmania'),
(155, 'en', 'Victoria'),
(156, 'en', 'Western Australia'),
(157, 'en', 'Drenthe'),
(158, 'en', 'Flevoland'),
(159, 'en', 'Friesland'),
(160, 'en', 'Gelderland'),
(161, 'en', 'Groningen'),
(162, 'en', 'Limburg'),
(163, 'en', 'Noord Brabant'),
(164, 'en', 'Noord Holland'),
(165, 'en', 'Overijssel'),
(166, 'en', 'Utrecht'),
(167, 'en', 'Zeeland'),
(168, 'en', 'Zuid Holland'),
(169, 'en', 'Baden-Württemberg'),
(170, 'en', 'Bayern'),
(171, 'en', 'Berlin'),
(172, 'en', 'Branderburg'),
(173, 'en', 'Bremen'),
(174, 'en', 'Hamburg'),
(175, 'en', 'Hessen'),
(176, 'en', 'Mecklenburg-Vorpommern'),
(177, 'en', 'Niedersachsen'),
(178, 'en', 'Nordrhein-Westfalen'),
(179, 'en', 'Rheinland-Pfalz'),
(180, 'en', 'Saarland'),
(181, 'en', 'Sachsen'),
(182, 'en', 'Sachsen-Anhalt'),
(183, 'en', 'Schleswig-Holstein'),
(184, 'en', 'Thüringen'),
(185, 'en', 'Aberdeen'),
(186, 'en', 'Aberdeenshire'),
(187, 'en', 'Anglesey'),
(188, 'en', 'Angus'),
(189, 'en', 'Argyll and Bute'),
(190, 'en', 'Bedfordshire'),
(191, 'en', 'Berkshire'),
(192, 'en', 'Blaenau Gwent'),
(193, 'en', 'Bridgend'),
(194, 'en', 'Bristol'),
(195, 'en', 'Buckinghamshire'),
(196, 'en', 'Caerphilly'),
(197, 'en', 'Cambridgeshire'),
(198, 'en', 'Cardiff'),
(199, 'en', 'Carmarthenshire'),
(200, 'en', 'Ceredigion'),
(201, 'en', 'Cheshire'),
(202, 'en', 'Clackmannanshire'),
(203, 'en', 'Conwy'),
(204, 'en', 'Cornwall'),
(205, 'en', 'Denbighshire'),
(206, 'en', 'Derbyshire'),
(207, 'en', 'Devon'),
(208, 'en', 'Dorset'),
(209, 'en', 'Dumfries and Galloway'),
(210, 'en', 'Dundee'),
(211, 'en', 'Durham'),
(212, 'en', 'East Ayrshire'),
(213, 'en', 'East Dunbartonshire'),
(214, 'en', 'East Lothian'),
(215, 'en', 'East Renfrewshire'),
(216, 'en', 'East Riding of Yorkshire'),
(217, 'en', 'East Sussex'),
(218, 'en', 'Edinburgh'),
(219, 'en', 'Essex'),
(220, 'en', 'Falkirk'),
(221, 'en', 'Fife'),
(222, 'en', 'Flintshire'),
(223, 'en', 'Glasgow'),
(224, 'en', 'Gloucestershire'),
(225, 'en', 'Greater London'),
(226, 'en', 'Greater Manchester'),
(227, 'en', 'Gwynedd'),
(228, 'en', 'Hampshire'),
(229, 'en', 'Herefordshire'),
(230, 'en', 'Hertfordshire'),
(231, 'en', 'Highlands'),
(232, 'en', 'Inverclyde'),
(233, 'en', 'Isle of Wight'),
(234, 'en', 'Kent'),
(235, 'en', 'Lancashire'),
(236, 'en', 'Leicestershire'),
(237, 'en', 'Lincolnshire'),
(238, 'en', 'Merseyside'),
(239, 'en', 'Merthyr Tydfil'),
(240, 'en', 'Midlothian'),
(241, 'en', 'Monmouthshire'),
(242, 'en', 'Moray'),
(243, 'en', 'Neath Port Talbot'),
(244, 'en', 'Newport'),
(245, 'en', 'Norfolk'),
(246, 'en', 'North Ayrshire'),
(247, 'en', 'North Lanarkshire'),
(248, 'en', 'North Yorkshire'),
(249, 'en', 'Northamptonshire'),
(250, 'en', 'Northumberland'),
(251, 'en', 'Nottinghamshire'),
(252, 'en', 'Orkney Islands'),
(253, 'en', 'Oxfordshire'),
(254, 'en', 'Pembrokeshire'),
(255, 'en', 'Perth and Kinross'),
(256, 'en', 'Powys'),
(257, 'en', 'Renfrewshire'),
(258, 'en', 'Rhondda Cynon Taff'),
(259, 'en', 'Rutland'),
(260, 'en', 'Scottish Borders'),
(261, 'en', 'Shetland Islands'),
(262, 'en', 'Shropshire'),
(263, 'en', 'Somerset'),
(264, 'en', 'South Ayrshire'),
(265, 'en', 'South Lanarkshire'),
(266, 'en', 'Yorkshire'),
(267, 'en', 'Staffordshire'),
(268, 'en', 'Stirling'),
(269, 'en', 'Suffolk'),
(270, 'en', 'Surrey'),
(271, 'en', 'Swansea'),
(272, 'en', 'Torfaen'),
(273, 'en', 'Tyne and Wear'),
(274, 'en', 'Vale of Glamorgan'),
(275, 'en', 'Warwickshire'),
(276, 'en', 'West Dunbartonshire'),
(277, 'en', 'West Lothian'),
(278, 'en', 'West Midlands'),
(279, 'en', 'West Sussex'),
(280, 'en', 'West Yorkshire'),
(281, 'en', 'Western Isles'),
(282, 'en', 'Wiltshire'),
(283, 'en', 'Worcestershire'),
(284, 'en', 'Wrexham'),
(285, 'en', 'Grisons'),
(286, 'en', 'Berne'),
(287, 'en', 'Valais'),
(288, 'en', 'Vaud'),
(289, 'en', 'Tessin'),
(290, 'en', 'Saint-Gall'),
(291, 'en', 'Zurich'),
(292, 'en', 'Fribourg'),
(293, 'en', 'Lucerne'),
(294, 'en', 'Argovie'),
(295, 'en', 'Uri'),
(296, 'en', 'Thurgovie'),
(297, 'en', 'Schwytz'),
(298, 'en', 'Jura'),
(299, 'en', 'Neuchâtel'),
(300, 'en', 'Soleure'),
(301, 'en', 'Glaris'),
(302, 'en', 'Bâle-Campagne'),
(303, 'en', 'Obwald'),
(304, 'en', 'Schaffhouse'),
(305, 'en', 'Genève'),
(306, 'en', 'Nidwald'),
(307, 'en', 'Appenzell Rhodes-Extérieures'),
(308, 'en', 'Zoug'),
(309, 'en', 'Appenzell Rhodes-Intérieures'),
(310, 'en', 'Bâle-Ville'),
(385, 'en', 'Abruzzo'),
(386, 'en', 'Basilicata'),
(387, 'en', 'Calabria'),
(388, 'en', 'Campania'),
(389, 'en', 'Emilia-Romagna'),
(390, 'en', 'Lazio'),
(391, 'en', 'Liguria'),
(392, 'en', 'Lombardy'),
(393, 'en', 'Marche'),
(394, 'en', 'Molise'),
(395, 'en', 'Piedmont'),
(396, 'en', 'Apulia'),
(397, 'en', 'Tuscany'),
(398, 'en', 'Umbria'),
(399, 'en', 'Veneto'),
(400, 'en', 'Friuli Venezia Giulia'),
(401, 'en', 'Sardinia'),
(402, 'en', 'Sicily'),
(403, 'en', 'Trentino-South Tyrol'),
(404, 'en', 'Aosta Valley'),
(492, 'en', 'County Antrim'),
(493, 'en', 'County Armagh'),
(494, 'en', 'County Down'),
(495, 'en', 'County Fermanagh'),
(496, 'en', 'County Londonderry'),
(497, 'en', 'County Tyrone'),
(498, 'en', 'Northern Mariana Islands'),
(499, 'en', 'Avon'),
(500, 'en', 'Cleveland'),
(501, 'en', 'Cumbria'),
(502, 'en', 'Middlesex'),
(503, 'en', 'Isles of Scilly'),
(504, 'en', 'Humberside'),
(505, 'en', 'South Yorkshire'),
(506, 'en', 'Banffshire'),
(507, 'en', 'Berwickshire'),
(508, 'en', 'Caithness'),
(509, 'en', 'Dumfries-shire'),
(510, 'en', 'Inverness-shire'),
(511, 'en', 'Kincardineshire'),
(512, 'en', 'Nairnshire'),
(513, 'en', 'Peebles-shire'),
(514, 'en', 'Roxburghshire'),
(515, 'en', 'Selkirkshire'),
(516, 'en', 'Stirlingshire'),
(517, 'en', 'Sutherland'),
(518, 'en', 'Wigtownshire'),
(519, 'en', 'Clwyd'),
(520, 'en', 'Dyfed'),
(521, 'en', 'Merionethshire'),
(522, 'en', 'Respublika Adygeja'),
(523, 'en', 'Respublika Altaj'),
(524, 'en', 'Respublika Bashkortostan'),
(525, 'en', 'Respublika Burjatija'),
(526, 'en', 'Respublika Dagestan'),
(527, 'en', 'Respublika Ingushetija'),
(528, 'en', 'Kabardino-Balkarskaja Respublika'),
(529, 'en', 'Respublika Kalmykija'),
(530, 'en', 'Karachaevo-Cherkesskaja respublika'),
(531, 'en', 'Respublika Karelija'),
(532, 'en', 'Respublika Komi'),
(533, 'en', 'Respublika Marij Jel'),
(534, 'en', 'Respublika Mordovija'),
(535, 'en', 'Respublika Saha (Jakutija)'),
(536, 'en', 'Respublika Severnaja Osetija-Alanija'),
(537, 'en', 'Respublika Tatarstan'),
(538, 'en', 'Respublika Tyva'),
(539, 'en', 'Udmurtskaja Respublika'),
(540, 'en', 'Respublika Hakasija'),
(541, 'en', 'Chechenskaja respublika'),
(542, 'en', 'Chuvashskaja Respublika'),
(543, 'en', 'Altajskij kraj'),
(544, 'en', 'Krasnodarskij kraj'),
(545, 'en', 'Krasnojarskij kraj'),
(546, 'en', 'Permskij kraj'),
(547, 'en', 'Primorskij kraj'),
(548, 'en', 'Stavropol''skij kraj'),
(549, 'en', 'Habarovskij kraj'),
(550, 'en', 'Amurskaja oblast'''),
(551, 'en', 'Arhangel''skaja oblast'''),
(552, 'en', 'Astrahanskaja oblast'''),
(553, 'en', 'Belgorodskaja oblast'''),
(554, 'en', 'Brjanskaja oblast'''),
(555, 'en', 'Vladimirskaja oblast'''),
(556, 'en', 'Volgogradskaja oblast'''),
(557, 'en', 'Vologodskaja oblast'''),
(558, 'en', 'Voronezhskaja oblast'''),
(559, 'en', 'Ivanovskaja oblast'''),
(560, 'en', 'Irkutskaja oblast'''),
(561, 'en', 'Kaliningradskaja oblast'''),
(562, 'en', 'Kaluzhskaja oblast'''),
(564, 'en', 'Kemerovskaja oblast'''),
(565, 'en', 'Kirovskaja oblast'''),
(566, 'en', 'Kostromskaja oblast'''),
(567, 'en', 'Kurganskaja oblast'''),
(568, 'en', 'Kurskaja oblast'''),
(569, 'en', 'Leningradskaja oblast'''),
(570, 'en', 'Lipeckaja oblast'''),
(571, 'en', 'Magadanskaja oblast'''),
(572, 'en', 'Moskovskaja oblast'''),
(573, 'en', 'Murmanskaja oblast'''),
(574, 'en', 'Nizhegorodskaja oblast'''),
(575, 'en', 'Novgorodskaja oblast'''),
(576, 'en', 'Novosibirskaja oblast'''),
(577, 'en', 'Omskaja oblast'''),
(578, 'en', 'Orenburgskaja oblast'''),
(579, 'en', 'Orlovskaja oblast'''),
(580, 'en', 'Penzenskaja oblast'''),
(581, 'en', 'Pskovskaja oblast'''),
(582, 'en', 'Rostovskaja oblast'''),
(583, 'en', 'Rjazanskaja oblast'''),
(584, 'en', 'Samarskaja oblast'''),
(585, 'en', 'Saratovskaja oblast'''),
(586, 'en', 'Sahalinskaja oblast'''),
(587, 'en', 'Sverdlovskaja oblast'''),
(588, 'en', 'Smolenskaja oblast'''),
(589, 'en', 'Tambovskaja oblast'''),
(590, 'en', 'Tverskaja oblast'''),
(591, 'en', 'Tomskaja oblast'''),
(592, 'en', 'Tul''skaja oblast'''),
(593, 'en', 'Tjumenskaja oblast'''),
(594, 'en', 'Ul''janovskaja oblast'''),
(595, 'en', 'Cheljabinskaja oblast'''),
(597, 'en', 'Jaroslavskaja oblast'''),
(598, 'en', 'Moskva'),
(599, 'en', 'Sankt-Peterburg'),
(600, 'en', 'Evrejskaja avtonomnaja oblast'''),
(603, 'en', 'Neneckij avtonomnyj okrug'),
(605, 'en', 'Hanty-Mansijskij avtonomnyj okrug - Jugra'),
(606, 'en', 'Chukotskij avtonomnyj okrug'),
(607, 'en', 'Jamalo-Neneckij avtonomnyj okrug'),
(608, 'en', 'Zabaykal''skiy kraj'),
(609, 'en', 'Kamchatskiy kraj'),
(610, 'en', 'Mayenne'),
(611, 'en', 'Meurthe-et-Moselle'),
(612, 'en', 'Meuse'),
(613, 'en', 'Morbihan'),
(614, 'en', 'Moselle'),
(615, 'en', 'Nièvre'),
(616, 'en', 'Nord'),
(617, 'en', 'Oise'),
(618, 'en', 'Orne'),
(619, 'en', 'Pas-de-Calais'),
(620, 'en', 'Puy-de-Dôme'),
(621, 'en', 'Pyrénées-Atlantiques'),
(622, 'en', 'Hautes-Pyrénées'),
(623, 'en', 'Pyrénées-Orientales'),
(624, 'en', 'Bas-Rhin'),
(625, 'en', 'Haut-Rhin'),
(626, 'en', 'Rhône'),
(627, 'en', 'Haute-Saône'),
(628, 'en', 'Saône-et-Loire'),
(629, 'en', 'Sarthe'),
(630, 'en', 'Savoie'),
(631, 'en', 'Haute-Savoie'),
(632, 'en', 'Seine-Maritime'),
(633, 'en', 'Seine-et-Marne'),
(634, 'en', 'Yvelines'),
(635, 'en', 'Deux-Sèvres'),
(636, 'en', 'A Coruña'),
(637, 'en', 'Álava'),
(638, 'en', 'Albacete'),
(639, 'en', 'Alicante'),
(640, 'en', 'Almería'),
(641, 'en', 'Asturias'),
(642, 'en', 'Ávila'),
(643, 'en', 'Badajoz'),
(644, 'en', 'Baleares'),
(645, 'en', 'Barcelona'),
(646, 'en', 'Burgos'),
(647, 'en', 'Cáceres'),
(648, 'en', 'Cádiz'),
(649, 'en', 'Cantabria'),
(650, 'en', 'Castellón'),
(651, 'en', 'Ceuta'),
(652, 'en', 'Ciudad Real'),
(653, 'en', 'Córdoba'),
(654, 'en', 'Cuenca'),
(655, 'en', 'Girona'),
(656, 'en', 'Granada'),
(657, 'en', 'Guadalajara'),
(658, 'en', 'Guipúzcoa'),
(659, 'en', 'Huelva'),
(660, 'en', 'Huesca'),
(661, 'en', 'Jaén'),
(662, 'en', 'La Rioja'),
(663, 'en', 'Las Palmas'),
(664, 'en', 'León'),
(665, 'en', 'Lleida'),
(666, 'en', 'Lugo'),
(667, 'en', 'Madrid'),
(668, 'en', 'Málaga'),
(669, 'en', 'Melilla'),
(670, 'en', 'Murcia'),
(671, 'en', 'Navarra'),
(672, 'en', 'Ourense'),
(673, 'en', 'Palencia'),
(674, 'en', 'Pontevedra'),
(675, 'en', 'Salamanca'),
(676, 'en', 'Santa Cruz de Tenerife'),
(677, 'en', 'Segovia'),
(678, 'en', 'Sevilla'),
(679, 'en', 'Soria'),
(680, 'en', 'Tarragona'),
(681, 'en', 'Teruel'),
(682, 'en', 'Toledo'),
(683, 'en', 'Valencia'),
(684, 'en', 'Valladolid'),
(685, 'en', 'Vizcaya'),
(686, 'en', 'Zamora'),
(687, 'en', 'Zaragoza'),
(688, 'en', 'Sofia'),
(702, 'en', 'Aetolia-Acarnania'),
(703, 'en', 'Argolis'),
(704, 'en', 'Arcadia'),
(705, 'en', 'Arta'),
(706, 'en', 'Achaea'),
(707, 'en', 'Attica'),
(708, 'en', 'Boeotia'),
(709, 'en', 'Grevena'),
(710, 'en', 'Drama'),
(711, 'en', 'Dodecanese'),
(712, 'en', 'Evros'),
(713, 'en', 'Euboea'),
(714, 'en', 'Evrytania'),
(715, 'en', 'Zakynthos'),
(716, 'en', 'Elis'),
(717, 'en', 'Imathia'),
(718, 'en', 'Heraklion'),
(719, 'en', 'Thesprotia'),
(720, 'en', 'Thessaloniki'),
(721, 'en', 'Ioannina'),
(722, 'en', 'Kavala'),
(723, 'en', 'Karditsa'),
(724, 'en', 'Kastoria'),
(725, 'en', 'Corfu'),
(726, 'en', 'Cephalonia'),
(727, 'en', 'Kilkis'),
(728, 'en', 'Kozani'),
(729, 'en', 'Corinthia'),
(730, 'en', 'Cyclades'),
(731, 'en', 'Laconia'),
(732, 'en', 'Larissa'),
(733, 'en', 'Lasithi'),
(734, 'en', 'Lesbos'),
(735, 'en', 'Lefkada'),
(736, 'en', 'Magnesia'),
(737, 'en', 'Messinia'),
(738, 'en', 'Xanthi'),
(739, 'en', 'Pella'),
(740, 'en', 'Pieria'),
(741, 'en', 'Preveza'),
(742, 'en', 'Rethymno'),
(743, 'en', 'Rhodope'),
(744, 'en', 'Samos'),
(745, 'en', 'Serres'),
(746, 'en', 'Trikala'),
(747, 'en', 'Phthiotis'),
(748, 'en', 'Florina'),
(749, 'en', 'Phocis'),
(750, 'en', 'Chalkidiki'),
(751, 'en', 'Chania'),
(752, 'en', 'Chios'),
(753, 'en', 'Aragatsotn oblast'),
(754, 'en', 'Ararat oblast'),
(755, 'en', 'Armavir oblast'),
(756, 'en', 'Vayots Dzor oblast'),
(757, 'en', 'Gegharkunik oblast'),
(758, 'en', 'Kotayk oblast'),
(759, 'en', 'Lori oblast'),
(760, 'en', 'Syunik oblast'),
(761, 'en', 'Tavush oblast'),
(762, 'en', 'Shirak oblast'),
(763, 'en', 'Yerevan'),
(764, 'en', 'Brest Region'),
(765, 'en', 'Gomel Region'),
(766, 'en', 'Grodno Region'),
(767, 'en', 'Mogilev Region'),
(768, 'en', 'Minsk Region'),
(769, 'en', 'City of Minsk'),
(770, 'en', 'Vitebsk Region'),
(771, 'en', 'Batkenskaya oblast'),
(772, 'en', 'Narynskaya oblast'),
(773, 'en', 'Chuyskaya oblast'),
(774, 'en', 'Oshskaya oblast'),
(775, 'en', 'Bishkek'),
(776, 'en', 'Talasskaya oblast'),
(777, 'en', 'Dzhalal-Abadskaya oblast'),
(778, 'en', 'Issyk-Kulskaya oblast'),
(779, 'en', 'Almaty'),
(780, 'en', 'Astana'),
(781, 'en', 'Almatinskaya oblast'),
(782, 'en', 'Akmolinskaya oblast'),
(783, 'en', 'Aktyubinskaya oblast'),
(784, 'en', 'Atyrauskaya oblast'),
(785, 'en', 'Vostochno-Kazakhstanskaya oblast'),
(786, 'en', 'Zhambylskaya oblast'),
(787, 'en', 'Zapadno-Kazakhstanskaya oblast'),
(788, 'en', 'Karagandinskaya oblast'),
(789, 'en', 'Kostanayskaya oblast'),
(790, 'en', 'Kyzylordinskaya oblast'),
(791, 'en', 'Mangistauskaya oblast'),
(792, 'en', 'Pavlodarskaya oblast'),
(793, 'en', 'Severo-Kazakhstanskaya oblast'),
(794, 'en', 'Yuzhno-Kazakhstankaya oblast'),
(795, 'en', 'Vinnytska oblast'),
(796, 'en', 'Volynska oblast'),
(797, 'en', 'Luhanska oblast'),
(798, 'en', 'Dnipropetrovska oblast'),
(799, 'en', 'Donetska oblast'),
(800, 'en', 'Zhytomyrska oblast'),
(801, 'en', 'Rovnenska oblast'),
(802, 'en', 'Zakarpatska oblast'),
(803, 'en', 'Zaporizka oblast'),
(804, 'en', 'Ivano-Frankivska oblast'),
(805, 'en', 'Kyiv'),
(806, 'en', 'Kyivska oblast'),
(807, 'en', 'Kirovohradska oblast'),
(808, 'en', 'Lvivska oblast'),
(809, 'en', 'Nykolaivska oblast'),
(810, 'en', 'Odeska oblast'),
(811, 'en', 'Poltavska oblast'),
(812, 'en', 'Sumska oblast'),
(813, 'en', 'Ternopilska oblast'),
(814, 'en', 'Kharkivska oblast'),
(815, 'en', 'Khersonska oblast'),
(816, 'en', 'Khmelnytska oblast'),
(817, 'en', 'Cherkaska oblast'),
(818, 'en', 'Chernihivska oblast'),
(819, 'en', 'Chernivetska oblast'),
(820, 'en', 'Carlow'),
(821, 'en', 'Cavan'),
(822, 'en', 'Clare'),
(823, 'en', 'Cork'),
(824, 'en', 'Donegal'),
(825, 'en', 'Dublin'),
(826, 'en', 'Galway'),
(827, 'en', 'Kerry'),
(828, 'en', 'Kildare'),
(829, 'en', 'Kilkenny'),
(830, 'en', 'Laois'),
(831, 'en', 'Leitrim'),
(832, 'en', 'Limerick'),
(833, 'en', 'Longford'),
(834, 'en', 'Louth'),
(835, 'en', 'Mayo'),
(836, 'en', 'Meath'),
(837, 'en', 'Monaghan'),
(838, 'en', 'Offaly'),
(839, 'en', 'Roscommon'),
(840, 'en', 'Sligo'),
(841, 'en', 'Tipperary'),
(842, 'en', 'Waterford'),
(843, 'en', 'Westmeath'),
(844, 'en', 'Wexford'),
(845, 'en', 'Wicklow'),
(846, 'en', 'Antrim and Newtownabbey'),
(847, 'en', 'Ards and North Down'),
(848, 'en', 'Armagh City, Banbridge and Craigavon'),
(849, 'en', 'Belfast City'),
(850, 'en', 'Causeway Coast and Glens'),
(851, 'en', 'Derry and Strabane'),
(852, 'en', 'Fermanagh and Omagh'),
(853, 'en', 'Lisburn and Castlereagh'),
(854, 'en', 'Mid and East Antrim'),
(855, 'en', 'Mid-Ulster'),
(856, 'en', 'Newry, Mourne and Down');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]static_data`
--

CREATE TABLE `[[dbprefix]]static_data` (
  `param_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `param` varchar(255) NOT NULL DEFAULT '',
  `param_2` varchar(255) NOT NULL DEFAULT '',
  `param_3` varchar(255) NOT NULL DEFAULT '',
  `param_4` varchar(255) NOT NULL DEFAULT '',
  `param_5` varchar(255) NOT NULL DEFAULT '',
  `param_6` varchar(255) NOT NULL DEFAULT '',
  `class` varchar(128) NOT NULL DEFAULT '',
  `section` char(1) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'A',
  `position` smallint(5) NOT NULL DEFAULT '0',
  `parent_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `id_path` varchar(255) NOT NULL DEFAULT '',
  `localization` varchar(255) NOT NULL DEFAULT '',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`param_id`),
  KEY `section` (`section`,`status`,`localization`),
  KEY `position` (`position`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=197 ;

--
-- Dumping data for table `[[dbprefix]]static_data`
--

INSERT INTO `[[dbprefix]]static_data` VALUES
(150, 'gift_certificates.add', '', '', '', '1', '', '', 'A', 'A', 30, 0, '150', '', 1),
(151, 'product_features.view_all?filter_id=10', '', '', '', '1', '', '', 'A', 'A', 40, 0, '151', '', 1),
(152, 'pages.view&page_id=7', '', '', '', '1', '', '', 'A', 'A', 10, 0, '152', '', 1),
(153, '', '', 'C:166:Y', '', '2', '', 'ty-menu-item__electronics', 'A', 'A', 20, 0, '153', '', 1),
(154, '', '', 'C:203:Y', '', '2', '', 'ty-menu-item__sport', 'A', 'A', 30, 0, '154', '', 1),
(155, '', '', 'C:250:Y', '', '2', '', 'ty-menu-item__office', 'A', 'A', 40, 0, '155', '', 1),
(158, 'promotions.list', '', '', '', '2', '', 'ty-menu-item__promotions', 'A', 'A', 120, 0, '158', '', 1),
(159, 'product_features.view_all&filter_id=10', '', '', '', '2', '', 'ty-menu-item__brands', 'A', 'A', 80, 0, '159', '', 1),
(195, 'products.newest', '', '', '', '2', '', 'ty-menu-item__newest', 'A', 'A', 90, 0, '195', '', 1),
(196, 'products.bestsellers', '', '', '', '2', '', 'ty-menu-item__hits', 'A', 'A', 100, 0, '196', '', 1),
(162, 'products.on_sale', '', '', '', '2', '', 'ty-menu-item__sale', 'A', 'A', 110, 0, '162', '', 1),
(169, 'index.php?dispatch=pages.view&page_id=2', '', '', '', '3', '', '', 'A', 'A', 0, 0, '169', '', 1),
(170, 'index.php?dispatch=pages.view&page_id=7', '', '', '', '3', '', '', 'A', 'A', 0, 0, '170', '', 1),
(171, 'index.php?dispatch=discussion.view&thread_id=26', '', '', '', '3', '', '', 'A', 'A', 0, 0, '171', '', 1),
(172, 'index.php?dispatch=pages.view&page_id=23', '', '', '', '3', '', '', 'A', 'A', 0, 0, '172', '', 1),
(173, 'index.php?dispatch=pages.view&page_id=19', '', '', '', '3', '', '', 'A', 'A', 0, 0, '173', '', 1),
(174, 'sitemap.view', '', '', '', '3', '', '', 'A', 'A', 0, 0, '174', '', 1),
(175, 'index.php?dispatch=pages.view&page_id=22', '', '', '', '4', '', '', 'A', 'A', 0, 0, '175', '', 1),
(176, 'index.php?dispatch=pages.view&page_id=21', '', '', '', '4', '', '', 'A', 'A', 0, 0, '176', '', 1),
(178, '', '', 'C:245:Y', '', '2', '', 'ty-menu-item__media', 'A', 'A', 45, 0, '178', '', 1),
(182, '', '', 'C:0:N', '', '2', '', 'ty-menu-item__products', 'A', 'A', 0, 0, '182', '', 1),
(194, '', '', 'C:223:Y', '', '2', '', 'ty-menu-item__apparel', 'A', 'A', 20, 0, '194', '', 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]static_data_descriptions`
--

CREATE TABLE `[[dbprefix]]static_data_descriptions` (
  `param_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `descr` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`param_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]static_data_descriptions`
--

INSERT INTO `[[dbprefix]]static_data_descriptions` VALUES
(150, 'en', 'Gift certificates'),
(151, 'en', 'Our brands'),
(152, 'en', 'Our blog'),
(153, 'en', 'Electronics'),
(154, 'en', 'Sports & Outdoors'),
(155, 'en', 'Office Supplies'),
(158, 'en', 'Promotions'),
(159, 'en', 'Brands'),
(195, 'en', 'Newest'),
(196, 'en', 'Bestsellers'),
(162, 'en', 'Sales'),
(169, 'en', 'About us'),
(170, 'en', 'Blog'),
(171, 'en', 'Reviews'),
(172, 'en', 'Reward points'),
(173, 'en', 'Gift certificates'),
(174, 'en', 'Sitemap'),
(175, 'en', 'Delivery and payment'),
(176, 'en', 'Returns'),
(178, 'en', 'Media'),
(182, 'en', 'Catalog'),
(189, 'en', 'Reward points'),
(190, 'en', 'Gift certificates'),
(194, 'en', 'Apparel');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]statuses`
--

CREATE TABLE `[[dbprefix]]statuses` (
  `status_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `status` char(1) NOT NULL DEFAULT '',
  `type` char(1) NOT NULL DEFAULT 'O',
  `is_default` char(1) NOT NULL DEFAULT 'N',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`status_id`),
  UNIQUE KEY `status` (`status`,`type`),
  KEY `position` (`position`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=20 ;

--
-- Dumping data for table `[[dbprefix]]statuses`
--

INSERT INTO `[[dbprefix]]statuses` VALUES
(1, 'P', 'O', 'Y', 0),
(2, 'C', 'O', 'Y', 0),
(3, 'O', 'O', 'Y', 0),
(4, 'F', 'O', 'Y', 0),
(5, 'D', 'O', 'Y', 0),
(6, 'B', 'O', 'Y', 0),
(7, 'I', 'O', 'Y', 0),
(8, 'P', 'S', 'Y', 0),
(9, 'A', 'S', 'Y', 0),
(10, 'S', 'S', 'Y', 0),
(11, 'P', 'G', 'Y', 0),
(12, 'A', 'G', 'Y', 0),
(13, 'C', 'G', 'Y', 0),
(14, 'U', 'G', 'Y', 0),
(15, 'R', 'R', 'Y', 0),
(16, 'A', 'R', 'Y', 0),
(17, 'D', 'R', 'Y', 0),
(18, 'C', 'R', 'Y', 0),
(19, 'Y', 'O', 'Y', 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]status_data`
--

CREATE TABLE `[[dbprefix]]status_data` (
  `status_id` mediumint(8) unsigned NOT NULL,
  `param` char(255) NOT NULL DEFAULT '',
  `value` char(255) NOT NULL DEFAULT 'Y',
  PRIMARY KEY (`status_id`,`param`),
  KEY `inventory` (`value`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]status_data`
--

INSERT INTO `[[dbprefix]]status_data` VALUES
(6, 'allow_return', 'N'),
(2, 'allow_return', 'Y'),
(7, 'allow_return', 'N'),
(5, 'allow_return', 'N'),
(5, 'inventory', 'I'),
(4, 'allow_return', 'N'),
(7, 'inventory', 'I'),
(3, 'allow_return', 'N'),
(1, 'allow_return', 'N'),
(6, 'repay', 'Y'),
(2, 'repay', 'N'),
(7, 'repay', 'Y'),
(5, 'repay', 'Y'),
(4, 'repay', 'Y'),
(3, 'repay', 'N'),
(1, 'repay', 'N'),
(6, 'gift_cert_status', 'C'),
(7, 'gift_cert_status', 'C'),
(2, 'gift_cert_status', 'A'),
(5, 'gift_cert_status', 'C'),
(4, 'gift_cert_status', 'C'),
(3, 'gift_cert_status', 'P'),
(1, 'gift_cert_status', 'P'),
(2, 'inventory', 'D'),
(6, 'inventory', 'I'),
(4, 'inventory', 'I'),
(3, 'inventory', 'D'),
(1, 'inventory', 'D'),
(6, 'color', '#28abf6'),
(2, 'color', '#97cf4d'),
(5, 'color', '#ff5215'),
(4, 'color', '#ff5215'),
(7, 'color', '#c2c2c2'),
(3, 'color', '#ff9522'),
(1, 'color', '#97cf4d'),
(6, 'remove_cc_info', 'Y'),
(7, 'remove_cc_info', 'Y'),
(2, 'remove_cc_info', 'Y'),
(5, 'remove_cc_info', 'Y'),
(4, 'remove_cc_info', 'Y'),
(3, 'remove_cc_info', 'Y'),
(1, 'remove_cc_info', 'Y'),
(1, 'payment_received', 'Y'),
(2, 'payment_received', 'Y'),
(1, 'is_editable_inventory', 'N'),
(3, 'is_editable_inventory', 'N'),
(1, 'inventory_info', 'default_decline_inventory_info'),
(3, 'inventory_info', 'default_decline_inventory_info'),
(11, 'notify', 'N'),
(12, 'notify', 'Y'),
(13, 'notify', 'Y'),
(14, 'notify', 'N'),
(16, 'inventory', 'I'),
(18, 'inventory', 'I'),
(17, 'inventory', 'D'),
(15, 'inventory', 'I'),
(13, 'grant_reward_points', 'Y'),
(2, 'grant_reward_points', 'Y'),
(18, 'grant_reward_points', 'Y'),
(19, 'color', '#cc4125'),
(19, 'repay', 'Y'),
(19, 'inventory', 'D');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]status_descriptions`
--

CREATE TABLE `[[dbprefix]]status_descriptions` (
  `status_id` mediumint(8) unsigned NOT NULL,
  `description` varchar(255) NOT NULL DEFAULT '',
  `email_subj` varchar(255) NOT NULL DEFAULT '',
  `email_header` text,
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`status_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]status_descriptions`
--

INSERT INTO `[[dbprefix]]status_descriptions` VALUES
(2, 'Complete', 'has been completed', 'Your order has been completed. Thank you for choosing us.', 'en'),
(1, 'Paid', 'has been paid', 'Your order has been paid successfully.', 'en'),
(3, 'Open', 'has been placed successfully.', 'Thank you for the order. You are welcome to come back!', 'en'),
(4, 'Failed', 'failed', 'Your order has been unsuccessful. Please contact shop administration.', 'en'),
(5, 'Declined', 'has been declined', 'Your order has been declined. Please contact shop administration.', 'en'),
(6, 'Backordered', 'has been backordered', 'Your order has been backordered.', 'en'),
(7, 'Canceled', 'has been canceled', 'Your order has been canceled. Please contact shop administration.', 'en'),
(8, 'Picked up', '', '', 'en'),
(9, 'Packed', '', '', 'en'),
(10, 'Shipped', '', '', 'en'),
(11, 'Pending', 'has been created.', 'Your gift certificate has been created successfully. Please wait until it is activated.', 'en'),
(12, 'Active', 'has been activated.', 'Your gift certificate has status Active. You can use it now.', 'en'),
(13, 'Disabled', 'has been disabled.', 'Your gift certificate has been disabled. Please contact shop administration.', 'en'),
(14, 'Used', 'has been used.', 'Your gift certificate is spent. Thank you for choosing us.', 'en'),
(15, 'Requested', 'has been requested successfully.', 'Your return has been requested successfully.', 'en'),
(16, 'Approved', 'has been approved.', 'Your return has been approved.', 'en'),
(17, 'Declined', 'has been declined.', 'Your return has been declined. Please contact shop administration.', 'en'),
(18, 'Completed', 'has been completed.', 'Your return has been completed. Thank you for choosing us.', 'en'),
(19, 'Awaiting call', 'Awaiting call', 'Awaiting call', 'en');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]storage_data`
--

CREATE TABLE `[[dbprefix]]storage_data` (
  `data_key` varchar(255) NOT NULL DEFAULT '',
  `data` mediumblob,
  PRIMARY KEY (`data_key`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]storage_data`
--

INSERT INTO `[[dbprefix]]storage_data` VALUES
('store_mode', 'free'),
('addons_snapshots', '099f8e404ffb885933249ce63bd69cda,9f71cf66aabc45aca700ccd19d277437,0ad509f77398848a3504be8b37afde1d,810afafc9f104cf93c75c5b0c0170225,ced89963a35fcbf5389349cf6376d98c,e2f2aca3ce3adb719db6136bd6069d22,d85faebd5e9ca967b08c8f4820b2c403'),
('cache_id', '[[timestamp]]'),
('cart_products_next_check', '[[timestamp]]'),
('hd_request_code', '[[hd_request_code]]');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]stored_sessions`
--

CREATE TABLE `[[dbprefix]]stored_sessions` (
  `session_id` varchar(64) NOT NULL,
  `expiry` int(11) unsigned NOT NULL,
  `data` mediumblob,
  PRIMARY KEY (`session_id`),
  KEY `expiry` (`expiry`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]stored_sessions`
--


-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]storefronts`
--

CREATE TABLE `[[dbprefix]]storefronts` (
  `storefront_id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'Storefront ID',
  `url` varchar(256) NOT NULL DEFAULT '' COMMENT 'Storefront URL (host + path)',
  `redirect_customer` char(1) NOT NULL DEFAULT 'N' COMMENT 'Whether customers must be redirected from the storefront to a storefront with proper assigned countries',
  `is_default` char(1) NOT NULL DEFAULT 'N' COMMENT 'Whether a storefront is the default one. Default storefront cannot be deleted',
  `status` char(1) NOT NULL DEFAULT 'N' COMMENT 'Storefront status: N - open, Y - closed',
  `access_key` varchar(128) NOT NULL DEFAULT '' COMMENT 'Secret key to access closed storefront',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT 'Storefront name',
  `theme_name` varchar(128) NOT NULL DEFAULT '' COMMENT 'Theme that the storefront uses',
  `is_accessible_for_authorized_customers_only` char(1) NOT NULL DEFAULT 'N' COMMENT 'Storefront is accessible for authorized customers only',
  PRIMARY KEY (`storefront_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]storefronts`
--

INSERT INTO `[[dbprefix]]storefronts` VALUES
(1, '[[domhost]][[relativeurl]]', 'N', 'Y', 'N', '', 'CS-Cart', 'bright_theme', 'N');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]storefronts_companies`
--

CREATE TABLE `[[dbprefix]]storefronts_companies` (
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`storefront_id`,`company_id`),
  KEY `idx_storefront_id` (`storefront_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]storefronts_companies`
--

INSERT INTO `[[dbprefix]]storefronts_companies` VALUES
(1, 1);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]storefronts_countries`
--

CREATE TABLE `[[dbprefix]]storefronts_countries` (
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `country_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`storefront_id`,`country_code`),
  KEY `idx_storefront_id` (`storefront_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]storefronts_currencies`
--

CREATE TABLE `[[dbprefix]]storefronts_currencies` (
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `currency_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`storefront_id`,`currency_id`),
  KEY `idx_storefront_id` (`storefront_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]storefronts_languages`
--

CREATE TABLE `[[dbprefix]]storefronts_languages` (
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `language_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`storefront_id`,`language_id`),
  KEY `idx_storefront_id` (`storefront_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]storefronts_payments`
--

CREATE TABLE `[[dbprefix]]storefronts_payments` (
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `payment_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`storefront_id`,`payment_id`),
  KEY `idx_storefront_id` (`storefront_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]storefronts_payments`
--

INSERT INTO `[[dbprefix]]storefronts_payments` VALUES
(1, 1),
(1, 2),
(1, 5),
(1, 6),
(1, 7),
(1, 8),
(1, 10),
(1, 11);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]storefronts_promotions`
--

CREATE TABLE `[[dbprefix]]storefronts_promotions` (
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `promotion_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`storefront_id`,`promotion_id`),
  KEY `idx_storefront_id` (`storefront_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]storefronts_promotions`
--

INSERT INTO `[[dbprefix]]storefronts_promotions` VALUES
(1, 14),
(1, 15),
(1, 18),
(1, 19),
(1, 23),
(1, 24);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]storefronts_shippings`
--

CREATE TABLE `[[dbprefix]]storefronts_shippings` (
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `shipping_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`storefront_id`,`shipping_id`),
  KEY `idx_storefront_id` (`storefront_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]storefronts_shippings`
--

INSERT INTO `[[dbprefix]]storefronts_shippings` VALUES
(1, 1),
(1, 3),
(1, 4),
(1, 5);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]store_locations`
--

CREATE TABLE `[[dbprefix]]store_locations` (
  `store_location_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `position` smallint(5) NOT NULL DEFAULT '0',
  `country` char(2) NOT NULL DEFAULT '',
  `state` varchar(32) NOT NULL DEFAULT '',
  `latitude` double NOT NULL DEFAULT '0',
  `longitude` double NOT NULL DEFAULT '0',
  `localization` varchar(255) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT 'A',
  `main_destination_id` int(11) unsigned DEFAULT NULL,
  `pickup_destinations_ids` text NOT NULL,
  PRIMARY KEY (`store_location_id`),
  KEY `status` (`status`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]store_location_descriptions`
--

CREATE TABLE `[[dbprefix]]store_location_descriptions` (
  `store_location_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `name` varchar(80) NOT NULL DEFAULT '',
  `description` mediumtext,
  `city` varchar(60) NOT NULL DEFAULT '',
  `pickup_address` varchar(128) NOT NULL DEFAULT '',
  `pickup_phone` varchar(128) NOT NULL DEFAULT '',
  `pickup_time` varchar(128) NOT NULL DEFAULT '',
  PRIMARY KEY (`store_location_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]subscribers`
--

CREATE TABLE `[[dbprefix]]subscribers` (
  `subscriber_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `email` varchar(128) NOT NULL DEFAULT '',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`subscriber_id`),
  UNIQUE KEY `email` (`email`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]sync_data_settings`
--

CREATE TABLE `[[dbprefix]]sync_data_settings` (
  `provider_id` varchar(128) NOT NULL DEFAULT '',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `settings_data` text,
  PRIMARY KEY (`provider_id`,`company_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]tags`
--

CREATE TABLE `[[dbprefix]]tags` (
  `tag_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `tag` varchar(255) NOT NULL DEFAULT '',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'P',
  PRIMARY KEY (`tag_id`),
  UNIQUE KEY `tag` (`tag`,`company_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=5 ;

--
-- Dumping data for table `[[dbprefix]]tags`
--

INSERT INTO `[[dbprefix]]tags` VALUES
(1, 1, 'Books', 1328701513, 'A'),
(2, 1, 'Music', 1328701563, 'A'),
(4, 1, 'Sport', 1328701593, 'A');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]tag_links`
--

CREATE TABLE `[[dbprefix]]tag_links` (
  `tag_id` mediumint(8) unsigned NOT NULL,
  `object_type` char(1) NOT NULL DEFAULT 'P',
  `object_id` mediumint(8) unsigned NOT NULL,
  PRIMARY KEY (`object_type`,`object_id`,`tag_id`),
  KEY `tag_id` (`tag_id`),
  KEY `ids` (`tag_id`,`object_type`,`object_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]tag_links`
--

INSERT INTO `[[dbprefix]]tag_links` VALUES
(3, 'P', 12),
(1, 'P', 13),
(1, 'P', 17),
(1, 'P', 20),
(1, 'P', 45),
(4, 'P', 131),
(4, 'P', 187),
(2, 'P', 197),
(2, 'P', 198),
(2, 'P', 199),
(2, 'P', 201),
(2, 'P', 203);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]taxes`
--

CREATE TABLE `[[dbprefix]]taxes` (
  `tax_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `address_type` char(1) NOT NULL DEFAULT 'S',
  `status` char(1) NOT NULL DEFAULT 'D',
  `price_includes_tax` char(1) NOT NULL DEFAULT 'N',
  `display_including_tax` char(1) NOT NULL DEFAULT 'N',
  `display_info` char(1) NOT NULL DEFAULT '',
  `regnumber` varchar(255) NOT NULL DEFAULT '',
  `priority` mediumint(8) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`tax_id`),
  KEY `c_status` (`status`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=7 ;

--
-- Dumping data for table `[[dbprefix]]taxes`
--

INSERT INTO `[[dbprefix]]taxes` VALUES
(6, 'S', 'A', 'Y', 'N', '', '1234242', 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]tax_descriptions`
--

CREATE TABLE `[[dbprefix]]tax_descriptions` (
  `tax_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `tax` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`tax_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]tax_descriptions`
--

INSERT INTO `[[dbprefix]]tax_descriptions` VALUES
(6, 'en', 'VAT');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]tax_rates`
--

CREATE TABLE `[[dbprefix]]tax_rates` (
  `rate_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `tax_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `destination_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `rate_value` decimal(13,3) NOT NULL DEFAULT '0.000',
  `rate_type` char(1) NOT NULL DEFAULT '',
  PRIMARY KEY (`rate_id`),
  UNIQUE KEY `tax_rate` (`tax_id`,`destination_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=13 ;

--
-- Dumping data for table `[[dbprefix]]tax_rates`
--

INSERT INTO `[[dbprefix]]tax_rates` VALUES
(5, 6, 1, '12.000', 'P'),
(11, 6, 8, '3.000', 'P'),
(12, 6, 7, '10.000', 'P');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]template_documents`
--

CREATE TABLE `[[dbprefix]]template_documents` (
  `document_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `template` text,
  `default_template` text,
  `type` varchar(32) NOT NULL DEFAULT '',
  `code` varchar(128) NOT NULL DEFAULT '',
  `addon` varchar(32) NOT NULL DEFAULT '',
  `updated` int(10) unsigned NOT NULL DEFAULT '0',
  `created` int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`document_id`),
  UNIQUE KEY `code` (`code`,`type`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=6 ;

--
-- Dumping data for table `[[dbprefix]]template_documents`
--

INSERT INTO `[[dbprefix]]template_documents` VALUES
(1, NULL, '<table width="100%;" style="min-width: 800px; font-family: Helvetica, Arial, sans-serif; border-collapse: separate;" cellspacing="0" cellpadding="0" border="0">\n<tbody>\n<tr style="vertical-align: top;">\n    <td>\n        <table width="100%;" cellspacing="0" border="0" style="border-collapse: separate; font-family: Helvetica, Arial, sans-serif;">\n        <tbody>\n        <tr>\n            <td width="66%" style="padding-bottom: 40px; vertical-align: top; font-family: Helvetica, Arial, sans-serif;"><img src="{{c.logos.mail.image.image_path}}" width="{{c.logos.mail.image.image_x}}" height="{{c.logos.mail.image.image_y}}" alt="{{ c.name }}" style="width: auto; max-width: 300px; max-height: 150px;">\n            </td>\n            <td width="34%" style="padding-bottom: 40px; -webkit-print-color-adjust: exact; font-family: Helvetica, Arial, sans-serif;">\n                <p style="color: #787878; font-size: 14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 3px; margin: 0px;">\n                    <span style="color: #000000; font-weight: bold; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; line-height: 20px;">{{ o.invoice_id_text }}</span>\n                </p>\n\n                <p style="color: #787878; font-size: 14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px; margin: 0px;">\n                    <span style="color: #000000; font-weight: bold; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase;">{{__("order_date")}}</span>  {{o.timestamp}}\n                </p>\n                <p style="color: #787878; font-size: 14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px; margin: 0px;">\n                    <span style="color: #000000; font-weight: bold; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase;">{{__("payment")}}</span>  {{p.payment}}\n                </p>\n                <p style="color: #787878; font-size: 14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px; margin: 0px;">\n                    <span style="color: #000000; font-weight: bold; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase;">{{__("shipping")}}</span>  {{o.shippings_method}}\n                </p>\n                {% if o.tracking_number %}\n                <p style="color: #787878; font-size: 14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px; margin: 0px;">\n                    <span style="color: #000000; font-weight: bold; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase;">{{__("tracking_number")}}</span>  {{o.tracking_number}}\n                </p>\n                {% endif %}\n            </td>\n        </tr>\n        </tbody>\n        </table>\n    </td>\n</tr>\n<tr>\n    <td colspan="2">\n        <table width="100%;" cellspacing="0" cellpadding="0" border="0" style=" border-collapse: separate; font-family: Helvetica, Arial, sans-serif;">\n        <tbody>\n        <tr>\n            <td style="vertical-align: top; background-color: #f7f7f7; color: #444444; padding: 20px 10px; color: #444444; font-size: 14px; font-family: Helvetica, Arial, sans-serif; -webkit-print-color-adjust: exact;" width="30%">\n                <h1 style="margin: 0px; font-size: 22px; font-family: Helvetica, Arial, sans-serif; color: #444444; text-transform: uppercase; padding-bottom: 20px; border-bottom: 3px solid #444444; margin-bottom: 20px;">{{__("store")}}</h1>\n                <p style="margin: 0px; padding-bottom: 10px;"><strong>{{c.name}}</strong>\n                </p>\n                {{ snippet("company_address") }}\n            </td>\n            <td style="vertical-align: top; padding: 20px 30px; color: #444444; font-size: 14px; font-family: Helvetica, Arial, sans-serif;" width="36%">\n                {{ snippet("bill_to") }}\n            </td>\n            <td style="vertical-align: top; padding: 20px 0px; color: #444444; font-size: 14px; font-family: Helvetica, Arial, sans-serif;" width="34%">\n                {% if pickup_point.is_selected %}\n                {{ snippet("pickup_point") }}\n                {% else %}\n                {{ snippet("ship_to") }}\n                {% endif %}\n            </td>\n        </tr>\n        </tbody>\n        </table>\n    </td>\n</tr>\n<tr>\n    <td style="font-family: Helvetica, Arial, sans-serif;">\n        {{ snippet("products_table") }}\n    </td>\n</tr>\n<tr>\n    <td style="border-top: 3px solid #444444; padding-top: 10px; font-family: Helvetica, Arial, sans-serif;">\n        <table width="100%" style="border-collapse: separate; font-family: Helvetica, Arial, sans-serif;">\n        <tbody>\n        <tr>\n            <td width="66%" style="font-size: 14px; font-family: Helvetica, Arial, sans-serif; line-height: 21px; color: #444444; padding-right: 30px; vertical-align:top;">\n                {% if o.notes %}\n                <h2 style="margin: 0px; font-size: 22px; font-family: Helvetica, Arial, sans-serif; color: #444444; text-transform: uppercase; padding-bottom: 20px; border-bottom: 3px solid #e8e8e8; margin-bottom: 10px;">{{ __("customer_notes") }}</h2>\n                {{ o.notes }}\n                                {% endif %}\n            </td>\n            <td width="34%" style="vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                <table width="100%;" style="font-size: 14px; color: #444; font-family: Helvetica, Arial, sans-serif;">\n                <tbody>\n                <tr style=" vertical-align: top;">\n                    <td align="left" style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;">{{ __("subtotal") }}\n                    </td>\n                    <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{{o.display_subtotal}}\n                    </td>\n                </tr>\n                <tr style=" vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                    <td align="left" style="padding-bottom: 20px; text-transform: uppercase; font-family: Helvetica, Arial, sans-serif;">{{o.tax_name}}\n                    </td>\n                    <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{{o.tax_total}}\n                    </td>\n                </tr>\n                <tr style=" vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                    <td align="left" style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;">{{ __("shipping") }}\n                    </td>\n                    <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{{ o.display_shipping_cost }}\n                    </td>\n                </tr>\n                <tr style=" vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                    <td align="left" style="font-family: Helvetica, Arial, sans-serif;">{% if o.payment_surcharge %}\n                        <div style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;"> {{__("payment_surcharge")}} </div> {% endif %}\n                    </td>\n                    <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{% if o.payment_surcharge %} {{o.payment_surcharge}} {% endif %}<br>\n                    </td>\n                </tr>\n                <tr style=" vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                    <td align="left">{% if o.coupon_code %} <div style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;"> {{ __("coupon") }} </div> {% endif %}\n                    </td>\n                    <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{% if o.coupon_code %} {{o.coupon_code}} {% endif %}\n                    </td>\n                </tr>\n                <tr style=" vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                    <td align="left" style="font-family: Helvetica, Arial, sans-serif;">{% if o.raw.discount %} <div style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;"> {{ __("including_discount") }} </div> {% endif %}\n                    </td>\n                    <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{% if o.raw.discount %} {{o.discount}} {% endif %}\n                    </td>\n                </tr>\n                <tr style=" vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                    <td align="left" style="font-family: Helvetica, Arial, sans-serif;">{% if o.raw.subtotal_discount %} <div style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;"> {{ __("order_discount") }} </div> {% endif %}\n                    </td>\n                    <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{% if o.raw.subtotal_discount %} {{o.subtotal_discount}} {% endif %}\n                    </td>\n                </tr>\n                <tr style=" vertical-align: top; font-size: 22px; font-family: Helvetica, Arial, sans-serif; font-weight: bold;">\n                    <td align="left" style="padding-top: 20px; border-top: 1px solid #e8e8e8; font-size: 22px; font-family: Helvetica, Arial, sans-serif; ">{{ __("total") }}\n                    </td>\n                    <td align="right" style="padding-top: 20px; border-top: 1px solid #e8e8e8; font-size: 22px; font-family: Helvetica, Arial, sans-serif; ">{{o.total}}\n                    </td>\n                </tr>\n                </tbody>\n                </table>\n            </td>\n        </tr>\n        </tbody>\n        </table>\n    </td>\n</tr>\n</tbody>\n</table>', 'order', 'invoice', '', [[timestamp]], [[timestamp]]),
(2, NULL, '<table width="600" style=" font-family: Helvetica, Arial, sans-serif; border-collapse: separate;" rel="min-width: 800px; font-family: Helvetica, Arial, sans-serif; border-collapse: separate;" cellspacing="0" cellpadding="0" border="0">\n<tbody>\n<tr style="vertical-align: top;">\n    <td>\n        <table width="100%;" cellspacing="0" border="0" style="border-collapse: separate; font-family: Helvetica, Arial, sans-serif;">\n        <tbody>\n        <tr>\n            <td width="50%" style="padding: 0px; padding-bottom: 10px; padding-right: 40px; vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                {% if pickup_point.is_selected %}\n                {{ snippet("pickup_point") }}\n                {% else %}\n                {{ snippet("ship_to") }}\n                {% endif %}\n            </td>\n            <td width="50%" style="padding: 0px; padding-bottom: 10px; padding-left: 40px; -webkit-print-color-adjust: exact; vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                <p style="color: #787878; font-size: 14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px; margin: 0px;">\n                    <span style="color: #444444; font-weight: bold; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase;">{{__("order_date")}}</span>  {{o.timestamp}}\n                </p>\n                <p style="color: #787878; font-size: 14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px; margin: 0px;">\n                    <span style="color: #444444; font-weight: bold; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase;">{{__("payment")}}</span>  {{p.payment}}\n                </p>\n                <p style="color: #787878; font-size: 14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px; margin: 0px;">\n                    <span style="color: #444444; font-weight: bold; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase;">{{__("shipping")}}</span>  {{o.shippings_method}}\n                </p>\n                {% if o.tracking_number %}\n                <p style="color: #787878; font-size: 14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px; margin: 0px;">\n                    <span style="color: #444444; font-weight: bold; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase;">{{__("tracking_number")}}</span>  {{o.tracking_number}}\n                </p>\n                {% endif %}\n            </td>\n        </tr>\n        </tbody>\n        </table>\n    </td>\n</tr>\n<tr>\n    <td style="padding: 0px;">\n        {{ snippet("products_table") }}\n    </td>\n</tr>\n<tr>\n    <td style="padding: 0px; border-top: 2px solid #f5f5f5; padding-top: 10px; font-family: Helvetica, Arial, sans-serif;">\n        <table width="100%" style="border-collapse: separate; font-family: Helvetica, Arial, sans-serif;">\n        <tbody>\n        <tr>\n            <td width="66%" style="font-size: 14px; font-family: Helvetica, Arial, sans-serif; line-height: 21px; color: #444444; padding-right: 30px; vertical-align:top;">\n                {% if o.notes %}\n                <h2 style="margin: 0px; font-size: 22px; font-family: Helvetica, Arial, sans-serif; color: #444444; text-transform: uppercase; padding-bottom: 20px; border-bottom: 3px solid #e8e8e8; margin-bottom: 10px;">{{ __("customer_notes") }}</h2>\n                {{ o.notes }}\n                                {% endif %}\n            </td>\n            <td width="34%" style="vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                <table width="100%;" style="font-size: 14px; font-family: Helvetica, Arial, sans-serif; color: #444;">\n                <tbody>\n                    <tr style=" vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                        <td align="left" style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;">{{ __("subtotal") }}\n                        </td>\n                        <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{{o.display_subtotal}}\n                        </td>\n                    </tr>\n                    <tr style=" vertical-align: top;">\n                        <td align="left" style="padding-bottom: 20px; text-transform: uppercase; font-family: Helvetica, Arial, sans-serif;">{{o.tax_name}}\n                        </td>\n                        <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{{o.tax_total}}\n                        </td>\n                    </tr>\n                    <tr style=" vertical-align: top;">\n                        <td align="left" style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;">{{ __("shipping") }}\n                        </td>\n                        <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{{ o.display_shipping_cost }}\n                        </td>\n                    </tr>\n                    <tr style=" vertical-align: top;">\n                        <td style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;" align="left">{{ __("payment_surcharge") }}\n                        </td>\n                        <td style="font-family: Helvetica, Arial, sans-serif;" align="right">{{ o.payment_surcharge }}\n                        </td>\n                    </tr>\n                    <tr style=" vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                        <td align="left" style="font-family: Helvetica, Arial, sans-serif;">{% if o.coupon_code %} <div style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;"> {{ __("coupon") }} </div> {% endif %}\n                        </td>\n                        <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{% if o.coupon_code %} {{o.coupon_code}} {% endif %}\n                        </td>\n                    </tr>\n                    <tr style=" vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                        <td align="left" style="font-family: Helvetica, Arial, sans-serif;">{% if o.raw.discount %} <div style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;"> {{ __("including_discount") }} </div> {% endif %}\n                        </td>\n                        <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{% if o.raw.discount %} {{o.discount}} {% endif %}\n                        </td>\n                    </tr>\n                    <tr style=" vertical-align: top; font-family: Helvetica, Arial, sans-serif;">\n                        <td align="left" style="font-family: Helvetica, Arial, sans-serif;">{% if o.raw.subtotal_discount %} <div style="padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;"> {{ __("order_discount") }} </div> {% endif %}\n                        </td>\n                        <td align="right" style="font-family: Helvetica, Arial, sans-serif;">{% if o.raw.subtotal_discount %} {{o.subtotal_discount}} {% endif %}\n                        </td>\n                    </tr>\n                    <tr style=" vertical-align: top; font-size: 22px; font-weight: bold; font-family: Helvetica, Arial, sans-serif;">\n                        <td align="left" style="padding-top: 20px; border-top: 1px solid #e8e8e8; font-size: 22px; font-family: Helvetica, Arial, sans-serif;">{{ __("total") }}\n                        </td>\n                        <td align="right" style="padding-top: 20px; border-top: 1px solid #e8e8e8; font-size: 22px; font-family: Helvetica, Arial, sans-serif;">{{o.total}}\n                        </td>\n                    </tr>\n                </tbody>\n                </table>\n            </td>\n        </tr>\n        </tbody>\n        </table>\n    </td>\n</tr>\n</tbody>\n</table>', 'order', 'summary', '', [[timestamp]], [[timestamp]]),
(3, NULL, '<table class="main-table" style="height: 100%; font-size: 12px; font-family: Helvetica, Arial, sans-serif;" rel="height: 100%; border="0" cellpadding="0" cellspacing="0" width="100%">\n<tbody>\n<tr>\n    <td style="width: 100%; height: 100%; padding: 24px 0; font-family: Helvetica, Arial, sans-serif;" align="center">\n        <div style="background-color: #ffffff; margin: 0px auto; padding: 0px 44px 0px 46px; width: 510px; text-align: left; font-family: Helvetica, Arial, sans-serif;">\n            <table style="border-collapse: separate; padding-top: 32px; font-family: Helvetica, Arial, sans-serif;" border="0" cellpadding="0" cellspacing="0" width="100%">\n            <tbody>\n            <tr valign="top">\n                <td style="border-bottom: 1px dashed #000000; padding-bottom: 20px; font-family: Helvetica, Arial, sans-serif;" align="center" width="100%">\n                    <h3 style="font-size: 17px; font-weight: bold; font-family: Helvetica, Arial, sans-serif; padding: 0px 0px 3px 1px; margin: 0px;">{{ __("ship_to") }}:</h3>\n                    <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                        {% if u.s_firstname %}\n                            {{u.s_firstname}} {{u.s_lastname}}\n                        {% else %}\n                            {{u.firstname}} {{u.lastname}}\n                        {% endif %}\n                    </p>\n                    <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                        {{ u.s_address  }} {{ u.s_address_2 }}\n                    </p>\n                    <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                        {{ u.s_city }} {{ u.s_state_descr }} {{ u.s_zipcode }}\n                    </p>\n                    <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                        {{ u.s_country_descr }}\n                    </p>\n                    {% for field in u.s_fields %}\n                    <p style="font-family: Helvetica, Arial, sans-serif;">{{ field.name }}: {{ field.value }}\n                    </p>\n                    {% endfor %}\n                </td>\n            </tr>\n            <tr class="scissors" valign="top">\n                <td style="padding-left: 20px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;" width="100%">\n                    <img style="vertical-align: top;" src="{{ runtime.images_dir }}/scissors.gif" border="0">\n                </td>\n            </tr>\n            </tbody>\n            </table>\n            <table border="0" cellpadding="0" cellspacing="0" width="100%">\n            <tbody>\n            <tr>\n                <td style="width: 50%; padding: 14px 0px 0px 2px;">\n                    <h2 style="font-size: 12px; font-weight: bold; font-family: Helvetica, Arial, sans-serif; margin: 0px 0px 3px 0px;">{{ c.name }}</h2>\n                    <p style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;">{{ snippet("company_address") }}\n                    </p>\n                    <p style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;">{{ snippet("company_info") }}<br>\n                    </p>\n                </td>\n                <td style="padding-top: 14px; font-family: Helvetica, Arial, sans-serif;" valign="top">{{ snippet("order_date") }}\n                </td>\n            </tr>\n            </tbody>\n            </table>\n            <table style="padding: 20px 0px 24px 0px; font-family: Helvetica, Arial, sans-serif;" border="0" cellpadding="0" cellspacing="0" width="100%">\n            <tbody>\n            <tr valign="top">\n                <td style="font-family: Helvetica, Arial, sans-serif;" width="54%">\n                    {{snippet("bill_to")}}\n                </td>\n                <td style="font-family: Helvetica, Arial, sans-serif;" width="54%">\n                    {% if pickup_point.is_selected %}\n                    {{ snippet("pickup_point") }}\n                    {% else %}\n                    {{ snippet("ship_to") }}\n                    {% endif %}\n                </td>\n            </tr>\n            </tbody>\n            </table>\n            <div style="font-family: Helvetica, Arial, sans-serif;">\n                {{ snippet("order_info") }}\n            </div>\n            <div style="font-family: Helvetica, Arial, sans-serif;">\n                {{ snippet("products_table") }}\n                <br>{{ snippet("notes") }}\n            </div>\n        </div>\n    </td>\n</tr>\n</tbody>\n</table>', 'packing_slip', 'default', '', [[timestamp]], [[timestamp]]),
(4, NULL, '<table border="0" cellpadding="0" cellspacing="0" width="100%">\n<tbody>\n<tr>\n    <td style="width: 100%; height: 100%;vertical-align: top;" align="center">\n        <table border="0" cellpadding="0" cellspacing="0" width="600px">\n        <tbody style="font-family: arial;">\n        <tr>\n            <td style="padding: 17px 25px 40px; background: #F57171;" align="center" valign="top" width="600px">\n                <h1 style="color: #fff; text-transform: uppercase; font-size: 40px; font-weight: bold;margin: 10px 0 0;">\n                {{ __("gift_certificate") }}\n                </h1>\n                <h2 style="font-size: 50px; font-weight: normal; color: #fff; margin: 0px; line-height: 1.2em;">\n                {{ gift_certificate.amount }}\n                </h2>\n                <p style="color: #fff; margin: 0 0 12px; font-size: 12px">\n                    {{ __("gift_cert_code") }}\n                </p>\n                <span style="background: #fff; padding: 5px 20px; font-size: 19px; font-weight: lighter; border-radius: 2px;">\n                {{ gift_certificate.gift_cert_code }}</span>\n            </td>\n        </tr>\n        <tr>\n            <td style="padding: 30px 0px 80px;" valign="middle" width="600px">\n                <div style="padding: 10px;">{{ snippet("info") }}\n                </div>\n                <div>{{ snippet("products_table") }}\n                </div>\n                <div style="padding: 30px 20px 0px 20px; text-align: right;">\n                    {{__("shop_now")}} : <a href="{{c.storefront_url}}" target="_blank">{{c.storefront_url}}</a>\n                </div>\n            </td>\n        </tr>\n        </tbody>\n        </table>\n    </td>\n</tr>\n</tbody>\n</table>', 'gift_certificate', 'default', 'gift_certificates', [[timestamp]], [[timestamp]]),
(5, NULL, '<table cellspacing="0" width="100%">\n<tbody>\n<tr>\n	<td align="center" width="100%">\n		<table border="0" cellpadding="0" cellspacing="0">\n		<tbody>\n		<tr>\n			<td style="background-color: #ffffff; margin: 0px auto; padding: 0px 40px 40px 40px; width: 510px;" align="left">\n				<h1 style="text-align: left; font-size: 26px; font-weight: bold; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; border-bottom: 1px solid #eeeeee; padding: 10px 0px 8px 0px; margin-bottom: 0px;">\n				{{ __("packing_slip") }}\n				</h1>\n				<table border="0" cellpadding="0" cellspacing="0" width="100%">\n				<tbody>\n				<tr valign="top">\n					<td style="width: 50%; padding: 14px 0px 0px 2px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n						<h2 style="font-size: 17px; font-weight: normal; font-family: Helvetica, Arial, sans-serif; margin: 0px 0px 3px 0px;"><strong>{{c.name}}</strong></h2>\n						{{ snippet("company_address") }}<br>{{ snippet("company_info") }}\n					</td>\n					<td style="padding-top: 14px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n						<h2 style="font-size: 17px; font-weight: normal; font-family: Helvetica, Arial, sans-serif; margin: 0px;"><strong>{{ __("rma_return") }} # {{ r.return_id }}</strong></h2>\n						<table border="0" cellpadding="0" cellspacing="0">\n						<tbody>\n						<tr valign="top">\n							<td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("action") }}:\n							</td>\n							<td width="100%" style="font-family: Helvetica, Arial, sans-serif;">{{ r.action_name}}\n							</td>\n						</tr>\n						<tr valign="top">\n							<td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("status") }}:\n							</td>\n							<td width="100%" style="font-family: Helvetica, Arial, sans-serif;">{{ r.status_name }}\n							</td>\n						</tr>\n						<tr valign="top">\n							<td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("date") }}:\n							</td>\n							<td style="font-family: Helvetica, Arial, sans-serif;">{{ r.timestamp }}\n							</td>\n						</tr>\n						</tbody>\n						</table>\n					</td>\n				</tr>\n				</tbody>\n				</table>\n				<table style="padding: 20px 0px 24px 0px;" border="0" cellpadding="0" cellspacing="0" width="100%">\n				<tbody>\n				<tr valign="top">\n					<td width="54%" style="font-family: Helvetica, Arial, sans-serif;">\n						{{snippet("bill_to")}}\n					</td>\n					<td width="54%" style="font-family: Helvetica, Arial, sans-serif;">\n						{% if pickup_point.is_selected %}\n                        {{ snippet("pickup_point") }}\n                        {% else %}\n                        {{ snippet("ship_to") }}\n                        {% endif %}\n					</td>\n				</tr>\n				</tbody>\n				</table>\n				<div style="font-family: Helvetica, Arial, sans-serif;">\n					{{ snippet("products_table") }}\n				</div>\n				<div>\n					{% if r.comment %}\n					<p style="margin-top: 15px; font-weight: normal; font-size: 12px; font-family: Helvetica, Arial, sans-serif;"><strong>{{ __("comments") }}:</strong>\n					</p>\n					<p style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n						{{ r.comment|nl2br }}\n					</p>\n					{% endif %}\n				</div>\n			</td>\n		</tr>\n		</tbody>\n		</table>\n	</td>\n</tr>\n</tbody>\n</table>', 'rma_packing_slip', 'default', 'rma', [[timestamp]], [[timestamp]]);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]template_emails`
--

CREATE TABLE `[[dbprefix]]template_emails` (
  `template_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `code` varchar(128) NOT NULL,
  `area` char(1) NOT NULL DEFAULT 'C',
  `status` char(1) NOT NULL DEFAULT 'A',
  `subject` text,
  `template` text,
  `default_subject` text,
  `default_template` text,
  `params_schema` text,
  `params` text,
  `addon` varchar(32) NOT NULL DEFAULT '',
  `updated` int(10) unsigned NOT NULL DEFAULT '0',
  `created` int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`template_id`),
  UNIQUE KEY `template` (`code`,`area`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=64 ;

--
-- Dumping data for table `[[dbprefix]]template_emails`
--

INSERT INTO `[[dbprefix]]template_emails` VALUES
(1, 'activate_profile', 'A', 'A', NULL, NULL, '{{ company_name }}: {{__("new_user_profile")}}', '{{ snippet("header", {"title": __("new_user_profile")} ) }}\n\n    {{ __("hello") }},\n    <br />\n    <br /> {{ __("text_new_user_activation", {"[user_login]": user_data.email, "[url]": url, "[url_text]": url|puny_decode}) }}\n\n{{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(2, 'back_in_stock_notification', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ product.name|striptags }} {{ __("is_back_in_stock") }}', '{{ snippet("header", {"title": product.name  } ) }}\n    {{ __("hello") }},\n    <br />\n    <br />\n    {{ __("back_in_stock_notification_header") }}\n    <br />\n    <br />\n    <b><a href="{{ url }}">{{ product.name }}</a></b>\n    <br />\n    <br /> {{ __("back_in_stock_notification_footer") }}\n    <br />\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(3, 'create_profile', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("new_profile_notification") }}', '{{ snippet("header", {"title": __("new_profile_notification")} ) }}\n    {% if user_data.firstname %} {{__("hello_name", {"[name]" : user_data.firstname})}} {% else %} {{ __("hello") }}, {% endif %}\n    <br>\n    <br>\n    {{ __("create_profile_notification_header") }}\n    <br>\n    <br>\n    <table border="0" class="info">\n      <tr>\n        <td align="right"><b>{{ __("login_url") }}:</b></td>\n        <td><a href="{{ login_url }}">{{ login_url|puny_decode }}</a></td>\n      </tr>\n      <tr>\n        <td align="right"><b>{{ __("email") }}:</b></td>\n        <td><a>{{ user_data.email }}</a></td>\n      </tr>\n      <tr>\n        <td align="right"><b>{{ __("password") }}:</b></td>\n        <td>\n{% if password %}\n    {{ password }}\n{% else %}\n    *********** (<a href="{{ forgot_pass_url }}">{{ __("forgot_password_question") }}</a>)\n{% endif %}</td>\n      </tr>\n    </table>\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(4, 'create_profile', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("new_profile_notification") }}', '{{ snippet("header", {"title": __("new_profile_notification")} ) }}\n    {% if user_data.firstname %} {{__("hello_name", {"[name]" : user_data.firstname})}} {% else %} {{ __("hello") }}, {% endif %}\n    <br>\n    {{ __("update_profile_notification_header") }}\n    <br>\n    <br>\n    <h4 class="with-subline">{{ __("user_account_information") }}</h4>\n    <table border="0" width="100%" class="info">\n      <tr>\n        <td><b>{{ __("login_url") }}:</b></td>\n        <td><a href="{{ login_url }}">{{ login_url|puny_decode }}</a></td>\n      </tr>\n      <tr>\n        <td><b>{{ __("email") }}:</b></td>\n        <td><a>{{ user_data.email }}</a></td>\n      </tr>\n      <tr>\n        <td><b>{{ __("password") }}:</b></td>\n        <td> *********** (<a href="{{ forgot_pass_url }}">{{ __("forgot_password_question") }}</a>)</td>\n      </tr>\n    </table>\n\n\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(5, 'edp_access', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("order") }} #{{ order_info.order_id }} {{ __("edp_access_subj") }}', '{{ snippet("header") }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    <br /> {{ __("edp_access_granted") }}\n    <br />\n    <br /> <a href="{{ order_files_list_url }}"><b>{{ __("view_avail_files_for_order", {"[order_id]": order_info.order_id}) }}</b></a>\n    <br />\n    <br /> {% for product in edp_data %}\n    {% for file in product.files %}\n    <a href="{{ file.url }}">{{ file.file_name }} ({{ file.file_size|filesize }}&nbsp;{{ __("bytes") }})</a>\n    <br />\n    <br /> {% endfor %} {% endfor %}\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(6, 'give_coupon', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("give_coupon_subj") }}', '{{ snippet("header", {"title": __("give_coupon_subj") } ) }}\n    {{__("hello_name", {"[name]" : user_data.firstname})}}\n    <br /> {{ __("text_applied_promotions") }}\n    <br />\n    <br /> {{ promotion_data.name }}\n    <br />\n    <br /> {{ promotion_data.detailed_description }}\n    <br />\n    <b>{{ bonus_data.coupon_code }}</b>\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(7, 'low_stock', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("low_stock_subj", {"[product]": "#{product} ##{product_id}"}) }}', '{{ snippet("header", {"title":__("low_stock_subj", {"[product]": "#{product} ##{product_id}"}) } ) }}\n\n    <table class="info">\n      <tr>\n        <td>{{ __("product") }}:</td>\n        <td>{{ product }}</td>\n      </tr>\n      <tr>\n        <td>{{ __("id") }}:</td>\n        <td>{{ product_id }}</td>\n      </tr>\n      <tr>\n        <td>{{ __("sku") }}:</td>\n        <td>{{ product_code }}</td>\n      </tr>\n      <tr>\n        <td>{{ __("qty") }}:</td>\n        <td><b>{{ new_qty }}</b></td>\n      </tr>\n      {% if product_options %}\n      <tr>\n        <td colspan="2">{{ __("product_options") }}:\n          <br>\n          <hr>\n        </td>\n      </tr>\n      {% for option in product_options %}\n      <tr>\n        <td>{{ option.option_name }}:</td>\n        <td>{{ option.variant_name }}</td>\n      </tr>\n      {% endfor %} {% endif %}\n    </table>\n\n{{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(8, 'order_notification.b', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_b_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_b_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(9, 'order_notification.b', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_b_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_b_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(10, 'order_notification.c', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_c_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_c_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":"invoice"}', '', [[timestamp]], [[timestamp]]),
(11, 'order_notification.c', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_c_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_c_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":"invoice"}', '', [[timestamp]], [[timestamp]]),
(12, 'order_notification.d', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_d_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_d_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(13, 'order_notification.d', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_d_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_d_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(14, 'order_notification.f', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_f_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_f_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(15, 'order_notification.f', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_f_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_f_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(16, 'order_notification.i', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_i_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_i_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(17, 'order_notification.i', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_i_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_i_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(18, 'order_notification.o', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_o_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_o_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(19, 'order_notification.o', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_o_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_o_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(20, 'order_notification.p', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_p_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_p_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(21, 'order_notification.p', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_p_subj", {"[order]": order_info.order_id}) }}', '{{ snippet("header", {"title": __("change_order_status_p_subj", {"[order]": order_info.order_id}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":"invoice"}', '', [[timestamp]], [[timestamp]]),
(22, 'shipping_error', 'A', 'A', NULL, NULL, '{{ company_name }}: {{__("request_error_information_title")}}', '{{ snippet("header", {"title": __("request_error_information_title")}) }} {{ log_message }} {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(23, 'order_notification_default', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_default_subj", {"[order]": order_info.order_id, "[status]": order_status.description}) }}', '{{ snippet("header", {"title": __("change_order_status_default_subj", {"[order]": order_info.order_id, "[status]": order_status.description}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(24, 'order_notification_default', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_default_subj", {"[order]": order_info.order_id, "[status]": order_status.description}) }}', '{{ snippet("header", {"title": __("change_order_status_default_subj", {"[order]": order_info.order_id, "[status]": order_status.description}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(25, 'profile_activated', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("profile_activated") }}', '{{ snippet("header", {"title": __("profile_activated")} ) }}\n\n    {{__("hello_name", {"[name]" : firstname})}}\n    <br />\n    <br /> {{ __("text_profile_activated") }}\n\n{{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(26, 'profile_activated', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("profile_activated") }}', '{{ snippet("header", {"title": __("profile_activated")} ) }}\n    {% if user_data.firstname %} {{__("hello_name", {"[name]" : user_data.firstname})}} {% else %} {{ __("hello") }}, {% endif %}\n    <br /> {{ __("text_profile_activated") }}\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(27, 'profile_deactivated', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("profile_deactivated") }}', '{{ snippet("header", {"title": __("profile_deactivated")} ) }}\n\n    {{__("hello_name", {"[name]" : firstname})}}\n    <br />\n    <br /> {{ __("text_profile_deactivated") }}\n\n{{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(28, 'profile_deactivated', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("profile_deactivated") }}', '{{ snippet("header", {"title": __("profile_deactivated")} ) }}\n    {% if user_data.firstname %} {{__("hello_name", {"[name]" : user_data.firstname})}} {% else %} {{ __("hello") }}, {% endif %}\n    <br /> {{ __("text_profile_deactivated") }}\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(29, 'recover_password', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("recover_password_subj") }}', '{{ snippet("header", {"title": __("recover_password_subj") } ) }}\n\n        {{ __("hello") }}<br /><br />\n        {{ __("password_recovery.text_confirm", {"[site]": company_name}) }}<br /><br />\n        {{ __("password_recovery.link_expire") }}:<br /><br />\n        <a href="{{ url }}">{{ url|puny_decode }}</a>\n\n{{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(30, 'recover_password', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("recover_password_subj") }}', '{{ snippet("header", { "title" : __("recover_password_subj") }) }}\n        {{ __("hello") }}<br /><br />\n        {{ __("password_recovery.text_confirm", {"[site]": company_name}) }}<br /><br />\n        {{ __("password_recovery.link_expire") }}:<br /><br />\n        <a href="{{ url }}">{{ url|puny_decode }}</a>\n    {{ snippet("footer") }}\n', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(31, 'reminder', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_password_notification") }}', '{{ snippet("header", {"title": __("change_password_notification") } ) }}\n\n    {{__("hello_name", {"[name]" : firstname})}}\n    <br>\n    <br> {{ __("change_password_notification_body", {"[days]": days, "[store]": store_url}) }}\n    <br>\n    <br>\n\n    <a href="{{ url }}">{{ url|puny_decode }}</a>\n    <br>\n    <br>\n\n{{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(32, 'shipment_products', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("order") }} #{{ order_info.order_id }} {{ __("new_shipment_was_created") }}', '{{ snippet("header", { "title" : __("new_shipment_was_created") }) }}\n    {{__("hello_name", {"[name]" : order_info.firstname})}}\n    <br />\n    <br /> {{ __("products_were_sent") }}\n    <br />\n    <br />\n\n    <b>{{ __("order_id") }}</b>:&nbsp;#{{ order_info.order_id }}\n    <br />\n    <b>{{ __("shipping_method") }}</b>:&nbsp;{{ shipment.shipping }}\n    <br />\n    <b>{{ __("shipment_date") }}</b>:&nbsp;{{ shipment.timestamp|date("#{settings.Appearance.date_format}, #{settings.Appearance.time_format}") }}\n    <br /> {% if shipment.carrier_info %}\n    <b>{{ __("carrier") }}</b>:&nbsp;{{ shipment.carrier_info.name }}\n    <br /> {% endif %} {% if shipment.tracking_number %}\n    <b>{{ __("tracking_number") }}</b>:&nbsp; {% if shipment.carrier_info.tracking_url %}\n    <a href="{{ shipment.carrier_info.tracking_url }}">{{ shipment.tracking_number }}</a> {% else %} {{ shipment.tracking_number }} {% endif %}\n    <br />\n    <br /> {% endif %} {{ shipment.carrier_info.info }}\n\n    <b>{{ __("products") }}:</b>\n    <p>\n      {% for hash, amount in shipment.products %} {% if amount > 0 %} {{ amount }}<span dir="{$language_direction}">&nbsp;x&nbsp;</span>{{ order_info.products[hash].product }}\n      <br /> {% if order_info.products[hash].product_options %} {% for option in order_info.products[hash].product_options %} {{ option.option_name }}:&nbsp;{{ option.variant_name }}{% if not loop.last%}, {% endif %} {% endfor %}\n      <br /> {% endif %}\n      <br /> {% endif %} {% endfor %}\n    </p>\n\n    {% if shipment.comments %}\n    <br />\n    <br />\n    <b>{{ __("comments") }}</b>: {{ shipment.comments }} {% endif %}\n\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(33, 'track', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("track_request_subj") }}', '{{ snippet("header", { "title" : __("track_request_subj") }) }}\n    {{ __("hello") }},\n    <br />\n    <br /> {{ __("text_track_request") }}\n    <br />\n    <br /> {% if order_id %} {{ __("text_track_view_order", {"[order]": order_id}) }}\n    <br />\n    <a href="{{ url }}">{{ url|puny_decode }}</a>\n    <br />\n    <br /> {% endif %} {{ __("text_track_view_all_orders") }}\n    <br />\n    <a href="{{ track_all_url }}">{{ track_all_url|puny_decode }}</a>\n    <br />\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(34, 'update_profile', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("update_profile_notification") }}', '{{ snippet("header", {"title": __("update_profile_notification")} ) }}\n    {% if user_data.firstname %} {{__("hello_name", {"[name]" : user_data.firstname})}} {% else %} {{ __("hello") }}, {% endif %}\n    <br>\n    {{ __("update_profile_notification_header") }}\n    <br>\n    <strong>\n      {% if api_access_status == "enabled" %}\n        <br>{{ __("api_access_has_been_enabled") }}<br>\n      {% elseif api_access_status == "disabled" %}\n        <br>{{ __("api_access_has_been_disabled") }}<br>\n      {% endif %}\n    </strong>\n    <br>\n    <h4 class="with-subline">{{ __("user_account_information") }}</h4>\n    <table border="0" width="100%" class="info">\n      <tr>\n        <td><b>{{ __("login_url") }}:</b></td>\n        <td><a href="{{ login_url }}">{{ login_url|puny_decode }}</a></td>\n      </tr>\n      <tr>\n        <td><b>{{ __("email") }}:</b></td>\n        <td><a>{{ user_data.email }}</a></td>\n      </tr>\n      <tr>\n        <td><b>{{ __("password") }}:</b></td>\n        <td> *********** (<a href="{{ forgot_pass_url }}">{{ __("forgot_password_question") }}</a>)</td>\n      </tr>\n    </table>\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(35, 'update_profile', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("update_profile_notification") }}', '{{ snippet("header", {"title": __("update_profile_notification_header")} ) }}\n    {% if user_data.firstname %} {{__("hello_name", {"[name]" : user_data.firstname})}} {% else %} {{ __("hello") }}, {% endif %}\n    <br>\n    {{ __("update_profile_notification_header") }}\n    <br>\n    <br>\n    <h4 class="with-subline">{{ __("user_account_information") }}</h4>\n    <table border="0" width="100%" class="info">\n      <tr>\n        <td><b>{{ __("login_url") }}:</b></td>\n        <td><a href="{{ login_url }}">{{ login_url|puny_decode }}</a></td>\n      </tr>\n      <tr>\n        <td><b>{{ __("email") }}:</b></td>\n        <td><a>{{ user_data.email }}</a></td>\n      </tr>\n      <tr>\n        <td><b>{{ __("password") }}:</b></td>\n        <td> *********** (<a href="{{ forgot_pass_url }}">{{ __("forgot_password_question") }}</a>)</td>\n      </tr>\n    </table>\n    <br>\n    <table class="info" width="269" align="left">\n      <tr>\n        <td>\n          <h4 class="with-subline">{{ __("billing_address") }}</h4>\n          <strong>{{ user_data.b_firstname }} {{ user_data.b_lastname }}</strong><br>\n          {{ user_data.b_address_2 }} {{ user_data.b_address }}<br>\n          {{ user_data.b_city }} {{ user_data.b_country }} <br>\n          {{ user_data.b_phone }} <br>\n        </td>\n      </tr>\n    </table>\n\n    <table class="info" width="269" align="left">\n      <tr>\n        <td>\n          <h4 class="with-subline">{{ __("shipping") }} {{ __("address") }}</h4>\n          <strong>{{ user_data.s_firstname }} {{ user_data.s_lastname }}</strong><br>\n          {{ user_data.s_address_2 }} {{ user_data.s_address }}<br>\n          {{ user_data.s_city }} {{ user_data.s_country }} <br>\n          {{ user_data.s_phone }} <br>\n        </td>\n      </tr>\n    </table>\n\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(36, 'upgrade_backup_info', 'A', 'A', NULL, NULL, '{% if backup_file is not defined %} {{__("uc_info_subj")}} {% else %} {{ __("uc_backup_info_subj") }} {% endif %}', '{% if backup_file is not defined %}\n    {{ snippet("header", {"title": __("uc_info_subj")}) }}\n    {{__("uc_open_store_email_body",  {"[settings_section]":  settings_section_url}) }}\n{% else %}\n{{ snippet("header", {"title": __("uc_backup_info_subj") } ) }}\n{{ __("uc_restore_email_body", {"[backup_file]": backup_file, "[settings_section]": settings_section_url}) }}\n    <p>\n      {{restore_link}}\n    </p>\n{% endif %}\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(37, 'usergroup_activation', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("usergroup_activated") }}', '{{ snippet("header", {"title": __("usergroup_activated") } ) }}\n    {{ __("text_usergroup_activated", {"[usergroups]": usergroups}) }}\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(38, 'usergroup_activation', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("usergroup_activated") }}', '{{ snippet("header", {"title": __("usergroup_activated") } ) }}\n    {{ __("text_usergroup_activated", {"[usergroups]": usergroups}) }}\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(39, 'usergroup_disactivation', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("usergroup_disactivated") }}', '{{ snippet("header", {"title": __("usergroup_disactivated") } ) }}\n    {{ __("text_usergroup_disactivated", {"[usergroups]": usergroups}) }}\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(40, 'usergroup_disactivation', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("usergroup_disactivated") }}', '{{ snippet("header", {"title": __("usergroup_disactivated") } ) }}\n    {{ __("text_usergroup_disactivated", {"[usergroups]": usergroups}) }}\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(41, 'usergroup_request', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("usergroup_request_by_customer") }} "{{ user_data.email }}"', '{{ snippet("header", {"title": __("usergroup_request_by_customer") } ) }}\n    {{ __("text_usergroup_requested_by", {"[usergroup]": usergroup, "[name]": "#{user_data.firstname} #{user_data.lastname}" , "[email]": user_data.email}) }}\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(42, 'one_time_password_request', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("email.one_time_password.title") }}', '{{ snippet("header", {"title": __("email.one_time_password.title") } ) }}\n    {{ __("email.one_time_password.message", {"[storefront_url]": storefront_url, "[password]": password}) }}\n  {{ snippet("footer") }}', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(43, 'newsletters_newsletter', 'C', 'A', NULL, NULL, '{{ subject }}', '{{ snippet("header") }}\n\n{{ body }}\n\n{{ snippet("footer") }}', NULL, NULL, 'newsletters', [[timestamp]], [[timestamp]]),
(44, 'newsletters_promotion', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ subject }}', '{{ snippet("header") }}\n\n <h1>{{ promotion.name }}</h1> {{ __("discount_coupon_code") }}: <b>{{ coupon }}</b> {{ promotion.short_description }}<br/> {{ __("more_info") }}: <a href="{{ url }}">{{ url|puny_decode }}</a>\n{{ snippet("footer") }}', NULL, NULL, 'newsletters', [[timestamp]], [[timestamp]]),
(45, 'email_marketing_confirmation', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("email_marketing.confirm_subscription") }}', '{{ snippet("header") }}\n\n{{ __("email_marketing.text_confirm_subscription", {"[href]": url}) }}\n\n{{ snippet("footer") }}', NULL, NULL, 'email_marketing', [[timestamp]], [[timestamp]]),
(46, 'email_marketing_welcome', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("email_marketing.email_subscribed") }}', '{{ snippet("header") }}\n{{ __("email_marketing.text_email_subscribed", {"[href]": url}) }}\n{{ snippet("footer") }}', NULL, NULL, 'email_marketing', [[timestamp]], [[timestamp]]),
(47, 'email_marketing_welcome_2optin', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("email_marketing.email_subscribed_2optin") }}', '{{ snippet("header") }}\n\n{{ __("email_marketing.text_email_subscribed_2optin", {"[href]": url}) }}\n\n{{ snippet("footer") }}', NULL, NULL, 'email_marketing', [[timestamp]], [[timestamp]]),
(48, 'vendor_communication.notify_admin', 'A', 'A', NULL, NULL, '{{ __("vendor_communication.subject_email", {"[message_from]": message_from}) }}', '\n                {{ snippet("header") }}\n                <p>\n                    {{ __("hello") }},\n                </p>\n                <p>\n                    {{ __("vendor_communication.you_have_new_message", {"[thread_url]": thread_url, "[message_from]": message_from}) }}\n                </p>\n                {{ snippet("footer") }}\n            ', NULL, NULL, 'vendor_communication', [[timestamp]], [[timestamp]]),
(49, 'vendor_communication.notify_customer', 'C', 'A', NULL, NULL, '{{ __("vendor_communication.subject_email", {"[message_from]": message_from}) }}', '\n                {{ snippet("header") }}\n                <p>\n                    {{ __("hello") }},\n                </p>\n                <p>\n                    {{ __("vendor_communication.you_have_new_message", {"[thread_url]": thread_url, "[message_from]": message_from}) }}\n                </p>\n                {{ snippet("footer") }}\n            ', NULL, NULL, 'vendor_communication', [[timestamp]], [[timestamp]]),
(50, 'gift_certificates_notification', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("gift_certificate") }} {{ certificate_info.gift_cert_code }} {{ certificate_status.email_subj }}', '{% set title %}\n{{__("gift_certificate")}} {{ certificate_info.gift_cert_code }} {{ certificate_status.email_subj }}\n{% endset %}\n{{ snippet("header", {"title": title }  ) }}\n\n<p>\n                     {% if gift_cert_data.recipient %}\n                     {{__("hello_name", {"[name]" : gift_cert_data.recipient})}}\n                     {% else %}\n                     {{ __("hello") }},\n                     {% endif %}<br/>\n                      {{ certificate_status.email_header }}<br />\n                     {{__("gift_cert_from")}}: {{gift_cert_data.sender}}    {{__("gift_cert_to")}}: {{gift_cert_data.recipient}}<br />\n                     </p>\n                </td>\n           </tr>\n\n           <tr>\n                <td width="600px" valign="top" align="center" >\n                  {{ include_doc("gift_certificate.default", gift_cert_data.gift_cert_id) }}{{ snippet("footer") }}', NULL, NULL, 'gift_certificates', [[timestamp]], [[timestamp]]),
(51, 'rma_slip_notification', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("rma_return") }} #{{ return_info.return_id }} {{ return_status.email_subj }}', '{{ snippet("header") }}\n\n{% if order_info.firstname %}\n  {{__("hello_name", {"[name]" : order_info.firstname})}}<br /><br />\n{% else %}\n  {{ __("hello") }},<br /><br />\n{% endif %}\n\n{{ return_status.email_header }}<br /><br />\n\n<b>{{ __("packing_slip") }}:</b><br />\n\n{{ include_doc("rma_packing_slip.default", return_info.return_id) }}\n{{ snippet("footer") }}', NULL, NULL, 'rma', [[timestamp]], [[timestamp]]),
(52, 'rma_slip_notification', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("rma_return") }} #{{ return_info.return_id }} {{ return_status.email_subj }}', '{{ snippet("header") }}\n\n\n{% if order_info.firstname %}\n  {{__("hello_name", {"[name]" : order_info.firstname})}}<br /><br />\n{% else %}\n  {{ __("hello") }},<br /><br />\n{% endif %}\n\n{{ return_status.email_header }}<br /><br />\n\n<b>{{ __("packing_slip") }}:</b><br />\n\n{{ include_doc("rma_packing_slip.default", return_info.return_id) }}\n{{ snippet("footer") }}\n', NULL, NULL, 'rma', [[timestamp]], [[timestamp]]),
(53, 'reward_points_notification', 'C', 'A', NULL, NULL, '{{ company_name }}: {% if reason.action == ''A'' %}{{ __("reward_points_subj_added_to", [reason.amount]) }}{% else %}{{ __("reward_points_subj_subtracted_from", [reason.amount]) }}{% endif %}', '{{ snippet("header") }}\n{% if user_data.firstname %}\n  {{__("hello_name", {"[name]" : user_data.firstname})}}\n{% else %}\n  {{ __("hello") }},\n{% endif %}<br /><br />\n{{ __("we_would_like_to_inform") }}: {% if reason.action == ''A'' %}{{ __("reward_points_subj_added_to", [reason.amount]) }}{% else %}{{ __("reward_points_subj_subtracted_from", [reason.amount]) }}{% endif %}<br />\n\n<b>{{ __("reason") }}:</b><br />\n{{ reason.reason }}\n\n{{ snippet("footer") }}', NULL, NULL, 'reward_points', [[timestamp]], [[timestamp]]),
(54, 'call_requests_buy_with_one_click', 'A', 'A', NULL, NULL, '{{ __("call_requests") }}', '{{ snippet("header") }}\n\n {{ __("call_requests.text_buy_with_one_click_request", {"[customer]": customer, "[href]": url, "[phone_number]": phone_number, "[product_href]": product_url, "[product_name]": product_name}) }}\n\n{{ snippet("footer") }}', NULL, NULL, 'call_requests', [[timestamp]], [[timestamp]]),
(55, 'call_requests_call_request', 'A', 'A', NULL, NULL, '{{ __("call_requests") }}', '{{ snippet("header") }}\n\n {{ __("call_requests.text_call_request", {"[customer]": customer, "[href]": url, "[phone_number]": phone_number}) }} <br /> {{ __("call_requests.text_call_request_call_time", {"[time_from]": time_from, "[time_to]": time_to}) }}\n\n{{ snippet("footer") }}', NULL, NULL, 'call_requests', [[timestamp]], [[timestamp]]),
(56, 'order_notification.y', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_default_subj", {"[order]": order_info.order_id, "[status]": order_status.description}) }}', '{{ snippet("header", {"title": __("change_order_status_default_subj", {"[order]": order_info.order_id, "[status]": order_status.description}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(57, 'order_notification.y', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("change_order_status_default_subj", {"[order]": order_info.order_id, "[status]": order_status.description}) }}', '{{ snippet("header", {"title": __("change_order_status_default_subj", {"[order]": order_info.order_id, "[status]": order_status.description}) } ) }}\n    {% if order_info.firstname %}{{__("hello_name", {"[name]" : order_info.firstname})}} {% else %} {{ __("hello") }},  {{ __("customer") }} {% endif %}\n    <br />\n    {{ __("change_order_status_default_text", {"[status]": order_status.description}) }}\n    <br />\n    <br /> {{ include_doc("order.summary", order_info.order_id) }}\n  {{ snippet("footer") }}', '{"attach_order_document":{"type":"selectbox","title":"email_template.params.attach_order_document","func":"fn_emails_get_order_document_variants"}}', '{"attach_order_document":""}', '', [[timestamp]], [[timestamp]]),
(58, 'form_builder_form', 'A', 'A', NULL, NULL, '{{ form_title }}', '{{ snippet("header") }}\n\n  <table>\n{% for element_id, element in elements %}\n{% if element.element_type == constant("FORM_SEPARATOR") %}\n<tr>\n    <td colspan="2"><hr width="100%" /></td>\n</tr>\n{% elseif element.element_type == constant("FORM_HEADER") %}\n<tr>\n    <td colspan="2"><b>{{ element.description }}</b></td>\n</tr>\n{% elseif element.element_type != constant("FORM_FILE") %}\n<tr>\n    <td>{{ element.description }}:&nbsp;</td>\n    <td>\n        {% set value=form_values[element_id] %}\n\n        {% if element.element_type == constant("FORM_SELECT") or element.element_type == constant("FORM_RADIO") %}\n            {{ element.variants[value].description }}\n        {% elseif element.element_type == constant("FORM_CHECKBOX") %}\n            {% if value == ''Y'' %}{{ __("yes") }}{% else %}{{ __("no") }}{% endif %}\n        {% elseif element.element_type == constant("FORM_TEXTAREA") %}\n            {{ value|nl2br }}\n        {% elseif element.element_type == constant("FORM_DATE") %}\n            {{ value|date(settings.Appearance.date_format) }}\n        {% else %}\n            {{ value }}\n        {% endif %}\n    </td>\n</tr>\n{% endif %}\n{% endfor %}\n</table>\n\n{{ snippet("footer") }}', NULL, NULL, 'form_builder', [[timestamp]], [[timestamp]]),
(59, 'discussion_notification', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ subject }}', '{{ snippet("header") }}\n\n  {{ __("hello") }},<br /><br />\n\n{{ __("text_new_post_notification") }}&nbsp;<b>{{ __(object_name) }}</b>:&nbsp;{{ object_data.description }}\n<br /><br />\n<b>{{ __("person_name") }}</b>:&nbsp;{{ post_data.name }}<br />\n{% if post_data.rating_value %}\n<b>{{ __("rating") }}</b>:&nbsp;{% if post_data.rating_value == "5" %}{{ __("excellent") }}{% elseif post_data.rating_value == "4" %}{{ __("very_good") }}{% elseif post_data.rating_value == "3" %}{{ __("average") }}{% elseif post_data.rating_value == "2" %}{{ __("fair") }}{% elseif post_data.rating_value == "1" %}{{ __("poor") }}{% endif %}\n<br />\n{% endif %}\n\n{% if post_data.message %}\n<b>{{ __("message") }}</b>:<br />\n{{ post_data.message|nl2br }}\n<br /><br />\n{% endif %}\n\n{% if post_data.status == ''N'' %}\n<b>{{ __("text_approval_notice") }}</b>\n<br />\n{% endif %}\n{{ __("view") }}:<br />\n<a href="{{ url }}">{{ url|puny_decode }}</a>\n{{ snippet("footer") }}', NULL, NULL, 'discussion', [[timestamp]], [[timestamp]]),
(60, 'discussion_notification', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ subject }}', '{{ snippet("header") }}\n\n  {{ __("hello") }},<br /><br />\n\n{{ __("text_new_post_notification") }}&nbsp;<b>{{ __(object_name) }}</b>:&nbsp;{{ object_data.description }}\n<br /><br />\n<b>{{ __("person_name") }}</b>:&nbsp;{{ post_data.name }}<br />\n{% if post_data.rating_value %}\n<b>{{ __("rating") }}</b>:&nbsp;{% if post_data.rating_value == "5" %}{{ __("excellent") }}{% elseif post_data.rating_value == "4" %}{{ __("very_good") }}{% elseif post_data.rating_value == "3" %}{{ __("average") }}{% elseif post_data.rating_value == "2" %}{{ __("fair") }}{% elseif post_data.rating_value == "1" %}{{ __("poor") }}{% endif %}\n<br />\n{% endif %}\n\n{% if post_data.message %}\n<b>{{ __("message") }}</b>:<br />\n{{ post_data.message|nl2br }}\n<br /><br />\n{% endif %}\n\n{% if post_data.status == ''N'' %}\n<b>{{ __("text_approval_notice") }}</b>\n<br />\n{% endif %}\n{{ __("view") }}:<br />\n<a href="{{ url }}">{{ url|puny_decode }}</a>\n{{ snippet("footer") }}', NULL, NULL, 'discussion', [[timestamp]], [[timestamp]]),
(61, 'product_reviews_reply_notification', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("product_reviews.text_new_reply_notification") }}', '{{ snippet("header") }}\n\n  {{ __("hello") }}, {{ user_data.firstname }} {{ user_data.lastname }}<br /><br />\n\n{{ __("product_reviews.text_new_reply_notification") }}:&nbsp;<a href="{{ product_url }}">{{ product_data.product }}</a>\n<br /><br />\n\n<b>{{ __("product_reviews.reply") }}</b>:<br />\n{{ product_review_data.reply.reply|nl2br }}\n<br /><br />\n\n{{ __("view") }}:<br />\n<a href="{{ product_url }}">{{ product_url|puny_decode }}</a>\n{{ snippet("footer") }}', NULL, NULL, 'product_reviews', [[timestamp]], [[timestamp]]),
(62, 'product_reviews_notification', 'A', 'A', NULL, NULL, '{{ company_name }}: {{ __("product_reviews.text_new_post_notification") }}', '{{ snippet("header") }}\n\n  {{ __("hello") }},<br /><br />\n\n{{ __("product_reviews.text_new_post_notification") }}:&nbsp;<a href="{{ product_url }}">{{ product_data.product }}</a>\n<br /><br />\n<b>{{ __("person_name") }}</b>:&nbsp;{% if product_review_data.user_data.name %}{{ product_review_data.user_data.name }}{% else %}{{ __("customer") }}{% endif %}<br />\n\n<b>{{ __("product_reviews.rating") }}</b>:&nbsp;<span style="color:#feba0f">{% if product_review_data.rating_value == "5" %}&#9733;&#9733;&#9733;&#9733;&#9733;</span>{% elseif product_review_data.rating_value == "4" %}&#9733;&#9733;&#9733;&#9733;&#9734;{% elseif product_review_data.rating_value == "3" %}&#9733;&#9733;&#9733;&#9734;&#9734;{% elseif product_review_data.rating_value == "2" %}&#9733;&#9733;&#9734;&#9734;&#9734;{% elseif product_review_data.rating_value == "1" %}&#9733;&#9734;&#9734;&#9734;&#9734;{% endif %}</span>\n<br />\n\n{% if review_fields == ''advanced'' %}\n    {% if product_review_data.message.advantages %}\n    <b>{{ __("product_reviews.advantages") }}</b>:<br />\n    {{ product_review_data.message.advantages|nl2br }}\n    <br />\n    {% endif %}\n\n    {% if product_review_data.message.disadvantages %}\n    <b>{{ __("product_reviews.disadvantages") }}</b>:<br />\n    {{ product_review_data.message.disadvantages|nl2br }}\n    <br />\n    {% endif %}\n{% endif %}\n\n{% if product_review_data.message.comment %}\n<b>{{ __("product_reviews.comment") }}</b>:<br />\n{{ product_review_data.message.comment|nl2br }}\n<br /><br />\n{% endif %}\n\n{% if product_review_data.status == ''D'' %}\n<b>{{ __("product_reviews.text_approval_notice") }}</b>\n<br />\n{% endif %}\n{{ __("view") }}:<br />\n<a href="{{ product_review_url }}">{{ product_review_url|puny_decode }}</a>\n{{ snippet("footer") }}', NULL, NULL, 'product_reviews', [[timestamp]], [[timestamp]]),
(63, 'hybrid_auth_create_profile', 'C', 'A', NULL, NULL, '{{ company_name }}: {{ __("new_profile_notification") }}', '{{ snippet("header") }}\n\n{% if user_data.firstname %}\n{{__("hello_name", {"[name]" : user_data.firstname})}}\n{% else %}\n{{ __("hello") }},\n{% endif %}\n<br><br>\n{{ __("hybrid_auth.password_generated") }}: {{ user_data.password }}<br> <br />\n{{ __("hybrid_auth.change_password") }}: <br>\n<a href="{{ url }}">{{ url|puny_decode }}</a>\n<br />\n\n{{ snippet("footer") }}', NULL, NULL, 'hybrid_auth', [[timestamp]], [[timestamp]]);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]template_internal_notifications`
--

CREATE TABLE `[[dbprefix]]template_internal_notifications` (
  `template_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `code` varchar(128) NOT NULL,
  `area` char(1) NOT NULL DEFAULT 'C',
  `status` char(1) NOT NULL DEFAULT 'A',
  `subject` text,
  `template` text,
  `default_subject` text,
  `default_template` text,
  `params_schema` text,
  `params` text,
  `addon` varchar(32) NOT NULL DEFAULT '',
  `updated` int(10) unsigned NOT NULL DEFAULT '0',
  `created` int(10) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`template_id`),
  UNIQUE KEY `template` (`code`,`area`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=2 ;

--
-- Dumping data for table `[[dbprefix]]template_internal_notifications`
--

INSERT INTO `[[dbprefix]]template_internal_notifications` VALUES
(1, 'vendor_communication_message_received', 'A', 'A', NULL, NULL, '{% if is_vendor_to_admin %}{{ __("vendor_communication.subject_email", {"[message_from]": message_author}) }}{% else %}{{ __("vendor_communication.new_message.title", {"[customer]": message_author, "[company_name]": company_name}) }}{% endif %}', '{{ __("vendor_communication.new_message.message") }}', NULL, NULL, 'vendor_communication', [[timestamp]], [[timestamp]]);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]template_snippets`
--

CREATE TABLE `[[dbprefix]]template_snippets` (
  `snippet_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `code` varchar(128) NOT NULL DEFAULT '',
  `type` varchar(32) NOT NULL DEFAULT '',
  `template` text,
  `default_template` text,
  `status` char(1) NOT NULL DEFAULT '',
  `params` text,
  `handler` text,
  `addon` varchar(32) NOT NULL DEFAULT '',
  `updated` int(11) unsigned NOT NULL DEFAULT '0',
  `created` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`snippet_id`),
  UNIQUE KEY `code` (`code`,`type`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=30 ;

--
-- Dumping data for table `[[dbprefix]]template_snippets`
--

INSERT INTO `[[dbprefix]]template_snippets` VALUES
(1, 'footer', 'mail', NULL, '</td>\n\n</tr>\n\n<tr class="message-footer">\n<td>\n<table class="info ty-email-footer-left-part" width="250" align="left">\n  <tr>\n    <th class="footer-contact__title ty-email-footer" style="text-align: center;">\n      {{ __("contact_information") }}\n    </th>\n  </tr>\n  <tr>\n    <td class="ty-email-footer" style="text-align: center;">\n      <address>{{ company_data.company_address }}, {{ company_data.company_city }}</address>\n    </td>\n  </tr>\n</table>\n\n<table class="info ty-email-footer-right-part" width="250" align="right">\n  <tr>\n    <th class="footer-social__title ty-email-footer" style="text-align: center;">\n      {{ __("get_social") }}\n    </th>\n  </tr>\n  <tr>\n    <td class="ty-email-footer-social-buttons footer-social">\n      <table cellspacing="0" cellpadding="0" align="center">\n        <tr>\n          <td>\n            <a href="http://www.facebook.com"><img width="30" height="30" src="design/themes/responsive/mail/media/images/social/facebook.png"></a>\n          </td>\n          <td>\n            <a href="https://twitter.com"><img width="30" height="30" src="design/themes/responsive/mail/media/images/social/twitter.png"></a>\n          </td>\n        </tr>\n      </table>\n    </td>\n  </tr>\n</table>\n</td>\n</tr>\n{% if company_data.company_name %}\n<tr class="message-copyright">\n<td>\n<table class="copyright" width="100%">\n<tr>\n  <td>\n    &copy;&nbsp;{{ company_data.company_name }}\n  </td>\n  <td align="right">\n    {{ __("customer_text_letter_footer") }}\n  </td>\n</tr>\n</table>\n</td>\n</tr>\n{% endif %}\n</table>\n<!-- content-wrapper -->\n</td>\n</tr>\n</table>\n<!-- main-wrapper -->\n</body>\n</html>', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(2, 'header', 'mail', NULL, '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">\n<html xmlns="http://www.w3.org/1999/xhtml">\n\n<head>\n  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />\n  <meta name="viewport" content="width=device-width, initial-scale=1.0" />\n  <title>{{ company_name }}: Message title</title>\n  <style type="text/css">\n    #outlook a {\n      padding: 0;\n    }\n\n    body {\n      width: 100% !important;\n      -webkit-text-size-adjust: 100%;\n      -ms-text-size-adjust: 100%;\n      margin: 0;\n      padding: 0;\n    }\n\n    img {\n      outline: none;\n      text-decoration: none;\n      -ms-interpolation-mode: bicubic;\n    }\n\n    a {\n      outline: none;\n    }\n\n    a img {\n      border: none;\n    }\n\n    .image_fix {\n      display: block;\n    }\n\n    .message-header > td {\n      padding: 10px 30px 20px 30px;\n    }\n\n    .message-header__title {\n      background-color: {% if styles.links %}{{styles.links}}{% else %}#999{% endif %}\n    }\n\n    .message-header__title > td {\n      padding: 20px 30px;\n    }\n\n    .message-header__title h1 {\n      font-size: 20px;\n      text-transform: uppercase;\n      font-weight: normal;\n      color: #Fff;\n    }\n\n    .message-title > td,\n    .message-body > td {\n      padding: 30px;\n    }\n\n    .message-footer > td {\n      padding: 20px 30px;\n      background-color: #757f83;\n    }\n\n    .message-copyright > td {\n      padding: 0px 30px 10px;\n    }\n\n    .message-header td,\n    .message-title td,\n    .message-body th, .message-body td,\n    .message-footer th, .message-footer td,\n    .message-copyright th, .message-copyright td {\n      color: {{styles.font}};\n      font-size: {{styles.body_font_size}};\n      font-family: {{styles.body_font}},Helvetica,Arial,sans-serif;\n    }\n\n    .message-footer {\n      border-top: 1px solid {{styles.base}}\n    }\n\n    .message-body table th,\n    .message-footer table th {\n      text-transform: uppercase;\n      border-bottom: 1px solid {{styles.base}};\n      text-align: left;\n    }\n\n    .message-body table td,\n    .message-footer table td {\n      padding: 5px;\n    }\n\n    .message-footer table th{\n        border: none;\n    }\n\n    .message-footer td {\n      color: #fff;\n    }\n\n    .footer-contact__title {\n      margin: 0px;\n      text-transform: uppercase;\n      font-size: 16px !important;\n      font-weight: bold;\n      color: #fff !important;\n    }\n\n    .footer-social__title {\n      margin: 0px;\n      text-transform: uppercase;\n      font-size: 16px !important;\n      font-weight: bold;\n      color: #fff !important;\n    }\n\n    .message-footer table td.footer-social td {\n      padding: 0px;\n      padding-right: 10px;\n    }\n\n    .email-preview{\n      display:none;\n      font-size:1px;\n      color:#333333;\n      line-height:1px;\n      max-height:0px;\n      max-width:0px;\n      opacity:0;\n      overflow:hidden;\n    }\n\n    .with-subline {\n      color: {{styles.font}};\n      text-transform: uppercase;\n      font-weight: bold;\n      font-size: 1em;\n      padding-bottom: 10px;\n      border-bottom: 1px solid #D4D4D4;\n    }\n\n    p {\n      margin: 1em 0;\n    }\n\n    h1,h2,h3,h4,h5,h6 {\n      color: {{styles.font}};\n    }\n\n    h1 a,h2 a,h3 a,h4 a,h5 a,h6 a {\n      color: {{styles.links}};\n    }\n\n    h1 a:active,h2 a:active,h3 a:active,h4 a:active,h5 a:active,h6 a:active {\n      color: red;\n    }\n\n    h1 a:visited,h2 a:visited,h3 a:visited,h4 a:visited,h5 a:visited,h6 a:visited {\n      color: purple;\n    }\n\n    table td,\n    table th {\n      border-collapse: collapse;\n    }\n\n    table {\n      border-collapse: collapse;\n      mso-table-lspace: 0pt;\n      mso-table-rspace: 0pt;\n    }\n\n    address {\n      margin: 0px;\n    }\n\n    .content-wrapper {\n      border: 1px solid {{ styles.base }};\n      background-color: {{ styles.general_bg_color }};\n    }\n\n    .copyright td {\n      padding: 10px 0 0 0;\n      padding-bottom: 0 !important;\n    }\n\n    a {\n      color: {{styles.links}};\n    }\n\n    {% if language_direction == "rtl" %}\n\n    .ty-email-footer {\n      text-align: center !important;\n    }\n\n    .ty-email-footer-social-buttons {\n      text-align: center !important;\n    }\n\n    .ty-email-footer-right-part {\n      text-align: center !important;\n      float: left !important;\n    }\n\n    .ty-email-footer-left-part {\n      text-align: center !important;\n      float: right !important;\n    }\n\n    {% endif %}\n\n  </style>\n</head>\n\n<body>\n    <style>\n\n      @media only screen and (max-device-width: 480px){\n        .content-wrapper{width: 100% !important;border: 3px solid #ccc !important; }\n\n        .message-header > td,\n        .message-title > td,\n        .message-body > td,\n        .message-footer > td,\n        .message-copyright > td {\n          padding: 10px !important;\n        }\n\n        .message-header td,\n        .message-title td,\n        .message-body th, .message-body td,\n        .message-footer th, .message-footer td,\n        .message-copyright th, .message-copyright td {\n          font-size: 16px !important;\n        }\n      }\n\n      @media only screen and (min-device-width: 768px) and (max-device-width: 1024px) {}\n\n      @media only screen and (-webkit-min-device-pixel-ratio: 2) {}\n\n      @media only screen and (-webkit-device-pixel-ratio:.75) {}\n\n      @media only screen and (-webkit-device-pixel-ratio:1) {}\n\n      @media only screen and (-webkit-device-pixel-ratio:1.5) {}\n    </style>\n  <!-- Targeting Windows Mobile -->\n  <!--[if IEMobile 7]>\n  <style type="text/css">\n\n  </style>\n  <![endif]-->\n\n  <!--[if gte mso 9]>\n    <style>\n        /* Target Outlook 2007 and 2010 */\n    </style>\n  <![endif]-->\n  <table class="main-wrapper" cellpadding="0" cellspacing="0" width="100%" bgcolor="{{ styles.base }}" style="background-color: {{ styles.base }}" dir="{{ language_direction }}">\n    <tr>\n      <td style="padding: 40px 10px 40px 10px;">\n        <table class="content-wrapper" cellpadding="0" cellspacing="0" align="center" width="600">\n          <tr class="message-header">\n            <td>\n              <table cellpadding="0" cellspacing="0" width="100%">\n                <tr>\n                  <td><a href="{{ storefront_data.url }}"><img src="{{logos.mail.image.image_path}}" alt="{{ company_data.company_name }}" width="{{logos.mail.image.image_x}}" height="{{logos.mail.image.image_y}}" style="width: auto; max-width: 300px; max-height: 150px;" /></a></td>\n                </tr>\n              </table>\n            </td>\n          </tr>\n          {% if title %}\n          <tr class="message-header__title">\n            <td>\n              <h1>{{title}}</h1>\n            </td>\n          </tr>\n          {% endif %}\n\n          <tr class="message-body">\n\n<td>', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(3, 'bill_to', 'order_invoice', NULL, '\n        {% if u.b_firstname or u.b_lastname or u.b_address or u.b_address_2 or u.b_city or u.b_state_descr or u.b_zipcode %}\n        <h2 style="margin: 0px; font-size: 22px; font-family: Helvetica, Arial, sans-serif; color: #444444; text-transform: uppercase; padding-bottom: 20px; border-bottom: 3px solid #e8e8e8; margin-bottom: 20px;">{{__("bill_to")}}</h2>\n        <p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">\n            <strong>{{u.b_firstname}} {{u.b_lastname}}</strong>\n        </p>\n        <p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">\n            {{u.b_address}} <br>{{u.b_address_2}}\n        </p>\n        <p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">\n            {{u.b_city}}, {{u.b_state_descr}} {{u.b_zipcode}}\n        </p>\n        <p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">\n            {{u.b_country_descr}}\n        </p>\n        <p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">\n            <span dir="ltr">{{u.b_phone}}</span>\n        </p>\n        {% endif %}\n', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(4, 'company_address', 'order_invoice', NULL, '{% set parts = [c.city] %}\n{% if c.state_descr %}\n    <p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">{% set parts = parts|merge([c.state_descr]) %}</p>\n{% endif %}\n\n<p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">{{ c.address }}</p>\n<p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">{{ parts|join('', '') }} {{ c.zipcode }}</p>\n<p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">{{ c.country_descr }} </p>\n<p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;"><span dir="ltr">{{ c.phone }} </span></p>\n<p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">{{ c.users_department }} </p>\n<p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">{{ c.website }} </p>\n', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(5, 'products_table', 'order_invoice', NULL, '{% if products_table.rows %}\n<table width="100%" cellspacing="0" cellpadding="0" border="0" style="border-top: 3px solid #444; color: #444;  text-transofrm: uppercase; border-collapse: separate; font-family: Helvetica, Arial, sans-serif;">\n    <tbody>\n        <tr style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; font-weight: bold; text-transform: uppercase; text-align: center; vertical-aling: top;">\n            {% for  header in products_table.headers %}\n                <td style="padding:10px; font-family: Helvetica, Arial, sans-serif;">{{ header }}</td>\n            {% endfor %}\n        </tr>\n        {% for  row in products_table.rows %}\n            <tr style="font-size: 14px; font-family: Helvetica, Arial, sans-serif; font-weight: normal; text-transform: uppercase; text-align: center; vertical-aling: middle;">\n                {% for  column in row %}\n                    <td style="padding:10px 0px; border-bottom: 1px solid #ebebeb; font-family: Helvetica, Arial, sans-serif;">{{ column }}</td>\n                {% endfor %}\n            </tr>\n        {% endfor %}\n    </tbody>\n</table>\n{% endif %}', 'A', '{"used_table":"1","variable_schema":"order_products_table"}', '"fn_snippet_init_order_product_table_variable"', '', [[timestamp]], [[timestamp]]),
(6, 'ship_to', 'order_invoice', NULL, '<h2 style="margin: 0px; font-size: 22px; font-family: Helvetica, Arial, sans-serif; color: #444444; text-transform: uppercase; padding-bottom: 20px; border-bottom: 3px solid #e8e8e8; margin-bottom: 20px;">{{__("ship_to")}}</h2>\n    <p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">\n        {% if u.s_firstname %}\n            <strong>{{u.s_firstname}} {{u.s_lastname}}</strong>\n        {% else %}\n            <strong>{{u.firstname}} {{u.lastname}}</strong>\n        {% endif %}\n    </p>\n    <p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">\n        {{u.s_address}} <br>{{u.s_address_2}}\n    </p>\n    <p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">\n        {{u.s_city}}, {{u.s_state_descr}} {{u.s_zipcode}}\n    </p>\n    <p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">\n        {{u.s_country_descr}}\n    </p>\n    <p style="margin: 0px; padding-bottom: 5px; font-family: Helvetica, Arial, sans-serif;">\n        {% if u.s_phone %}\n            <span dir="ltr">{{u.s_phone}}</span>\n        {% else %}\n            <span dir="ltr">{{u.phone}}</span>\n        {% endif %}\n    </p>\n', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(7, 'pickup_point', 'order_invoice', NULL, '<h2 style="margin: 0px; font-size: 22px; font-family: Helvetica, Arial, sans-serif; color: #444444; text-transform: uppercase; padding-bottom: 20px; border-bottom: 3px solid #e8e8e8; margin-bottom: 20px;">{{__("ship_to")}}</h2>\n{% if pickup_point.name %}\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        <strong>{{ pickup_point.name }}</strong>\n    </p>\n{% endif %}\n{% if pickup_point.full_address %}\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        {{ pickup_point.full_address }}\n    </p>\n{% endif %}\n{% if pickup_point.phone %}\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        <strong>{{ __("phone") }}:</strong>\n        <span dir="ltr">{{ pickup_point.phone }}</span>\n    </p>\n{% endif %}\n{% if pickup_point.open_hours %}\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        <strong>{{ __("open_hours") }}:</strong><br/>\n        {{ pickup_point.open_hours }}\n    </p>\n{% endif %}\n{% if pickup_point.description %}\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        <strong>{{ __("description") }}:</strong><br/>\n        {{ pickup_point.description }}\n    </p>\n{% endif %}', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(8, 'products_table', 'order_summary', NULL, '{% if products_table.rows %}\n<table width="100%" cellspacing="0" cellpadding="0" border="0" style="border-top: 3px solid #444; color: #444;  text-transofrm: uppercase; border-collapse: separate; font-family: Helvetica, Arial, sans-serif;">\n    <tbody>\n        <tr style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; font-weight: bold; text-transform: uppercase; text-align: center; vertical-aling: top;">\n            {% for  header in products_table.headers %}\n                <td style="padding:10px; font-family: Helvetica, Arial, sans-serif;">{{ header }}</td>\n            {% endfor %}\n        </tr>\n        {% for  row in products_table.rows %}\n            <tr style="font-size: 14px; font-family: Helvetica, Arial, sans-serif; font-weight: normal; text-transform: uppercase; text-align: center; vertical-aling: middle;">\n                {% for  column in row %}\n                    <td style="padding:10px 0px; border-bottom: 1px solid #ebebeb; font-family: Helvetica, Arial, sans-serif;">{{ column }}</td>\n                {% endfor %}\n            </tr>\n        {% endfor %}\n    </tbody>\n</table>\n{% endif %}', 'A', '{"used_table":"1","variable_schema":"order_products_table"}', '"fn_snippet_init_order_product_table_variable"', '', [[timestamp]], [[timestamp]]),
(9, 'ship_to', 'order_summary', NULL, '<h2 style="margin: 0px; font-size: 22px; font-family: Helvetica, Arial, sans-serif; color: #444444; text-transform: uppercase; margin-bottom: 15px; line-height: 1.5em; ">{{__("ship_to")}}</h2>\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        <strong>{{u.firstname}} {{u.lastname}}</strong>\n    </p>\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        {{u.s_address}} <br>{{u.s_address_2}}\n    </p>\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        {{u.s_city}}, {{u.s_state_descr}} {{u.s_zipcode}}\n    </p>\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        {{u.s_country_descr}}\n    </p>\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        <span dir="ltr">{{u.phone}}</span>\n    </p>\n', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(10, 'pickup_point', 'order_summary', NULL, '<h2 style="margin: 0px; font-size: 22px; font-family: Helvetica, Arial, sans-serif; color: #444444; text-transform: uppercase; margin-bottom: 15px; line-height: 1.5em; ">{{__("ship_to")}}</h2>\n{% if pickup_point.name %}\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        <strong>{{ pickup_point.name }}</strong>\n    </p>\n{% endif %}\n{% if pickup_point.full_address %}\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        {{ pickup_point.full_address }}\n    </p>\n{% endif %}\n{% if pickup_point.phone %}\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        <strong>{{ __("phone") }}:</strong>\n        <span dir="ltr">{{ pickup_point.phone }}</span>\n    </p>\n{% endif %}\n{% if pickup_point.open_hours %}\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        <strong>{{ __("open_hours") }}:</strong><br/>\n        {{ pickup_point.open_hours }}\n    </p>\n{% endif %}\n{% if pickup_point.description %}\n    <p style="margin: 0px; font-size:14px; font-family: Helvetica, Arial, sans-serif; padding-bottom: 5px;">\n        <strong>{{ __("description") }}:</strong><br/>\n        {{ pickup_point.description }}\n    </p>\n{% endif %}', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(11, 'bill_to', 'packing_slip_default', NULL, '\n    {% if u.b_firstname or u.b_lastname or u.b_address or u.b_address_2 or u.b_city or u.b_state_descr or u.b_zipcode %}\n    <h3 style=" padding: 0px 0px 10px 1px; font-weight: bold; font-size: 15px; font-family: Helvetica, Arial, sans-serif; border-bottom: 1px solid #ededed;">{{__("bill_to")}}:</h3>\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        {{u.b_firstname}} {{u.b_lastname}}\n    </p>\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        {{u.b_address}} <br>{{u.b_address_2}}\n    </p>\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        {{u.b_city}}, {{u.b_state_descr}} {{u.b_zipcode}}\n    </p>\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        {{u.b_country_descr}}\n    </p>\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        <span dir="ltr">{{u.b_phone}}</span>\n    </p>\n    {% endif %}\n', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(12, 'company_address', 'packing_slip_default', NULL, '{% set parts = [c.city] %}\n{% if c.state_descr %}\n    {% set parts = parts|merge([c.state_descr]) %}\n{% endif %}\n\n{{ c.address }} <br />\n{{ parts|join('', '') }} {{ c.zipcode }}  <br />\n{{ c.country_descr }}', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(13, 'company_info', 'packing_slip_default', NULL, '<table border="0" cellpadding="0" cellspacing="0">\n	<tbody>\n		{% if c.phone %}\n		<tr valign="top">\n			<td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("phone1_label") }}:</td>\n			<td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" width="100%"><span dir="ltr">{{ c.phone }}</span></td>\n		</tr>\n		{% endif %}\n		{% if c.phone_2 %}\n		<tr valign="top">\n			<td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("phone2_label") }}:</td>\n			<td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" width="100%"><span dir="ltr">{{ c.phone_2 }}</span></td>\n		</tr>\n		{% endif %}\n		{% if c.website %}\n		<tr valign="top">\n			<td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("web_site") }}:</td>\n			<td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" width="100%">{{ c.website }}</td>\n		</tr>\n		{% endif %}\n		{% if c.orders_department %}\n		<tr valign="top">\n			<td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("email") }}:</td>\n			<td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" width="100%"><a href="mailto:{{ c.orders_department }}">{{ c.orders_department_display }}</a></td>\n		</tr>\n		{% endif %}\n	</tbody>\n</table>', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(14, 'order_date', 'packing_slip_default', NULL, '<h2 style="font-size: 17px; font-weight: bold; font-family: Helvetica, Arial, sans-serif; margin: 0px;">{{ __("packing_slip_for_order") }} #{{ o.order_id }}</h2>\n{% if o.shipment %}\n<table border="0" cellpadding="0" cellspacing="0">\n    <tbody>\n        <tr valign="top">\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("order_date") }}:\n            </td>\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;">{{ o.timestamp }}\n            </td>\n        </tr>\n        <tr valign="top">\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("shipment_date") }}:\n            </td>\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;">{{ o.shipment.shipment_timestamp }}\n            </td>\n        </tr>\n    </tbody>\n</table>\n{% else %}\n<table border="0" cellpadding="0" cellspacing="0">\n    <tbody>\n        <tr valign="top">\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("date") }}:\n            </td>\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;">{{ o.timestamp }}\n            </td>\n        </tr>\n    </tbody>\n</table>\n{% endif %}', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(15, 'order_info', 'packing_slip_default', NULL, '<table border="0" cellpadding="0" cellspacing="0">\n    <tbody>\n    <tr valign="top">\n        <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("status") }}:\n        </td>\n        <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" width="100%">{{ o.status.description }}\n        </td>\n    </tr>\n    <tr valign="top">\n        <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("payment_method") }}:\n        </td>\n        <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" valign="bottom">{{ p.payment|default("-") }}\n        </td>\n    </tr>\n    {% if o.shipment %}\n        {% if o.shipment.shipping %}\n        <tr valign="top">\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("shipping_method") }}:\n            </td>\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" valign="bottom">{{ o.shipment.shipping }}\n            </td>\n        </tr>\n        {% endif %}\n        {% if o.shipment.tracking_number %}\n        <tr valign="top">\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("tracking_number") }}:\n            </td>\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" valign="bottom">{{ o.shipment.tracking_number }}\n            </td>\n        </tr>\n        {% endif %}\n    {% else %}\n        {% if o.shippings_method %}\n        <tr valign="top">\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("shipping_method") }}:\n            </td>\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" valign="bottom">{{ o.shippings_method }}\n            </td>\n        </tr>\n        {% endif %}\n        {% if o.tracking_number %}\n        <tr valign="top">\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px; white-space: nowrap;">{{ __("tracking_number") }}:\n            </td>\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" valign="bottom">{{ o.tracking_number }}\n            </td>\n        </tr>\n        {% endif %}\n    {% endif %}\n\n    </tbody>\n</table>', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(16, 'notes', 'packing_slip_default', NULL, '{% if o.shipment.comments %}\n<div style="float: left; padding-top: 20px; font-family: Helvetica, Arial, sans-serif;"><strong>{{ __("comments") }}:</strong></div>\n<div style="padding-left: 7px; padding-bottom: 15px; overflow-x: auto; clear: both; width: 505px; height: 100%; padding-bottom: 20px; overflow-y: hidden; font-family: Helvetica, Arial, sans-serif;">{{ o.shipment.comments|wordwrap(90,"\\n")|nl2br }}</div>\n{% elseif o.notes %}\n<div style="float: left; padding-top: 20px;"><strong>{{ __("notes") }}:</strong></div>\n<div style="padding-left: 7px; padding-bottom: 15px; overflow-x: auto; clear: both; width: 505px; height: 100%; padding-bottom: 20px; overflow-y: hidden; font-family: Helvetica, Arial, sans-serif;">{{ o.notes|wordwrap(90, "\\n") }}</div>\n{% endif %}', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(17, 'products_table', 'packing_slip_default', NULL, '<table width="100%" cellpadding="0" cellspacing="1" style="border-collapse: separate; border-spacing: 1px; background-color: #dddddd; margin-top: 20px; font-family: Helvetica, Arial, sans-serif;">\n\n<thead>\n    <tr>\n\n        {% for  header in products_table.headers %}\n            <th style="background-color: #eeeeee; padding: 6px 10px; white-space: nowrap; font-size: 12px; text-align:center; font-family: Helvetica, Arial, sans-serif;">{{ header }}</th>\n        {% endfor %}\n    </tr>\n</thead>\n<tbody>\n    {% for  row in products_table.rows %}\n        <tr style="page-break-inside: avoid;">\n            {% for  column in row %}\n                <td style="padding: 5px 10px; background-color: #ffffff; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">{{ column }}</td>\n            {% endfor %}\n        </tr>\n    {% endfor %}\n</tbody>\n</table>', 'A', '{"used_table":"1","variable_schema":"packing_slip_products_table"}', '"fn_snippet_init_order_product_table_variable"', '', [[timestamp]], [[timestamp]]),
(18, 'ship_to', 'packing_slip_default', NULL, '<h3 style="padding: 0px 0px 10px 1px; font-weight: bold; font-size: 15px; font-family: Helvetica, Arial, sans-serif; border-bottom: 1px solid #ededed;">{{__("ship_to")}}:</h3>\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        {% if u.s_firstname %}\n            {{u.s_firstname}} {{u.s_lastname}}\n        {% else %}\n            {{u.firstname}} {{u.lastname}}\n        {% endif %}\n    </p>\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        {{u.s_address}} <br>{{u.s_address_2}}\n    </p>\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        {{u.s_city}}, {{u.s_state_descr}} {{u.s_zipcode}}\n    </p>\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        {{u.s_country_descr}}\n    </p>\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        {% if u.s_phone %}\n            <span dir="ltr">{{u.s_phone}}</span>\n        {% else %}\n            <span dir="ltr">{{u.phone}}</span>\n        {% endif %}\n    </p>\n', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(19, 'pickup_point', 'packing_slip_default', NULL, '<h2 style="margin: 0px; font-size: 22px; font-family: Helvetica, Arial, sans-serif; color: #444444; text-transform: uppercase; margin-bottom: 15px; line-height: 1.5em; ">{{__("ship_to")}}</h2>\n{% if pickup_point.name %}\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        <strong>{{ pickup_point.name }}</strong>\n    </p>\n{% endif %}\n{% if pickup_point.full_address %}\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        {{ pickup_point.full_address }}\n    </p>\n{% endif %}\n{% if pickup_point.phone %}\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        <strong>{{ __("phone") }}:</strong>\n        <span dir="ltr">{{ pickup_point.phone }}</span>\n    </p>\n{% endif %}\n{% if pickup_point.open_hours %}\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        <strong>{{ __("open_hours") }}:</strong><br/>\n        {{ pickup_point.open_hours }}\n    </p>\n{% endif %}\n{% if pickup_point.description %}\n    <p style="font-family: Helvetica, Arial, sans-serif;">\n        <strong>{{ __("description") }}:</strong><br/>\n        {{ pickup_point.description }}\n    </p>\n{% endif %}', 'A', NULL, NULL, '', [[timestamp]], [[timestamp]]),
(20, 'info', 'gift_certificate_default', NULL, '{% if gift_certificate.send_via == ''P'' %}\n<p>\n    {{ __("gift_cert_from") }}: {{ gift_certificate.sender }}\n</p>\n<p>\n    {{ __("gift_cert_to") }}: {{ gift_certificate.recipient }}\n</p>\n<p>\n    {{ gift_certificate.address }}<br />\n    {% if gift_certificate.address_2 %}\n        {{ gift_certificate.address_2 }}<br />\n    {% endif %}\n    {% if gift_certificate.phone %}\n        <span dir="ltr">{{ gift_certificate.phone }}</span><br />\n    {% endif %}\n    {{ gift_certificate.city }},&nbsp;{{ gift_certificate.descr_country }},&nbsp;{{ gift_certificate.descr_state }}<br />\n    {{ gift_certificate.zipcode }}\n</p>\n{% endif %}\n\n{% if gift_certificate.message %}\n<div>{{ gift_certificate.message }}</div>\n{% endif %}', 'A', NULL, NULL, 'gift_certificates', [[timestamp]], [[timestamp]]),
(21, 'products_table', 'gift_certificate_default', NULL, '\n{% if products_table.rows %}\n<table width="100%" cellpadding="0" cellspacing="1" style="background-color: #dddddd; -webkit-print-color-adjust: exact;">\n<thead>\n    <tr>\n\n        {% for  header in products_table.headers %}\n            <th style="background-color: #eeeeee; padding: 6px 10px; white-space: nowrap; font-size: 12px; font-family: Arial;">{{ header }}</th>\n        {% endfor %}\n    </tr>\n</thead>\n<tbody>\n    {% for  row in products_table.rows %}\n        <tr style="padding: 10px; background-color: #ffffff; font-size: 12px; font-family: Arial; border: 1px solid #eeeeee; text-align: center;">\n            {% for  column in row %}\n                <td style="border: 1px solid #eeeeee; padding:5px; text-align:left;">\n                {{ column }}\n                </td>\n            {% endfor %}\n        </tr>\n    {% endfor %}\n</tbody>\n</table>{% endif %}', 'A', '{"used_table":"1","variable_schema":"gift_certificate_products_table"}', '"fn_gift_certificates_init_product_table_variable"', 'gift_certificates', [[timestamp]], [[timestamp]]),
(22, 'bill_to', 'rma_packing_slip_default', NULL, '<h3 style=" padding: 0px 0px 10px 1px; font-weight: bold; font-size: 15px; font-family: Helvetica, Arial, sans-serif; border-bottom: 1px solid #ededed;">{{ __("bill_to") }}:</h3>\n                        <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                            {{ u.b_firstname }} {{ u.b_lastname }}\n                        </p>\n                        <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                            {{ u.b_address }} {{ u.b_address_2 }}\n                        </p>\n                        <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                            {{ u.b_city }} {{ u.b_state_descr }} {{ u.b_zipcode }}\n                        </p>\n                        <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                            {{ u.b_country_descr }}\n                        </p>\n                        {% for field in u.b_fields %}\n                        <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">{{ field.name }}: {{ field.value }}\n                        </p>\n                        {% endfor %}', 'A', NULL, NULL, 'rma', [[timestamp]], [[timestamp]]),
(23, 'company_address', 'rma_packing_slip_default', NULL, '{% set parts = [c.city] %}\n{% if c.state_descr %}\n	{% set parts = parts|merge([c.state_descr]) %}\n{% endif %}\n\n{{ c.address }} <br />\n{{ parts|join('', '') }} {{ c.zipcode }}  <br />\n{{ c.country_descr }}', 'A', NULL, NULL, 'rma', [[timestamp]], [[timestamp]]),
(24, 'company_info', 'rma_packing_slip_default', NULL, '<table border="0" cellpadding="0" cellspacing="0">\n    <tbody>\n        {% if c.phone %}\n        <tr valign="top">\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px;  padding-left: 0px; white-space: nowrap;">{{ __("phone1_label") }}:</td>\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" width="100%"><span dir="ltr">{{ c.phone }}</span></td>\n        </tr>\n        {% endif %}\n        {% if c.phone_2 %}\n        <tr valign="top">\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px;  padding-left: 0px; white-space: nowrap;">{{ __("phone2_label") }}:</td>\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" width="100%"><span dir="ltr">{{ c.phone_2 }}</span></td>\n        </tr>\n        {% endif %}\n        {% if c.website %}\n        <tr valign="top">\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px;  padding-left: 0px; white-space: nowrap;">{{ __("web_site") }}:</td>\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" width="100%">{{ c.website }}</td>\n        </tr>\n        {% endif %}\n        {% if c.orders_department %}\n        <tr valign="top">\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif; text-transform: uppercase; color: #000000; padding-right: 10px;  padding-left: 0px; white-space: nowrap;">{{ __("email") }}:</td>\n            <td style="font-size: 12px; font-family: Helvetica, Arial, sans-serif;" width="100%"><a href="mailto:{{ c.orders_department }}">{{ c.orders_department_display }}</a></td>\n        </tr>\n        {% endif %}\n    </tbody>\n</table>', 'A', NULL, NULL, 'rma', [[timestamp]], [[timestamp]]),
(25, 'products_table', 'rma_packing_slip_default', NULL, '<table width="100%" cellpadding="0" cellspacing="1" style="border-collapse: separate; border-spacing: 1px; background-color: #dddddd; margin-top: 20px;">\n\n<thead>\n    <tr>\n\n        {% for  header in products_table.headers %}\n            <th style="background-color: #eeeeee; padding: 6px 10px; white-space: nowrap; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">{{ header }}</th>\n        {% endfor %}\n    </tr>\n</thead>\n<tbody>\n    {% for  row in products_table.rows %}\n        <tr>\n            {% for  column in row %}\n                <td style="padding: 5px 10px; background-color: #ffffff; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">{{ column }}</td>\n            {% endfor %}\n        </tr>\n    {% endfor %}\n</tbody>\n</table>', 'A', '{"used_table":"1","variable_schema":"rma_packing_slip_products_table"}', '"fn_rma_init_snippet_rma_products_table_variable"', 'rma', [[timestamp]], [[timestamp]]),
(26, 'ship_to', 'rma_packing_slip_default', NULL, '<h3 style=" padding: 0px 0px 10px 1px; font-weight: bold; font-size: 15px; font-family: Helvetica, Arial, sans-serif; border-bottom: 1px solid #ededed;">{{ __("ship_to") }}:</h3>\n                        <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                            {{ u.firstname }} {{ u.lastname }}\n                        </p>\n                        <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                            {{ u.s_address }} {{ u.s_address_2 }}\n                        </p>\n                        <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                            {{ u.s_city }} {{ u.s_state_descr }} {{ u.s_zipcode }}\n                        </p>\n                        <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n                            {{ u.s_country_descr }}\n                        </p>\n                        {% for field in u.s_fields %}\n                        <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">{{ field.name }}: {{ field.value }}\n                        </p>\n                        {% endfor %}', 'A', NULL, NULL, 'rma', [[timestamp]], [[timestamp]]),
(27, 'pickup_point', 'rma_packing_slip_default', NULL, '<h3 style="padding: 0px 0px 10px 1px; font-size: 15px; font-family: Helvetica, Arial, sans-serif; border-bottom: 1px solid #ededed;">{{__("ship_to")}}:</h3>\n{% if pickup_point.name %}\n    <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n        <strong>{{ pickup_point.name }}</strong>\n    </p>\n{% endif %}\n{% if pickup_point.full_address %}\n    <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n        {{ pickup_point.full_address }}\n    </p>\n{% endif %}\n{% if pickup_point.phone %}\n    <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n        <strong>{{ __("phone") }}:</strong>\n        <span dir="ltr">{{ pickup_point.phone }}</span>\n    </p>\n{% endif %}\n{% if pickup_point.open_hours %}\n    <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n        <strong>{{ __("open_hours") }}:</strong><br/>\n        {{ pickup_point.open_hours }}\n    </p>\n{% endif %}\n{% if pickup_point.description %}\n    <p style="margin: 2px 0px 3px 0px; font-size: 12px; font-family: Helvetica, Arial, sans-serif;">\n        <strong>{{ __("description") }}:</strong><br/>\n        {{ pickup_point.description }}\n    </p>\n{% endif %}', 'A', NULL, NULL, 'rma', [[timestamp]], [[timestamp]]),
(28, 'returned_products_table', 'order_invoice', NULL, '{% if products_table.rows %}<table width="100%" cellpadding="0" cellspacing="1" style="border-collapse: separate; border-spacing: 1px; background-color: #dddddd; margin-top: 20px;">\n\n<thead>\n    <tr>\n\n        {% for  header in products_table.headers %}\n            <th style="background-color: #eeeeee; padding: 6px 10px; white-space: nowrap; font-size: 12px; font-family: Arial;">{{ header }}</th>\n        {% endfor %}\n    </tr>\n</thead>\n<tbody>\n    {% for  row in products_table.rows %}\n        <tr>\n            {% for  column in row %}\n                <td style="padding: 5px 10px; background-color: #ffffff; font-size: 12px; font-family: Arial;">{{ column }}</td>\n            {% endfor %}\n        </tr>\n    {% endfor %}\n</tbody>\n</table>\n{% endif %}', 'D', '{"used_table":"1","variable_schema":"order_returned_products_table"}', '"fn_rma_init_snippet_returned_products_table_variable"', 'rma', [[timestamp]], [[timestamp]]),
(29, 'returned_products_table', 'order_summary', NULL, '{% if products_table.rows %}<table width="100%" cellpadding="0" cellspacing="1" style="border-collapse: separate; border-spacing: 1px; background-color: #dddddd; margin-top: 20px;">\n\n<thead>\n    <tr>\n\n        {% for  header in products_table.headers %}\n            <th style="background-color: #eeeeee; padding: 6px 10px; white-space: nowrap; font-size: 12px; font-family: Arial;">{{ header }}</th>\n        {% endfor %}\n    </tr>\n</thead>\n<tbody>\n    {% for  row in products_table.rows %}\n        <tr>\n            {% for  column in row %}\n                <td style="padding: 5px 10px; background-color: #ffffff; font-size: 12px; font-family: Arial;">{{ column }}</td>\n            {% endfor %}\n        </tr>\n    {% endfor %}\n</tbody>\n</table>\n{% endif %}', 'D', '{"used_table":"1","variable_schema":"order_returned_products_table"}', '"fn_rma_init_snippet_returned_products_table_variable"', 'rma', [[timestamp]], [[timestamp]]);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]template_snippet_descriptions`
--

CREATE TABLE `[[dbprefix]]template_snippet_descriptions` (
  `snippet_id` int(11) unsigned NOT NULL,
  `lang_code` varchar(2) NOT NULL DEFAULT '',
  `name` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`snippet_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]template_snippet_descriptions`
--

INSERT INTO `[[dbprefix]]template_snippet_descriptions` VALUES
(1, 'en', 'Footer'),
(2, 'en', 'Header'),
(3, 'en', 'Bill to'),
(4, 'en', 'Company address'),
(5, 'en', 'Products table'),
(6, 'en', 'Shipping address'),
(7, 'en', 'Pickup point'),
(8, 'en', 'Products table'),
(9, 'en', 'Shipping address'),
(10, 'en', 'Pickup point'),
(11, 'en', 'Bill to'),
(12, 'en', 'Company address'),
(13, 'en', 'Company info'),
(14, 'en', 'Order date'),
(15, 'en', 'Order info'),
(16, 'en', 'Packing slip notes'),
(17, 'en', 'Products table'),
(18, 'en', 'Shipping address'),
(19, 'en', 'Pickup point'),
(20, 'en', 'Info'),
(21, 'en', 'Products table'),
(22, 'en', 'Bill to'),
(23, 'en', 'Company address'),
(24, 'en', 'Company info'),
(25, 'en', 'Products table'),
(26, 'en', 'Shipping address'),
(27, 'en', 'Pickup point'),
(28, 'en', 'Returned products table'),
(29, 'en', 'Returned products table');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]template_table_columns`
--

CREATE TABLE `[[dbprefix]]template_table_columns` (
  `column_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `code` varchar(128) DEFAULT NULL,
  `snippet_code` varchar(128) NOT NULL DEFAULT '',
  `snippet_type` varchar(32) NOT NULL DEFAULT '',
  `status` char(1) NOT NULL DEFAULT '',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `template` text,
  `default_template` text,
  `addon` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`column_id`),
  KEY `snippet_idx` (`snippet_code`,`snippet_type`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=31 ;

--
-- Dumping data for table `[[dbprefix]]template_table_columns`
--

INSERT INTO `[[dbprefix]]template_table_columns` VALUES
(1, 'product', 'products_table', 'order_invoice', 'A', 0, NULL, '<table>\n<tbody>\n<tr>\n    <td rowspan="2" style="padding-right: 20px; font-family: Helvetica, Arial, sans-serif;" width="20%">{{ p.image }}\n    </td>\n    <td style="vertical-align: middle; {% if language_direction == "rtl" %}text-align: right;{% else %}text-align: left;{% endif %}" width="80%"><span style="font-family: Helvetica, Arial, sans-serif; text-transfrom: uppercase; "><strong style="font-weight: bold;"><a href="{{ p.product_url }}">{{ p.name }}</a></strong></span>\n    </td>\n</tr>\n<tr>\n    <td style="vertical-align: top; font-family: Helvetica, Arial, sans-serif; {% if language_direction == "rtl" %}text-align: right;{% else %}text-align: left;{% endif %}"><span style="font-size: 11px; font-weight: normal; font-family: Helvetica, Arial, sans-serif; color: #a8a8a8; ">{% if p.product_code %}{{ p.product_code }}<br> {% endif %}{% if p.options %}{{ p.options }}{%  endif %}</span>\n    </td>\n</tr>\n</tbody>\n</table>', ''),
(2, 'amount', 'products_table', 'order_invoice', 'A', 1, NULL, '<p style="text-align: center; font-family: Helvetica, Arial, sans-serif;"><strong style="font-weight: bold;">{{ p.amount }}</strong></p>', ''),
(3, 'original_price', 'products_table', 'order_invoice', 'A', 2, NULL, '<p style="text-align: center; font-family: Helvetica, Arial, sans-serif;"><strong style="font-weight: bold;">{{ p.original_price }}</strong></p>', ''),
(4, 'discount', 'products_table', 'order_invoice', 'A', 3, NULL, '<p style="text-align: center; font-family: Helvetica, Arial, sans-serif;"><strong style="font-weight: bold;">{{ p.discount }}</strong></p>', ''),
(5, 'tax', 'products_table', 'order_invoice', 'A', 4, NULL, '<p style="text-align: center; font-family: Helvetica, Arial, sans-serif;"><strong style="font-weight: bold;">{{ p.tax }}</strong></p>', ''),
(6, 'display_subtotal', 'products_table', 'order_invoice', 'A', 5, NULL, '<p style="text-align: center; font-family: Helvetica, Arial, sans-serif;"><strong style="font-weight: bold;">{{ p.display_subtotal }}</strong></p>', ''),
(7, 'product', 'products_table', 'order_summary', 'A', 0, NULL, '<table>\n<tbody>\n<tr>\n    <td rowspan="2" style="padding-right: 20px; font-family: Helvetica, Arial, sans-serif;" width="20%">{{ p.image }}\n    </td>\n    <td style="vertical-align: middle; {% if language_direction == "rtl" %}text-align: right;{% else %}text-align: left;{% endif %}" width="80%"><span style="font-family: Helvetica, Arial, sans-serif; text-transfrom: uppercase; "><strong style="font-weight: bold;"><a href="{{ p.product_url }}">{{ p.name }}</a></strong></span>\n    </td>\n</tr>\n<tr>\n    <td style="vertical-align: top; font-family: Helvetica, Arial, sans-serif; {% if language_direction == "rtl" %}text-align: right;{% else %}text-align: left;{% endif %}"><span style="font-size: 11px; font-weight: normal; font-family: Helvetica, Arial, sans-serif; color: #a8a8a8; ">{% if p.product_code %}{{ p.product_code }}<br> {% endif %}{% if p.options %}{{ p.options }}{%  endif %}</span>\n    </td>\n</tr>\n</tbody>\n</table>', ''),
(8, 'amount', 'products_table', 'order_summary', 'A', 1, NULL, '<p style="text-align: center; font-family: Helvetica, Arial, sans-serif;"><strong style="font-weight: bold;">{{ p.amount }}</strong></p>', ''),
(9, 'original_price', 'products_table', 'order_summary', 'A', 2, NULL, '<p style="text-align: center; font-family: Helvetica, Arial, sans-serif;"><strong style="font-weight: bold;">{{ p.original_price }}</strong></p>', ''),
(10, 'discount', 'products_table', 'order_summary', 'D', 3, NULL, '<p style="text-align: center; font-family: Helvetica, Arial, sans-serif;"><strong style="font-weight: bold;">{{ p.discount }}</strong></p>', ''),
(11, 'tax', 'products_table', 'order_summary', 'D', 4, NULL, '<p style="text-align: center; font-family: Helvetica, Arial, sans-serif;"><strong style="font-weight: bold;">{{ p.tax }}</strong></p>', ''),
(12, 'display_subtotal', 'products_table', 'order_summary', 'A', 5, NULL, '<p style="text-align: center; font-family: Helvetica, Arial, sans-serif;"><strong style="font-weight: bold;">{{ p.display_subtotal }}</strong></p>', ''),
(13, 'name', 'products_table', 'packing_slip_default', 'A', 100, NULL, '<p style="font-family: Helvetica, Arial, sans-serif; {% if language_direction == "rtl" %}text-align: right;{% else %}text-align: left;{% endif %}">{{ p.name }}</p>', ''),
(14, 'product_code', 'products_table', 'packing_slip_default', 'A', 100, NULL, '<p style="font-family: Helvetica, Arial, sans-serif; {% if language_direction == "rtl" %}text-align: right;{% else %}text-align: left;{% endif %}">{{ p.product_code }}</p>', ''),
(15, 'amount', 'products_table', 'packing_slip_default', 'A', 100, NULL, '<p style="text-align: center; font-family: Helvetica, Arial, sans-serif;">{{ p.amount }}</p>', ''),
(16, 'name', 'products_table', 'gift_certificate_default', 'A', 10, NULL, '<p><a href="{{ p.url }}">{{ p.name }}</a> {% if p.options %}<br>{{ p.options }}<br>{% endif %}</p>', 'gift_certificates'),
(17, 'amount', 'products_table', 'gift_certificate_default', 'A', 20, NULL, '<p style="text-align: center;">{{ p.amount }}</p>', 'gift_certificates'),
(18, 'code', 'products_table', 'rma_packing_slip_default', 'A', 20, NULL, '<p style="font-family: Helvetica, Arial, sans-serif;">{{ p.code }}</p>', 'rma'),
(19, 'name', 'products_table', 'rma_packing_slip_default', 'A', 30, NULL, '<p style="font-family: Helvetica, Arial, sans-serif;">{{ p.name }}</p>', 'rma'),
(20, 'price', 'products_table', 'rma_packing_slip_default', 'A', 40, NULL, '<p style="font-family: Helvetica, Arial, sans-serif;">{{ p.price }}</p>', 'rma'),
(21, 'amount', 'products_table', 'rma_packing_slip_default', 'A', 50, NULL, '<p style="text-align:center; font-family: Helvetica, Arial, sans-serif;">{{ p.amount }}</p>', 'rma'),
(22, 'reason', 'products_table', 'rma_packing_slip_default', 'A', 60, NULL, '<p style="font-family: Helvetica, Arial, sans-serif;">{{ p.reason_text }}</p>', 'rma'),
(23, 'code', 'returned_products_table', 'order_invoice', 'A', 10, NULL, '<p>{{ p.product_code }}</p>', 'rma'),
(24, 'name', 'returned_products_table', 'order_invoice', 'A', 20, NULL, '<div style="float:left;">{{ p.image }}</div><div><p>{{ p.name }}</p><p>{{ p.options }}</p></div>', 'rma'),
(25, 'amount', 'returned_products_table', 'order_invoice', 'A', 30, NULL, '<p>{{ p.amount }}</p>', 'rma'),
(26, 'subtotal', 'returned_products_table', 'order_invoice', 'A', 40, NULL, '<p>{{ p.display_subtotal }}</p>', 'rma'),
(27, 'code', 'returned_products_table', 'order_summary', 'A', 10, NULL, '<p>{{ p.product_code }}</p>', 'rma'),
(28, 'name', 'returned_products_table', 'order_summary', 'A', 20, NULL, '<div style="float:left;">{{ p.image }}</div><div><p>{{ p.name }}</p><p>{{ p.options }}</p></div>', 'rma'),
(29, 'amount', 'returned_products_table', 'order_summary', 'A', 30, NULL, '<p>{{ p.amount }}</p>', 'rma'),
(30, 'subtotal', 'returned_products_table', 'order_summary', 'A', 40, NULL, '<p>{{ p.display_subtotal }}</p>', 'rma');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]template_table_column_descriptions`
--

CREATE TABLE `[[dbprefix]]template_table_column_descriptions` (
  `column_id` int(11) unsigned NOT NULL,
  `lang_code` char(2) NOT NULL DEFAULT '',
  `name` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`column_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]template_table_column_descriptions`
--

INSERT INTO `[[dbprefix]]template_table_column_descriptions` VALUES
(1, 'en', 'Item description'),
(2, 'en', 'Qty'),
(3, 'en', 'Price'),
(4, 'en', 'Discount'),
(5, 'en', 'Tax'),
(6, 'en', 'Item total'),
(7, 'en', 'Item description'),
(8, 'en', 'Qty'),
(9, 'en', 'Price'),
(10, 'en', 'Discount'),
(11, 'en', 'Tax'),
(12, 'en', 'Item total'),
(13, 'en', 'Product'),
(14, 'en', 'Code'),
(15, 'en', 'Quantity'),
(16, 'en', 'Free Products'),
(17, 'en', 'Quantity'),
(18, 'en', 'Code'),
(19, 'en', 'Product'),
(20, 'en', 'Price'),
(21, 'en', 'Amount'),
(22, 'en', 'Reason'),
(23, 'en', 'Code'),
(24, 'en', 'Returned product'),
(25, 'en', 'Quantity'),
(26, 'en', 'Subtotal'),
(27, 'en', 'Code'),
(28, 'en', 'Returned product'),
(29, 'en', 'Quantity'),
(30, 'en', 'Subtotal');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]ult_language_values`
--

CREATE TABLE `[[dbprefix]]ult_language_values` (
  `lang_code` char(2) NOT NULL DEFAULT '',
  `name` varchar(128) NOT NULL DEFAULT '',
  `value` text NOT NULL,
  `company_id` int(11) unsigned NOT NULL,
  PRIMARY KEY (`lang_code`,`name`,`company_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]ult_objects_sharing`
--

CREATE TABLE `[[dbprefix]]ult_objects_sharing` (
  `share_company_id` int(11) unsigned NOT NULL,
  `share_object_id` mediumint(8) NOT NULL DEFAULT '0',
  `share_object_type` varchar(50) NOT NULL DEFAULT '',
  PRIMARY KEY (`share_object_id`,`share_company_id`,`share_object_type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]ult_objects_sharing`
--

INSERT INTO `[[dbprefix]]ult_objects_sharing` VALUES
(1, 1, 'mailing_lists'),
(1, 1, 'pages'),
(1, 1, 'product_filters'),
(1, 1, 'product_options'),
(1, 2, 'pages'),
(1, 2, 'product_options'),
(1, 3, 'pages'),
(1, 4, 'pages'),
(1, 4, 'usergroups'),
(1, 5, 'pages'),
(1, 6, 'banners'),
(1, 6, 'pages'),
(1, 6, 'profile_fields'),
(1, 7, 'banners'),
(1, 7, 'pages'),
(1, 7, 'product_filters'),
(1, 7, 'profile_fields'),
(1, 8, 'banners'),
(1, 8, 'pages'),
(1, 8, 'product_filters'),
(1, 8, 'profile_fields'),
(1, 9, 'banners'),
(1, 9, 'product_filters'),
(1, 9, 'product_options'),
(1, 9, 'profile_fields'),
(1, 10, 'product_filters'),
(1, 10, 'product_options'),
(1, 10, 'profile_fields'),
(1, 11, 'product_options'),
(1, 11, 'profile_fields'),
(1, 13, 'product_options'),
(1, 14, 'product_features'),
(1, 14, 'product_options'),
(1, 14, 'profile_fields'),
(1, 15, 'product_features'),
(1, 15, 'product_options'),
(1, 15, 'profile_fields'),
(1, 16, 'banners'),
(1, 16, 'product_features'),
(1, 16, 'profile_fields'),
(1, 17, 'banners'),
(1, 17, 'product_features'),
(1, 17, 'profile_fields'),
(1, 18, 'banners'),
(1, 18, 'product_features'),
(1, 18, 'profile_fields'),
(1, 19, 'banners'),
(1, 19, 'pages'),
(1, 19, 'profile_fields'),
(1, 20, 'pages'),
(1, 20, 'product_features'),
(1, 20, 'product_options'),
(1, 20, 'profile_fields'),
(1, 21, 'pages'),
(1, 21, 'product_features'),
(1, 21, 'profile_fields'),
(1, 22, 'pages'),
(1, 22, 'product_features'),
(1, 22, 'profile_fields'),
(1, 23, 'pages'),
(1, 23, 'product_features'),
(1, 23, 'profile_fields'),
(1, 24, 'product_features'),
(1, 24, 'profile_fields'),
(1, 25, 'product_features'),
(1, 25, 'product_options'),
(1, 25, 'profile_fields'),
(1, 26, 'product_features'),
(1, 26, 'profile_fields'),
(1, 27, 'product_features'),
(1, 27, 'profile_fields'),
(1, 28, 'product_features'),
(1, 28, 'profile_fields'),
(1, 29, 'product_features'),
(1, 29, 'profile_fields'),
(1, 30, 'pages'),
(1, 30, 'product_features'),
(1, 30, 'profile_fields'),
(1, 31, 'product_features'),
(1, 31, 'profile_fields'),
(1, 32, 'product_features'),
(1, 32, 'profile_fields'),
(1, 33, 'product_features'),
(1, 33, 'profile_fields'),
(1, 34, 'product_features'),
(1, 35, 'product_features'),
(1, 35, 'profile_fields'),
(1, 36, 'product_features'),
(1, 37, 'product_features'),
(1, 38, 'product_features'),
(1, 39, 'product_features'),
(1, 40, 'pages'),
(1, 40, 'product_features'),
(1, 41, 'product_features'),
(1, 42, 'product_features'),
(1, 43, 'product_features'),
(1, 44, 'product_features'),
(1, 45, 'product_features'),
(1, 46, 'product_features'),
(1, 47, 'product_features'),
(1, 312, 'product_filters'),
(1, 313, 'product_filters'),
(1, 548, 'product_features'),
(1, 549, 'product_features');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]ult_product_descriptions`
--

CREATE TABLE `[[dbprefix]]ult_product_descriptions` (
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `company_id` int(11) unsigned NOT NULL,
  `product` varchar(255) NOT NULL DEFAULT '',
  `shortname` varchar(255) NOT NULL DEFAULT '',
  `short_description` mediumtext NOT NULL,
  `full_description` mediumtext NOT NULL,
  `meta_keywords` varchar(255) NOT NULL DEFAULT '',
  `meta_description` varchar(255) NOT NULL DEFAULT '',
  `search_words` text NOT NULL,
  `page_title` varchar(255) NOT NULL DEFAULT '',
  `age_warning_message` text NOT NULL,
  `promo_text` mediumtext NOT NULL,
  PRIMARY KEY (`product_id`,`lang_code`,`company_id`),
  KEY `product_id` (`product_id`),
  KEY `company_id` (`company_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]ult_product_option_variants`
--

CREATE TABLE `[[dbprefix]]ult_product_option_variants` (
  `variant_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `option_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `company_id` int(11) unsigned NOT NULL,
  `modifier` decimal(13,3) NOT NULL DEFAULT '0.000',
  `modifier_type` char(1) NOT NULL DEFAULT 'A',
  PRIMARY KEY (`variant_id`,`company_id`),
  KEY `company_id` (`company_id`),
  KEY `option_id` (`option_id`,`variant_id`,`company_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]ult_product_prices`
--

CREATE TABLE `[[dbprefix]]ult_product_prices` (
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `price` decimal(12,2) NOT NULL DEFAULT '0.00',
  `percentage_discount` int(2) unsigned NOT NULL DEFAULT '0',
  `lower_limit` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `company_id` int(11) unsigned NOT NULL,
  `usergroup_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  UNIQUE KEY `usergroup` (`product_id`,`usergroup_id`,`lower_limit`,`company_id`),
  KEY `product_id` (`product_id`),
  KEY `company_id` (`company_id`),
  KEY `lower_limit` (`lower_limit`),
  KEY `usergroup_id` (`usergroup_id`,`product_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]ult_product_prices`
--

INSERT INTO `[[dbprefix]]ult_product_prices` VALUES
(7, '55.00', 0, 1, 1, 0),
(11, '30.00', 0, 1, 1, 0),
(12, '30.00', 0, 1, 1, 0),
(15, '150.00', 0, 1, 1, 0);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]ult_status_descriptions`
--

CREATE TABLE `[[dbprefix]]ult_status_descriptions` (
  `company_id` int(11) unsigned NOT NULL,
  `status_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `email_subj` varchar(255) NOT NULL DEFAULT '',
  `email_header` text NOT NULL,
  `lang_code` char(2) NOT NULL DEFAULT '',
  PRIMARY KEY (`status_id`,`lang_code`,`company_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]usergroups`
--

CREATE TABLE `[[dbprefix]]usergroups` (
  `usergroup_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `status` char(1) NOT NULL DEFAULT '',
  `type` char(1) NOT NULL DEFAULT 'C',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`usergroup_id`),
  KEY `c_status` (`usergroup_id`,`status`),
  KEY `status` (`status`,`type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]usergroup_descriptions`
--

CREATE TABLE `[[dbprefix]]usergroup_descriptions` (
  `usergroup_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `usergroup` varchar(255) NOT NULL DEFAULT '',
  PRIMARY KEY (`usergroup_id`,`lang_code`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]usergroup_links`
--

CREATE TABLE `[[dbprefix]]usergroup_links` (
  `link_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` mediumint(8) unsigned NOT NULL,
  `usergroup_id` mediumint(8) unsigned NOT NULL,
  `status` char(1) NOT NULL DEFAULT 'D',
  PRIMARY KEY (`link_id`),
  UNIQUE KEY `user_id` (`user_id`,`usergroup_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]usergroup_privileges`
--

CREATE TABLE `[[dbprefix]]usergroup_privileges` (
  `usergroup_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `privilege` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`usergroup_id`,`privilege`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]users`
--

CREATE TABLE `[[dbprefix]]users` (
  `user_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `status` char(1) NOT NULL DEFAULT 'A',
  `user_type` char(1) NOT NULL DEFAULT 'C',
  `user_login` varchar(255) NOT NULL DEFAULT '',
  `referer` varchar(255) NOT NULL DEFAULT '',
  `is_root` char(1) NOT NULL DEFAULT 'N',
  `company_id` int(11) unsigned NOT NULL DEFAULT '0',
  `last_login` int(11) unsigned NOT NULL DEFAULT '0',
  `last_activity` int(11) unsigned NOT NULL DEFAULT '0',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `password` varchar(255) NOT NULL DEFAULT '',
  `salt` varchar(10) NOT NULL DEFAULT '',
  `firstname` varchar(128) NOT NULL DEFAULT '',
  `lastname` varchar(128) NOT NULL DEFAULT '',
  `company` varchar(255) NOT NULL DEFAULT '',
  `email` varchar(128) NOT NULL DEFAULT '',
  `phone` varchar(128) NOT NULL DEFAULT '',
  `fax` varchar(128) NOT NULL DEFAULT '',
  `url` varchar(128) NOT NULL DEFAULT '',
  `tax_exempt` char(1) NOT NULL DEFAULT 'N',
  `lang_code` char(2) NOT NULL DEFAULT '',
  `birthday` int(11) NOT NULL DEFAULT '0',
  `purchase_timestamp_from` int(11) NOT NULL DEFAULT '0',
  `purchase_timestamp_to` int(11) NOT NULL DEFAULT '0',
  `responsible_email` varchar(80) NOT NULL DEFAULT '',
  `password_change_timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `api_key` varchar(255) NOT NULL DEFAULT '',
  `helpdesk_user_id` int(11) unsigned NOT NULL DEFAULT '0',
  `janrain_identifier` varchar(32) NOT NULL DEFAULT '',
  PRIMARY KEY (`user_id`),
  KEY `user_login` (`user_login`),
  KEY `uname` (`firstname`,`lastname`),
  KEY `idx_email` (`email`),
  KEY `idx_last_activity` (`last_activity`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=4 ;

--
-- Dumping data for table `[[dbprefix]]users`
--

INSERT INTO `[[dbprefix]]users` VALUES
(1, 'A', 'A', 'admin', '', 'Y', 0, 0, [[timestamp]], [[timestamp]], '[[admin_pass]]', '[[salt]]', 'Admin', 'Admin', 'Your company', '[[admin_email]]', '+16175555555', '', '', 'N', 'en', 0, 0, 0, '', [[timestamp]], '', 0, ''),
(3, 'A', 'C', 'customer', '', 'N', 1, 0, 0, [[timestamp]], '91ec1f9324753048c0096d036a694f86', '', 'Customer', 'Customer', 'CS-Cart', 'customer@example.com', '+77777777777', '', '', 'N', 'en', 0, 0, 0, '', 0, '', 0, '');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]user_data`
--

CREATE TABLE `[[dbprefix]]user_data` (
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `type` char(1) NOT NULL DEFAULT '',
  `data` text,
  PRIMARY KEY (`user_id`,`type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

--
-- Dumping data for table `[[dbprefix]]user_data`
--

INSERT INTO `[[dbprefix]]user_data` VALUES
(1, 'L', 'a:0:{}');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]user_last_passwords`
--

CREATE TABLE `[[dbprefix]]user_last_passwords` (
  `user_id` int(11) unsigned NOT NULL DEFAULT '0',
  `last_password` varchar(255) NOT NULL DEFAULT ''
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]user_mailing_lists`
--

CREATE TABLE `[[dbprefix]]user_mailing_lists` (
  `subscriber_id` mediumint(8) unsigned NOT NULL,
  `list_id` mediumint(8) unsigned NOT NULL,
  `activation_key` varchar(32) NOT NULL DEFAULT '',
  `unsubscribe_key` varchar(32) NOT NULL DEFAULT '',
  `confirmed` tinyint(3) unsigned NOT NULL DEFAULT '0',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  UNIQUE KEY `subscriber_list` (`list_id`,`subscriber_id`),
  KEY `subscriber_id` (`subscriber_id`),
  KEY `list_id` (`list_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]user_profiles`
--

CREATE TABLE `[[dbprefix]]user_profiles` (
  `profile_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `profile_type` char(1) NOT NULL DEFAULT 'P',
  `b_firstname` varchar(128) NOT NULL DEFAULT '',
  `b_lastname` varchar(128) NOT NULL DEFAULT '',
  `b_address` varchar(255) NOT NULL DEFAULT '',
  `b_address_2` varchar(255) NOT NULL DEFAULT '',
  `b_city` varchar(64) NOT NULL DEFAULT '',
  `b_county` varchar(32) NOT NULL DEFAULT '',
  `b_state` varchar(32) NOT NULL DEFAULT '',
  `b_country` char(2) NOT NULL DEFAULT '',
  `b_zipcode` varchar(16) NOT NULL DEFAULT '',
  `b_phone` varchar(128) NOT NULL DEFAULT '',
  `s_firstname` varchar(128) NOT NULL DEFAULT '',
  `s_lastname` varchar(128) NOT NULL DEFAULT '',
  `s_address` varchar(255) NOT NULL DEFAULT '',
  `s_address_2` varchar(255) NOT NULL DEFAULT '',
  `s_city` varchar(64) NOT NULL DEFAULT '',
  `s_county` varchar(32) NOT NULL DEFAULT '',
  `s_state` varchar(32) NOT NULL DEFAULT '',
  `s_country` char(2) NOT NULL DEFAULT '',
  `s_zipcode` varchar(16) NOT NULL DEFAULT '',
  `s_phone` varchar(128) NOT NULL DEFAULT '',
  `s_address_type` varchar(255) NOT NULL DEFAULT '',
  `profile_name` varchar(32) NOT NULL DEFAULT '',
  `profile_update_timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  PRIMARY KEY (`profile_id`),
  KEY `uid_p` (`user_id`,`profile_type`),
  KEY `profile_type` (`profile_type`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=3 ;

--
-- Dumping data for table `[[dbprefix]]user_profiles`
--

INSERT INTO `[[dbprefix]]user_profiles` VALUES
(1, 1, 'P', 'John', 'Doe', '44 Main street', 'test', 'Boston', '', 'MA', 'US', '02134', '', 'John', 'Doe', '44 Main street', 'test', 'Boston', '', 'MA', 'US', '02134', '', '', 'Main', [[timestamp]]),
(2, 3, 'P', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '+77777777777', 'Customer', 'Customer', '44 Main street', '', 'Boston', '', 'MA', 'US', '02134', '+77777777777', '', 'Main', 1720074902);

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]user_session_products`
--

CREATE TABLE `[[dbprefix]]user_session_products` (
  `user_id` int(11) unsigned NOT NULL DEFAULT '0',
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `type` char(1) NOT NULL DEFAULT 'C',
  `user_type` char(1) NOT NULL DEFAULT 'R',
  `item_id` int(11) unsigned NOT NULL DEFAULT '0',
  `item_type` char(1) NOT NULL DEFAULT 'P',
  `product_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `amount` mediumint(8) unsigned NOT NULL DEFAULT '1',
  `price` decimal(12,2) NOT NULL DEFAULT '0.00',
  `extra` blob,
  `session_id` varchar(64) NOT NULL DEFAULT '',
  `ip_address` varbinary(40) NOT NULL DEFAULT '',
  `order_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `position` smallint(5) unsigned NOT NULL DEFAULT '0',
  `company_id` int(11) unsigned NOT NULL,
  PRIMARY KEY (`user_id`,`type`,`user_type`,`item_id`,`storefront_id`,`company_id`),
  KEY `timestamp` (`timestamp`,`user_type`),
  KEY `session_id` (`session_id`),
  KEY `type` (`type`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]vendor_communications`
--

CREATE TABLE `[[dbprefix]]vendor_communications` (
  `thread_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `storefront_id` int(11) unsigned NOT NULL DEFAULT '0',
  `status` char(1) NOT NULL DEFAULT 'N',
  `user_id` mediumint(8) unsigned NOT NULL,
  `company_id` int(11) unsigned NOT NULL,
  `object_id` int(11) unsigned DEFAULT '0',
  `object_type` char(1) DEFAULT '',
  `created_at` int(11) unsigned NOT NULL DEFAULT '0',
  `last_message` varchar(255) DEFAULT '',
  `last_message_user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `last_message_user_type` char(1) NOT NULL DEFAULT '',
  `last_updated` int(11) unsigned NOT NULL DEFAULT '0',
  `subject` varchar(255) NOT NULL DEFAULT '',
  `communication_type` varchar(40) NOT NULL DEFAULT '',
  PRIMARY KEY (`thread_id`),
  KEY `idx_company_id` (`company_id`),
  KEY `idx_user_id` (`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]vendor_communication_messages`
--

CREATE TABLE `[[dbprefix]]vendor_communication_messages` (
  `message_id` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `thread_id` int(11) unsigned NOT NULL,
  `user_id` mediumint(8) unsigned NOT NULL,
  `user_type` char(1) NOT NULL,
  `timestamp` int(11) unsigned NOT NULL DEFAULT '0',
  `message` text,
  PRIMARY KEY (`message_id`),
  KEY `idx_thread_id` (`thread_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]views`
--

CREATE TABLE `[[dbprefix]]views` (
  `view_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `object` varchar(24) NOT NULL DEFAULT '',
  `name` varchar(32) NOT NULL DEFAULT '',
  `params` text,
  `view_results` text,
  `user_id` mediumint(8) unsigned NOT NULL DEFAULT '0',
  `active` char(1) NOT NULL DEFAULT 'N',
  `is_default` char(1) NOT NULL DEFAULT 'N',
  PRIMARY KEY (`view_id`),
  KEY `idx_user_id_object` (`user_id`,`object`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=19 ;

--
-- Dumping data for table `[[dbprefix]]views`
--

INSERT INTO `[[dbprefix]]views` VALUES
(5, 'products', 'Recently updated', 'a:12:{s:4:"type";s:6:"simple";s:12:"pcode_from_q";s:1:"Y";s:9:"is_search";s:1:"Y";s:7:"subcats";s:1:"Y";s:7:"sort_by";s:7:"product";s:10:"sort_order";s:3:"asc";s:14:"created_period";s:1:"A";s:16:"updated_in_hours";s:1:"1";s:14:"items_per_page";i:50;s:17:"only_short_fields";b:1;s:22:"apply_disabled_filters";b:1;s:6:"extend";a:2:{i:0;s:9:"companies";i:1;s:7:"sharing";}}', NULL, 1, 'Y', 'N'),
(13, 'addons', 'Recently installed', 'a:2:{s:9:"is_search";s:1:"Y";s:6:"period";s:2:"HH";}', '', 1, 'N', 'N'),
(14, 'addons', 'Favorites', 'a:2:{s:9:"is_search";s:1:"Y";s:9:"favorites";s:1:"Y";}', '', 1, 'N', 'N'),
(15, 'addons', 'Available upgrade', 'a:2:{s:9:"is_search";s:1:"Y";s:16:"available_update";s:1:"Y";}', '', 1, 'N', 'N'),
(1, 'orders', 'Everything done', 'a:14:{s:5:"cname";s:0:"";s:5:"email";s:0:"";s:10:"total_from";s:0:"";s:8:"total_to";s:0:"";s:10:"tax_exempt";s:0:"";s:6:"status";a:1:{i:0;s:1:"C";}s:6:"period";s:1:"A";s:9:"time_from";s:0:"";s:7:"time_to";s:0:"";s:8:"order_id";s:0:"";s:14:"gift_cert_code";s:0:"";s:12:"gift_cert_in";s:3:"B|U";s:5:"p_ids";s:0:"";s:17:"product_filter_id";s:1:"0";}', NULL, 1, 'N', 'N'),
(2, 'orders', 'Money received', 'a:14:{s:5:"cname";s:0:"";s:5:"email";s:0:"";s:10:"total_from";s:0:"";s:8:"total_to";s:0:"";s:10:"tax_exempt";s:0:"";s:6:"status";a:2:{i:0;s:1:"P";i:1;s:1:"C";}s:6:"period";s:1:"A";s:9:"time_from";s:0:"";s:7:"time_to";s:0:"";s:8:"order_id";s:0:"";s:14:"gift_cert_code";s:0:"";s:12:"gift_cert_in";s:3:"B|U";s:5:"p_ids";s:0:"";s:17:"product_filter_id";s:1:"0";}', NULL, 1, 'N', 'N'),
(3, 'orders', 'Action required', 'a:14:{s:5:"cname";s:0:"";s:5:"email";s:0:"";s:10:"total_from";s:0:"";s:8:"total_to";s:0:"";s:10:"tax_exempt";s:0:"";s:6:"status";a:4:{i:0;s:1:"P";i:1;s:1:"O";i:2;s:1:"B";i:3;s:1:"Y";}s:6:"period";s:1:"A";s:9:"time_from";s:0:"";s:7:"time_to";s:0:"";s:8:"order_id";s:0:"";s:14:"gift_cert_code";s:0:"";s:12:"gift_cert_in";s:3:"B|U";s:5:"p_ids";s:0:"";s:17:"product_filter_id";s:1:"0";}', NULL, 1, 'N', 'N'),
(4, 'orders', 'Problem encountered', 'a:14:{s:5:"cname";s:0:"";s:5:"email";s:0:"";s:10:"total_from";s:0:"";s:8:"total_to";s:0:"";s:10:"tax_exempt";s:0:"";s:6:"status";a:2:{i:0;s:1:"F";i:1;s:1:"N";}s:6:"period";s:1:"A";s:9:"time_from";s:0:"";s:7:"time_to";s:0:"";s:8:"order_id";s:0:"";s:14:"gift_cert_code";s:0:"";s:12:"gift_cert_in";s:3:"B|U";s:5:"p_ids";s:0:"";s:17:"product_filter_id";s:1:"0";}', NULL, 1, 'N', 'N'),
(17, 'orders', 'Sale aborted', 'a:14:{s:5:"cname";s:0:"";s:5:"email";s:0:"";s:10:"total_from";s:0:"";s:8:"total_to";s:0:"";s:10:"tax_exempt";s:0:"";s:6:"status";a:2:{i:0;s:1:"D";i:1;s:1:"I";}s:6:"period";s:1:"A";s:9:"time_from";s:0:"";s:7:"time_to";s:0:"";s:8:"order_id";s:0:"";s:14:"gift_cert_code";s:0:"";s:12:"gift_cert_in";s:3:"B|U";s:5:"p_ids";s:0:"";s:17:"product_filter_id";s:1:"0";}', NULL, 1, 'N', 'N'),
(6, 'orders', 'No manager assigned', 'a:20:{s:9:"is_search";s:1:"Y";s:5:"cname";s:0:"";s:5:"email";s:0:"";s:5:"phone";s:0:"";s:10:"total_from";s:0:"";s:8:"total_to";s:0:"";s:6:"issuer";s:0:"";s:9:"no_issuer";s:1:"Y";s:6:"period";s:1:"A";s:9:"time_from";s:0:"";s:7:"time_to";s:0:"";s:10:"tax_exempt";s:0:"";s:8:"order_id";s:0:"";s:7:"company";s:0:"";s:14:"credit_memo_id";s:0:"";s:10:"invoice_id";s:0:"";s:5:"p_ids";s:0:"";s:15:"product_view_id";s:1:"0";s:14:"items_per_page";i:50;s:19:"include_incompleted";b:1;}', NULL, 1, 'Y', 'N'),
(18, 'blocks', 'Product type', 'a:2:{s:9:"is_search";s:1:"Y";s:4:"type";s:8:"products";}', NULL, 1, 'Y', 'N');

-- --------------------------------------------------------

--
-- Table structure for table `[[dbprefix]]zapier_hooks`
--

CREATE TABLE `[[dbprefix]]zapier_hooks` (
  `hook_id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT,
  `hook_url` varchar(255) DEFAULT '',
  `trigger_name` varchar(255) DEFAULT '',
  PRIMARY KEY (`hook_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
